(function(videojs, Hls) {

    // nothing to do if loaded without videojs/hlsjs
    if (!videojs || !Hls) {
        console.error('Missing videojs/Hls libraries');
        return;
    }

    /**
     *
     * @param source
     * @param tech
     * @constructor
     */
    function Html5HlsJS(source, tech) {
        var options = tech.options_;
        var el = tech.el();
        var duration = null;
        var hls = new Hls(options.hlsjsConfig);

        /**
         * creates an error handler function
         * @returns {Function}
         */
        function errorHandlerFactory() {
            var _recoverDecodingErrorDate = null;
            var _recoverAudioCodecErrorDate = null;

            return function() {
                var now = Date.now();

                if (!_recoverDecodingErrorDate || (now - _recoverDecodingErrorDate) > 2000) {
                    _recoverDecodingErrorDate = now;
                    hls.recoverMediaError();
                } else if (!_recoverAudioCodecErrorDate || (now - _recoverAudioCodecErrorDate) > 2000) {
                    _recoverAudioCodecErrorDate = now;
                    hls.swapAudioCodec();
                    hls.recoverMediaError();
                } else {
                    console.error('Error loading media: File could not be played');
                }
            }
        }

        // create separate error handlers for hlsjs and the video tag
        var hlsjsErrorHandler = errorHandlerFactory();
        var videoTagErrorHandler = errorHandlerFactory();

        // listen to error events coming from the video tag
        el.addEventListener('error', function(e) {
            var mediaError = e.currentTarget.error;

            if (mediaError.code === mediaError.MEDIA_ERR_DECODE) {
                videoTagErrorHandler();
            } else {
                console.error('Error loading media: File could not be played');
            }
        });

        /**
         *
         */
        this.dispose = function() {
            hls.destroy();
        };

        /**
         * returns the duration of the stream, or Infinity if live video
         * @returns {Infinity|number}
         */
        this.duration = function() {
            return duration || el.duration || 0;
        };

        // update live status on level load
        hls.on(Hls.Events.LEVEL_LOADED, function(event, data) {
            duration = data.details.live ? Infinity : data.details.totalduration;
        });

        // try to recover on fatal errors
        hls.on(Hls.Events.ERROR, function(event, data) {
            if (data.fatal) {
                switch (data.type) {
                    case Hls.ErrorTypes.NETWORK_ERROR:
                        hls.startLoad();
                        break;
                    case Hls.ErrorTypes.MEDIA_ERROR:
                        hlsjsErrorHandler();
                        break;
                    default:
                        console.error('Error loading media: File could not be played');
                        break;
                }
            }
        });

        // attach hlsjs to videotag
        hls.attachMedia(el);
        hls.loadSource(source.src);
    }

    var HlsSourceHandler = {
        canHandleSource: function(source) {
            var hlsTypeRE = /^application\/x-mpegURL$/i;
            var hlsExtRE = /\.m3u8/i;

            if (hlsTypeRE.test(source.type)) {
                return 'probably';
            } else if (hlsExtRE.test(source.src)) {
                return 'maybe';
            } else {
                return '';
            }
        },
        handleSource: function(source, tech) {
            return new Html5HlsJS(source, tech);
        },
        canPlayType: function(type) {
            var hlsTypeRE = /^application\/x-mpegURL$/i;
            if (hlsTypeRE.test(type)) {
                return 'probably';
            }

            return '';
        }
    };

    // only attach this source handler is its supported
    if (Hls.isSupported()) {
        videojs.getComponent('Html5').registerSourceHandler(HlsSourceHandler, 0);
    }
})(window.videojs, window.Hls);
/**
 * videojs-contrib-media-sources
 * @version 3.1.2
 * @copyright 2016 Brightcove, Inc.
 * @license Apache-2.0
 */
!function(t){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=t();else if("function"==typeof define&&define.amd)define([],t);else{var e;e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this,e.videojsContribMediaSources=t()}}(function(){return function t(e,i,a){function n(s,o){if(!i[s]){if(!e[s]){var d="function"==typeof require&&require;if(!o&&d)return d(s,!0);if(r)return r(s,!0);var u=new Error("Cannot find module '"+s+"'");throw u.code="MODULE_NOT_FOUND",u}var h=i[s]={exports:{}};e[s][0].call(h.exports,function(t){var i=e[s][1][t];return n(i?i:t)},h,h.exports,t,e,i,a)}return i[s].exports}for(var r="function"==typeof require&&require,s=0;s<a.length;s++)n(a[s]);return n}({1:[function(t,e,i){(function(t){"use strict";function a(t){return t&&t.__esModule?t:{"default":t}}Object.defineProperty(i,"__esModule",{value:!0});var n="undefined"!=typeof window?window.videojs:"undefined"!=typeof t?t.videojs:null,r=a(n),s=function(t){Object.defineProperties(t.frame,{id:{get:function(){return r["default"].log.warn("cue.frame.id is deprecated. Use cue.value.key instead."),t.value.key}},value:{get:function(){return r["default"].log.warn("cue.frame.value is deprecated. Use cue.value.data instead."),t.value.data}},privateData:{get:function(){return r["default"].log.warn("cue.frame.privateData is deprecated. Use cue.value.data instead."),t.value.data}}})},o=function(t,e,i){var a=window.WebKitDataCue||window.VTTCue;e&&e.forEach(function(t){this.inbandTextTrack_.addCue(new a(t.startTime+this.timestampOffset,t.endTime+this.timestampOffset,t.text))},t),i&&i.forEach(function(t){var e=t.cueTime+this.timestampOffset;t.frames.forEach(function(t){var i=new a(e,e,t.value||t.url||t.data||"");i.frame=t,i.value=t,s(i),this.metadataTrack_.addCue(i)},this)},t)};i["default"]=o,e.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{}],2:[function(t,e,i){"use strict";Object.defineProperty(i,"__esModule",{value:!0});var a=function(t){return/mp4a\.\d+.\d+/i.test(t)},n=function(t){return/avc1\.[\da-f]+/i.test(t)},r=function(t){var e={type:"",parameters:{}},i=t.trim().split(";");return e.type=i.shift().trim(),i.forEach(function(t){var i=t.trim().split("=");if(i.length>1){var a=i[0].replace(/"/g,"").trim(),n=i[1].replace(/"/g,"").trim();e.parameters[a]=n}}),e};i["default"]={isAudioCodec:a,parseContentType:r,isVideoCodec:n},e.exports=i["default"]},{}],3:[function(t,e,i){"use strict";Object.defineProperty(i,"__esModule",{value:!0});var a=function(t,e,i){i.captions&&i.captions.length&&!t.inbandTextTrack_&&(t.inbandTextTrack_=e.player_.addTextTrack("captions","cc1")),i.metadata&&i.metadata.length&&!t.metadataTrack_&&(t.metadataTrack_=e.player_.addTextTrack("metadata","Timed Metadata"),t.metadataTrack_.inBandMetadataTrackDispatchType=i.metadata.dispatchType)};i["default"]=a,e.exports=i["default"]},{}],4:[function(t,e,i){"use strict";Object.defineProperty(i,"__esModule",{value:!0});var a={TIME_BETWEEN_TICKS:Math.floor(1e3/480),TIME_PER_TICK:Math.floor(1e3/240),BYTES_PER_CHUNK:1024,MIN_CHUNK:1024,MAX_CHUNK:1048576};i["default"]=a,e.exports=i["default"]},{}],5:[function(t,e,i){(function(a){"use strict";function n(t){return t&&t.__esModule?t:{"default":t}}function r(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(i,"__esModule",{value:!0});var o=function(){function t(t,e){for(var i=0;i<e.length;i++){var a=e[i];a.enumerable=a.enumerable||!1,a.configurable=!0,"value"in a&&(a.writable=!0),Object.defineProperty(t,a.key,a)}}return function(e,i,a){return i&&t(e.prototype,i),a&&t(e,a),e}}(),d=function(t,e,i){for(var a=!0;a;){var n=t,r=e,s=i;a=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,r);if(void 0!==o){if("value"in o)return o.value;var d=o.get;if(void 0===d)return;return d.call(s)}var u=Object.getPrototypeOf(n);if(null===u)return;t=u,e=r,i=s,a=!0,o=u=void 0}},u="undefined"!=typeof window?window.videojs:"undefined"!=typeof a?a.videojs:null,h=n(u),f=t("./flash-source-buffer"),c=n(f),p=t("./flash-constants"),l=n(p),m=t("./codec-utils"),g=function(t){function e(){var t=this;r(this,e),d(Object.getPrototypeOf(e.prototype),"constructor",this).call(this),this.sourceBuffers=[],this.readyState="closed",this.on(["sourceopen","webkitsourceopen"],function(e){t.swfObj=document.getElementById(e.swfId),t.player_=(0,h["default"])(t.swfObj.parentNode),t.tech_=t.swfObj.tech,t.readyState="open",t.tech_.on("seeking",function(){for(var e=t.sourceBuffers.length;e--;)t.sourceBuffers[e].abort()}),t.swfObj&&t.swfObj.vjs_load()})}return s(e,t),o(e,[{key:"addSeekableRange_",value:function(){}},{key:"addSourceBuffer",value:function(t){var e=(0,m.parseContentType)(t),i=void 0;if("video/mp2t"!==e.type)throw new Error("NotSupportedError (Video.js)");return i=new c["default"](this),this.sourceBuffers.push(i),i}},{key:"endOfStream",value:function(t){"network"===t?this.tech_.error(2):"decode"===t&&this.tech_.error(3),"ended"!==this.readyState&&(this.readyState="ended",this.swfObj.vjs_endOfStream())}}]),e}(h["default"].EventTarget);i["default"]=g;try{Object.defineProperty(g.prototype,"duration",{get:function(){return this.swfObj?this.swfObj.vjs_getProperty("duration"):NaN},set:function(t){var e=void 0,i=this.swfObj.vjs_getProperty("duration");if(this.swfObj.vjs_setProperty("duration",t),i>t)for(e=0;e<this.sourceBuffers.length;e++)this.sourceBuffers[e].remove(t,i);return t}})}catch(y){g.prototype.duration=NaN}for(var b in l["default"])g[b]=l["default"][b];e.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./codec-utils":2,"./flash-constants":4,"./flash-source-buffer":6}],6:[function(t,e,i){(function(a){"use strict";function n(t){return t&&t.__esModule?t:{"default":t}}function r(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(i,"__esModule",{value:!0});var o=function(){function t(t,e){for(var i=0;i<e.length;i++){var a=e[i];a.enumerable=a.enumerable||!1,a.configurable=!0,"value"in a&&(a.writable=!0),Object.defineProperty(t,a.key,a)}}return function(e,i,a){return i&&t(e.prototype,i),a&&t(e,a),e}}(),d=function(t,e,i){for(var a=!0;a;){var n=t,r=e,s=i;a=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,r);if(void 0!==o){if("value"in o)return o.value;var d=o.get;if(void 0===d)return;return d.call(s)}var u=Object.getPrototypeOf(n);if(null===u)return;t=u,e=r,i=s,a=!0,o=u=void 0}},u="undefined"!=typeof window?window.videojs:"undefined"!=typeof a?a.videojs:null,h=n(u),f=t("mux.js/lib/flv"),c=n(f),p=t("./remove-cues-from-track"),l=n(p),m=t("./create-text-tracks-if-necessary"),g=n(m),y=t("./add-text-track-data"),b=n(y),v=t("./flash-constants"),_=n(v),w=function(t){window.setTimeout(t,_["default"].TIME_BETWEEN_TICKS)},S=function(t,e){("number"!=typeof e||0>e)&&(e=0);var i=Math.pow(10,e);return Math.round(t*i)/i},T=function(t){function e(t){var i=this;r(this,e),d(Object.getPrototypeOf(e.prototype),"constructor",this).call(this);var a=void 0;this.chunkSize_=_["default"].BYTES_PER_CHUNK,this.buffer_=[],this.bufferSize_=0,this.basePtsOffset_=NaN,this.mediaSource=t,this.updating=!1,this.timestampOffset_=0,this.segmentParser_=new c["default"].Transmuxer,this.segmentParser_.on("data",this.receiveBuffer_.bind(this)),a=window.btoa(String.fromCharCode.apply(null,Array.prototype.slice.call(this.segmentParser_.getFlvHeader()))),this.mediaSource.swfObj.vjs_appendBuffer(a),Object.defineProperty(this,"timestampOffset",{get:function(){return this.timestampOffset_},set:function(t){"number"==typeof t&&t>=0&&(this.timestampOffset_=t,this.segmentParser_=new c["default"].Transmuxer,this.segmentParser_.on("data",this.receiveBuffer_.bind(this)),this.mediaSource.swfObj.vjs_discontinuity(),this.basePtsOffset_=NaN)}}),Object.defineProperty(this,"buffered",{get:function(){if(!(this.mediaSource&&this.mediaSource.swfObj&&"vjs_getProperty"in this.mediaSource.swfObj))return h["default"].createTimeRange();var t=this.mediaSource.swfObj.vjs_getProperty("buffered");return t&&t.length&&(t[0][0]=S(t[0][0],3),t[0][1]=S(t[0][1],3)),h["default"].createTimeRanges(t)}}),this.mediaSource.player_.on("seeked",function(){(0,l["default"])(0,1/0,i.metadataTrack_),(0,l["default"])(0,1/0,i.inbandTextTrack_)})}return s(e,t),o(e,[{key:"appendBuffer",value:function(t){var e=this,i=void 0,a=524288,n=0;if(this.updating)throw i=new Error("SourceBuffer.append() cannot be called while an update is in progress"),i.name="InvalidStateError",i.code=11,i;this.updating=!0,this.mediaSource.readyState="open",this.trigger({type:"update"});var r=function s(){e.segmentParser_.push(t.subarray(n,n+a)),n+=a,w(n<t.byteLength?s:e.segmentParser_.flush.bind(e.segmentParser_))};r()}},{key:"abort",value:function(){this.buffer_=[],this.bufferSize_=0,this.mediaSource.swfObj.vjs_abort(),this.updating&&(this.updating=!1,this.trigger({type:"updateend"}))}},{key:"remove",value:function(t,e){(0,l["default"])(t,e,this.metadataTrack_),(0,l["default"])(t,e,this.inbandTextTrack_),this.trigger({type:"update"}),this.trigger({type:"updateend"})}},{key:"receiveBuffer_",value:function(t){var e=this;(0,g["default"])(this,this.mediaSource,t),(0,b["default"])(this,t.captions,t.metadata),w(function(){var i=e.convertTagsToData_(t);0===e.buffer_.length&&w(e.processBuffer_.bind(e)),i&&(e.buffer_.push(i),e.bufferSize_+=i.byteLength)})}},{key:"processBuffer_",value:function(){var t=void 0,e=void 0,i=void 0,a=void 0,n=void 0,r=0,s=0,o=+new Date,d=void 0;if(!this.buffer_.length)return void(this.updating!==!1&&(this.updating=!1,this.trigger({type:"updateend"})));do{for(s++,t=this.buffer_[0].subarray(r,r+this.chunkSize_),t.byteLength<this.chunkSize_||this.buffer_[0].byteLength===r+this.chunkSize_?(r=0,this.buffer_.shift()):r+=this.chunkSize_,this.bufferSize_-=t.byteLength,a="",i=t.byteLength,e=0;i>e;e++)a+=String.fromCharCode(t[e]);n=window.btoa(a),this.mediaSource.swfObj.CallFunction('<invoke name="vjs_appendBuffer"returntype="javascript"><arguments><string>'+n+"</string></arguments></invoke>"),d=new Date-o}while(this.buffer_.length&&d<_["default"].TIME_PER_TICK);this.buffer_.length&&r&&(this.buffer_[0]=this.buffer_[0].subarray(r)),d>=_["default"].TIME_PER_TICK&&(this.chunkSize_=Math.floor(this.chunkSize_*(s/4))),this.chunkSize_=Math.max(_["default"].MIN_CHUNK,Math.min(this.chunkSize_,_["default"].MAX_CHUNK)),0!==this.bufferSize_?w(this.processBuffer_.bind(this)):(this.updating=!1,this.trigger({type:"updateend"}))}},{key:"convertTagsToData_",value:function(t){var e=0,i=this.mediaSource.tech_,a=0,n=void 0,r=void 0,s=void 0,o=[],d=this.getOrderedTags_(t);for(isNaN(this.basePtsOffset_)&&d.length&&(this.basePtsOffset_=d[0].pts),i.buffered().length&&(a=i.buffered().end(0)-this.timestampOffset),a=Math.max(a,i.currentTime()-this.timestampOffset),a*=1e3,a+=this.basePtsOffset_,n=0;n<d.length;n++)d[n].pts>=a&&o.push(d[n]);if(0!==o.length){for(n=0;n<o.length;n++)e+=o[n].bytes.byteLength;for(s=new Uint8Array(e),n=0,r=0;n<o.length;n++)s.set(o[n].bytes,r),r+=o[n].bytes.byteLength;return s}}},{key:"getOrderedTags_",value:function(t){for(var e=t.tags.videoTags,i=t.tags.audioTags,a=void 0,n=[];e.length||i.length;)a=e.length?i.length&&i[0].dts<e[0].dts?i.shift():e.shift():i.shift(),n.push(a.finalize());return n}}]),e}(h["default"].EventTarget);i["default"]=T,e.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./add-text-track-data":1,"./create-text-tracks-if-necessary":3,"./flash-constants":4,"./remove-cues-from-track":8,"mux.js/lib/flv":15}],7:[function(t,e,i){(function(a){"use strict";function n(t){return t&&t.__esModule?t:{"default":t}}function r(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(i,"__esModule",{value:!0});var o=function(){function t(t,e){for(var i=0;i<e.length;i++){var a=e[i];a.enumerable=a.enumerable||!1,a.configurable=!0,"value"in a&&(a.writable=!0),Object.defineProperty(t,a.key,a)}}return function(e,i,a){return i&&t(e.prototype,i),a&&t(e,a),e}}(),d=function(t,e,i){for(var a=!0;a;){var n=t,r=e,s=i;a=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,r);if(void 0!==o){if("value"in o)return o.value;var d=o.get;if(void 0===d)return;return d.call(s)}var u=Object.getPrototypeOf(n);if(null===u)return;t=u,e=r,i=s,a=!0,o=u=void 0}},u="undefined"!=typeof window?window.videojs:"undefined"!=typeof a?a.videojs:null,h=n(u),f=t("./virtual-source-buffer"),c=n(f),p=t("./codec-utils"),l=function(t){return t.map(function(t){return t.replace(/avc1\.(\d+)\.(\d+)/i,function(t,e,i){var a=("00"+Number(e).toString(16)).slice(-2),n=("00"+Number(i).toString(16)).slice(-2);return"avc1."+a+"00"+n})})},m=function(t){function e(){var t=this;r(this,e),d(Object.getPrototypeOf(e.prototype),"constructor",this).call(this);var i=void 0;this.nativeMediaSource_=new window.MediaSource;for(i in this.nativeMediaSource_)i in e.prototype||"function"!=typeof this.nativeMediaSource_[i]||(this[i]=this.nativeMediaSource_[i].bind(this.nativeMediaSource_));this.duration_=NaN,Object.defineProperty(this,"duration",{get:function(){return this.duration_===1/0?this.duration_:this.nativeMediaSource_.duration},set:function(t){return this.duration_=t,t!==1/0?void(this.nativeMediaSource_.duration=t):void 0}}),Object.defineProperty(this,"seekable",{get:function(){return this.duration_===1/0?h["default"].createTimeRanges([[0,this.nativeMediaSource_.duration]]):this.nativeMediaSource_.seekable}}),Object.defineProperty(this,"readyState",{get:function(){return this.nativeMediaSource_.readyState}}),Object.defineProperty(this,"activeSourceBuffers",{get:function(){return this.activeSourceBuffers_}}),this.sourceBuffers=[],this.activeSourceBuffers_=[],this.updateActiveSourceBuffers_=function(){t.activeSourceBuffers_.length=0;for(var e=!1,i=!0,a=0;a<t.player_.audioTracks().length;a++){var n=t.player_.audioTracks()[a];if(n.enabled&&"main"!==n.kind){e=!0,i=!1;break}}t.sourceBuffers.forEach(function(a){if(a.videoCodec_&&a.audioCodec_)a.audioDisabled_=e;else if(a.videoCodec_&&!a.audioCodec_)a.audioDisabled_=!0,i=!1;else if(!a.videoCodec_&&a.audioCodec_&&(a.audioDisabled_=i,i))return;t.activeSourceBuffers_.push(a)})},["sourceopen","sourceclose","sourceended"].forEach(function(t){this.nativeMediaSource_.addEventListener(t,this.trigger.bind(this))},this),this.on("sourceopen",function(e){var i=document.querySelector('[src="'+t.url_+'"]');i&&(t.player_=(0,h["default"])(i.parentNode),t.player_.audioTracks&&t.player_.audioTracks()&&(t.player_.audioTracks().on("change",t.updateActiveSourceBuffers_),t.player_.audioTracks().on("addtrack",t.updateActiveSourceBuffers_),t.player_.audioTracks().on("removetrack",t.updateActiveSourceBuffers_)))}),this.on("sourceclose",function(t){this.sourceBuffers.forEach(function(t){t.transmuxer_&&t.transmuxer_.terminate()}),this.sourceBuffers.length=0,this.player_&&this.player_.audioTracks&&this.player_.audioTracks()&&(this.player_.audioTracks().off("change",this.updateActiveSourceBuffers_),this.player_.audioTracks().off("addtrack",this.updateActiveSourceBuffers_),this.player_.audioTracks().off("removetrack",this.updateActiveSourceBuffers_))})}return s(e,t),o(e,[{key:"addSeekableRange_",value:function(t,e){var i=void 0;if(this.duration!==1/0)throw i=new Error("MediaSource.addSeekableRange() can only be invoked when the duration is Infinity"),i.name="InvalidStateError",i.code=11,i;(e>this.nativeMediaSource_.duration||isNaN(this.nativeMediaSource_.duration))&&(this.nativeMediaSource_.duration=e)}},{key:"addSourceBuffer",value:function(t){var e=void 0,i=(0,p.parseContentType)(t);if("video/mp2t"===i.type){var a=[];i.parameters&&i.parameters.codecs&&(a=i.parameters.codecs.split(","),a=l(a),a=a.filter(function(t){return(0,p.isAudioCodec)(t)||(0,p.isVideoCodec)(t)})),0===a.length&&(a=["avc1.4d400d","mp4a.40.2"]),e=new c["default"](this,a),0!==this.sourceBuffers.length&&(this.sourceBuffers[0].createRealSourceBuffers_(),e.createRealSourceBuffers_(),this.sourceBuffers[0].audioDisabled_=!0)}else e=this.nativeMediaSource_.addSourceBuffer(t);return this.sourceBuffers.push(e),e}}]),e}(h["default"].EventTarget);i["default"]=m,e.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./codec-utils":2,"./virtual-source-buffer":10}],8:[function(t,e,i){"use strict";Object.defineProperty(i,"__esModule",{value:!0});var a=function(t,e,i){var a=void 0,n=void 0;if(i)for(a=i.cues.length;a--;)n=i.cues[a],n.startTime<=e&&n.endTime>=t&&i.removeCue(n)};i["default"]=a,e.exports=i["default"]},{}],9:[function(t,e,i){"use strict";function a(t){return t&&t.__esModule?t:{"default":t}}function n(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(i,"__esModule",{value:!0});var r=function(){function t(t,e){for(var i=0;i<e.length;i++){var a=e[i];a.enumerable=a.enumerable||!1,a.configurable=!0,"value"in a&&(a.writable=!0),Object.defineProperty(t,a.key,a)}}return function(e,i,a){return i&&t(e.prototype,i),a&&t(e,a),e}}(),s=t("mux.js/lib/mp4"),o=a(s),d=function(t){t.on("data",function(t){var e=t.data;t.data=e.buffer,postMessage({action:"data",segment:t,byteOffset:e.byteOffset,byteLength:e.byteLength},[t.data])}),t.captionStream&&t.captionStream.on("data",function(t){postMessage({action:"caption",data:t})}),t.on("done",function(t){postMessage({action:"done"})})},u=function(){function t(e){n(this,t),this.options=e||{},this.init()}return r(t,[{key:"init",value:function(){this.transmuxer&&this.transmuxer.dispose(),this.transmuxer=new o["default"].Transmuxer(this.options),d(this.transmuxer)}},{key:"push",value:function(t){var e=new Uint8Array(t.data,t.byteOffset,t.byteLength);this.transmuxer.push(e)}},{key:"reset",value:function(){this.init()}},{key:"setTimestampOffset",value:function(t){var e=t.timestampOffset||0;this.transmuxer.setBaseMediaDecodeTime(Math.round(9e4*e))}},{key:"flush",value:function(t){this.transmuxer.flush()}}]),t}(),h=function(t){t.onmessage=function(t){return"init"===t.data.action&&t.data.options?void(this.messageHandlers=new u(t.data.options)):(this.messageHandlers||(this.messageHandlers=new u),void(t.data&&t.data.action&&"init"!==t.data.action&&this.messageHandlers[t.data.action]&&this.messageHandlers[t.data.action](t.data)))}};i["default"]=function(t){return new h(t)},e.exports=i["default"]},{"mux.js/lib/mp4":21}],10:[function(t,e,i){(function(a){"use strict";function n(t){return t&&t.__esModule?t:{"default":t}}function r(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(i,"__esModule",{value:!0});var o=function(){function t(t,e){for(var i=0;i<e.length;i++){var a=e[i];a.enumerable=a.enumerable||!1,a.configurable=!0,"value"in a&&(a.writable=!0),Object.defineProperty(t,a.key,a)}}return function(e,i,a){return i&&t(e.prototype,i),a&&t(e,a),e}}(),d=function(t,e,i){for(var a=!0;a;){var n=t,r=e,s=i;a=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,r);if(void 0!==o){if("value"in o)return o.value;var d=o.get;if(void 0===d)return;return d.call(s)}var u=Object.getPrototypeOf(n);if(null===u)return;t=u,e=r,i=s,a=!0,o=u=void 0}},u="undefined"!=typeof window?window.videojs:"undefined"!=typeof a?a.videojs:null,h=n(u),f=t("./create-text-tracks-if-necessary"),c=n(f),p=t("./remove-cues-from-track"),l=n(p),m=t("./add-text-track-data"),g=n(m),y=t("webworkify"),b=n(y),v=t("./transmuxer-worker"),_=n(v),w=t("./codec-utils"),S=function(t){function e(t,i){var a=this;r(this,e),d(Object.getPrototypeOf(e.prototype),"constructor",this).call(this,h["default"].EventTarget),this.timestampOffset_=0,this.pendingBuffers_=[],this.bufferUpdating_=!1,this.mediaSource_=t,this.codecs_=i,this.audioCodec_=null,this.videoCodec_=null,this.audioDisabled_=!1;var n={remux:!1};this.codecs_.forEach(function(t){(0,w.isAudioCodec)(t)?a.audioCodec_=t:(0,w.isVideoCodec)(t)&&(a.videoCodec_=t)}),this.transmuxer_=(0,b["default"])(_["default"]),this.transmuxer_.postMessage({action:"init",options:n}),this.transmuxer_.onmessage=function(t){return"data"===t.data.action?a.data_(t):"done"===t.data.action?a.done_(t):void 0},Object.defineProperty(this,"timestampOffset",{get:function(){return this.timestampOffset_},set:function(t){"number"==typeof t&&t>=0&&(this.timestampOffset_=t,this.transmuxer_.postMessage({action:"setTimestampOffset",timestampOffset:t}))}}),Object.defineProperty(this,"appendWindowStart",{get:function(){return(this.videoBuffer_||this.audioBuffer_).appendWindowStart},set:function(t){this.videoBuffer_&&(this.videoBuffer_.appendWindowStart=t),this.audioBuffer_&&(this.audioBuffer_.appendWindowStart=t)}}),Object.defineProperty(this,"updating",{get:function(){return!!(this.bufferUpdating_||!this.audioDisabled_&&this.audioBuffer_&&this.audioBuffer_.updating||this.videoBuffer_&&this.videoBuffer_.updating)}}),Object.defineProperty(this,"buffered",{get:function(){var t=null,e=null,i=0,a=[],n=[];if(!this.videoBuffer_&&(this.audioDisabled_||!this.audioBuffer_))return h["default"].createTimeRange();if(!this.videoBuffer_)return this.audioBuffer_.buffered;if(this.audioDisabled_||!this.audioBuffer_)return this.videoBuffer_.buffered;if(!(this.videoBuffer_&&0!==this.videoBuffer_.buffered.length||this.audioBuffer_&&0!==this.audioBuffer_.buffered.length))return h["default"].createTimeRange();for(var r=this.videoBuffer_.buffered,s=this.audioBuffer_.buffered,o=r.length;o--;)a.push({time:r.start(o),type:"start"}),a.push({time:r.end(o),type:"end"});for(o=s.length;o--;)a.push({time:s.start(o),type:"start"}),a.push({time:s.end(o),type:"end"});for(a.sort(function(t,e){return t.time-e.time}),o=0;o<a.length;o++)"start"===a[o].type?(i++,2===i&&(t=a[o].time)):"end"===a[o].type&&(i--,1===i&&(e=a[o].time)),null!==t&&null!==e&&(n.push([t,e]),t=null,e=null);return h["default"].createTimeRanges(n)}})}return s(e,t),o(e,[{key:"data_",value:function(t){var e=t.data.segment;e.data=new Uint8Array(e.data,t.data.byteOffset,t.data.byteLength),(0,c["default"])(this,this.mediaSource_,e),this.pendingBuffers_.push(e)}},{key:"done_",value:function(t){this.processPendingSegments_()}},{key:"createRealSourceBuffers_",value:function(){var t=this,e=["audio","video"];e.forEach(function(i){if(t[i+"Codec_"]&&!t[i+"Buffer_"]){var a=null;t.mediaSource_[i+"Buffer_"]?a=t.mediaSource_[i+"Buffer_"]:(a=t.mediaSource_.nativeMediaSource_.addSourceBuffer(i+'/mp4;codecs="'+t[i+"Codec_"]+'"'),t.mediaSource_[i+"Buffer_"]=a),t[i+"Buffer_"]=a,["update","updatestart","updateend"].forEach(function(n){a.addEventListener(n,function(){if("audio"!==i||!t.audioDisabled_){var a=e.every(function(e){return"audio"===e&&t.audioDisabled_?!0:i===e||!t[e+"Buffer_"]||!t[e+"Buffer_"].updating});return a?t.trigger(n):void 0}})})}})}},{key:"appendBuffer",value:function(t){this.bufferUpdating_=!0,this.transmuxer_.postMessage({action:"push",data:t.buffer,byteOffset:t.byteOffset,byteLength:t.byteLength},[t.buffer]),this.transmuxer_.postMessage({action:"flush"})}},{key:"remove",value:function(t,e){this.videoBuffer_&&this.videoBuffer_.remove(t,e),!this.audioDisabled_&&this.audioBuffer_&&this.audioBuffer_.remove(t,e),(0,l["default"])(t,e,this.metadataTrack_),(0,l["default"])(t,e,this.inbandTextTrack_)}},{key:"processPendingSegments_",value:function(){var t={video:{segments:[],bytes:0},audio:{segments:[],bytes:0},captions:[],metadata:[]};t=this.pendingBuffers_.reduce(function(t,e){var i=e.type,a=e.data;return t[i].segments.push(a),t[i].bytes+=a.byteLength,e.captions&&(t.captions=t.captions.concat(e.captions)),e.info&&(t[i].info=e.info),e.metadata&&(t.metadata=t.metadata.concat(e.metadata)),t},t),this.videoBuffer_||this.audioBuffer_||(0===t.video.bytes&&(this.videoCodec_=null),0===t.audio.bytes&&(this.audioCodec_=null),this.createRealSourceBuffers_()),t.audio.info&&this.mediaSource_.trigger({type:"audioinfo",info:t.audio.info}),t.video.info&&this.mediaSource_.trigger({type:"videoinfo",info:t.video.info}),this.videoBuffer_&&(this.concatAndAppendSegments_(t.video,this.videoBuffer_),(0,g["default"])(this,t.captions,t.metadata)),!this.audioDisabled_&&this.audioBuffer_&&this.concatAndAppendSegments_(t.audio,this.audioBuffer_),this.pendingBuffers_.length=0,this.bufferUpdating_=!1}},{key:"concatAndAppendSegments_",value:function(t,e){var i=0,a=void 0;t.bytes&&(a=new Uint8Array(t.bytes),t.segments.forEach(function(t){a.set(t,i),i+=t.byteLength}),e.appendBuffer(a))}},{key:"abort",value:function(){this.videoBuffer_&&this.videoBuffer_.abort(),this.audioBuffer_&&this.audioBuffer_.abort(),this.transmuxer_&&this.transmuxer_.postMessage({action:"reset"}),this.pendingBuffers_.length=0,this.bufferUpdating_=!1}}]),e}(h["default"].EventTarget);i["default"]=S,e.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./add-text-track-data":1,"./codec-utils":2,"./create-text-tracks-if-necessary":3,"./remove-cues-from-track":8,"./transmuxer-worker":9,webworkify:26}],11:[function(t,e,i){"use strict";var a,n=t("../utils/stream.js");a=function(){var t=new Uint8Array,e=0;a.prototype.init.call(this),this.setTimestamp=function(t){e=t},this.parseId3TagSize=function(t,e){var i=t[e+6]<<21|t[e+7]<<14|t[e+8]<<7|t[e+9],a=t[e+5],n=(16&a)>>4;return n?i+20:i+10},this.parseAdtsSize=function(t,e){var i=(224&t[e+5])>>5,a=t[e+4]<<3,n=6144&t[e+3];return n|a|i},this.push=function(i){var a,n,r,s,o=0,d=0;for(t.length?(s=t.length,t=new Uint8Array(i.byteLength+s),t.set(t.subarray(0,s)),t.set(i,s)):t=i;t.length-d>=3;)if(t[d]!=="I".charCodeAt(0)||t[d+1]!=="D".charCodeAt(0)||t[d+2]!=="3".charCodeAt(0))if(t[d]&!0&&240===(240&t[d+1])){if(t.length-d<7)break;if(o=this.parseAdtsSize(t,d),o>t.length)break;r={type:"audio",data:t.subarray(d,d+o),pts:e,dts:e},this.trigger("data",r),d+=o}else d++;else{if(t.length-d<10)break;if(o=this.parseId3TagSize(t,d),o>t.length)break;n={type:"timed-metadata",data:t.subarray(d,d+o)},this.trigger("data",n),d+=o}a=t.length-d,t=a>0?t.subarray(d):new Uint8Array}},a.prototype=new n,e.exports=a},{"../utils/stream.js":25}],12:[function(t,e,i){"use strict";var a,n=t("../utils/stream.js"),r=[96e3,88200,64e3,48e3,44100,32e3,24e3,22050,16e3,12e3,11025,8e3,7350];a=function(){var t,e;a.prototype.init.call(this),t=this,this.push=function(t){var i,a,n,s,o,d,u=0,h=0;if("audio"===t.type)for(e?(s=e,e=new Uint8Array(s.byteLength+t.data.byteLength),e.set(s),e.set(t.data,s.byteLength)):e=t.data;u+5<e.length;)if(255===e[u]&&240===(246&e[u+1])){if(a=2*(1&~e[u+1]),i=(3&e[u+3])<<11|e[u+4]<<3|(224&e[u+5])>>5,o=1024*((3&e[u+6])+1),d=9e4*o/r[(60&e[u+2])>>>2],n=u+i,e.byteLength<n)return;if(this.trigger("data",{pts:t.pts+h*d,dts:t.dts+h*d,sampleCount:o,audioobjecttype:(e[u+2]>>>6&3)+1,channelcount:(1&e[u+2])<<2|(192&e[u+3])>>>6,samplerate:r[(60&e[u+2])>>>2],samplingfrequencyindex:(60&e[u+2])>>>2,samplesize:16,data:e.subarray(u+7+a,n)}),e.byteLength===n)return void(e=void 0);h++,e=e.subarray(n)}else u++},this.flush=function(){this.trigger("done")}},a.prototype=new n,e.exports=a},{"../utils/stream.js":25}],13:[function(t,e,i){"use strict";var a,n,r=t("../utils/stream.js"),s=t("../utils/exp-golomb.js");n=function(){var t,e,i=0;n.prototype.init.call(this),this.push=function(a){var n;for(e?(n=new Uint8Array(e.byteLength+a.data.byteLength),n.set(e),n.set(a.data,e.byteLength),e=n):e=a.data;i<e.byteLength-3;i++)if(1===e[i+2]){t=i+5;break}for(;t<e.byteLength;)switch(e[t]){case 0:if(0!==e[t-1]){t+=2;break}if(0!==e[t-2]){t++;break}i+3!==t-2&&this.trigger("data",e.subarray(i+3,t-2));do t++;while(1!==e[t]&&t<e.length);i=t-2,t+=3;break;case 1:if(0!==e[t-1]||0!==e[t-2]){t+=3;break}this.trigger("data",e.subarray(i+3,t-2)),i=t-2,t+=3;break;default:t+=3}e=e.subarray(i),t-=i,i=0},this.flush=function(){e&&e.byteLength>3&&this.trigger("data",e.subarray(i+3)),e=null,i=0,this.trigger("done")}},n.prototype=new r,a=function(){var t,e,i,r,o,d,u,h=new n;a.prototype.init.call(this),t=this,this.push=function(t){"video"===t.type&&(e=t.trackId,i=t.pts,r=t.dts,h.push(t))},h.on("data",function(a){var n={trackId:e,pts:i,dts:r,data:a};switch(31&a[0]){case 5:n.nalUnitType="slice_layer_without_partitioning_rbsp_idr";break;case 6:n.nalUnitType="sei_rbsp",n.escapedRBSP=o(a.subarray(1));break;case 7:n.nalUnitType="seq_parameter_set_rbsp",n.escapedRBSP=o(a.subarray(1)),n.config=d(n.escapedRBSP);break;case 8:n.nalUnitType="pic_parameter_set_rbsp";break;case 9:n.nalUnitType="access_unit_delimiter_rbsp"}t.trigger("data",n)}),h.on("done",function(){t.trigger("done")}),this.flush=function(){h.flush()},u=function(t,e){var i,a,n=8,r=8;for(i=0;t>i;i++)0!==r&&(a=e.readExpGolomb(),r=(n+a+256)%256),n=0===r?n:r},o=function(t){for(var e,i,a=t.byteLength,n=[],r=1;a-2>r;)0===t[r]&&0===t[r+1]&&3===t[r+2]?(n.push(r+2),r+=2):r++;if(0===n.length)return t;e=a-n.length,i=new Uint8Array(e);var s=0;for(r=0;e>r;s++,r++)s===n[0]&&(s++,n.shift()),i[r]=t[s];return i},d=function(t){var e,i,a,n,r,o,d,h,f,c,p,l,m,g,y=0,b=0,v=0,_=0,w=1;if(e=new s(t),i=e.readUnsignedByte(),n=e.readUnsignedByte(),a=e.readUnsignedByte(),e.skipUnsignedExpGolomb(),(100===i||110===i||122===i||244===i||44===i||83===i||86===i||118===i||128===i||138===i||139===i||134===i)&&(r=e.readUnsignedExpGolomb(),3===r&&e.skipBits(1),e.skipUnsignedExpGolomb(),e.skipUnsignedExpGolomb(),e.skipBits(1),e.readBoolean()))for(p=3!==r?8:12,g=0;p>g;g++)e.readBoolean()&&(6>g?u(16,e):u(64,e));if(e.skipUnsignedExpGolomb(),o=e.readUnsignedExpGolomb(),0===o)e.readUnsignedExpGolomb();else if(1===o)for(e.skipBits(1),e.skipExpGolomb(),e.skipExpGolomb(),d=e.readUnsignedExpGolomb(),g=0;d>g;g++)e.skipExpGolomb();if(e.skipUnsignedExpGolomb(),e.skipBits(1),h=e.readUnsignedExpGolomb(),f=e.readUnsignedExpGolomb(),c=e.readBits(1),0===c&&e.skipBits(1),e.skipBits(1),e.readBoolean()&&(y=e.readUnsignedExpGolomb(),b=e.readUnsignedExpGolomb(),v=e.readUnsignedExpGolomb(),_=e.readUnsignedExpGolomb()),e.readBoolean()&&e.readBoolean()){switch(m=e.readUnsignedByte()){case 1:l=[1,1];break;case 2:l=[12,11];break;case 3:l=[10,11];break;case 4:l=[16,11];break;case 5:l=[40,33];break;case 6:l=[24,11];break;case 7:l=[20,11];break;case 8:l=[32,11];break;case 9:l=[80,33];break;case 10:l=[18,11];break;case 11:l=[15,11];break;case 12:l=[64,33];break;case 13:l=[160,99];break;case 14:l=[4,3];break;case 15:l=[3,2];break;case 16:l=[2,1];break;case 255:l=[e.readUnsignedByte()<<8|e.readUnsignedByte(),e.readUnsignedByte()<<8|e.readUnsignedByte()]}l&&(w=l[0]/l[1])}return{profileIdc:i,levelIdc:a,profileCompatibility:n,width:Math.ceil((16*(h+1)-2*y-2*b)*w),height:(2-c)*(f+1)*16-2*v-2*_}}},a.prototype=new r,e.exports={
H264Stream:a,NalByteStream:n}},{"../utils/exp-golomb.js":24,"../utils/stream.js":25}],14:[function(t,e,i){"use strict";var a;a=function(t,e){var i,n=0,r=16384,s=function(t,e){var i,a=t.position+e;a<t.bytes.byteLength||(i=new Uint8Array(2*a),i.set(t.bytes.subarray(0,t.position),0),t.bytes=i,t.view=new DataView(t.bytes.buffer))},o=a.widthBytes||new Uint8Array("width".length),d=a.heightBytes||new Uint8Array("height".length),u=a.videocodecidBytes||new Uint8Array("videocodecid".length);if(!a.widthBytes){for(i=0;i<"width".length;i++)o[i]="width".charCodeAt(i);for(i=0;i<"height".length;i++)d[i]="height".charCodeAt(i);for(i=0;i<"videocodecid".length;i++)u[i]="videocodecid".charCodeAt(i);a.widthBytes=o,a.heightBytes=d,a.videocodecidBytes=u}switch(this.keyFrame=!1,t){case a.VIDEO_TAG:this.length=16,r*=6;break;case a.AUDIO_TAG:this.length=13,this.keyFrame=!0;break;case a.METADATA_TAG:this.length=29,this.keyFrame=!0;break;default:throw"Error Unknown TagType"}this.bytes=new Uint8Array(r),this.view=new DataView(this.bytes.buffer),this.bytes[0]=t,this.position=this.length,this.keyFrame=e,this.pts=0,this.dts=0,this.writeBytes=function(t,e,i){var a,n=e||0;i=i||t.byteLength,a=n+i,s(this,i),this.bytes.set(t.subarray(n,a),this.position),this.position+=i,this.length=Math.max(this.length,this.position)},this.writeByte=function(t){s(this,1),this.bytes[this.position]=t,this.position++,this.length=Math.max(this.length,this.position)},this.writeShort=function(t){s(this,2),this.view.setUint16(this.position,t),this.position+=2,this.length=Math.max(this.length,this.position)},this.negIndex=function(t){return this.bytes[this.length-t]},this.nalUnitSize=function(){return 0===n?0:this.length-(n+4)},this.startNalUnit=function(){if(n>0)throw new Error("Attempted to create new NAL wihout closing the old one");n=this.length,this.length+=4,this.position=this.length},this.endNalUnit=function(t){var e,i;this.length===n+4?this.length-=4:n>0&&(e=n+4,i=this.length-e,this.position=n,this.view.setUint32(this.position,i),this.position=this.length,t&&t.push(this.bytes.subarray(e,e+i))),n=0},this.writeMetaDataDouble=function(t,e){var i;if(s(this,2+t.length+9),this.view.setUint16(this.position,t.length),this.position+=2,"width"===t)this.bytes.set(o,this.position),this.position+=5;else if("height"===t)this.bytes.set(d,this.position),this.position+=6;else if("videocodecid"===t)this.bytes.set(u,this.position),this.position+=12;else for(i=0;i<t.length;i++)this.bytes[this.position]=t.charCodeAt(i),this.position++;this.position++,this.view.setFloat64(this.position,e),this.position+=8,this.length=Math.max(this.length,this.position),++n},this.writeMetaDataBoolean=function(t,e){var i;for(s(this,2),this.view.setUint16(this.position,t.length),this.position+=2,i=0;i<t.length;i++)s(this,1),this.bytes[this.position]=t.charCodeAt(i),this.position++;s(this,2),this.view.setUint8(this.position,1),this.position++,this.view.setUint8(this.position,e?1:0),this.position++,this.length=Math.max(this.length,this.position),++n},this.finalize=function(){var t,i;switch(this.bytes[0]){case a.VIDEO_TAG:this.bytes[11]=7|(this.keyFrame||e?16:32),this.bytes[12]=e?0:1,t=this.pts-this.dts,this.bytes[13]=(16711680&t)>>>16,this.bytes[14]=(65280&t)>>>8,this.bytes[15]=(255&t)>>>0;break;case a.AUDIO_TAG:this.bytes[11]=175,this.bytes[12]=e?0:1;break;case a.METADATA_TAG:this.position=11,this.view.setUint8(this.position,2),this.position++,this.view.setUint16(this.position,10),this.position+=2,this.bytes.set([111,110,77,101,116,97,68,97,116,97],this.position),this.position+=10,this.bytes[this.position]=8,this.position++,this.view.setUint32(this.position,n),this.position=this.length,this.bytes.set([0,0,9],this.position),this.position+=3,this.length=this.position}return i=this.length-11,this.bytes[1]=(16711680&i)>>>16,this.bytes[2]=(65280&i)>>>8,this.bytes[3]=(255&i)>>>0,this.bytes[4]=(16711680&this.dts)>>>16,this.bytes[5]=(65280&this.dts)>>>8,this.bytes[6]=(255&this.dts)>>>0,this.bytes[7]=(4278190080&this.dts)>>>24,this.bytes[8]=0,this.bytes[9]=0,this.bytes[10]=0,s(this,4),this.view.setUint32(this.length,this.length),this.length+=4,this.position+=4,this.bytes=this.bytes.subarray(0,this.length),this.frameTime=a.frameTime(this.bytes),this}},a.AUDIO_TAG=8,a.VIDEO_TAG=9,a.METADATA_TAG=18,a.isAudioFrame=function(t){return a.AUDIO_TAG===t[0]},a.isVideoFrame=function(t){return a.VIDEO_TAG===t[0]},a.isMetaData=function(t){return a.METADATA_TAG===t[0]},a.isKeyFrame=function(t){return a.isVideoFrame(t)?23===t[11]:a.isAudioFrame(t)?!0:!!a.isMetaData(t)},a.frameTime=function(t){var e=t[4]<<16;return e|=t[5]<<8,e|=t[6]<<0,e|=t[7]<<24},e.exports=a},{}],15:[function(t,e,i){e.exports={tag:t("./flv-tag"),Transmuxer:t("./transmuxer")}},{"./flv-tag":14,"./transmuxer":16}],16:[function(t,e,i){"use strict";var a,n,r,s,o,d,u,h=t("../utils/stream.js"),f=t("./flv-tag.js"),c=t("../m2ts/m2ts.js"),p=t("../codecs/adts.js"),l=t("../codecs/h264").H264Stream;o=function(t,e){"number"==typeof e.pts&&(void 0===t.timelineStartInfo.pts?t.timelineStartInfo.pts=e.pts:t.timelineStartInfo.pts=Math.min(t.timelineStartInfo.pts,e.pts)),"number"==typeof e.dts&&(void 0===t.timelineStartInfo.dts?t.timelineStartInfo.dts=e.dts:t.timelineStartInfo.dts=Math.min(t.timelineStartInfo.dts,e.dts))},d=function(t,e){var i=new f(f.METADATA_TAG);return i.dts=e,i.pts=e,i.writeMetaDataDouble("videocodecid",7),i.writeMetaDataDouble("width",t.width),i.writeMetaDataDouble("height",t.height),i},u=function(t,e){var i,a=new f(f.VIDEO_TAG,!0);for(a.dts=e,a.pts=e,a.writeByte(1),a.writeByte(t.profileIdc),a.writeByte(t.profileCompatibility),a.writeByte(t.levelIdc),a.writeByte(255),a.writeByte(225),a.writeShort(t.sps[0].length),a.writeBytes(t.sps[0]),a.writeByte(t.pps.length),i=0;i<t.pps.length;++i)a.writeShort(t.pps[i].length),a.writeBytes(t.pps[i]);return a},r=function(t){var e,i=[];r.prototype.init.call(this),this.push=function(e){o(t,e),t&&void 0===t.channelcount&&(t.audioobjecttype=e.audioobjecttype,t.channelcount=e.channelcount,t.samplerate=e.samplerate,t.samplingfrequencyindex=e.samplingfrequencyindex,t.samplesize=e.samplesize,t.extraData=t.audioobjecttype<<11|t.samplingfrequencyindex<<7|t.channelcount<<3),e.pts=Math.round(e.pts/90),e.dts=Math.round(e.dts/90),i.push(e)},this.flush=function(){var a,n,r,s=[];if(0===i.length)return void this.trigger("done");for(r=-(1/0);i.length;)a=i.shift(),(t.extraData!==e||a.pts-r>=1e3)&&(n=new f(f.METADATA_TAG),n.pts=a.pts,n.dts=a.dts,n.writeMetaDataDouble("audiocodecid",10),n.writeMetaDataBoolean("stereo",2===t.channelcount),n.writeMetaDataDouble("audiosamplerate",t.samplerate),n.writeMetaDataDouble("audiosamplesize",16),s.push(n),e=t.extraData,n=new f(f.AUDIO_TAG,!0),n.pts=a.pts,n.dts=a.dts,n.view.setUint16(n.position,t.extraData),n.position+=2,n.length=Math.max(n.length,n.position),s.push(n),r=a.pts),n=new f(f.AUDIO_TAG),n.pts=a.pts,n.dts=a.dts,n.writeBytes(a.data),s.push(n);e=null,this.trigger("data",{track:t,tags:s}),this.trigger("done")}},r.prototype=new h,n=function(t){var e,i,a=[];n.prototype.init.call(this),this.finishFrame=function(i,a){a&&(e&&t&&t.newMetadata&&(a.keyFrame||0===i.length)&&(i.push(d(e,a.pts)),i.push(u(t,a.pts)),t.newMetadata=!1),a.endNalUnit(),i.push(a))},this.push=function(e){o(t,e),e.pts=Math.round(e.pts/90),e.dts=Math.round(e.dts/90),a.push(e)},this.flush=function(){for(var n,r=[];a.length&&"access_unit_delimiter_rbsp"!==a[0].nalUnitType;)a.shift();if(0===a.length)return void this.trigger("done");for(;a.length;)n=a.shift(),"seq_parameter_set_rbsp"===n.nalUnitType?(t.newMetadata=!0,e=n.config,t.width=e.width,t.height=e.height,t.sps=[n.data],t.profileIdc=e.profileIdc,t.levelIdc=e.levelIdc,t.profileCompatibility=e.profileCompatibility,i.endNalUnit()):"pic_parameter_set_rbsp"===n.nalUnitType?(t.newMetadata=!0,t.pps=[n.data],i.endNalUnit()):"access_unit_delimiter_rbsp"===n.nalUnitType?(i&&this.finishFrame(r,i),i=new f(f.VIDEO_TAG),i.pts=n.pts,i.dts=n.dts):("slice_layer_without_partitioning_rbsp_idr"===n.nalUnitType&&(i.keyFrame=!0),i.endNalUnit()),i.startNalUnit(),i.writeBytes(n.data);i&&this.finishFrame(r,i),this.trigger("data",{track:t,tags:r}),this.trigger("done")}},n.prototype=new h,s=function(t){this.numberOfTracks=0,this.metadataStream=t.metadataStream,this.videoTags=[],this.audioTags=[],this.videoTrack=null,this.audioTrack=null,this.pendingCaptions=[],this.pendingMetadata=[],this.pendingTracks=0,s.prototype.init.call(this),this.push=function(t){return t.text?this.pendingCaptions.push(t):t.frames?this.pendingMetadata.push(t):("video"===t.track.type&&(this.videoTrack=t.track,this.videoTags=t.tags,this.pendingTracks++),void("audio"===t.track.type&&(this.audioTrack=t.track,this.audioTags=t.tags,this.pendingTracks++)))}},s.prototype=new h,s.prototype.flush=function(){var t,e,i,a,n={tags:{},captions:[],metadata:[]};if(!(this.pendingTracks<this.numberOfTracks)){for(this.videoTrack?a=this.videoTrack.timelineStartInfo.pts:this.audioTrack&&(a=this.audioTrack.timelineStartInfo.pts),n.tags.videoTags=this.videoTags,n.tags.audioTags=this.audioTags,i=0;i<this.pendingCaptions.length;i++)e=this.pendingCaptions[i],e.startTime=e.startPts-a,e.startTime/=9e4,e.endTime=e.endPts-a,e.endTime/=9e4,n.captions.push(e);for(i=0;i<this.pendingMetadata.length;i++)t=this.pendingMetadata[i],t.cueTime=t.pts-a,t.cueTime/=9e4,n.metadata.push(t);n.metadata.dispatchType=this.metadataStream.dispatchType,this.videoTrack=null,this.audioTrack=null,this.videoTags=[],this.audioTags=[],this.pendingCaptions.length=0,this.pendingMetadata.length=0,this.pendingTracks=0,this.trigger("data",n),this.trigger("done")}},a=function(t){var e,i,o,d,u,h,m,g,y,b=this;a.prototype.init.call(this),t=t||{},this.metadataStream=new c.MetadataStream,t.metadataStream=this.metadataStream,e=new c.TransportPacketStream,i=new c.TransportParseStream,o=new c.ElementaryStream,d=new p,u=new l,y=new s(t),e.pipe(i).pipe(o),o.pipe(u),o.pipe(d),o.pipe(this.metadataStream).pipe(y),g=new c.CaptionStream,u.pipe(g).pipe(y),o.on("data",function(t){var e,i,a;if("metadata"===t.type){for(e=t.tracks.length;e--;)"video"===t.tracks[e].type?i=t.tracks[e]:"audio"===t.tracks[e].type&&(a=t.tracks[e]);i&&!h&&(y.numberOfTracks++,h=new n(i),u.pipe(h).pipe(y)),a&&!m&&(y.numberOfTracks++,m=new r(a),d.pipe(m).pipe(y))}}),this.push=function(t){e.push(t)},this.flush=function(){e.flush()},y.on("data",function(t){b.trigger("data",t)}),y.on("done",function(){b.trigger("done")}),this.getFlvHeader=function(t,e,i){var a,n,r,s=new Uint8Array(9),o=new DataView(s.buffer);return t=t||0,e=void 0===e?!0:e,i=void 0===i?!0:i,o.setUint8(0,70),o.setUint8(1,76),o.setUint8(2,86),o.setUint8(3,1),o.setUint8(4,(e?4:0)|(i?1:0)),o.setUint32(5,s.byteLength),0>=t?(n=new Uint8Array(s.byteLength+4),n.set(s),n.set([0,0,0,0],s.byteLength),n):(a=new f(f.METADATA_TAG),a.pts=a.dts=0,a.writeMetaDataDouble("duration",t),r=a.finalize().length,n=new Uint8Array(s.byteLength+r),n.set(s),n.set(o.byteLength,r),n)}},a.prototype=new h,e.exports=a},{"../codecs/adts.js":12,"../codecs/h264":13,"../m2ts/m2ts.js":18,"../utils/stream.js":25,"./flv-tag.js":14}],17:[function(t,e,i){"use strict";var a=4,n=128,r=t("../utils/stream"),s=function(t){for(var e=0,i={payloadType:-1,payloadSize:0},r=0,s=0;e<t.byteLength&&t[e]!==n;){for(;255===t[e];)r+=255,e++;for(r+=t[e++];255===t[e];)s+=255,e++;if(s+=t[e++],!i.payload&&r===a){i.payloadType=r,i.payloadSize=s,i.payload=t.subarray(e,e+s);break}e+=s,r=0,s=0}return i},o=function(t){return 181!==t.payload[0]?null:49!==(t.payload[1]<<8|t.payload[2])?null:"GA94"!==String.fromCharCode(t.payload[3],t.payload[4],t.payload[5],t.payload[6])?null:3!==t.payload[7]?null:t.payload.subarray(8,t.payload.length-1)},d=function(t,e){var i,a,n,r,s=[];if(!(64&e[0]))return s;for(a=31&e[0],i=0;a>i;i++)n=3*i,r={type:3&e[n+2],pts:t},4&e[n+2]&&(r.ccData=e[n+3]<<8|e[n+4],s.push(r));return s},u=function(){u.prototype.init.call(this),this.captionPackets_=[],this.field1_=new k,this.field1_.on("data",this.trigger.bind(this,"data")),this.field1_.on("done",this.trigger.bind(this,"done"))};u.prototype=new r,u.prototype.push=function(t){var e,i;"sei_rbsp"===t.nalUnitType&&(e=s(t.escapedRBSP),e.payloadType===a&&(i=o(e),i&&(this.captionPackets_=this.captionPackets_.concat(d(t.pts,i)))))},u.prototype.flush=function(){return this.captionPackets_.length?(this.captionPackets_.sort(function(t,e){return t.pts-e.pts}),this.captionPackets_.forEach(this.field1_.push,this.field1_),this.captionPackets_.length=0,void this.field1_.flush()):void this.field1_.flush()};var h={42:225,92:233,94:237,95:243,96:250,123:231,124:247,125:209,126:241,127:9608},f=function(t){return null===t?"":(t=h[t]||t,String.fromCharCode(t))},c=0,p=5152,l=5167,m=5157,g=5158,y=5159,b=5165,v=5153,_=5164,w=5166,S=14,T=function(){for(var t=[],e=S+1;e--;)t.push("");return t},k=function(){k.prototype.init.call(this),this.mode_="popOn",this.topRow_=0,this.startPts_=0,this.displayed_=T(),this.nonDisplayed_=T(),this.lastControlCode_=null,this.push=function(t){if(0===t.type){var e,i,a,n;if(e=32639&t.ccData,e===this.lastControlCode_)return void(this.lastControlCode_=null);switch(4096===(61440&e)?this.lastControlCode_=e:this.lastControlCode_=null,e){case c:break;case p:this.mode_="popOn";break;case l:this.flushDisplayed(t.pts),i=this.displayed_,this.displayed_=this.nonDisplayed_,this.nonDisplayed_=i,this.startPts_=t.pts;break;case m:this.topRow_=S-1,this.mode_="rollUp";break;case g:this.topRow_=S-2,this.mode_="rollUp";break;case y:this.topRow_=S-3,this.mode_="rollUp";break;case b:this.flushDisplayed(t.pts),this.shiftRowsUp_(),this.startPts_=t.pts;break;case v:"popOn"===this.mode_?this.nonDisplayed_[S]=this.nonDisplayed_[S].slice(0,-1):this.displayed_[S]=this.displayed_[S].slice(0,-1);break;case _:this.flushDisplayed(t.pts),this.displayed_=T();break;case w:this.nonDisplayed_=T();break;default:if(a=e>>>8,n=255&e,a>=16&&23>=a&&n>=64&&127>=n&&(16!==a||96>n)&&(a=32,n=null),(17===a||25===a)&&n>=48&&63>=n&&(a=9834,n=""),16===(240&a))return;this[this.mode_](t.pts,a,n)}}}};k.prototype=new r,k.prototype.flushDisplayed=function(t){var e=this.displayed_.map(function(t){return t.trim()}).filter(function(t){return t.length}).join("\n");e.length&&this.trigger("data",{startPts:this.startPts_,endPts:t,text:e})},k.prototype.popOn=function(t,e,i){var a=this.nonDisplayed_[S];a+=f(e),a+=f(i),this.nonDisplayed_[S]=a},k.prototype.rollUp=function(t,e,i){var a=this.displayed_[S];""===a&&(this.flushDisplayed(t),this.startPts_=t),a+=f(e),a+=f(i),this.displayed_[S]=a},k.prototype.shiftRowsUp_=function(){var t;for(t=0;t<this.topRow_;t++)this.displayed_[t]="";for(t=this.topRow_;S>t;t++)this.displayed_[t]=this.displayed_[t+1];this.displayed_[S]=""},e.exports={CaptionStream:u,Cea608Stream:k}},{"../utils/stream":25}],18:[function(t,e,i){"use strict";var a,n,r,s=t("../utils/stream.js"),o=t("./caption-stream"),d=t("./stream-types"),s=t("../utils/stream.js"),u=t("./stream-types.js"),h=188,f=71,a=function(){var t=new Uint8Array(h),e=0;a.prototype.init.call(this),this.push=function(i){var a,n=0,r=h;for(e?(a=new Uint8Array(i.byteLength+e),a.set(t.subarray(0,e)),a.set(i,e),e=0):a=i;r<a.byteLength;)a[n]!==f||a[r]!==f?(n++,r++):(this.trigger("data",a.subarray(n,r)),n+=h,r+=h);n<a.byteLength&&(t.set(a.subarray(n),0),e=a.byteLength-n)},this.flush=function(){e===h&&t[0]===f&&(this.trigger("data",t),e=0),this.trigger("done")}};a.prototype=new s,n=function(){var t,e,i,a;n.prototype.init.call(this),a=this,this.packetsWaitingForPmt=[],this.programMapTable=void 0,t=function(t,a){var n=0;a.payloadUnitStartIndicator&&(n+=t[n]+1),"pat"===a.type?e(t.subarray(n),a):i(t.subarray(n),a)},e=function(t,e){e.section_number=t[7],e.last_section_number=t[8],a.pmtPid=(31&t[10])<<8|t[11],e.pmtPid=a.pmtPid},i=function(t,e){var i,n,r,s;if(1&t[5]){for(a.programMapTable={},i=(15&t[1])<<8|t[2],n=3+i-4,r=(15&t[10])<<8|t[11],s=12+r;n>s;)a.programMapTable[(31&t[s+1])<<8|t[s+2]]=t[s],s+=((15&t[s+3])<<8|t[s+4])+5;for(e.programMapTable=a.programMapTable;a.packetsWaitingForPmt.length;)a.processPes_.apply(a,a.packetsWaitingForPmt.shift())}},this.push=function(e){var i={},a=4;i.payloadUnitStartIndicator=!!(64&e[1]),i.pid=31&e[1],i.pid<<=8,i.pid|=e[2],(48&e[3])>>>4>1&&(a+=e[a]+1),0===i.pid?(i.type="pat",t(e.subarray(a),i),this.trigger("data",i)):i.pid===this.pmtPid?(i.type="pmt",t(e.subarray(a),i),this.trigger("data",i)):void 0===this.programMapTable?this.packetsWaitingForPmt.push([e,a,i]):this.processPes_(e,a,i)},this.processPes_=function(t,e,i){i.streamType=this.programMapTable[i.pid],i.type="pes",i.data=t.subarray(e),this.trigger("data",i)}},n.prototype=new s,n.STREAM_TYPES={h264:27,adts:15},r=function(){var t,e={data:[],size:0},i={data:[],size:0},a={data:[],size:0},n=function(t,e){var i;e.dataAlignmentIndicator=0!==(4&t[6]),i=t[7],192&i&&(e.pts=(14&t[9])<<27|(255&t[10])<<20|(254&t[11])<<12|(255&t[12])<<5|(254&t[13])>>>3,e.pts*=4,e.pts+=(6&t[13])>>>1,e.dts=e.pts,64&i&&(e.dts=(14&t[14])<<27|(255&t[15])<<20|(254&t[16])<<12|(255&t[17])<<5|(254&t[18])>>>3,e.dts*=4,e.dts+=(6&t[18])>>>1)),e.data=t.subarray(9+t[8])},s=function(e,i){var a,r=new Uint8Array(e.size),s={type:i},o=0;if(e.data.length){for(s.trackId=e.data[0].pid;e.data.length;)a=e.data.shift(),r.set(a.data,o),o+=a.data.byteLength;n(r,s),e.size=0,t.trigger("data",s)}};r.prototype.init.call(this),t=this,this.push=function(n){({pat:function(){},pes:function(){var t,r;switch(n.streamType){case d.H264_STREAM_TYPE:case u.H264_STREAM_TYPE:t=e,r="video";break;case d.ADTS_STREAM_TYPE:t=i,r="audio";break;case d.METADATA_STREAM_TYPE:t=a,r="timed-metadata";break;default:return}n.payloadUnitStartIndicator&&s(t,r),t.data.push(n),t.size+=n.data.byteLength},pmt:function(){var e,i,a={type:"metadata",tracks:[]},r=n.programMapTable;for(e in r)r.hasOwnProperty(e)&&(i={timelineStartInfo:{baseMediaDecodeTime:0}},i.id=+e,r[e]===u.H264_STREAM_TYPE?(i.codec="avc",i.type="video"):r[e]===u.ADTS_STREAM_TYPE&&(i.codec="adts",i.type="audio"),a.tracks.push(i));t.trigger("data",a)}})[n.type]()},this.flush=function(){s(e,"video"),s(i,"audio"),s(a,"timed-metadata"),this.trigger("done")}},r.prototype=new s;var c={PAT_PID:0,MP2T_PACKET_LENGTH:h,TransportPacketStream:a,TransportParseStream:n,ElementaryStream:r,CaptionStream:o.CaptionStream,Cea608Stream:o.Cea608Stream,MetadataStream:t("./metadata-stream")};for(var p in d)d.hasOwnProperty(p)&&(c[p]=d[p]);e.exports=c},{"../utils/stream.js":25,"./caption-stream":17,"./metadata-stream":19,"./stream-types":20,"./stream-types.js":20}],19:[function(t,e,i){"use strict";var a,n=t("../utils/stream"),r=t("./stream-types"),s=function(t,e,i){var a,n="";for(a=e;i>a;a++)n+="%"+("00"+t[a].toString(16)).slice(-2);return n},o=function(t,e,i){return decodeURIComponent(s(t,e,i))},d=function(t,e,i){return unescape(s(t,e,i))},u=function(t){return t[0]<<21|t[1]<<14|t[2]<<7|t[3]},h={TXXX:function(t){var e;if(3===t.data[0]){for(e=1;e<t.data.length;e++)if(0===t.data[e]){t.description=o(t.data,1,e),t.value=o(t.data,e+1,t.data.length-1);break}t.data=t.value}},WXXX:function(t){var e;if(3===t.data[0])for(e=1;e<t.data.length;e++)if(0===t.data[e]){t.description=o(t.data,1,e),t.url=o(t.data,e+1,t.data.length);break}},PRIV:function(t){var e;for(e=0;e<t.data.length;e++)if(0===t.data[e]){t.owner=d(t.data,0,e);break}t.privateData=t.data.subarray(e+1),t.data=t.privateData}};a=function(t){var e,i={debug:!(!t||!t.debug),descriptor:t&&t.descriptor},n=0,s=[],o=0;if(a.prototype.init.call(this),this.dispatchType=r.METADATA_STREAM_TYPE.toString(16),i.descriptor)for(e=0;e<i.descriptor.length;e++)this.dispatchType+=("00"+i.descriptor[e].toString(16)).slice(-2);this.push=function(t){var e,a,r,d,f,c;if("timed-metadata"===t.type){if(t.dataAlignmentIndicator&&(o=0,s.length=0),0===s.length&&(t.data.length<10||t.data[0]!=="I".charCodeAt(0)||t.data[1]!=="D".charCodeAt(0)||t.data[2]!=="3".charCodeAt(0)))return void(i.debug&&console.log("Skipping unrecognized metadata packet"));if(s.push(t),o+=t.data.byteLength,1===s.length&&(n=u(t.data.subarray(6,10)),n+=10),!(n>o)){for(e={data:new Uint8Array(n),frames:[],pts:s[0].pts,dts:s[0].dts},f=0;n>f;)e.data.set(s[0].data.subarray(0,n-f),f),f+=s[0].data.byteLength,o-=s[0].data.byteLength,s.shift();a=10,64&e.data[5]&&(a+=4,a+=u(e.data.subarray(10,14)),n-=u(e.data.subarray(16,20)));do{if(r=u(e.data.subarray(a+4,a+8)),1>r)return console.log("Malformed ID3 frame encountered. Skipping metadata parsing.");if(c=String.fromCharCode(e.data[a],e.data[a+1],e.data[a+2],e.data[a+3]),d={id:c,data:e.data.subarray(a+10,a+r+10)},d.key=d.id,h[d.id]&&(h[d.id](d),"com.apple.streaming.transportStreamTimestamp"===d.owner)){var p=d.data,l=(1&p[3])<<30|p[4]<<22|p[5]<<14|p[6]<<6|p[7]>>>2;l*=4,l+=3&p[7],d.timeStamp=l,this.trigger("timestamp",d)}e.frames.push(d),a+=10,a+=r}while(n>a);this.trigger("data",e)}}}},a.prototype=new n,e.exports=a},{"../utils/stream":25,"./stream-types":20}],20:[function(t,e,i){"use strict";e.exports={H264_STREAM_TYPE:27,ADTS_STREAM_TYPE:15,METADATA_STREAM_TYPE:21}},{}],21:[function(t,e,i){e.exports={generator:t("./mp4-generator"),Transmuxer:t("./transmuxer").Transmuxer,AudioSegmentStream:t("./transmuxer").AudioSegmentStream,VideoSegmentStream:t("./transmuxer").VideoSegmentStream}},{"./mp4-generator":22,"./transmuxer":23}],22:[function(t,e,i){"use strict";var a,n,r,s,o,d,u,h,f,c,p,l,m,g,y,b,v,_,w,S,T,k,A,M,O,x,U,B,P,D,j,C,E,L,I,R,z;!function(){var t;if(M={avc1:[],avcC:[],btrt:[],dinf:[],dref:[],esds:[],ftyp:[],hdlr:[],mdat:[],mdhd:[],mdia:[],mfhd:[],minf:[],moof:[],moov:[],mp4a:[],mvex:[],mvhd:[],sdtp:[],smhd:[],stbl:[],stco:[],stsc:[],stsd:[],stsz:[],stts:[],styp:[],tfdt:[],tfhd:[],traf:[],trak:[],trun:[],trex:[],tkhd:[],vmhd:[]},"undefined"!=typeof Uint8Array){for(t in M)M.hasOwnProperty(t)&&(M[t]=[t.charCodeAt(0),t.charCodeAt(1),t.charCodeAt(2),t.charCodeAt(3)]);O=new Uint8Array(["i".charCodeAt(0),"s".charCodeAt(0),"o".charCodeAt(0),"m".charCodeAt(0)]),U=new Uint8Array(["a".charCodeAt(0),"v".charCodeAt(0),"c".charCodeAt(0),"1".charCodeAt(0)]),x=new Uint8Array([0,0,0,1]),B=new Uint8Array([0,0,0,0,0,0,0,0,118,105,100,101,0,0,0,0,0,0,0,0,0,0,0,0,86,105,100,101,111,72,97,110,100,108,101,114,0]),P=new Uint8Array([0,0,0,0,0,0,0,0,115,111,117,110,0,0,0,0,0,0,0,0,0,0,0,0,83,111,117,110,100,72,97,110,100,108,101,114,0]),D={video:B,audio:P},E=new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,12,117,114,108,32,0,0,0,1]),C=new Uint8Array([0,0,0,0,0,0,0,0]),L=new Uint8Array([0,0,0,0,0,0,0,0]),I=L,R=new Uint8Array([0,0,0,0,0,0,0,0,0,0,0,0]),z=L,j=new Uint8Array([0,0,0,1,0,0,0,0,0,0,0,0])}}(),a=function(t){var e,i,a,n=[],r=0;for(e=1;e<arguments.length;e++)n.push(arguments[e]);for(e=n.length;e--;)r+=n[e].byteLength;for(i=new Uint8Array(r+8),a=new DataView(i.buffer,i.byteOffset,i.byteLength),a.setUint32(0,i.byteLength),i.set(t,4),e=0,r=8;e<n.length;e++)i.set(n[e],r),r+=n[e].byteLength;return i},n=function(){return a(M.dinf,a(M.dref,E))},r=function(t){return a(M.esds,new Uint8Array([0,0,0,0,3,25,0,0,0,4,17,64,21,0,6,0,0,0,218,192,0,0,218,192,5,2,t.audioobjecttype<<3|t.samplingfrequencyindex>>>1,t.samplingfrequencyindex<<7|t.channelcount<<3,6,1,2]))},s=function(){return a(M.ftyp,O,x,O,U)},b=function(t){return a(M.hdlr,D[t])},o=function(t){return a(M.mdat,t)},y=function(t){var e=new Uint8Array([0,0,0,0,0,0,0,2,0,0,0,3,0,1,95,144,t.duration>>>24&255,t.duration>>>16&255,t.duration>>>8&255,255&t.duration,85,196,0,0]);return t.samplerate&&(e[12]=t.samplerate>>>24&255,e[13]=t.samplerate>>>16&255,e[14]=t.samplerate>>>8&255,e[15]=255&t.samplerate),a(M.mdhd,e)},g=function(t){return a(M.mdia,y(t),b(t.type),u(t))},d=function(t){return a(M.mfhd,new Uint8Array([0,0,0,0,(4278190080&t)>>24,(16711680&t)>>16,(65280&t)>>8,255&t]))},u=function(t){return a(M.minf,"video"===t.type?a(M.vmhd,j):a(M.smhd,C),n(),_(t))},h=function(t,e){for(var i=[],n=e.length;n--;)i[n]=T(e[n]);return a.apply(null,[M.moof,d(t)].concat(i))},f=function(t){for(var e=t.length,i=[];e--;)i[e]=l(t[e]);return a.apply(null,[M.moov,p(4294967295)].concat(i).concat(c(t)))},c=function(t){for(var e=t.length,i=[];e--;)i[e]=k(t[e]);return a.apply(null,[M.mvex].concat(i))},p=function(t){var e=new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,2,0,1,95,144,(4278190080&t)>>24,(16711680&t)>>16,(65280&t)>>8,255&t,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255]);return a(M.mvhd,e)},v=function(t){var e,i,n=t.samples||[],r=new Uint8Array(4+n.length);for(i=0;i<n.length;i++)e=n[i].flags,r[i+4]=e.dependsOn<<4|e.isDependedOn<<2|e.hasRedundancy;return a(M.sdtp,r)},_=function(t){return a(M.stbl,w(t),a(M.stts,z),a(M.stsc,I),a(M.stsz,R),a(M.stco,L))},function(){var t,e;w=function(i){return a(M.stsd,new Uint8Array([0,0,0,0,0,0,0,1]),"video"===i.type?t(i):e(i))},t=function(t){var e,i=t.sps||[],n=t.pps||[],r=[],s=[];for(e=0;e<i.length;e++)r.push((65280&i[e].byteLength)>>>8),r.push(255&i[e].byteLength),r=r.concat(Array.prototype.slice.call(i[e]));for(e=0;e<n.length;e++)s.push((65280&n[e].byteLength)>>>8),s.push(255&n[e].byteLength),s=s.concat(Array.prototype.slice.call(n[e]));return a(M.avc1,new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,(65280&t.width)>>8,255&t.width,(65280&t.height)>>8,255&t.height,0,72,0,0,0,72,0,0,0,0,0,0,0,1,19,118,105,100,101,111,106,115,45,99,111,110,116,114,105,98,45,104,108,115,0,0,0,0,0,0,0,0,0,0,0,0,0,24,17,17]),a(M.avcC,new Uint8Array([1,t.profileIdc,t.profileCompatibility,t.levelIdc,255].concat([i.length]).concat(r).concat([n.length]).concat(s))),a(M.btrt,new Uint8Array([0,28,156,128,0,45,198,192,0,45,198,192])))},e=function(t){return a(M.mp4a,new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,(65280&t.channelcount)>>8,255&t.channelcount,(65280&t.samplesize)>>8,255&t.samplesize,0,0,0,0,(65280&t.samplerate)>>8,255&t.samplerate,0,0]),r(t))}}(),S=function(){return a(M.styp,O,x,O)},m=function(t){var e=new Uint8Array([0,0,0,7,0,0,0,0,0,0,0,0,(4278190080&t.id)>>24,(16711680&t.id)>>16,(65280&t.id)>>8,255&t.id,0,0,0,0,(4278190080&t.duration)>>24,(16711680&t.duration)>>16,(65280&t.duration)>>8,255&t.duration,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,(65280&t.width)>>8,255&t.width,0,0,(65280&t.height)>>8,255&t.height,0,0]);return a(M.tkhd,e)},T=function(t){var e,i,n,r,s;return e=a(M.tfhd,new Uint8Array([0,0,0,58,(4278190080&t.id)>>24,(16711680&t.id)>>16,(65280&t.id)>>8,255&t.id,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0])),i=a(M.tfdt,new Uint8Array([0,0,0,0,t.baseMediaDecodeTime>>>24&255,t.baseMediaDecodeTime>>>16&255,t.baseMediaDecodeTime>>>8&255,255&t.baseMediaDecodeTime])),s=88,"audio"===t.type?(n=A(t,s),a(M.traf,e,i,n)):(r=v(t),n=A(t,r.length+s),a(M.traf,e,i,n,r))},l=function(t){return t.duration=t.duration||4294967295,a(M.trak,m(t),g(t))},k=function(t){var e=new Uint8Array([0,0,0,0,(4278190080&t.id)>>24,(16711680&t.id)>>16,(65280&t.id)>>8,255&t.id,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1]);return"video"!==t.type&&(e[e.length-1]=0),a(M.trex,e)},function(){var t,e,i;i=function(t,e){var i=0,a=0,n=0,r=0;return t.length&&(void 0!==t[0].duration&&(i=1),void 0!==t[0].size&&(a=2),void 0!==t[0].flags&&(n=4),void 0!==t[0].compositionTimeOffset&&(r=8)),[0,0,i|a|n|r,1,(4278190080&t.length)>>>24,(16711680&t.length)>>>16,(65280&t.length)>>>8,255&t.length,(4278190080&e)>>>24,(16711680&e)>>>16,(65280&e)>>>8,255&e]},e=function(t,e){var n,r,s,o;for(r=t.samples||[],e+=20+16*r.length,n=i(r,e),o=0;o<r.length;o++)s=r[o],n=n.concat([(4278190080&s.duration)>>>24,(16711680&s.duration)>>>16,(65280&s.duration)>>>8,255&s.duration,(4278190080&s.size)>>>24,(16711680&s.size)>>>16,(65280&s.size)>>>8,255&s.size,s.flags.isLeading<<2|s.flags.dependsOn,s.flags.isDependedOn<<6|s.flags.hasRedundancy<<4|s.flags.paddingValue<<1|s.flags.isNonSyncSample,61440&s.flags.degradationPriority,15&s.flags.degradationPriority,(4278190080&s.compositionTimeOffset)>>>24,(16711680&s.compositionTimeOffset)>>>16,(65280&s.compositionTimeOffset)>>>8,255&s.compositionTimeOffset]);return a(M.trun,new Uint8Array(n))},t=function(t,e){var n,r,s,o;for(r=t.samples||[],e+=20+8*r.length,n=i(r,e),o=0;o<r.length;o++)s=r[o],n=n.concat([(4278190080&s.duration)>>>24,(16711680&s.duration)>>>16,(65280&s.duration)>>>8,255&s.duration,(4278190080&s.size)>>>24,(16711680&s.size)>>>16,(65280&s.size)>>>8,255&s.size]);return a(M.trun,new Uint8Array(n))},A=function(i,a){return"audio"===i.type?t(i,a):e(i,a)}}(),e.exports={ftyp:s,mdat:o,moof:h,moov:f,initSegment:function(t){var e,i=s(),a=f(t);return e=new Uint8Array(i.byteLength+a.byteLength),e.set(i),e.set(a,i.byteLength),e}}},{}],23:[function(t,e,i){"use strict";var a,n,r,s,o,d,u,h,f,c,p,l=t("../utils/stream.js"),m=t("./mp4-generator.js"),g=t("../m2ts/m2ts.js"),y=t("../codecs/adts.js"),b=t("../codecs/h264").H264Stream,v=t("../aac"),_=["audioobjecttype","channelcount","samplerate","samplingfrequencyindex","samplesize"],w=["width","height","profileIdc","levelIdc","profileCompatibility"];o=function(){return{size:0,flags:{isLeading:0,dependsOn:1,isDependedOn:0,hasRedundancy:0,degradationPriority:0}}},d=function(t){return t[0]==="I".charCodeAt(0)&&t[1]==="D".charCodeAt(0)&&t[2]==="3".charCodeAt(0)},c=function(t,e){var i;if(t.length!==e.length)return!1;for(i=0;i<t.length;i++)if(t[i]!==e[i])return!1;return!0},p=function(t){var e,i,a=0;for(e=0;e<t.length;e++)i=t[e],a+=i.data.byteLength;return a},n=function(t){var e=[],i=0,a=0;n.prototype.init.call(this),this.push=function(i){u(t,i),t&&_.forEach(function(e){t[e]=i[e]}),e.push(i)},this.setEarliestDts=function(e){a=e-t.timelineStartInfo.baseMediaDecodeTime},this.flush=function(){var a,n,r,s;return 0===e.length?void this.trigger("done","AudioSegmentStream"):(a=this.trimAdtsFramesByEarliestDts_(e),t.samples=this.generateSampleTable_(a),r=m.mdat(this.concatenateFrameData_(a)),e=[],f(t),n=m.moof(i,[t]),s=new Uint8Array(n.byteLength+r.byteLength),i++,s.set(n),s.set(r,n.byteLength),h(t),this.trigger("data",{track:t,boxes:s}),void this.trigger("done","AudioSegmentStream"))},this.trimAdtsFramesByEarliestDts_=function(e){return t.minSegmentDts>=a?e:(t.minSegmentDts=1/0,e.filter(function(e){return e.dts>=a?(t.minSegmentDts=Math.min(t.minSegmentDts,e.dts),t.minSegmentPts=t.minSegmentDts,!0):!1}))},this.generateSampleTable_=function(t){var e,i,a=[];for(e=0;e<t.length;e++)i=t[e],a.push({size:i.data.byteLength,duration:1024});return a},this.concatenateFrameData_=function(t){var e,i,a=0,n=new Uint8Array(p(t));for(e=0;e<t.length;e++)i=t[e],n.set(i.data,a),a+=i.data.byteLength;return n}},n.prototype=new l,a=function(t){var e,i,n=0,r=[];a.prototype.init.call(this),delete t.minPTS,this.gopCache_=[],this.push=function(a){u(t,a),"seq_parameter_set_rbsp"!==a.nalUnitType||e||(e=a.config,t.sps=[a.data],w.forEach(function(i){t[i]=e[i]},this)),"pic_parameter_set_rbsp"!==a.nalUnitType||i||(i=a.data,t.pps=[a.data]),r.push(a)},this.flush=function(){for(var e,i,a,s,o,d;r.length&&"access_unit_delimiter_rbsp"!==r[0].nalUnitType;)r.shift();return 0===r.length?(this.resetStream_(),void this.trigger("done","VideoSegmentStream")):(e=this.groupNalsIntoFrames_(r),a=this.groupFramesIntoGops_(e),a[0][0].keyFrame||(i=this.getGopForFusion_(r[0],t),i?(a.unshift(i),a.byteLength+=i.byteLength,a.nalCount+=i.nalCount,a.pts=i.pts,a.dts=i.dts,a.duration+=i.duration):a=this.extendFirstKeyFrame_(a)),u(t,a),t.samples=this.generateSampleTable_(a),o=m.mdat(this.concatenateNalData_(a)),this.gopCache_.unshift({gop:a.pop(),pps:t.pps,sps:t.sps}),this.gopCache_.length=Math.min(6,this.gopCache_.length),r=[],f(t),this.trigger("timelineStartInfo",t.timelineStartInfo),s=m.moof(n,[t]),d=new Uint8Array(s.byteLength+o.byteLength),n++,d.set(s),d.set(o,s.byteLength),this.trigger("data",{track:t,boxes:d}),this.resetStream_(),void this.trigger("done","VideoSegmentStream"))},this.resetStream_=function(){h(t),e=void 0,i=void 0},this.getGopForFusion_=function(e){var i,a,n,r,s,o=45e3,d=1e4,u=1/0;for(s=0;s<this.gopCache_.length;s++)r=this.gopCache_[s],n=r.gop,t.pps&&c(t.pps[0],r.pps[0])&&t.sps&&c(t.sps[0],r.sps[0])&&(n.dts<t.timelineStartInfo.dts||(i=e.dts-n.dts-n.duration,i>=-d&&o>=i&&(!a||u>i)&&(a=r,u=i)));return a?a.gop:null},this.extendFirstKeyFrame_=function(t){var e;return t[0][0].keyFrame||(e=t.shift(),
t.byteLength-=e.byteLength,t.nalCount-=e.nalCount,t[0][0].dts=e.dts,t[0][0].pts=e.pts,t[0][0].duration+=e.duration),t},this.groupNalsIntoFrames_=function(t){var e,i,a=[],n=[];for(a.byteLength=0,e=0;e<t.length;e++)i=t[e],"access_unit_delimiter_rbsp"===i.nalUnitType?(a.length&&(a.duration=i.dts-a.dts,n.push(a)),a=[i],a.byteLength=i.data.byteLength,a.pts=i.pts,a.dts=i.dts):("slice_layer_without_partitioning_rbsp_idr"===i.nalUnitType&&(a.keyFrame=!0),a.duration=i.dts-a.dts,a.byteLength+=i.data.byteLength,a.push(i));return n.length&&(!a.duration||a.duration<=0)&&(a.duration=n[n.length-1].duration),n.push(a),n},this.groupFramesIntoGops_=function(t){var e,i,a=[],n=[];for(a.byteLength=0,a.nalCount=0,a.duration=0,a.pts=t[0].pts,a.dts=t[0].dts,n.byteLength=0,n.nalCount=0,n.duration=0,n.pts=t[0].pts,n.dts=t[0].dts,e=0;e<t.length;e++)i=t[e],i.keyFrame?(a.length&&(n.push(a),n.byteLength+=a.byteLength,n.nalCount+=a.nalCount,n.duration+=a.duration),a=[i],a.nalCount=i.length,a.byteLength=i.byteLength,a.pts=i.pts,a.dts=i.dts,a.duration=i.duration):(a.duration+=i.duration,a.nalCount+=i.length,a.byteLength+=i.byteLength,a.push(i));return n.length&&a.duration<=0&&(a.duration=n[n.length-1].duration),n.byteLength+=a.byteLength,n.nalCount+=a.nalCount,n.duration+=a.duration,n.push(a),n},this.generateSampleTable_=function(t,e){var i,a,n,r,s,d=e||0,u=[];for(i=0;i<t.length;i++)for(r=t[i],a=0;a<r.length;a++)s=r[a],n=o(),n.dataOffset=d,n.compositionTimeOffset=s.pts-s.dts,n.duration=s.duration,n.size=4*s.length,n.size+=s.byteLength,s.keyFrame&&(n.flags.dependsOn=2),d+=n.size,u.push(n);return u},this.concatenateNalData_=function(t){var e,i,a,n,r,s,o=0,d=t.byteLength,u=t.nalCount,h=d+4*u,f=new Uint8Array(h),c=new DataView(f.buffer);for(e=0;e<t.length;e++)for(n=t[e],i=0;i<n.length;i++)for(r=n[i],a=0;a<r.length;a++)s=r[a],c.setUint32(o,s.data.byteLength),o+=4,f.set(s.data,o),o+=s.data.byteLength;return f}},a.prototype=new l,u=function(t,e){"number"==typeof e.pts&&(void 0===t.timelineStartInfo.pts&&(t.timelineStartInfo.pts=e.pts),void 0===t.minSegmentPts?t.minSegmentPts=e.pts:t.minSegmentPts=Math.min(t.minSegmentPts,e.pts),void 0===t.maxSegmentPts?t.maxSegmentPts=e.pts:t.maxSegmentPts=Math.max(t.maxSegmentPts,e.pts)),"number"==typeof e.dts&&(void 0===t.timelineStartInfo.dts&&(t.timelineStartInfo.dts=e.dts),void 0===t.minSegmentDts?t.minSegmentDts=e.dts:t.minSegmentDts=Math.min(t.minSegmentDts,e.dts),void 0===t.maxSegmentDts?t.maxSegmentDts=e.dts:t.maxSegmentDts=Math.max(t.maxSegmentDts,e.dts))},h=function(t){delete t.minSegmentDts,delete t.maxSegmentDts,delete t.minSegmentPts,delete t.maxSegmentPts},f=function(t){var e,i=9e4,a=t.minSegmentDts-t.timelineStartInfo.dts,n=t.minSegmentPts-t.minSegmentDts;t.baseMediaDecodeTime=t.timelineStartInfo.baseMediaDecodeTime,t.baseMediaDecodeTime+=a,t.baseMediaDecodeTime-=n,t.baseMediaDecodeTime=Math.max(0,t.baseMediaDecodeTime),"audio"===t.type&&(e=t.samplerate/i,t.baseMediaDecodeTime*=e,t.baseMediaDecodeTime=Math.floor(t.baseMediaDecodeTime))},s=function(t,e){this.numberOfTracks=0,this.metadataStream=e,"undefined"!=typeof t.remux?this.remuxTracks=!!t.remux:this.remuxTracks=!0,this.pendingTracks=[],this.videoTrack=null,this.pendingBoxes=[],this.pendingCaptions=[],this.pendingMetadata=[],this.pendingBytes=0,this.emittedTracks=0,s.prototype.init.call(this),this.push=function(t){return t.text?this.pendingCaptions.push(t):t.frames?this.pendingMetadata.push(t):(this.pendingTracks.push(t.track),this.pendingBoxes.push(t.boxes),this.pendingBytes+=t.boxes.byteLength,"video"===t.track.type&&(this.videoTrack=t.track),void("audio"===t.track.type&&(this.audioTrack=t.track)))}},s.prototype=new l,s.prototype.flush=function(t){var e,i,a,n,r=0,s={captions:[],metadata:[],info:{}},o=0;if(this.pendingTracks.length<this.numberOfTracks){if("VideoSegmentStream"!==t&&"AudioSegmentStream"!==t)return;if(this.remuxTracks)return;if(0===this.pendingTracks.length)return this.emittedTracks++,void(this.emittedTracks>=this.numberOfTracks&&(this.trigger("done"),this.emittedTracks=0))}for(this.videoTrack?(o=this.videoTrack.timelineStartInfo.pts,w.forEach(function(t){s.info[t]=this.videoTrack[t]},this)):this.audioTrack&&(o=this.audioTrack.timelineStartInfo.pts,_.forEach(function(t){s.info[t]=this.audioTrack[t]},this)),1===this.pendingTracks.length?s.type=this.pendingTracks[0].type:s.type="combined",this.emittedTracks+=this.pendingTracks.length,a=m.initSegment(this.pendingTracks),s.data=new Uint8Array(a.byteLength+this.pendingBytes),s.data.set(a),r+=a.byteLength,n=0;n<this.pendingBoxes.length;n++)s.data.set(this.pendingBoxes[n],r),r+=this.pendingBoxes[n].byteLength;for(n=0;n<this.pendingCaptions.length;n++)e=this.pendingCaptions[n],e.startTime=e.startPts-o,e.startTime/=9e4,e.endTime=e.endPts-o,e.endTime/=9e4,s.captions.push(e);for(n=0;n<this.pendingMetadata.length;n++)i=this.pendingMetadata[n],i.cueTime=i.pts-o,i.cueTime/=9e4,s.metadata.push(i);s.metadata.dispatchType=this.metadataStream.dispatchType,this.pendingTracks.length=0,this.videoTrack=null,this.pendingBoxes.length=0,this.pendingCaptions.length=0,this.pendingBytes=0,this.pendingMetadata.length=0,this.trigger("data",s),this.emittedTracks>=this.numberOfTracks&&(this.trigger("done"),this.emittedTracks=0)},r=function(t){var e,i,o=this,u=!0;r.prototype.init.call(this),t=t||{},this.baseMediaDecodeTime=t.baseMediaDecodeTime||0,this.transmuxPipeline_={},this.setupAacPipeline=function(){var e={};this.transmuxPipeline_=e,e.type="aac",e.metadataStream=new g.MetadataStream,e.aacStream=new v,e.adtsStream=new y,e.coalesceStream=new s(t,e.metadataStream),e.headOfPipeline=e.aacStream,e.aacStream.pipe(e.adtsStream),e.aacStream.pipe(e.metadataStream),e.metadataStream.pipe(e.coalesceStream),e.metadataStream.on("timestamp",function(t){e.aacStream.setTimestamp(t.timeStamp)}),e.aacStream.on("data",function(t){"timed-metadata"!==t.type||e.audioSegmentStream||(i=i||{timelineStartInfo:{baseMediaDecodeTime:o.baseMediaDecodeTime},codec:"adts",type:"audio"},e.coalesceStream.numberOfTracks++,e.audioSegmentStream=new n(i),e.adtsStream.pipe(e.audioSegmentStream).pipe(e.coalesceStream))}),e.coalesceStream.on("data",this.trigger.bind(this,"data")),e.coalesceStream.on("done",this.trigger.bind(this,"done"))},this.setupTsPipeline=function(){var r={};this.transmuxPipeline_=r,r.type="ts",r.metadataStream=new g.MetadataStream,r.packetStream=new g.TransportPacketStream,r.parseStream=new g.TransportParseStream,r.elementaryStream=new g.ElementaryStream,r.adtsStream=new y,r.h264Stream=new b,r.captionStream=new g.CaptionStream,r.coalesceStream=new s(t,r.metadataStream),r.headOfPipeline=r.packetStream,r.packetStream.pipe(r.parseStream).pipe(r.elementaryStream),r.elementaryStream.pipe(r.h264Stream),r.elementaryStream.pipe(r.adtsStream),r.elementaryStream.pipe(r.metadataStream).pipe(r.coalesceStream),r.h264Stream.pipe(r.captionStream).pipe(r.coalesceStream),r.elementaryStream.on("data",function(t){var s;if("metadata"===t.type){for(s=t.tracks.length;s--;)e||"video"!==t.tracks[s].type?i||"audio"!==t.tracks[s].type||(i=t.tracks[s],i.timelineStartInfo.baseMediaDecodeTime=o.baseMediaDecodeTime):(e=t.tracks[s],e.timelineStartInfo.baseMediaDecodeTime=o.baseMediaDecodeTime);e&&!r.videoSegmentStream&&(r.coalesceStream.numberOfTracks++,r.videoSegmentStream=new a(e),r.videoSegmentStream.on("timelineStartInfo",function(t){i&&(i.timelineStartInfo=t,r.audioSegmentStream.setEarliestDts(t.dts))}),r.h264Stream.pipe(r.videoSegmentStream).pipe(r.coalesceStream)),i&&!r.audioSegmentStream&&(r.coalesceStream.numberOfTracks++,r.audioSegmentStream=new n(i),r.adtsStream.pipe(r.audioSegmentStream).pipe(r.coalesceStream))}}),r.coalesceStream.on("data",this.trigger.bind(this,"data")),r.coalesceStream.on("done",this.trigger.bind(this,"done"))},this.setBaseMediaDecodeTime=function(t){var a=this.transmuxPipeline_;this.baseMediaDecodeTime=t,i&&(i.timelineStartInfo.dts=void 0,i.timelineStartInfo.pts=void 0,h(i),i.timelineStartInfo.baseMediaDecodeTime=t),e&&(a.videoSegmentStream&&(a.videoSegmentStream.gopCache_=[]),e.timelineStartInfo.dts=void 0,e.timelineStartInfo.pts=void 0,h(e),e.timelineStartInfo.baseMediaDecodeTime=t)},this.push=function(t){if(u){var e=d(t);e&&"aac"!==this.transmuxPipeline_.type?this.setupAacPipeline():e||"ts"===this.transmuxPipeline_.type||this.setupTsPipeline(),u=!1}this.transmuxPipeline_.headOfPipeline.push(t)},this.flush=function(){u=!0,this.transmuxPipeline_.headOfPipeline.flush()}},r.prototype=new l,e.exports={Transmuxer:r,VideoSegmentStream:a,AudioSegmentStream:n,AUDIO_PROPERTIES:_,VIDEO_PROPERTIES:w}},{"../aac":11,"../codecs/adts.js":12,"../codecs/h264":13,"../m2ts/m2ts.js":18,"../utils/stream.js":25,"./mp4-generator.js":22}],24:[function(t,e,i){"use strict";var a;a=function(t){var e=t.byteLength,i=0,a=0;this.length=function(){return 8*e},this.bitsAvailable=function(){return 8*e+a},this.loadWord=function(){var n=t.byteLength-e,r=new Uint8Array(4),s=Math.min(4,e);if(0===s)throw new Error("no bytes available");r.set(t.subarray(n,n+s)),i=new DataView(r.buffer).getUint32(0),a=8*s,e-=s},this.skipBits=function(t){var n;a>t?(i<<=t,a-=t):(t-=a,n=Math.floor(t/8),t-=8*n,e-=n,this.loadWord(),i<<=t,a-=t)},this.readBits=function(t){var n=Math.min(a,t),r=i>>>32-n;return a-=n,a>0?i<<=n:e>0&&this.loadWord(),n=t-n,n>0?r<<n|this.readBits(n):r},this.skipLeadingZeros=function(){var t;for(t=0;a>t;++t)if(0!==(i&2147483648>>>t))return i<<=t,a-=t,t;return this.loadWord(),t+this.skipLeadingZeros()},this.skipUnsignedExpGolomb=function(){this.skipBits(1+this.skipLeadingZeros())},this.skipExpGolomb=function(){this.skipBits(1+this.skipLeadingZeros())},this.readUnsignedExpGolomb=function(){var t=this.skipLeadingZeros();return this.readBits(t+1)-1},this.readExpGolomb=function(){var t=this.readUnsignedExpGolomb();return 1&t?1+t>>>1:-1*(t>>>1)},this.readBoolean=function(){return 1===this.readBits(1)},this.readUnsignedByte=function(){return this.readBits(8)},this.loadWord()},e.exports=a},{}],25:[function(t,e,i){"use strict";var a=function(){this.init=function(){var t={};this.on=function(e,i){t[e]||(t[e]=[]),t[e].push(i)},this.off=function(e,i){var a;return t[e]?(a=t[e].indexOf(i),t[e].splice(a,1),a>-1):!1},this.trigger=function(e){var i,a,n,r;if(i=t[e])if(2===arguments.length)for(n=i.length,a=0;n>a;++a)i[a].call(this,arguments[1]);else{for(r=[],a=arguments.length,a=1;a<arguments.length;++a)r.push(arguments[a]);for(n=i.length,a=0;n>a;++a)i[a].apply(this,r)}},this.dispose=function(){t={}}}};a.prototype.pipe=function(t){return this.on("data",function(e){t.push(e)}),this.on("done",function(e){t.flush(e)}),t},a.prototype.push=function(t){this.trigger("data",t)},a.prototype.flush=function(t){this.trigger("done",t)},e.exports=a},{}],26:[function(t,e,i){var a=arguments[3],n=arguments[4],r=arguments[5],s=JSON.stringify;e.exports=function(t){for(var e,i=Object.keys(r),o=0,d=i.length;d>o;o++){var u=i[o];if(r[u].exports===t){e=u;break}}if(!e){e=Math.floor(Math.pow(16,8)*Math.random()).toString(16);for(var h={},o=0,d=i.length;d>o;o++){var u=i[o];h[u]=u}n[e]=[Function(["require","module","exports"],"("+t+")(self)"),h]}var f=Math.floor(Math.pow(16,8)*Math.random()).toString(16),c={};c[e]=e,n[f]=[Function(["require"],"require("+s(e)+")(self)"),c];var p="("+a+")({"+Object.keys(n).map(function(t){return s(t)+":["+n[t][0]+","+s(n[t][1])+"]"}).join(",")+"},{},["+s(f)+"])",l=window.URL||window.webkitURL||window.mozURL||window.msURL;return new Worker(l.createObjectURL(new Blob([p],{type:"text/javascript"})))}},{}],27:[function(t,e,i){(function(e){"use strict";function a(t){return t&&t.__esModule?t:{"default":t}}Object.defineProperty(i,"__esModule",{value:!0});var n=t("./flash-media-source"),r=a(n),s=t("./html-media-source"),o=a(s),d="undefined"!=typeof window?window.videojs:"undefined"!=typeof e?e.videojs:null,u=a(d),h=0,f={mode:"auto"};u["default"].mediaSources={};var c=function(t,e){var i=u["default"].mediaSources[t];if(!i)throw new Error("Media Source not found (Video.js)");i.trigger({type:"sourceopen",swfId:e})},p=function(){return!!window.MediaSource&&!!window.MediaSource.isTypeSupported&&window.MediaSource.isTypeSupported('video/mp4;codecs="avc1.4d400d,mp4a.40.2"')},l=function(t){var e=u["default"].mergeOptions(f,t);return this.MediaSource={open:c,supportsNativeMediaSources:p},"html5"===e.mode||"auto"===e.mode&&p()?new o["default"]:new r["default"]};i.MediaSource=l,l.open=c,l.supportsNativeMediaSources=p;var m={createObjectURL:function(t){var e="blob:vjs-media-source/",i=void 0;return t instanceof o["default"]?(i=window.URL.createObjectURL(t.nativeMediaSource_),t.url_=i,i):t instanceof r["default"]?(i=e+h,h++,u["default"].mediaSources[i]=t,i):(i=window.URL.createObjectURL(t),t.url_=i,i)}};i.URL=m,u["default"].MediaSource=l,u["default"].URL=m}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./flash-media-source":5,"./html-media-source":7}]},{},[27])(27)});
/**
 * videojs-contrib-hls
 * @version 3.1.0
 * @copyright 2016 Brightcove, Inc
 * @license Apache-2.0
 */
!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{var t;t="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this,t.videojsContribHls=e()}}(function(){return function e(t,i,r){function n(s,o){if(!i[s]){if(!t[s]){var u="function"==typeof require&&require;if(!o&&u)return u(s,!0);if(a)return a(s,!0);var d=new Error("Cannot find module '"+s+"'");throw d.code="MODULE_NOT_FOUND",d}var l=i[s]={exports:{}};t[s][0].call(l.exports,function(e){var i=t[s][1][e];return n(i?i:e)},l,l.exports,e,t,i,r)}return i[s].exports}for(var a="function"==typeof require&&require,s=0;s<r.length;s++)n(r[s]);return n}({1:[function(e,t,i){"use strict";Object.defineProperty(i,"__esModule",{value:!0});var r=function(e,t){return e.start(t)+"-"+e.end(t)},n=function(e,t){var i=e.toString(16);return"00".substring(0,2-i.length)+i+(t%2?" ":"")},a=function(e){return e>=32&&126>e?String.fromCharCode(e):"."},s={hexDump:function(e){for(var t=Array.prototype.slice.call(e),i=16,r="",s=void 0,o=void 0,u=0;u<t.length/i;u++)s=t.slice(u*i,u*i+i).map(n).join(""),o=t.slice(u*i,u*i+i).map(a).join(""),r+=s+" "+o+"\n";return r},tagDump:function(e){return s.hexDump(e.bytes)},textRanges:function(e){var t="",i=void 0;for(i=0;i<e.length;i++)t+=r(e,i)+" ";return t}};i["default"]=s,t.exports=i["default"]},{}],2:[function(e,t,i){"use strict";Object.defineProperty(i,"__esModule",{value:!0}),i["default"]={GOAL_BUFFER_LENGTH:30},t.exports=i["default"]},{}],3:[function(e,t,i){"use strict";function r(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(i,"__esModule",{value:!0});var n=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),a=function(){var e=[[[],[],[],[],[]],[[],[],[],[],[]]],t=e[0],i=e[1],r=t[4],n=i[4],a=void 0,s=void 0,o=void 0,u=[],d=[],l=void 0,f=void 0,c=void 0,h=void 0,p=void 0,m=void 0;for(a=0;256>a;a++)d[(u[a]=a<<1^283*(a>>7))^a]=a;for(s=o=0;!r[s];s^=l||1,o=d[o]||1)for(h=o^o<<1^o<<2^o<<3^o<<4,h=h>>8^255&h^99,r[s]=h,n[h]=s,c=u[f=u[l=u[s]]],m=16843009*c^65537*f^257*l^16843008*s,p=257*u[h]^16843008*h,a=0;4>a;a++)t[a][s]=p=p<<24^p>>>8,i[a][h]=m=m<<24^m>>>8;for(a=0;5>a;a++)t[a]=t[a].slice(0),i[a]=i[a].slice(0);return e},s=null,o=function(){function e(t){r(this,e),s||(s=a()),this._tables=[[s[0][0].slice(),s[0][1].slice(),s[0][2].slice(),s[0][3].slice(),s[0][4].slice()],[s[1][0].slice(),s[1][1].slice(),s[1][2].slice(),s[1][3].slice(),s[1][4].slice()]];var i=void 0,n=void 0,o=void 0,u=void 0,d=void 0,l=this._tables[0][4],f=this._tables[1],c=t.length,h=1;if(4!==c&&6!==c&&8!==c)throw new Error("Invalid aes key size");for(u=t.slice(0),d=[],this._key=[u,d],i=c;4*c+28>i;i++)o=u[i-1],(i%c===0||8===c&&i%c===4)&&(o=l[o>>>24]<<24^l[o>>16&255]<<16^l[o>>8&255]<<8^l[255&o],i%c===0&&(o=o<<8^o>>>24^h<<24,h=h<<1^283*(h>>7))),u[i]=u[i-c]^o;for(n=0;i;n++,i--)o=u[3&n?i:i-4],4>=i||4>n?d[n]=o:d[n]=f[0][l[o>>>24]]^f[1][l[o>>16&255]]^f[2][l[o>>8&255]]^f[3][l[255&o]]}return n(e,[{key:"decrypt",value:function(e,t,i,r,n,a){var s=this._key[1],o=e^s[0],u=r^s[1],d=i^s[2],l=t^s[3],f=void 0,c=void 0,h=void 0,p=s.length/4-2,m=void 0,y=4,g=this._tables[1],v=g[0],b=g[1],_=g[2],w=g[3],S=g[4];for(m=0;p>m;m++)f=v[o>>>24]^b[u>>16&255]^_[d>>8&255]^w[255&l]^s[y],c=v[u>>>24]^b[d>>16&255]^_[l>>8&255]^w[255&o]^s[y+1],h=v[d>>>24]^b[l>>16&255]^_[o>>8&255]^w[255&u]^s[y+2],l=v[l>>>24]^b[o>>16&255]^_[u>>8&255]^w[255&d]^s[y+3],y+=4,o=f,u=c,d=h;for(m=0;4>m;m++)n[(3&-m)+a]=S[o>>>24]<<24^S[u>>16&255]<<16^S[d>>8&255]<<8^S[255&l]^s[y++],f=o,o=u,u=d,d=l,l=f}}]),e}();i["default"]=o,t.exports=i["default"]},{}],4:[function(e,t,i){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}function n(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function a(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}Object.defineProperty(i,"__esModule",{value:!0});var s=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),o=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},u=e("../stream"),d=r(u),l=function(e){function t(){n(this,t),o(Object.getPrototypeOf(t.prototype),"constructor",this).call(this,d["default"]),this.jobs=[],this.delay=1,this.timeout_=null}return a(t,e),s(t,[{key:"processJob_",value:function(){this.jobs.shift()(),this.jobs.length?this.timeout_=setTimeout(this.processJob_.bind(this),this.delay):this.timeout_=null}},{key:"push",value:function(e){this.jobs.push(e),this.timeout_||(this.timeout_=setTimeout(this.processJob_.bind(this),this.delay))}}]),t}(d["default"]);i["default"]=l,t.exports=i["default"]},{"../stream":16}],5:[function(e,t,i){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}function n(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(i,"__esModule",{value:!0});var a=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),s=e("./aes"),o=r(s),u=e("./async-stream"),d=r(u),l=e("pkcs7"),f=function(e){return e<<24|(65280&e)<<8|(16711680&e)>>8|e>>>24},c=function(e,t,i){var r=new Int32Array(e.buffer,e.byteOffset,e.byteLength>>2),n=new o["default"](Array.prototype.slice.call(t)),a=new Uint8Array(e.byteLength),s=new Int32Array(a.buffer),u=void 0,d=void 0,l=void 0,c=void 0,h=void 0,p=void 0,m=void 0,y=void 0,g=void 0;for(u=i[0],d=i[1],l=i[2],c=i[3],g=0;g<r.length;g+=4)h=f(r[g]),p=f(r[g+1]),m=f(r[g+2]),y=f(r[g+3]),n.decrypt(h,p,m,y,s,g),s[g]=f(s[g]^u),s[g+1]=f(s[g+1]^d),s[g+2]=f(s[g+2]^l),s[g+3]=f(s[g+3]^c),u=h,d=p,l=m,c=y;return a};i.decrypt=c;var h=function(){function e(t,i,r,a){n(this,e);var s=e.STEP,o=new Int32Array(t.buffer),u=new Uint8Array(t.byteLength),c=0;for(this.asyncStream_=new d["default"],this.asyncStream_.push(this.decryptChunk_(o.subarray(c,c+s),i,r,u)),c=s;c<o.length;c+=s)r=new Uint32Array([f(o[c-4]),f(o[c-3]),f(o[c-2]),f(o[c-1])]),this.asyncStream_.push(this.decryptChunk_(o.subarray(c,c+s),i,r,u));this.asyncStream_.push(function(){a(null,(0,l.unpad)(u))})}return a(e,[{key:"decryptChunk_",value:function(e,t,i,r){return function(){var n=c(e,t,i);r.set(n,e.byteOffset)}}}],[{key:"STEP",get:function(){return 32e3}}]),e}();i.Decrypter=h,i["default"]={Decrypter:h,decrypt:c}},{"./aes":3,"./async-stream":4,pkcs7:62}],6:[function(e,t,i){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}Object.defineProperty(i,"__esModule",{value:!0});var n=e("./decrypter"),a=e("./async-stream"),s=r(a);i["default"]={decrypt:n.decrypt,Decrypter:n.Decrypter,AsyncStream:s["default"]},t.exports=i["default"]},{"./async-stream":4,"./decrypter":5}],7:[function(e,t,i){(function(r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function s(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}Object.defineProperty(i,"__esModule",{value:!0});var o=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),u=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},d="undefined"!=typeof window?window.videojs:"undefined"!=typeof r?r.videojs:null,l=e("./playlist-loader"),f=n(l),c=function(e){function t(e){a(this,t),u(Object.getPrototypeOf(t.prototype),"constructor",this).call(this,{kind:e["default"]?"main":"alternative",enabled:e["default"]||!1,language:e.language,label:e.label}),this.hls=e.hls,this.autoselect=e.autoselect||!1,this["default"]=e["default"]||!1,this.withCredentials=e.withCredentials||!1,this.mediaGroups_=[],this.addLoader(e.mediaGroup,e.resolvedUri)}return s(t,e),o(t,[{key:"getLoader",value:function(e){for(var t=0;t<this.mediaGroups_.length;t++){var i=this.mediaGroups_[t];if(i.mediaGroup===e)return i.loader}}},{key:"addLoader",value:function(e){var t=arguments.length<=1||void 0===arguments[1]?null:arguments[1],i=null;t&&(i=new f["default"](t,this.hls,this.withCredentials)),this.mediaGroups_.push({mediaGroup:e,loader:i})}},{key:"removeLoader",value:function(e){for(var t=0;t<this.mediaGroups_.length;t++){var i=this.mediaGroups_[t];if(i.mediaGroup===e)return i.loader&&i.loader.dispose(),void this.mediaGroups_.splice(t,1)}}},{key:"dispose",value:function(){for(var e=this.mediaGroups_.length;e--;)this.removeLoader(this.mediaGroups_[e].mediaGroup)}}]),t}(d.AudioTrack);i["default"]=c,t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./playlist-loader":9}],8:[function(e,t,i){(function(r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function s(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}Object.defineProperty(i,"__esModule",{value:!0});var o=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),u=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},d=e("./playlist-loader"),l=n(d),f=e("./segment-loader"),c=n(f),h=e("./ranges"),p=n(h),m="undefined"!=typeof window?window.videojs:"undefined"!=typeof r?r.videojs:null,y=n(m),g=e("./hls-audio-track"),v=n(g),b=3e5,_=void 0,w=function(e){var t={codecCount:0,videoCodec:null,audioProfile:null};return t.codecCount=e.split(",").length,t.codecCount=t.codecCount||2,t.videoCodec=/(^|\s|,)+(avc1)[^ ,]*/i.exec(e),t.videoCodec=t.videoCodec&&t.videoCodec[2],t.audioProfile=/(^|\s|,)+mp4a.\d+\.(\d+)/i.exec(e),t.audioProfile=t.audioProfile&&t.audioProfile[2],t},S=function(e){function t(e){var i=this,r=e.url,n=e.withCredentials,s=e.mode,o=e.tech,d=e.bandwidth,f=e.externHls;a(this,t),u(Object.getPrototypeOf(t.prototype),"constructor",this).call(this),_=f,this.withCredentials=n,this.tech_=o,this.hls_=o.hls,this.mode_=s,this.audioTracks_=[],this.mediaSource=new y["default"].MediaSource({mode:s}),this.mediaSource.on("audioinfo",function(e){return i.trigger(e)}),this.mediaSource.addEventListener("sourceopen",this.handleSourceOpen_.bind(this));var h={hls:this.hls_,mediaSource:this.mediaSource,currentTime:this.tech_.currentTime.bind(this.tech_),withCredentials:this.withCredentials,seekable:function(){return i.seekable()},seeking:function(){return i.tech_.seeking()},setCurrentTime:function(e){return i.tech_.setCurrentTime(e)},hasPlayed:function(){return 0!==i.tech_.played().length},bandwidth:d};if(this.mainSegmentLoader_=new c["default"](h),this.audioSegmentLoader_=new c["default"](h),!r)throw new Error("A non-empty playlist URL is required");this.masterPlaylistLoader_=new l["default"](r,this.hls_,this.withCredentials),this.masterPlaylistLoader_.on("loadedmetadata",function(){var e=i.masterPlaylistLoader_.media();e.endList&&"none"!==i.tech_.preload()&&(i.mainSegmentLoader_.playlist(e),i.mainSegmentLoader_.expired(i.masterPlaylistLoader_.expired_),i.mainSegmentLoader_.load()),i.setupSourceBuffer_(),i.setupFirstPlay(),i.useAudio()}),this.masterPlaylistLoader_.on("loadedplaylist",function(){var e=i.masterPlaylistLoader_.media(),t=void 0;return e?(i.mainSegmentLoader_.playlist(e),i.mainSegmentLoader_.expired(i.masterPlaylistLoader_.expired_),i.updateDuration(),t=i.seekable(),void(e.endList||0===t.length||i.mediaSource.addSeekableRange_(t.start(0),t.end(0)))):(i.initialMedia_=i.selectPlaylist(),i.masterPlaylistLoader_.media(i.initialMedia_),i.fillAudioTracks_(),void i.trigger("selectedinitialmedia"))}),this.masterPlaylistLoader_.on("error",function(){i.blacklistCurrentPlaylist(i.masterPlaylistLoader_.error)}),this.masterPlaylistLoader_.on("mediachanging",function(){i.mainSegmentLoader_.pause()}),this.masterPlaylistLoader_.on("mediachange",function(){var e=i.masterPlaylistLoader_.media();i.mainSegmentLoader_.abort(),i.mainSegmentLoader_.playlist(e),i.mainSegmentLoader_.expired(i.masterPlaylistLoader_.expired_),i.mainSegmentLoader_.load(),i.tech_.trigger({type:"mediachange",bubbles:!0})}),this.mainSegmentLoader_.on("progress",function(){i.masterPlaylistLoader_.media(i.selectPlaylist()),i.trigger("progress")}),this.mainSegmentLoader_.on("error",function(){i.blacklistCurrentPlaylist(i.mainSegmentLoader_.error())}),this.audioSegmentLoader_.on("error",function(){y["default"].log.warn("Problem encountered with the current alternate audio track. Switching back to default."),i.audioSegmentLoader_.abort(),i.audioPlaylistLoader_=null,i.useAudio()}),this.masterPlaylistLoader_.load()}return s(t,e),o(t,[{key:"mediaRequests_",value:function(){return this.audioSegmentLoader_.mediaRequests+this.mainSegmentLoader_.mediaRequests}},{key:"mediaTransferDuration_",value:function(){return this.audioSegmentLoader_.mediaTransferDuration+this.mainSegmentLoader_.mediaTransferDuration}},{key:"mediaBytesTransferred_",value:function(){return this.audioSegmentLoader_.mediaBytesTransferred+this.mainSegmentLoader_.mediaBytesTransferred}},{key:"fillAudioTracks_",value:function(){var e=this.master(),t=e.mediaGroups||{};t&&t.AUDIO&&0!==Object.keys(t.AUDIO).length&&"html5"===this.mode_||(t.AUDIO={main:{"default":{"default":!0}}});var i={};for(var r in t.AUDIO)for(var n in t.AUDIO[r]){var a=t.AUDIO[r][n];if(i[n])i[n].addLoader(r,a.resolvedUri);else{var s=new v["default"](y["default"].mergeOptions(a,{hls:this.hls_,withCredentials:this.withCredential,mediaGroup:r,label:n}));i[n]=s,this.audioTracks_.push(s)}}}},{key:"load",value:function(){this.mainSegmentLoader_.load(),this.audioPlaylistLoader_&&this.audioSegmentLoader_.load()}},{key:"activeAudioGroup",value:function(){var e=this.masterPlaylistLoader_.media(),t="main";return e&&e.attributes&&e.attributes.AUDIO&&(t=e.attributes.AUDIO),t}},{key:"useAudio",value:function(){var e=this,t=void 0;if(this.audioTracks_.forEach(function(e){!t&&e.enabled&&(t=e)}),t){this.audioPlaylistLoader_&&(this.audioPlaylistLoader_.pause(),this.audioPlaylistLoader_=null,this.audioSegmentLoader_.pause());var i=t.getLoader(this.activeAudioGroup());if(!i)return void this.mainSegmentLoader_.clearBuffer();if(this.audioPlaylistLoader_=i,this.audioPlaylistLoader_.started)return this.audioPlaylistLoader_.load(),this.audioSegmentLoader_.load(),void this.audioSegmentLoader_.clearBuffer();this.audioPlaylistLoader_.on("loadedmetadata",function(){var t=e.audioPlaylistLoader_.media();e.audioSegmentLoader_.playlist(t),e.addMimeType_(e.audioSegmentLoader_,"mp4a.40.2",t),(!e.tech_.paused()||t.endList&&"none"!==e.tech_.preload())&&e.audioSegmentLoader_.load(),t.endList||e.audioPlaylistLoader_.trigger("firstplay")}),this.audioPlaylistLoader_.on("loadedplaylist",function(){var t=void 0;return e.audioPlaylistLoader_&&(t=e.audioPlaylistLoader_.media()),t?void e.audioSegmentLoader_.playlist(t):void e.audioPlaylistLoader_.media(e.audioPlaylistLoader_.playlists.master.playlists[0])}),this.audioPlaylistLoader_.on("error",function(){y["default"].log.warn("Problem encountered loading the alternate audio track. Switching back to default."),e.audioSegmentLoader_.abort(),e.audioPlaylistLoader_=null,e.useAudio()}),this.audioSegmentLoader_.clearBuffer(),this.audioPlaylistLoader_.start()}}},{key:"fastQualityChange_",value:function(){var e=this.selectPlaylist();e!==this.masterPlaylistLoader_.media()&&(this.masterPlaylistLoader_.media(e),this.mainSegmentLoader_.sourceUpdater_.remove(this.tech_.currentTime()+5,1/0))}},{key:"play",value:function(){return this.setupFirstPlay()?void 0:(this.tech_.ended()&&this.tech_.setCurrentTime(0),this.load(),this.tech_.duration()===1/0&&this.tech_.currentTime()<this.tech_.seekable().start(0)?this.tech_.setCurrentTime(this.tech_.seekable().start(0)):void 0)}},{key:"setupFirstPlay",value:function(){var e=void 0,t=this.masterPlaylistLoader_.media();return!t||t.endList||this.tech_.paused()||this.hasPlayed_?!1:(this.load(),this.masterPlaylistLoader_.trigger("firstplay"),this.hasPlayed_=!0,e=this.seekable(),e.length&&this.tech_.setCurrentTime(e.end(0)),!0)}},{key:"handleSourceOpen_",value:function(){this.setupSourceBuffer_(),this.tech_.autoplay()&&this.tech_.play(),this.trigger("sourceopen")}},{key:"blacklistCurrentPlaylist",value:function(){var e=arguments.length<=0||void 0===arguments[0]?{}:arguments[0],t=void 0,i=void 0;return(t=e.playlist||this.masterPlaylistLoader_.media())?(t.excludeUntil=Date.now()+b,(i=this.selectPlaylist())?(y["default"].log.warn("Problem encountered with the current HLS playlist. Switching to another playlist."),this.masterPlaylistLoader_.media(i)):(y["default"].log.warn("Problem encountered with the current HLS playlist. No suitable alternatives found."),this.error=e,this.mediaSource.endOfStream("network"))):(this.error=e,this.mediaSource.endOfStream("network"))}},{key:"pauseLoading",value:function(){this.mainSegmentLoader_.pause(),this.audioPlaylistLoader_&&this.audioSegmentLoader_.pause()}},{key:"setCurrentTime",value:function(e){var t=p["default"].findRange(this.tech_.buffered(),e);return this.masterPlaylistLoader_&&this.masterPlaylistLoader_.media()&&this.masterPlaylistLoader_.media().segments?t&&t.length?e:(this.mainSegmentLoader_.abort(),this.audioPlaylistLoader_&&this.audioSegmentLoader_.abort(),void(this.tech_.paused()||(this.mainSegmentLoader_.load(),this.audioPlaylistLoader_&&this.audioSegmentLoader_.load()))):0}},{key:"duration",value:function(){return this.masterPlaylistLoader_?this.mediaSource?this.mediaSource.duration:_.Playlist.duration(this.masterPlaylistLoader_.media()):0}},{key:"seekable",value:function(){var e=void 0,t=void 0,i=void 0;return this.masterPlaylistLoader_&&(e=this.masterPlaylistLoader_.media())?(t=_.Playlist.seekable(e,this.masterPlaylistLoader_.expired_),0===t.length?t:this.audioPlaylistLoader_&&(i=_.Playlist.seekable(this.audioPlaylistLoader_.media(),this.audioPlaylistLoader_.expired_),0===i.length)?i:i?y["default"].createTimeRanges([[i.start(0)>t.start(0)?i.start(0):t.start(0),i.end(0)<t.end(0)?i.end(0):t.end(0)]]):t):y["default"].createTimeRanges()}},{key:"updateDuration",value:function(){var e=this,t=this.mediaSource.duration,i=_.Playlist.duration(this.masterPlaylistLoader_.media()),r=this.tech_.buffered(),n=function a(){e.mediaSource.duration=i,e.tech_.trigger("durationchange"),e.mediaSource.removeEventListener("sourceopen",a)};r.length>0&&(i=Math.max(i,r.end(r.length-1))),t!==i&&("open"!==this.mediaSource.readyState?this.mediaSource.addEventListener("sourceopen",n):n())}},{key:"dispose",value:function(){this.masterPlaylistLoader_.dispose(),this.audioTracks_.forEach(function(e){e.dispose()}),this.audioTracks_.length=0,this.mainSegmentLoader_.dispose(),this.audioSegmentLoader_.dispose()}},{key:"master",value:function(){return this.masterPlaylistLoader_.master}},{key:"media",value:function(){return this.masterPlaylistLoader_.media()||this.initialMedia_}},{key:"setupSourceBuffer_",value:function(){var e=this.masterPlaylistLoader_.media();e&&"open"===this.mediaSource.readyState&&(this.addMimeType_(this.mainSegmentLoader_,"avc1.4d400d, mp4a.40.2",e),this.excludeIncompatibleVariants_(e))}},{key:"addMimeType_",value:function(e,t,i){var r="video/mp2t";r+=i.attributes&&i.attributes.CODECS?'; codecs="'+i.attributes.CODECS+'"':'; codecs="'+t+'"',e.mimeType(r)}},{key:"excludeIncompatibleVariants_",value:function(e){var t=this.masterPlaylistLoader_.master,i=2,r=null,n=null,a=void 0;e.attributes&&e.attributes.CODECS&&(a=w(e.attributes.CODECS),r=a.videoCodec,n=a.audioProfile,i=a.codecCount),t.playlists.forEach(function(e){var t={codecCount:2,videoCodec:null,audioProfile:null};e.attributes&&e.attributes.CODECS&&(t=w(e.attributes.CODECS)),t.codecCount!==i&&(e.excludeUntil=1/0),t.videoCodec!==r&&(e.excludeUntil=1/0),("5"===t.audioProfile&&"5"!==n||"5"===n&&"5"!==t.audioProfile)&&(e.excludeUntil=1/0)})}}]),t}(y["default"].EventTarget);i["default"]=S,t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./hls-audio-track":7,"./playlist-loader":9,"./ranges":11,"./segment-loader":14}],9:[function(e,t,i){(function(r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}Object.defineProperty(i,"__esModule",{value:!0});var a=e("./resolve-url"),s=n(a),o="undefined"!=typeof window?window.videojs:"undefined"!=typeof r?r.videojs:null,u=e("./stream"),d=n(u),l=e("m3u8-parser"),f=n(l),c=function(e,t,i){var r=t.slice(),n=void 0,a=void 0;for(i=i||0,n=Math.min(e.length,t.length+i),a=i;n>a;a++)r[a-i]=(0,o.mergeOptions)(e[a],r[a-i]);return r},h=function(e,t){for(var i=!1,r=(0,o.mergeOptions)(e,{}),n=e.playlists.length,a=void 0,u=void 0,d=void 0;n--;)if(a=r.playlists[n],a.uri===t.uri){if(a.segments&&t.segments&&a.segments.length===t.segments.length&&a.mediaSequence===t.mediaSequence)continue;for(r.playlists[n]=(0,o.mergeOptions)(a,t),r.playlists[t.uri]=r.playlists[n],a.segments&&(r.playlists[n].segments=c(a.segments,t.segments,t.mediaSequence-a.mediaSequence)),d=0,r.playlists[n].segments&&(d=r.playlists[n].segments.length);d--;)u=r.playlists[n].segments[d],u.resolvedUri||(u.resolvedUri=(0,s["default"])(a.resolvedUri,u.uri)),u.key&&!u.key.resolvedUri&&(u.key.resolvedUri=(0,s["default"])(a.resolvedUri,u.key.uri));i=!0}return i?r:null},p=function m(e,t,i){var r=this,n=this,a=void 0,o=void 0,u=void 0,d=void 0,l=void 0;if(m.prototype.constructor.call(this),this.hls_=t,this.trackExpiredTime_=!1,!e)throw new Error("A non-empty playlist URL is required");d=function(e,t,i){n.setBandwidth(u||e),u=null,i&&(n.state=i),n.error={playlist:n.master.playlists[t],status:e.status,message:"HLS playlist request error at URL: "+t,responseText:e.responseText,code:e.status>=500?4:2},n.trigger("error")},l=function(e,t){var i=void 0,r=void 0,a=void 0;n.setBandwidth(u||e),u=null,n.state="HAVE_METADATA",i=new f["default"].Parser,i.push(e.responseText),i.end(),i.manifest.uri=t,a=h(n.master,i.manifest),r=1e3*(i.manifest.targetDuration||10),a?(n.master=a,n.updateMediaPlaylist_(i.manifest)):r/=2,n.media().endList||(window.clearTimeout(o),o=window.setTimeout(function(){n.trigger("mediaupdatetimeout")},r)),n.trigger("loadedplaylist")},n.state="HAVE_NOTHING",this.expired_=0,a=this.dispose,n.dispose=function(){n.stopRequest(),window.clearTimeout(o),a.call(this)},n.stopRequest=function(){if(u){var e=u;u=null,e.onreadystatechange=null,e.abort()}},n.media=function(e){var t=n.state,r=void 0;if(!e)return n.media_;if("HAVE_NOTHING"===n.state)throw new Error("Cannot switch media playlist from "+n.state);if("string"==typeof e){if(!n.master.playlists[e])throw new Error("Unknown playlist URI: "+e);e=n.master.playlists[e]}if(r=!n.media_||e.uri!==n.media_.uri,n.master.playlists[e.uri].endList)return u&&(u.onreadystatechange=null,u.abort(),u=null),n.state="HAVE_METADATA",n.media_=e,void(r&&(n.trigger("mediachanging"),n.trigger("mediachange")));if(r){if(n.state="SWITCHING_MEDIA",u){if((0,s["default"])(n.master.uri,e.uri)===u.url)return;u.onreadystatechange=null,u.abort(),u=null}this.media_&&this.trigger("mediachanging"),u=this.hls_.xhr({uri:(0,s["default"])(n.master.uri,e.uri),withCredentials:i},function(i,r){if(u){if(i)return d(u,e.uri,t);l(r,e.uri),"HAVE_MASTER"===t?n.trigger("loadedmetadata"):n.trigger("mediachange")}})}},n.setBandwidth=function(e){n.bandwidth=e.bandwidth},n.on("firstplay",function(){this.trackExpiredTime_=!0}),n.on("mediaupdatetimeout",function(){"HAVE_METADATA"===n.state&&(n.state="HAVE_CURRENT_METADATA",u=this.hls_.xhr({uri:(0,s["default"])(n.master.uri,n.media().uri),withCredentials:i},function(e,t){return u?e?d(u,n.media().uri):void l(u,n.media().uri):void 0}))}),n.pause=function(){n.stopRequest(),window.clearTimeout(o)},n.load=function(){n.started?n.media().endList?n.trigger("loadedplaylist"):n.trigger("mediaupdatetimeout"):n.start()},n.start=function(){n.started=!0,u=r.hls_.xhr({uri:e,withCredentials:i},function(t,i){var r=void 0,a=void 0,o=void 0;if(u){if(u=null,t)return n.error={status:i.status,message:"HLS playlist request error at URL: "+e,responseText:i.responseText,code:2},n.trigger("error");if(r=new f["default"].Parser,r.push(i.responseText),r.end(),n.state="HAVE_MASTER",r.manifest.uri=e,r.manifest.playlists){for(n.master=r.manifest,o=n.master.playlists.length;o--;)a=n.master.playlists[o],n.master.playlists[a.uri]=a,a.resolvedUri=(0,s["default"])(n.master.uri,a.uri);for(var d in n.master.mediaGroups.AUDIO)for(var c in n.master.mediaGroups.AUDIO[d]){var h=n.master.mediaGroups.AUDIO[d][c];h.uri&&(h.resolvedUri=(0,s["default"])(n.master.uri,h.uri))}return n.trigger("loadedplaylist"),void(u||n.media(r.manifest.playlists[0]))}return n.master={uri:window.location.href,playlists:[{uri:e}]},n.master.playlists[e]=n.master.playlists[0],n.master.playlists[0].resolvedUri=e,l(i,e),n.trigger("loadedmetadata")}})}};p.prototype=new d["default"],p.prototype.updateMediaPlaylist_=function(e){var t=void 0,i=void 0,r=void 0;if(t=this.media_,this.media_=this.master.playlists[e.uri],t&&this.trackExpiredTime_&&e.uri===t.uri){if(e.segments.length){if("undefined"!=typeof e.segments[0].start)return void(this.expired_=e.segments[0].start);if("undefined"!=typeof e.segments[0].end)return void(this.expired_=e.segments[0].end-e.segments[0].duration)}for(i=e.mediaSequence-t.mediaSequence-1;i>=0;i--)if(r=t.segments[i]){if("undefined"!=typeof r.end)return void(this.expired_=r.end);if("undefined"!=typeof r.start)return void(this.expired_=r.start+r.duration);this.expired_+=r.duration}else this.expired_+=t.targetDuration||10}},i["default"]=p,t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./resolve-url":13,"./stream":16,"m3u8-parser":56}],10:[function(e,t,i){(function(e){"use strict";Object.defineProperty(i,"__esModule",{value:!0});var t="undefined"!=typeof window?window.videojs:"undefined"!=typeof e?e.videojs:null,r={UNSAFE_LIVE_SEGMENTS:3},n=function(e,t){var i=0,r=t-e.mediaSequence,n=e.segments[r];if(n){if("undefined"!=typeof n.start)return{result:n.start,precise:!0};if("undefined"!=typeof n.end)return{result:n.end-n.duration,precise:!0}}for(;r--;){if(n=e.segments[r],"undefined"!=typeof n.end)return{result:i+n.end,precise:!0};if(i+=n.duration,"undefined"!=typeof n.start)return{result:i+n.start,precise:!0}}return{result:i,precise:!1}},a=function(e,t){for(var i=0,r=void 0,n=t-e.mediaSequence;n<e.segments.length;n++){if(r=e.segments[n],"undefined"!=typeof r.start)return{result:r.start-i,precise:!0};if(i+=r.duration,"undefined"!=typeof r.end)return{result:r.end-i,precise:!0}}return{result:-1,precise:!1}},s=function(e,t,i){var r=void 0,s=void 0;return"undefined"==typeof t&&(t=e.mediaSequence+e.segments.length),t<e.mediaSequence?0:(r=n(e,t),r.precise?r.result:(s=a(e,t),s.precise?s.result:r.result+i))},o=function(e,t,i){if(!e)return 0;if("number"!=typeof i&&(i=0),"undefined"==typeof t){if(e.totalDuration)return e.totalDuration;if(!e.endList)return window.Infinity}return s(e,t,i)};i.duration=o;var u=function(e,i){var n=void 0,a=void 0,u=void 0;return"number"!=typeof i&&(i=0),e&&e.segments?e.endList?(0,t.createTimeRange)(0,o(e)):(n=s(e,e.mediaSequence,i),u=Math.max(0,e.segments.length-r.UNSAFE_LIVE_SEGMENTS),a=s(e,e.mediaSequence+u,i),(0,t.createTimeRange)(n,a)):(0,t.createTimeRange)()};i.seekable=u;var d=function(e,t,i){var r=void 0,n=void 0,a=t,s=e.segments.length,o=s-1,u=void 0,d=void 0,l=void 0,f=void 0;if(!e)return 0;if(0>t)return 0;for(i=i||0,r=0;s>r;r++)if(n=e.segments[r],n.end){if(n.end>t){f=n.end,d=r;break}l=n.end,u=r+1}if(u===s)return s;if("undefined"!=typeof u){for(t-=l,r=u;(d||s)>r;r++)if(n=e.segments[r],t-=n.duration,0>t)return r;return r>=d?u+Math.floor((a-l)/(f-l)*(d-u)):o}if("undefined"!=typeof d){for(t=f-t,r=d;r>=0;r--)if(n=e.segments[r],t-=n.duration,0>t)return r;return 0===t?0:-1}if(t-=i,0>t)return-1;for(r=0;s>r;r++)if(n=e.segments[r],t-=n.duration,0>t)return r;return o};i.getMediaIndexForTime_=d,r.duration=o,r.seekable=u,r.getMediaIndexForTime_=d,i["default"]=r}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{}],11:[function(e,t,i){(function(e){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}Object.defineProperty(i,"__esModule",{value:!0});var n=function(){function e(e,t){var i=[],r=!0,n=!1,a=void 0;try{for(var s,o=e[Symbol.iterator]();!(r=(s=o.next()).done)&&(i.push(s.value),!t||i.length!==t);r=!0);}catch(u){n=!0,a=u}finally{try{!r&&o["return"]&&o["return"]()}finally{if(n)throw a}}return i}return function(t,i){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return e(t,i);throw new TypeError("Invalid attempt to destructure non-iterable instance")}}(),a="undefined"!=typeof window?window.videojs:"undefined"!=typeof e?e.videojs:null,s=r(a),o=1/30,u=function(e,t){var i=n(t,2),r=i[0],a=i[1];return Math.min(Math.max(r,e),a)},d=function(e,t){var i=[],r=void 0;if(e&&e.length)for(r=0;r<e.length;r++)t(e.start(r),e.end(r))&&i.push([e.start(r),e.end(r)]);return s["default"].createTimeRanges(i)},l=function(e,t){return d(e,function(e,i){return t>=e-o&&i+o>=t})},f=function(e,t){return d(e,function(e){return e-o>=t})},c=function(e,t){var i=void 0,r=void 0,n=void 0,a=[],s=[],o=function(e){return e[0]<=n&&e[1]>=n};if(e)for(i=0;i<e.length;i++)r=e.start(i),n=e.end(i),s.push([r,n]);if(t)for(i=0;i<t.length;i++)r=t.start(i),n=t.end(i),s.some(o)||a.push(n);return 1!==a.length?null:a[0]},h=function(e,t){var i=null,r=null,n=0,a=[],o=[];if(!(e&&e.length&&t&&t.length))return s["default"].createTimeRange();for(var u=e.length;u--;)a.push({time:e.start(u),type:"start"}),a.push({time:e.end(u),type:"end"});for(u=t.length;u--;)a.push({time:t.start(u),type:"start"}),a.push({time:t.end(u),type:"end"});for(a.sort(function(e,t){return e.time-t.time}),u=0;u<a.length;u++)"start"===a[u].type?(n++,2===n&&(i=a[u].time)):"end"===a[u].type&&(n--,1===n&&(r=a[u].time)),null!==i&&null!==r&&(o.push([i,r]),i=null,r=null);return s["default"].createTimeRanges(o);
},p=function(e,t,i,r){for(var n=t.end(0)-t.start(0),a=e.end(0)-e.start(0),s=n-a,o=h(e,r),u=h(t,r),d=0,l=0,f=o.length;f--;)d+=o.end(f)-o.start(f),o.start(f)===i&&(d+=s);for(f=u.length;f--;)l+=u.end(f)-u.start(f);return Math.max(d,l)/n*100},m=function(e,t,i,r){var n=e+t,a=s["default"].createTimeRanges([[e,n]]),o=s["default"].createTimeRanges([[u(e,[i,n]),n]]);if(o.start(0)===o.end(0))return 0;var d=p(o,a,i,r);return isNaN(d)||d===1/0||d===-(1/0)?0:d};i["default"]={findRange:l,findNextRange:f,findSoleUncommonTimeRangesEnd:c,getSegmentBufferedPercent:m,TIME_FUDGE_FACTOR:o},t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{}],12:[function(e,t,i){"use strict";function r(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(i,"__esModule",{value:!0});var n=function(e,t,i){var r="undefined"==typeof e.excludeUntil||e.excludeUntil<=Date.now();return"undefined"==typeof i?r:(i!==r&&(i?delete e.excludeUntil:e.excludeUntil=1/0,t()),i)},a=function o(e,t,i){r(this,o);var a=e.masterPlaylistController_.fastQualityChange_.bind(e.masterPlaylistController_);if(t.attributes){var s=t.attributes;if(s.RESOLUTION){var u=s.RESOLUTION;this.width=u.width,this.height=u.height}this.bandwidth=s.BANDWIDTH}this.id=i,this.enabled=n.bind(this,t,a)},s=function(e){var t=e.playlists;e.representations=function(){return t.master.playlists.map(function(t,i){return new a(e,t,i)})}};i["default"]=s,t.exports=i["default"]},{}],13:[function(e,t,i){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}Object.defineProperty(i,"__esModule",{value:!0});var n=e("global/document"),a=r(n),s=function(e,t){var i=a["default"].querySelector("base"),r=a["default"].querySelector("head"),n=a["default"].createElement("a"),s=i,o=void 0,u=void 0;return i?o=i.href:s=r.appendChild(a["default"].createElement("base")),s.href=e,n.href=t,u=n.href,i?i.href=o:r.removeChild(s),u};i["default"]=s,t.exports=i["default"]},{"global/document":19}],14:[function(e,t,i){(function(r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function s(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}Object.defineProperty(i,"__esModule",{value:!0});var o=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),u=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},d=e("./ranges"),l=n(d),f=e("./playlist"),c="undefined"!=typeof window?window.videojs:"undefined"!=typeof r?r.videojs:null,h=n(c),p=e("./source-updater"),m=n(p),y=e("./decrypter"),g=e("./config"),v=n(g),b=500,_=function(e,t,i){if(!e)return!1;var r=e.segments[t],n=e.segments[t-1];return i&&r?(r.end=i,n?n.end&&(r.duration=r.end-n.end):r.duration=r.end,!0):!1},w=function(e,t,i,r){if(!e)return!1;var n=e.segments,a=i===n.length-1,s=r.length&&n[n.length-1].end<=r.end(0);return e.endList&&"open"===t.readyState&&(a||s)},S=function(e){var t=void 0,i=void 0;return i=e.offset+e.length-1,t=e.offset,"bytes="+t+"-"+i},T=function(e){var t={};return"byterange"in e&&(t.Range=S(e.byterange)),t},k=function(e){function t(e){a(this,t),u(Object.getPrototypeOf(t.prototype),"constructor",this).call(this);var i=void 0;if(!e)throw new TypeError("Initialization options are required");if("function"!=typeof e.currentTime)throw new TypeError("No currentTime getter specified");if(!e.mediaSource)throw new TypeError("No MediaSource specified");i=h["default"].mergeOptions(h["default"].options.hls,e),this.state="INIT",this.bandwidth=i.bandwidth,this.roundTrip=NaN,this.resetStats_(),this.hasPlayed_=i.hasPlayed,this.currentTime_=i.currentTime,this.seekable_=i.seekable,this.seeking_=i.seeking,this.setCurrentTime_=i.setCurrentTime,this.mediaSource_=i.mediaSource,this.withCredentials_=i.withCredentials,this.checkBufferTimeout_=null,this.error_=void 0,this.expired_=0,this.timeCorrection_=0,this.currentTimeline_=-1,this.xhr_=null,this.pendingSegment_=null,this.sourceUpdater_=null,this.hls_=i.hls}return s(t,e),o(t,[{key:"resetStats_",value:function(){this.mediaBytesTransferred=0,this.mediaRequests=0,this.mediaTransferDuration=0}},{key:"dispose",value:function(){this.state="DISPOSED",this.abort_(),this.sourceUpdater_&&this.sourceUpdater_.dispose(),this.resetStats_()}},{key:"abort",value:function(){"WAITING"===this.state&&(this.abort_(),this.paused()||(this.state="READY",this.fillBuffer_()))}},{key:"error",value:function(e){return"undefined"!=typeof e&&(this.error_=e),this.pendingSegment_=null,this.error_}},{key:"load",value:function(){this.monitorBuffer_(),this.playlist_&&(!this.sourceUpdater_||"READY"!==this.state&&"INIT"!==this.state||(this.state="READY",this.fillBuffer_()))}},{key:"playlist",value:function(e){return this.playlist_=e,this.sourceUpdater_&&e&&"INIT"===this.state&&!this.paused()?(this.state="READY",this.fillBuffer_()):void 0}},{key:"pause",value:function(){this.checkBufferTimeout_&&(window.clearTimeout(this.checkBufferTimeout_),this.checkBufferTimeout_=null)}},{key:"paused",value:function(){return null===this.checkBufferTimeout_}},{key:"expired",value:function(e){this.expired_=e}},{key:"mimeType",value:function(e){return this.sourceUpdater_||(this.sourceUpdater_=new m["default"](this.mediaSource_,e),this.clearBuffer(),!this.playlist_||"INIT"!==this.state||this.paused())?void 0:(this.state="READY",this.fillBuffer_())}},{key:"monitorBuffer_",value:function(){"READY"===this.state&&this.fillBuffer_(),this.checkBufferTimeout_&&window.clearTimeout(this.checkBufferTimeout_),this.checkBufferTimeout_=window.setTimeout(this.monitorBuffer_.bind(this),b)}},{key:"checkBuffer_",value:function(e,t,i){var r=l["default"].findRange(e,i);0===r.length&&0===i&&(r=l["default"].findRange(e,i+l["default"].TIME_FUDGE_FACTOR));var n=void 0,a=void 0,s=this.sourceUpdater_.timestampOffset(),o=void 0,u=void 0;if(t.segments.length){if(0===r.length)u=(0,f.getMediaIndexForTime_)(t,i+this.timeCorrection_,this.expired_);else{if(a=r.end(0),n=Math.max(0,a-i),!this.hasPlayed_()&&n>=1)return null;if(this.hasPlayed_()&&n>=v["default"].GOAL_BUFFER_LENGTH)return null;u=(0,f.getMediaIndexForTime_)(t,a+this.timeCorrection_,this.expired_)}if(0>u||u===t.segments.length)return null;o=t.segments[u];var d=(0,f.duration)(t,t.mediaSequence+u,this.expired_);return(o.timeline!==this.currentTimeline_||d<this.sourceUpdater_.timestampOffset())&&(s=d),{uri:o.resolvedUri,mediaIndex:u,playlist:t,bytes:null,encryptedBytes:null,buffered:null,timestampOffset:s,timeline:o.timeline,duration:o.duration}}}},{key:"abort_",value:function(){this.xhr_&&this.xhr_.abort(),this.pendingSegment_=null}},{key:"fillBuffer_",value:function(){if(!this.sourceUpdater_.updating()){var e=this.checkBuffer_(this.sourceUpdater_.buffered(),this.playlist_,this.currentTime_(),this.timestampOffset_);if(e&&(e.mediaIndex!==this.playlist_.segments.length-1||"ended"!==this.mediaSource_.readyState||this.seeking_())){var t=this.playlist_.segments[e.mediaIndex],i=(0,f.duration)(this.playlist_,this.playlist_.mediaSequence+e.mediaIndex,this.expired_),r=l["default"].getSegmentBufferedPercent(i,t.duration,this.currentTime_(),this.sourceUpdater_.buffered());if(r>=90){var n=this.incrementTimeCorrection_(this.playlist_.targetDuration/2,1);return void(n&&!this.paused()&&this.fillBuffer_())}this.loadSegment_(e)}}}},{key:"loadSegment_",value:function(e){var t=void 0,i=void 0,r=void 0,n=void 0,a=this.seekable_(),s=this.currentTime_(),o=0;o=a.length&&a.start(0)>0&&a.start(0)<s?a.start(0):s-60,o>0&&this.sourceUpdater_.remove(0,o),t=e.playlist.segments[e.mediaIndex],i=1.5*t.duration*1e3,t.key&&(r=this.hls_.xhr({uri:t.key.resolvedUri,responseType:"arraybuffer",withCredentials:this.withCredentials_,timeout:i},this.handleResponse_.bind(this))),this.pendingSegment_=e,n=this.hls_.xhr({uri:e.uri,responseType:"arraybuffer",withCredentials:this.withCredentials_,timeout:i,headers:T(t)},this.handleResponse_.bind(this)),this.xhr_={keyXhr:r,segmentXhr:n,abort:function(){this.segmentXhr&&(this.segmentXhr.onreadystatechange=null,this.segmentXhr.abort(),this.segmentXhr=null),this.keyXhr&&(this.keyXhr.onreadystatechange=null,this.keyXhr.abort(),this.keyXhr=null)}},this.state="WAITING"}},{key:"handleResponse_",value:function(e,t){var i=void 0,r=void 0,n=void 0,a=void 0;if(this.xhr_&&(t===this.xhr_.segmentXhr||t===this.xhr_.keyXhr)){if(i=this.pendingSegment_,r=i.playlist.segments[i.mediaIndex],t.timedout)return this.abort_(),this.bandwidth=1,this.roundTrip=NaN,this.state="READY",this.trigger("progress");if(!t.aborted&&e)return n=this.xhr_.keyXhr,this.abort_(),this.error({status:t.status,message:t===n?"HLS key request error at URL: "+r.key.uri:"HLS segment request error at URL: "+i.uri,code:2,xhr:t}),this.state="READY",this.pause(),this.trigger("error");if(!t.response)return void this.abort_();if(t===this.xhr_.segmentXhr&&(this.xhr_.segmentXhr=null,this.roundTrip=t.roundTripTime,this.bandwidth=t.bandwidth,this.mediaBytesTransferred+=t.bytesReceived||0,this.mediaRequests+=1,this.mediaTransferDuration+=t.roundTripTime||0,r.key?i.encryptedBytes=new Uint8Array(t.response):i.bytes=new Uint8Array(t.response)),t===this.xhr_.keyXhr){if(n=this.xhr_.segmentXhr,this.xhr_.keyXhr=null,16!==t.response.byteLength)return this.abort_(),this.error({status:t.status,message:"Invalid HLS key at URL: "+r.key.uri,code:2,xhr:t}),this.state="READY",this.pause(),this.trigger("error");a=new DataView(t.response),r.key.bytes=new Uint32Array([a.getUint32(0),a.getUint32(4),a.getUint32(8),a.getUint32(12)]),r.key.iv=r.key.iv||new Uint32Array([0,0,0,i.mediaIndex+i.playlist.mediaSequence])}this.xhr_.segmentXhr||this.xhr_.keyXhr||(this.xhr_=null,this.processResponse_())}}},{key:"clearBuffer",value:function(){this.sourceUpdater_&&this.sourceUpdater_.buffered().length&&this.sourceUpdater_.remove(0,1/0)}},{key:"processResponse_",value:function(){var e=void 0,t=void 0;this.state="DECRYPTING",e=this.pendingSegment_,t=e.playlist.segments[e.mediaIndex],t.key?new y.Decrypter(e.encryptedBytes,t.key.bytes,t.key.iv,function(t,i){e.bytes=i,this.handleSegment_()}.bind(this)):this.handleSegment_()}},{key:"handleSegment_",value:function(){var e=void 0;this.state="APPENDING",e=this.pendingSegment_,e.buffered=this.sourceUpdater_.buffered(),this.currentTimeline_=e.timeline,e.timestampOffset!==this.sourceUpdater_.timestampOffset()&&this.sourceUpdater_.timestampOffset(e.timestampOffset),this.sourceUpdater_.appendBuffer(e.bytes,this.handleUpdateEnd_.bind(this))}},{key:"handleUpdateEnd_",value:function(){var e=this.pendingSegment_,t=this.currentTime_();this.pendingSegment_=null;var i=this.updateTimeline_(e);this.trigger("progress");var r=e.mediaIndex;r+=e.playlist.mediaSequence-this.playlist_.mediaSequence;var n=l["default"].findRange(this.sourceUpdater_.buffered(),t),a=w(e.playlist,this.mediaSource_,r,n);a&&this.mediaSource_.endOfStream();var s=this.seekable_(),o=l["default"].findNextRange(this.sourceUpdater_.buffered(),t);if(this.seeking_()&&0===n.length&&s.length&&t<s.start(0)&&o.length&&(h["default"].log("tried seeking to",t,"but that was too early, retrying at",o.start(0)),this.setCurrentTime_(o.start(0)+l["default"].TIME_FUDGE_FACTOR)),this.state="READY",i)return this.timeCorrection_=0,void(this.paused()||this.fillBuffer_());var u=this.incrementTimeCorrection_(e.duration,4);u&&!this.paused()&&this.fillBuffer_()}},{key:"updateTimeline_",value:function(e){var t=void 0,i=void 0,r=!1,n=e.playlist,a=e.mediaIndex;return a+=n.mediaSequence-this.playlist_.mediaSequence,t=n.segments[a],t&&e&&e.playlist.uri===this.playlist_.uri&&(i=l["default"].findSoleUncommonTimeRangesEnd(e.buffered,this.sourceUpdater_.buffered()),r=_(n,a,i)),r}},{key:"incrementTimeCorrection_",value:function(e,t){return this.timeCorrection_>=this.playlist_.targetDuration*t?(this.timeCorrection_=0,!1):(this.timeCorrection_+=e,!0)}}]),t}(h["default"].EventTarget);i["default"]=k,t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./config":2,"./decrypter":6,"./playlist":10,"./ranges":11,"./source-updater":15}],15:[function(e,t,i){(function(e){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}function n(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(i,"__esModule",{value:!0});var a=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),s="undefined"!=typeof window?window.videojs:"undefined"!=typeof e?e.videojs:null,o=r(s),u=function(){function e(t,i){var r=this;n(this,e);var a=function(){r.sourceBuffer_=t.addSourceBuffer(i),r.onUpdateendCallback_=function(){var e=r.pendingCallback_;r.pendingCallback_=null,e&&e(),r.runCallback_()},r.sourceBuffer_.addEventListener("updateend",r.onUpdateendCallback_),r.runCallback_()};this.callbacks_=[],this.pendingCallback_=null,this.timestampOffset_=0,this.mediaSource=t,"closed"===t.readyState?t.addEventListener("sourceopen",a):a()}return a(e,[{key:"abort",value:function(e){var t=this;this.queueCallback_(function(){t.sourceBuffer_.abort()},e)}},{key:"appendBuffer",value:function(e,t){var i=this;this.queueCallback_(function(){i.sourceBuffer_.appendBuffer(e)},t)}},{key:"buffered",value:function(){return this.sourceBuffer_?this.sourceBuffer_.buffered:o["default"].createTimeRanges()}},{key:"duration",value:function(e){var t=this;this.queueCallback_(function(){t.sourceBuffer_.duration=e})}},{key:"remove",value:function(e,t){var i=this;this.queueCallback_(function(){i.sourceBuffer_.remove(e,t)})}},{key:"updating",value:function(){return!this.sourceBuffer_||this.sourceBuffer_.updating}},{key:"timestampOffset",value:function(e){var t=this;return"undefined"!=typeof e&&(this.queueCallback_(function(){t.sourceBuffer_.timestampOffset=e}),this.timestampOffset_=e),this.timestampOffset_}},{key:"queueCallback_",value:function(e,t){this.callbacks_.push([e.bind(this),t]),this.runCallback_()}},{key:"runCallback_",value:function(){var e=void 0;this.sourceBuffer_&&!this.sourceBuffer_.updating&&this.callbacks_.length&&(e=this.callbacks_.shift(),this.pendingCallback_=e[1],e[0]())}},{key:"dispose",value:function(){this.sourceBuffer_.removeEventListener("updateend",this.onUpdateendCallback_),this.sourceBuffer_&&"open"===this.mediaSource.readyState&&this.sourceBuffer_.abort()}}]),e}();i["default"]=u,t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{}],16:[function(e,t,i){"use strict";function r(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(i,"__esModule",{value:!0});var n=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),a=function(){function e(){r(this,e),this.listeners={}}return n(e,[{key:"on",value:function(e,t){this.listeners[e]||(this.listeners[e]=[]),this.listeners[e].push(t)}},{key:"off",value:function(e,t){var i=void 0;return this.listeners[e]?(i=this.listeners[e].indexOf(t),this.listeners[e].splice(i,1),i>-1):!1}},{key:"trigger",value:function(e){var t=void 0,i=void 0,r=void 0,n=void 0;if(t=this.listeners[e])if(2===arguments.length)for(r=t.length,i=0;r>i;++i)t[i].call(this,arguments[1]);else for(n=Array.prototype.slice.call(arguments,1),r=t.length,i=0;r>i;++i)t[i].apply(this,n)}},{key:"dispose",value:function(){this.listeners={}}},{key:"pipe",value:function(e){this.on("data",function(t){e.push(t)})}}]),e}();i["default"]=a,t.exports=i["default"]},{}],17:[function(e,t,i){(function(e){"use strict";Object.defineProperty(i,"__esModule",{value:!0});var r="undefined"!=typeof window?window.videojs:"undefined"!=typeof e?e.videojs:null,n=function(){var e=function t(e,i){if(e=(0,r.mergeOptions)({timeout:45e3},e),t.beforeRequest&&"function"==typeof t.beforeRequest){var n=t.beforeRequest(e);n&&(e=n)}var a=(0,r.xhr)(e,function(e,t){!e&&a.response&&(a.responseTime=(new Date).getTime(),a.roundTripTime=a.responseTime-a.requestTime,a.bytesReceived=a.response.byteLength||a.response.length,a.bandwidth||(a.bandwidth=Math.floor(a.bytesReceived/a.roundTripTime*8*1e3))),e||a.timedout?a.timedout=a.timedout||"ETIMEDOUT"===e.code:a.timedout=!1,e||200===t.statusCode||206===t.statusCode||0===t.statusCode||(e=new Error("XHR Failed with a response of: "+(a&&(a.response||a.responseText)))),i(e,a)});return a.requestTime=(new Date).getTime(),a};return e};i["default"]=n,t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{}],18:[function(e,t,i){},{}],19:[function(e,t,i){(function(i){var r="undefined"!=typeof i?i:"undefined"!=typeof window?window:{},n=e("min-document");if("undefined"!=typeof document)t.exports=document;else{var a=r["__GLOBAL_DOCUMENT_CACHE@4"];a||(a=r["__GLOBAL_DOCUMENT_CACHE@4"]=n),t.exports=a}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"min-document":18}],20:[function(e,t,i){function r(e,t){if("function"!=typeof e)throw new TypeError(n);return t=a(void 0===t?e.length-1:+t||0,0),function(){for(var i=arguments,r=-1,n=a(i.length-t,0),s=Array(n);++r<n;)s[r]=i[t+r];switch(t){case 0:return e.call(this,s);case 1:return e.call(this,i[0],s);case 2:return e.call(this,i[0],i[1],s)}var o=Array(t+1);for(r=-1;++r<t;)o[r]=i[r];return o[t]=s,e.apply(this,o)}}var n="Expected a function",a=Math.max;t.exports=r},{}],21:[function(e,t,i){function r(e,t){var i=-1,r=e.length;for(t||(t=Array(r));++i<r;)t[i]=e[i];return t}t.exports=r},{}],22:[function(e,t,i){function r(e,t){for(var i=-1,r=e.length;++i<r&&t(e[i],i,e)!==!1;);return e}t.exports=r},{}],23:[function(e,t,i){function r(e,t,i){i||(i={});for(var r=-1,n=t.length;++r<n;){var a=t[r];i[a]=e[a]}return i}t.exports=r},{}],24:[function(e,t,i){var r=e("./createBaseFor"),n=r();t.exports=n},{"./createBaseFor":31}],25:[function(e,t,i){function r(e,t){return n(e,t,a)}var n=e("./baseFor"),a=e("../object/keysIn");t.exports=r},{"../object/keysIn":52,"./baseFor":24}],26:[function(e,t,i){function r(e,t,i,c,h){if(!u(e))return e;var p=o(t)&&(s(t)||l(t)),m=p?void 0:f(t);return n(m||t,function(n,s){if(m&&(s=n,n=t[s]),d(n))c||(c=[]),h||(h=[]),a(e,t,s,r,i,c,h);else{var o=e[s],u=i?i(o,n,s,e,t):void 0,l=void 0===u;l&&(u=n),void 0===u&&(!p||s in e)||!l&&(u===u?u===o:o!==o)||(e[s]=u)}}),e}var n=e("./arrayEach"),a=e("./baseMergeDeep"),s=e("../lang/isArray"),o=e("./isArrayLike"),u=e("../lang/isObject"),d=e("./isObjectLike"),l=e("../lang/isTypedArray"),f=e("../object/keys");t.exports=r},{"../lang/isArray":43,"../lang/isObject":46,"../lang/isTypedArray":49,"../object/keys":51,"./arrayEach":22,"./baseMergeDeep":27,"./isArrayLike":34,"./isObjectLike":39}],27:[function(e,t,i){function r(e,t,i,r,f,c,h){for(var p=c.length,m=t[i];p--;)if(c[p]==m)return void(e[i]=h[p]);var y=e[i],g=f?f(y,m,i,e,t):void 0,v=void 0===g;v&&(g=m,o(m)&&(s(m)||d(m))?g=s(y)?y:o(y)?n(y):[]:u(m)||a(m)?g=a(y)?l(y):u(y)?y:{}:v=!1),c.push(m),h.push(g),v?e[i]=r(g,m,f,c,h):(g===g?g!==y:y===y)&&(e[i]=g)}var n=e("./arrayCopy"),a=e("../lang/isArguments"),s=e("../lang/isArray"),o=e("./isArrayLike"),u=e("../lang/isPlainObject"),d=e("../lang/isTypedArray"),l=e("../lang/toPlainObject");t.exports=r},{"../lang/isArguments":42,"../lang/isArray":43,"../lang/isPlainObject":47,"../lang/isTypedArray":49,"../lang/toPlainObject":50,"./arrayCopy":21,"./isArrayLike":34}],28:[function(e,t,i){function r(e){return function(t){return null==t?void 0:n(t)[e]}}var n=e("./toObject");t.exports=r},{"./toObject":41}],29:[function(e,t,i){function r(e,t,i){if("function"!=typeof e)return n;if(void 0===t)return e;switch(i){case 1:return function(i){return e.call(t,i)};case 3:return function(i,r,n){return e.call(t,i,r,n)};case 4:return function(i,r,n,a){return e.call(t,i,r,n,a)};case 5:return function(i,r,n,a,s){return e.call(t,i,r,n,a,s)}}return function(){return e.apply(t,arguments)}}var n=e("../utility/identity");t.exports=r},{"../utility/identity":55}],30:[function(e,t,i){function r(e){return s(function(t,i){var r=-1,s=null==t?0:i.length,o=s>2?i[s-2]:void 0,u=s>2?i[2]:void 0,d=s>1?i[s-1]:void 0;for("function"==typeof o?(o=n(o,d,5),s-=2):(o="function"==typeof d?d:void 0,s-=o?1:0),u&&a(i[0],i[1],u)&&(o=3>s?void 0:o,s=1);++r<s;){var l=i[r];l&&e(t,l,o)}return t})}var n=e("./bindCallback"),a=e("./isIterateeCall"),s=e("../function/restParam");t.exports=r},{"../function/restParam":20,"./bindCallback":29,"./isIterateeCall":37}],31:[function(e,t,i){function r(e){return function(t,i,r){for(var a=n(t),s=r(t),o=s.length,u=e?o:-1;e?u--:++u<o;){var d=s[u];if(i(a[d],d,a)===!1)break}return t}}var n=e("./toObject");t.exports=r},{"./toObject":41}],32:[function(e,t,i){var r=e("./baseProperty"),n=r("length");t.exports=n},{"./baseProperty":28}],33:[function(e,t,i){function r(e,t){var i=null==e?void 0:e[t];return n(i)?i:void 0}var n=e("../lang/isNative");t.exports=r},{"../lang/isNative":45}],34:[function(e,t,i){function r(e){return null!=e&&a(n(e))}var n=e("./getLength"),a=e("./isLength");t.exports=r},{"./getLength":32,"./isLength":38}],35:[function(e,t,i){var r=function(){try{Object({toString:0}+"")}catch(e){return function(){return!1}}return function(e){return"function"!=typeof e.toString&&"string"==typeof(e+"")}}();t.exports=r},{}],36:[function(e,t,i){function r(e,t){return e="number"==typeof e||n.test(e)?+e:-1,t=null==t?a:t,e>-1&&e%1==0&&t>e}var n=/^\d+$/,a=9007199254740991;t.exports=r},{}],37:[function(e,t,i){function r(e,t,i){if(!s(i))return!1;var r=typeof t;if("number"==r?n(i)&&a(t,i.length):"string"==r&&t in i){var o=i[t];return e===e?e===o:o!==o}return!1}var n=e("./isArrayLike"),a=e("./isIndex"),s=e("../lang/isObject");t.exports=r},{"../lang/isObject":46,"./isArrayLike":34,"./isIndex":36}],38:[function(e,t,i){function r(e){return"number"==typeof e&&e>-1&&e%1==0&&n>=e}var n=9007199254740991;t.exports=r},{}],39:[function(e,t,i){function r(e){return!!e&&"object"==typeof e}t.exports=r},{}],40:[function(e,t,i){function r(e){for(var t=d(e),i=t.length,r=i&&e.length,l=!!r&&o(r)&&(a(e)||n(e)||u(e)),c=-1,h=[];++c<i;){var p=t[c];(l&&s(p,r)||f.call(e,p))&&h.push(p)}return h}var n=e("../lang/isArguments"),a=e("../lang/isArray"),s=e("./isIndex"),o=e("./isLength"),u=e("../lang/isString"),d=e("../object/keysIn"),l=Object.prototype,f=l.hasOwnProperty;t.exports=r},{"../lang/isArguments":42,"../lang/isArray":43,"../lang/isString":48,"../object/keysIn":52,"./isIndex":36,"./isLength":38}],41:[function(e,t,i){function r(e){if(s.unindexedChars&&a(e)){for(var t=-1,i=e.length,r=Object(e);++t<i;)r[t]=e.charAt(t);return r}return n(e)?e:Object(e)}var n=e("../lang/isObject"),a=e("../lang/isString"),s=e("../support");t.exports=r},{"../lang/isObject":46,"../lang/isString":48,"../support":54}],42:[function(e,t,i){function r(e){return a(e)&&n(e)&&o.call(e,"callee")&&!u.call(e,"callee")}var n=e("../internal/isArrayLike"),a=e("../internal/isObjectLike"),s=Object.prototype,o=s.hasOwnProperty,u=s.propertyIsEnumerable;t.exports=r},{"../internal/isArrayLike":34,"../internal/isObjectLike":39}],43:[function(e,t,i){var r=e("../internal/getNative"),n=e("../internal/isLength"),a=e("../internal/isObjectLike"),s="[object Array]",o=Object.prototype,u=o.toString,d=r(Array,"isArray"),l=d||function(e){return a(e)&&n(e.length)&&u.call(e)==s};t.exports=l},{"../internal/getNative":33,"../internal/isLength":38,"../internal/isObjectLike":39}],44:[function(e,t,i){function r(e){return n(e)&&o.call(e)==a}var n=e("./isObject"),a="[object Function]",s=Object.prototype,o=s.toString;t.exports=r},{"./isObject":46}],45:[function(e,t,i){function r(e){return null==e?!1:n(e)?f.test(d.call(e)):s(e)&&(a(e)?f:o).test(e)}var n=e("./isFunction"),a=e("../internal/isHostObject"),s=e("../internal/isObjectLike"),o=/^\[object .+?Constructor\]$/,u=Object.prototype,d=Function.prototype.toString,l=u.hasOwnProperty,f=RegExp("^"+d.call(l).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$");t.exports=r},{"../internal/isHostObject":35,"../internal/isObjectLike":39,"./isFunction":44}],46:[function(e,t,i){function r(e){var t=typeof e;return!!e&&("object"==t||"function"==t)}t.exports=r},{}],47:[function(e,t,i){function r(e){var t;if(!o(e)||c.call(e)!=d||s(e)||a(e)||!f.call(e,"constructor")&&(t=e.constructor,"function"==typeof t&&!(t instanceof t)))return!1;var i;return u.ownLast?(n(e,function(e,t,r){return i=f.call(r,t),!1}),i!==!1):(n(e,function(e,t){i=t}),void 0===i||f.call(e,i))}var n=e("../internal/baseForIn"),a=e("./isArguments"),s=e("../internal/isHostObject"),o=e("../internal/isObjectLike"),u=e("../support"),d="[object Object]",l=Object.prototype,f=l.hasOwnProperty,c=l.toString;t.exports=r},{"../internal/baseForIn":25,"../internal/isHostObject":35,"../internal/isObjectLike":39,"../support":54,"./isArguments":42}],48:[function(e,t,i){function r(e){return"string"==typeof e||n(e)&&o.call(e)==a}var n=e("../internal/isObjectLike"),a="[object String]",s=Object.prototype,o=s.toString;t.exports=r},{"../internal/isObjectLike":39}],49:[function(e,t,i){function r(e){return a(e)&&n(e.length)&&!!L[E.call(e)]}var n=e("../internal/isLength"),a=e("../internal/isObjectLike"),s="[object Arguments]",o="[object Array]",u="[object Boolean]",d="[object Date]",l="[object Error]",f="[object Function]",c="[object Map]",h="[object Number]",p="[object Object]",m="[object RegExp]",y="[object Set]",g="[object String]",v="[object WeakMap]",b="[object ArrayBuffer]",_="[object Float32Array]",w="[object Float64Array]",S="[object Int8Array]",T="[object Int16Array]",k="[object Int32Array]",O="[object Uint8Array]",P="[object Uint8ClampedArray]",x="[object Uint16Array]",A="[object Uint32Array]",L={};L[_]=L[w]=L[S]=L[T]=L[k]=L[O]=L[P]=L[x]=L[A]=!0,L[s]=L[o]=L[b]=L[u]=L[d]=L[l]=L[f]=L[c]=L[h]=L[p]=L[m]=L[y]=L[g]=L[v]=!1;var j=Object.prototype,E=j.toString;t.exports=r},{"../internal/isLength":38,"../internal/isObjectLike":39}],50:[function(e,t,i){function r(e){return n(e,a(e))}var n=e("../internal/baseCopy"),a=e("../object/keysIn");t.exports=r},{"../internal/baseCopy":23,"../object/keysIn":52}],51:[function(e,t,i){var r=e("../internal/getNative"),n=e("../internal/isArrayLike"),a=e("../lang/isObject"),s=e("../internal/shimKeys"),o=e("../support"),u=r(Object,"keys"),d=u?function(e){var t=null==e?void 0:e.constructor;return"function"==typeof t&&t.prototype===e||("function"==typeof e?o.enumPrototypes:n(e))?s(e):a(e)?u(e):[]}:s;t.exports=d},{"../internal/getNative":33,"../internal/isArrayLike":34,"../internal/shimKeys":40,"../lang/isObject":46,"../support":54}],52:[function(e,t,i){function r(e){if(null==e)return[];l(e)||(e=Object(e));var t=e.length;t=t&&d(t)&&(s(e)||a(e)||f(e))&&t||0;for(var i=e.constructor,r=-1,n=o(i)&&i.prototype||k,h=n===e,p=Array(t),m=t>0,g=c.enumErrorProps&&(e===T||e instanceof Error),v=c.enumPrototypes&&o(e);++r<t;)p[r]=r+"";for(var _ in e)v&&"prototype"==_||g&&("message"==_||"name"==_)||m&&u(_,t)||"constructor"==_&&(h||!P.call(e,_))||p.push(_);if(c.nonEnumShadows&&e!==k){var L=e===O?w:e===T?y:x.call(e),j=A[L]||A[b];for(L==b&&(n=k),t=S.length;t--;){_=S[t];var E=j[_];h&&E||(E?!P.call(e,_):e[_]===n[_])||p.push(_)}}return p}var n=e("../internal/arrayEach"),a=e("../lang/isArguments"),s=e("../lang/isArray"),o=e("../lang/isFunction"),u=e("../internal/isIndex"),d=e("../internal/isLength"),l=e("../lang/isObject"),f=e("../lang/isString"),c=e("../support"),h="[object Array]",p="[object Boolean]",m="[object Date]",y="[object Error]",g="[object Function]",v="[object Number]",b="[object Object]",_="[object RegExp]",w="[object String]",S=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],T=Error.prototype,k=Object.prototype,O=String.prototype,P=k.hasOwnProperty,x=k.toString,A={};A[h]=A[m]=A[v]={constructor:!0,toLocaleString:!0,toString:!0,valueOf:!0},A[p]=A[w]={constructor:!0,toString:!0,valueOf:!0},A[y]=A[g]=A[_]={constructor:!0,toString:!0},A[b]={constructor:!0},n(S,function(e){for(var t in A)if(P.call(A,t)){var i=A[t];i[e]=P.call(i,e)}}),t.exports=r},{"../internal/arrayEach":22,"../internal/isIndex":36,"../internal/isLength":38,"../lang/isArguments":42,"../lang/isArray":43,"../lang/isFunction":44,"../lang/isObject":46,"../lang/isString":48,"../support":54}],53:[function(e,t,i){var r=e("../internal/baseMerge"),n=e("../internal/createAssigner"),a=n(r);t.exports=a},{"../internal/baseMerge":26,"../internal/createAssigner":30}],54:[function(e,t,i){var r=Array.prototype,n=Error.prototype,a=Object.prototype,s=a.propertyIsEnumerable,o=r.splice,u={};!function(e){var t=function(){this.x=e},i={0:e,length:e},r=[];t.prototype={valueOf:e,y:e};for(var a in new t)r.push(a);u.enumErrorProps=s.call(n,"message")||s.call(n,"name"),u.enumPrototypes=s.call(t,"prototype"),u.nonEnumShadows=!/valueOf/.test(r),u.ownLast="x"!=r[0],u.spliceObjects=(o.call(i,0,1),!i[0]),u.unindexedChars="x"[0]+Object("x")[0]!="xx"}(1,0),t.exports=u},{}],55:[function(e,t,i){function r(e){return e}t.exports=r},{}],56:[function(e,t,i){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}Object.defineProperty(i,"__esModule",{value:!0});var n=e("./line-stream"),a=r(n),s=e("./parse-stream"),o=r(s),u=e("./parser"),d=r(u);i["default"]={LineStream:a["default"],ParseStream:o["default"],Parser:d["default"]},t.exports=i["default"]},{"./line-stream":57,"./parse-stream":58,"./parser":59}],57:[function(e,t,i){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}function n(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function a(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}Object.defineProperty(i,"__esModule",{value:!0});var s=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),o=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},u=e("./stream"),d=r(u),l=function(e){function t(){n(this,t),o(Object.getPrototypeOf(t.prototype),"constructor",this).call(this),this.buffer=""}return a(t,e),s(t,[{key:"push",value:function(e){var t=void 0;for(this.buffer+=e,t=this.buffer.indexOf("\n");t>-1;t=this.buffer.indexOf("\n"))this.trigger("data",this.buffer.substring(0,t)),this.buffer=this.buffer.substring(t+1)}}]),t}(d["default"]);i["default"]=l,t.exports=i["default"]},{"./stream":60}],58:[function(e,t,i){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}function n(e,t){
if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function a(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}Object.defineProperty(i,"__esModule",{value:!0});var s=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),o=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},u=e("./stream"),d=r(u),l=function(){var e="[^=]*",t='"[^"]*"|[^,]*',i="(?:"+e+")=(?:"+t+")";return new RegExp("(?:^|,)("+i+")")},f=function(e){for(var t=e.split(l()),i=t.length,r={},n=void 0;i--;)""!==t[i]&&(n=/([^=]*)=(.*)/.exec(t[i]).slice(1),n[0]=n[0].replace(/^\s+|\s+$/g,""),n[1]=n[1].replace(/^\s+|\s+$/g,""),n[1]=n[1].replace(/^['"](.*)['"]$/g,"$1"),r[n[0]]=n[1]);return r},c=function(e){function t(){n(this,t),o(Object.getPrototypeOf(t.prototype),"constructor",this).call(this)}return a(t,e),s(t,[{key:"push",value:function(e){var t=void 0,i=void 0;if(e=e.replace(/^[\u0000\s]+|[\u0000\s]+$/g,""),0!==e.length){if("#"!==e[0])return void this.trigger("data",{type:"uri",uri:e});if(0!==e.indexOf("#EXT"))return void this.trigger("data",{type:"comment",text:e.slice(1)});if(e=e.replace("\r",""),t=/^#EXTM3U/.exec(e))return void this.trigger("data",{type:"tag",tagType:"m3u"});if(t=/^#EXTINF:?([0-9\.]*)?,?(.*)?$/.exec(e))return i={type:"tag",tagType:"inf"},t[1]&&(i.duration=parseFloat(t[1])),t[2]&&(i.title=t[2]),void this.trigger("data",i);if(t=/^#EXT-X-TARGETDURATION:?([0-9.]*)?/.exec(e))return i={type:"tag",tagType:"targetduration"},t[1]&&(i.duration=parseInt(t[1],10)),void this.trigger("data",i);if(t=/^#ZEN-TOTAL-DURATION:?([0-9.]*)?/.exec(e))return i={type:"tag",tagType:"totalduration"},t[1]&&(i.duration=parseInt(t[1],10)),void this.trigger("data",i);if(t=/^#EXT-X-VERSION:?([0-9.]*)?/.exec(e))return i={type:"tag",tagType:"version"},t[1]&&(i.version=parseInt(t[1],10)),void this.trigger("data",i);if(t=/^#EXT-X-MEDIA-SEQUENCE:?(\-?[0-9.]*)?/.exec(e))return i={type:"tag",tagType:"media-sequence"},t[1]&&(i.number=parseInt(t[1],10)),void this.trigger("data",i);if(t=/^#EXT-X-DISCONTINUITY-SEQUENCE:?(\-?[0-9.]*)?/.exec(e))return i={type:"tag",tagType:"discontinuity-sequence"},t[1]&&(i.number=parseInt(t[1],10)),void this.trigger("data",i);if(t=/^#EXT-X-PLAYLIST-TYPE:?(.*)?$/.exec(e))return i={type:"tag",tagType:"playlist-type"},t[1]&&(i.playlistType=t[1]),void this.trigger("data",i);if(t=/^#EXT-X-BYTERANGE:?([0-9.]*)?@?([0-9.]*)?/.exec(e))return i={type:"tag",tagType:"byterange"},t[1]&&(i.length=parseInt(t[1],10)),t[2]&&(i.offset=parseInt(t[2],10)),void this.trigger("data",i);if(t=/^#EXT-X-ALLOW-CACHE:?(YES|NO)?/.exec(e))return i={type:"tag",tagType:"allow-cache"},t[1]&&(i.allowed=!/NO/.test(t[1])),void this.trigger("data",i);if(t=/^#EXT-X-STREAM-INF:?(.*)$/.exec(e)){if(i={type:"tag",tagType:"stream-inf"},t[1]){if(i.attributes=f(t[1]),i.attributes.RESOLUTION){var r=i.attributes.RESOLUTION.split("x"),n={};r[0]&&(n.width=parseInt(r[0],10)),r[1]&&(n.height=parseInt(r[1],10)),i.attributes.RESOLUTION=n}i.attributes.BANDWIDTH&&(i.attributes.BANDWIDTH=parseInt(i.attributes.BANDWIDTH,10)),i.attributes["PROGRAM-ID"]&&(i.attributes["PROGRAM-ID"]=parseInt(i.attributes["PROGRAM-ID"],10))}return void this.trigger("data",i)}return(t=/^#EXT-X-MEDIA:?(.*)$/.exec(e))?(i={type:"tag",tagType:"media"},t[1]&&(i.attributes=f(t[1])),void this.trigger("data",i)):(t=/^#EXT-X-ENDLIST/.exec(e))?void this.trigger("data",{type:"tag",tagType:"endlist"}):(t=/^#EXT-X-DISCONTINUITY/.exec(e))?void this.trigger("data",{type:"tag",tagType:"discontinuity"}):(t=/^#EXT-X-KEY:?(.*)$/.exec(e))?(i={type:"tag",tagType:"key"},t[1]&&(i.attributes=f(t[1]),i.attributes.IV&&("0x"===i.attributes.IV.substring(0,2).toLowerCase()&&(i.attributes.IV=i.attributes.IV.substring(2)),i.attributes.IV=i.attributes.IV.match(/.{8}/g),i.attributes.IV[0]=parseInt(i.attributes.IV[0],16),i.attributes.IV[1]=parseInt(i.attributes.IV[1],16),i.attributes.IV[2]=parseInt(i.attributes.IV[2],16),i.attributes.IV[3]=parseInt(i.attributes.IV[3],16),i.attributes.IV=new Uint32Array(i.attributes.IV))),void this.trigger("data",i)):void this.trigger("data",{type:"tag",data:e.slice(4,e.length)})}}}]),t}(d["default"]);i["default"]=c,t.exports=i["default"]},{"./stream":60}],59:[function(e,t,i){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}function n(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function a(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}Object.defineProperty(i,"__esModule",{value:!0});var s=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),o=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},u=e("./stream"),d=r(u),l=e("./line-stream"),f=r(l),c=e("./parse-stream"),h=r(c),p=e("lodash-compat/object/merge"),m=r(p),y=function(e){function t(){n(this,t),o(Object.getPrototypeOf(t.prototype),"constructor",this).call(this),this.lineStream=new f["default"],this.parseStream=new h["default"],this.lineStream.pipe(this.parseStream);var e=this,i=[],r={},a=void 0,s=function(){},u={AUDIO:{},VIDEO:{},"CLOSED-CAPTIONS":{},SUBTITLES:{}},d=0;this.manifest={allowCache:!0,discontinuityStarts:[]},this.parseStream.on("data",function(t){var n=void 0,o=void 0;({tag:function(){(({"allow-cache":function(){this.manifest.allowCache=t.allowed,"allowed"in t||(this.trigger("info",{message:"defaulting allowCache to YES"}),this.manifest.allowCache=!0)},byterange:function l(){var l={};"length"in t&&(r.byterange=l,l.length=t.length,"offset"in t||(this.trigger("info",{message:"defaulting offset to zero"}),t.offset=0)),"offset"in t&&(r.byterange=l,l.offset=t.offset)},endlist:function(){this.manifest.endList=!0},inf:function(){"mediaSequence"in this.manifest||(this.manifest.mediaSequence=0,this.trigger("info",{message:"defaulting media sequence to zero"})),"discontinuitySequence"in this.manifest||(this.manifest.discontinuitySequence=0,this.trigger("info",{message:"defaulting discontinuity sequence to zero"})),t.duration>0&&(r.duration=t.duration),0===t.duration&&(r.duration=.01,this.trigger("info",{message:"updating zero segment duration to a small value"})),this.manifest.segments=i},key:function(){return t.attributes?"NONE"===t.attributes.METHOD?void(a=null):t.attributes.URI?(t.attributes.METHOD||this.trigger("warn",{message:"defaulting key method to AES-128"}),a={method:t.attributes.METHOD||"AES-128",uri:t.attributes.URI},void("undefined"!=typeof t.attributes.IV&&(a.iv=t.attributes.IV))):void this.trigger("warn",{message:"ignoring key declaration without URI"}):void this.trigger("warn",{message:"ignoring key declaration without attribute list"})},"media-sequence":function(){return isFinite(t.number)?void(this.manifest.mediaSequence=t.number):void this.trigger("warn",{message:"ignoring invalid media sequence: "+t.number})},"discontinuity-sequence":function(){return isFinite(t.number)?(this.manifest.discontinuitySequence=t.number,void(d=t.number)):void this.trigger("warn",{message:"ignoring invalid discontinuity sequence: "+t.number})},"playlist-type":function(){return/VOD|EVENT/.test(t.playlistType)?void(this.manifest.playlistType=t.playlistType):void this.trigger("warn",{message:"ignoring unknown playlist type: "+t.playlist})},"stream-inf":function(){return this.manifest.playlists=i,this.manifest.mediaGroups=this.manifest.mediaGroups||u,t.attributes?(r.attributes||(r.attributes={}),void(r.attributes=(0,m["default"])(r.attributes,t.attributes))):void this.trigger("warn",{message:"ignoring empty stream-inf attributes"})},media:function(){if(this.manifest.mediaGroups=this.manifest.mediaGroups||u,!(t.attributes&&t.attributes.TYPE&&t.attributes["GROUP-ID"]&&t.attributes.NAME))return void this.trigger("warn",{message:"ignoring incomplete or missing media group"});var e=this.manifest.mediaGroups[t.attributes.TYPE];e[t.attributes["GROUP-ID"]]=e[t.attributes["GROUP-ID"]]||{},n=e[t.attributes["GROUP-ID"]],o={"default":/yes/i.test(t.attributes.DEFAULT)},o["default"]?o.autoselect=!0:o.autoselect=/yes/i.test(t.attributes.AUTOSELECT),t.attributes.LANGUAGE&&(o.language=t.attributes.LANGUAGE),t.attributes.URI&&(o.uri=t.attributes.URI),n[t.attributes.NAME]=o},discontinuity:function(){d+=1,r.discontinuity=!0,this.manifest.discontinuityStarts.push(i.length)},targetduration:function(){return!isFinite(t.duration)||t.duration<0?void this.trigger("warn",{message:"ignoring invalid target duration: "+t.duration}):void(this.manifest.targetDuration=t.duration)},totalduration:function(){return!isFinite(t.duration)||t.duration<0?void this.trigger("warn",{message:"ignoring invalid total duration: "+t.duration}):void(this.manifest.totalDuration=t.duration)}})[t.tagType]||s).call(e)},uri:function(){r.uri=t.uri,i.push(r),!this.manifest.targetDuration||"duration"in r||(this.trigger("warn",{message:"defaulting segment duration to the target duration"}),r.duration=this.manifest.targetDuration),a&&(r.key=a),r.timeline=d,r={}},comment:function(){}})[t.type].call(e)})}return a(t,e),s(t,[{key:"push",value:function(e){this.lineStream.push(e)}},{key:"end",value:function(){this.lineStream.push("\n")}}]),t}(d["default"]);i["default"]=y,t.exports=i["default"]},{"./line-stream":57,"./parse-stream":58,"./stream":60,"lodash-compat/object/merge":53}],60:[function(e,t,i){arguments[4][16][0].apply(i,arguments)},{dup:16}],61:[function(e,t,i){"use strict";var r;t.exports=function(e){var t=r[e.byteLength%16||0],i=new Uint8Array(e.byteLength+t.length);return i.set(e),i.set(t,e.byteLength),i},r=[[16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16],[15,15,15,15,15,15,15,15,15,15,15,15,15,15,15],[14,14,14,14,14,14,14,14,14,14,14,14,14,14],[13,13,13,13,13,13,13,13,13,13,13,13,13],[12,12,12,12,12,12,12,12,12,12,12,12],[11,11,11,11,11,11,11,11,11,11,11],[10,10,10,10,10,10,10,10,10,10],[9,9,9,9,9,9,9,9,9],[8,8,8,8,8,8,8,8],[7,7,7,7,7,7,7],[6,6,6,6,6,6],[5,5,5,5,5],[4,4,4,4],[3,3,3],[2,2],[1]]},{}],62:[function(e,t,i){"use strict";i.pad=e("./pad.js"),i.unpad=e("./unpad.js")},{"./pad.js":61,"./unpad.js":63}],63:[function(e,t,i){"use strict";t.exports=function(e){return e.subarray(0,e.byteLength-e[e.byteLength-1])}},{}],64:[function(e,t,i){(function(e){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}Object.defineProperty(i,"__esModule",{value:!0});var n="undefined"!=typeof window?window.videojs:"undefined"!=typeof e?e.videojs:null,a=r(n),s=function(e){Object.defineProperties(e.frame,{id:{get:function(){return a["default"].log.warn("cue.frame.id is deprecated. Use cue.value.key instead."),e.value.key}},value:{get:function(){return a["default"].log.warn("cue.frame.value is deprecated. Use cue.value.data instead."),e.value.data}},privateData:{get:function(){return a["default"].log.warn("cue.frame.privateData is deprecated. Use cue.value.data instead."),e.value.data}}})},o=function(e,t,i){var r=window.WebKitDataCue||window.VTTCue;t&&t.forEach(function(e){this.inbandTextTrack_.addCue(new r(e.startTime+this.timestampOffset,e.endTime+this.timestampOffset,e.text))},e),i&&i.forEach(function(e){var t=e.cueTime+this.timestampOffset;e.frames.forEach(function(e){var i=new r(t,t,e.value||e.url||e.data||"");i.frame=e,i.value=e,s(i),this.metadataTrack_.addCue(i)},this)},e)};i["default"]=o,t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{}],65:[function(e,t,i){"use strict";Object.defineProperty(i,"__esModule",{value:!0});var r=function(e){return/mp4a\.\d+.\d+/i.test(e)},n=function(e){return/avc1\.[\da-f]+/i.test(e)},a=function(e){var t={type:"",parameters:{}},i=e.trim().split(";");return t.type=i.shift().trim(),i.forEach(function(e){var i=e.trim().split("=");if(i.length>1){var r=i[0].replace(/"/g,"").trim(),n=i[1].replace(/"/g,"").trim();t.parameters[r]=n}}),t};i["default"]={isAudioCodec:r,parseContentType:a,isVideoCodec:n},t.exports=i["default"]},{}],66:[function(e,t,i){"use strict";Object.defineProperty(i,"__esModule",{value:!0});var r=function(e,t,i){i.captions&&i.captions.length&&!e.inbandTextTrack_&&(e.inbandTextTrack_=t.player_.addTextTrack("captions","cc1")),i.metadata&&i.metadata.length&&!e.metadataTrack_&&(e.metadataTrack_=t.player_.addTextTrack("metadata","Timed Metadata"),e.metadataTrack_.inBandMetadataTrackDispatchType=i.metadata.dispatchType)};i["default"]=r,t.exports=i["default"]},{}],67:[function(e,t,i){"use strict";Object.defineProperty(i,"__esModule",{value:!0});var r={TIME_BETWEEN_TICKS:Math.floor(1e3/480),TIME_PER_TICK:Math.floor(1e3/240),BYTES_PER_CHUNK:1024,MIN_CHUNK:1024,MAX_CHUNK:1048576};i["default"]=r,t.exports=i["default"]},{}],68:[function(e,t,i){(function(r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function s(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}Object.defineProperty(i,"__esModule",{value:!0});var o=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),u=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},d="undefined"!=typeof window?window.videojs:"undefined"!=typeof r?r.videojs:null,l=n(d),f=e("./flash-source-buffer"),c=n(f),h=e("./flash-constants"),p=n(h),m=e("./codec-utils"),y=function(e){function t(){var e=this;a(this,t),u(Object.getPrototypeOf(t.prototype),"constructor",this).call(this),this.sourceBuffers=[],this.readyState="closed",this.on(["sourceopen","webkitsourceopen"],function(t){e.swfObj=document.getElementById(t.swfId),e.player_=(0,l["default"])(e.swfObj.parentNode),e.tech_=e.swfObj.tech,e.readyState="open",e.tech_.on("seeking",function(){for(var t=e.sourceBuffers.length;t--;)e.sourceBuffers[t].abort()}),e.swfObj&&e.swfObj.vjs_load()})}return s(t,e),o(t,[{key:"addSeekableRange_",value:function(){}},{key:"addSourceBuffer",value:function(e){var t=(0,m.parseContentType)(e),i=void 0;if("video/mp2t"!==t.type)throw new Error("NotSupportedError (Video.js)");return i=new c["default"](this),this.sourceBuffers.push(i),i}},{key:"endOfStream",value:function(e){"network"===e?this.tech_.error(2):"decode"===e&&this.tech_.error(3),"ended"!==this.readyState&&(this.readyState="ended",this.swfObj.vjs_endOfStream())}}]),t}(l["default"].EventTarget);i["default"]=y;try{Object.defineProperty(y.prototype,"duration",{get:function(){return this.swfObj?this.swfObj.vjs_getProperty("duration"):NaN},set:function(e){var t=void 0,i=this.swfObj.vjs_getProperty("duration");if(this.swfObj.vjs_setProperty("duration",e),i>e)for(t=0;t<this.sourceBuffers.length;t++)this.sourceBuffers[t].remove(e,i);return e}})}catch(g){y.prototype.duration=NaN}for(var v in p["default"])y[v]=p["default"][v];t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./codec-utils":65,"./flash-constants":67,"./flash-source-buffer":69}],69:[function(e,t,i){(function(r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function s(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}Object.defineProperty(i,"__esModule",{value:!0});var o=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),u=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},d="undefined"!=typeof window?window.videojs:"undefined"!=typeof r?r.videojs:null,l=n(d),f=e("mux.js/lib/flv"),c=n(f),h=e("./remove-cues-from-track"),p=n(h),m=e("./create-text-tracks-if-necessary"),y=n(m),g=e("./add-text-track-data"),v=n(g),b=e("./flash-constants"),_=n(b),w=function(e){window.setTimeout(e,_["default"].TIME_BETWEEN_TICKS)},S=function(e,t){("number"!=typeof t||0>t)&&(t=0);var i=Math.pow(10,t);return Math.round(e*i)/i},T=function(e){function t(e){var i=this;a(this,t),u(Object.getPrototypeOf(t.prototype),"constructor",this).call(this);var r=void 0;this.chunkSize_=_["default"].BYTES_PER_CHUNK,this.buffer_=[],this.bufferSize_=0,this.basePtsOffset_=NaN,this.mediaSource=e,this.updating=!1,this.timestampOffset_=0,this.segmentParser_=new c["default"].Transmuxer,this.segmentParser_.on("data",this.receiveBuffer_.bind(this)),r=window.btoa(String.fromCharCode.apply(null,Array.prototype.slice.call(this.segmentParser_.getFlvHeader()))),this.mediaSource.swfObj.vjs_appendBuffer(r),Object.defineProperty(this,"timestampOffset",{get:function(){return this.timestampOffset_},set:function(e){"number"==typeof e&&e>=0&&(this.timestampOffset_=e,this.segmentParser_=new c["default"].Transmuxer,this.segmentParser_.on("data",this.receiveBuffer_.bind(this)),this.mediaSource.swfObj.vjs_discontinuity(),this.basePtsOffset_=NaN)}}),Object.defineProperty(this,"buffered",{get:function(){if(!(this.mediaSource&&this.mediaSource.swfObj&&"vjs_getProperty"in this.mediaSource.swfObj))return l["default"].createTimeRange();var e=this.mediaSource.swfObj.vjs_getProperty("buffered");return e&&e.length&&(e[0][0]=S(e[0][0],3),e[0][1]=S(e[0][1],3)),l["default"].createTimeRanges(e)}}),this.mediaSource.player_.on("seeked",function(){(0,p["default"])(0,1/0,i.metadataTrack_),(0,p["default"])(0,1/0,i.inbandTextTrack_)})}return s(t,e),o(t,[{key:"appendBuffer",value:function(e){var t=this,i=void 0,r=524288,n=0;if(this.updating)throw i=new Error("SourceBuffer.append() cannot be called while an update is in progress"),i.name="InvalidStateError",i.code=11,i;this.updating=!0,this.mediaSource.readyState="open",this.trigger({type:"update"});var a=function s(){t.segmentParser_.push(e.subarray(n,n+r)),n+=r,w(n<e.byteLength?s:t.segmentParser_.flush.bind(t.segmentParser_))};a()}},{key:"abort",value:function(){this.buffer_=[],this.bufferSize_=0,this.mediaSource.swfObj.vjs_abort(),this.updating&&(this.updating=!1,this.trigger({type:"updateend"}))}},{key:"remove",value:function(e,t){(0,p["default"])(e,t,this.metadataTrack_),(0,p["default"])(e,t,this.inbandTextTrack_),this.trigger({type:"update"}),this.trigger({type:"updateend"})}},{key:"receiveBuffer_",value:function(e){var t=this;(0,y["default"])(this,this.mediaSource,e),(0,v["default"])(this,e.captions,e.metadata),w(function(){var i=t.convertTagsToData_(e);0===t.buffer_.length&&w(t.processBuffer_.bind(t)),i&&(t.buffer_.push(i),t.bufferSize_+=i.byteLength)})}},{key:"processBuffer_",value:function(){var e=void 0,t=void 0,i=void 0,r=void 0,n=void 0,a=0,s=0,o=+new Date,u=void 0;if(!this.buffer_.length)return void(this.updating!==!1&&(this.updating=!1,this.trigger({type:"updateend"})));do{for(s++,e=this.buffer_[0].subarray(a,a+this.chunkSize_),e.byteLength<this.chunkSize_||this.buffer_[0].byteLength===a+this.chunkSize_?(a=0,this.buffer_.shift()):a+=this.chunkSize_,this.bufferSize_-=e.byteLength,r="",i=e.byteLength,t=0;i>t;t++)r+=String.fromCharCode(e[t]);n=window.btoa(r),this.mediaSource.swfObj.CallFunction('<invoke name="vjs_appendBuffer"returntype="javascript"><arguments><string>'+n+"</string></arguments></invoke>"),u=new Date-o}while(this.buffer_.length&&u<_["default"].TIME_PER_TICK);this.buffer_.length&&a&&(this.buffer_[0]=this.buffer_[0].subarray(a)),u>=_["default"].TIME_PER_TICK&&(this.chunkSize_=Math.floor(this.chunkSize_*(s/4))),this.chunkSize_=Math.max(_["default"].MIN_CHUNK,Math.min(this.chunkSize_,_["default"].MAX_CHUNK)),0!==this.bufferSize_?w(this.processBuffer_.bind(this)):(this.updating=!1,this.trigger({type:"updateend"}))}},{key:"convertTagsToData_",value:function(e){var t=0,i=this.mediaSource.tech_,r=0,n=void 0,a=void 0,s=void 0,o=[],u=this.getOrderedTags_(e);for(isNaN(this.basePtsOffset_)&&u.length&&(this.basePtsOffset_=u[0].pts),i.buffered().length&&(r=i.buffered().end(0)-this.timestampOffset),r=Math.max(r,i.currentTime()-this.timestampOffset),r*=1e3,r+=this.basePtsOffset_,n=0;n<u.length;n++)u[n].pts>=r&&o.push(u[n]);if(0!==o.length){for(n=0;n<o.length;n++)t+=o[n].bytes.byteLength;for(s=new Uint8Array(t),n=0,a=0;n<o.length;n++)s.set(o[n].bytes,a),a+=o[n].bytes.byteLength;return s}}},{key:"getOrderedTags_",value:function(e){for(var t=e.tags.videoTags,i=e.tags.audioTags,r=void 0,n=[];t.length||i.length;)r=t.length?i.length&&i[0].dts<t[0].dts?i.shift():t.shift():i.shift(),n.push(r.finalize());return n}}]),t}(l["default"].EventTarget);i["default"]=T,t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./add-text-track-data":64,"./create-text-tracks-if-necessary":66,"./flash-constants":67,"./remove-cues-from-track":71,"mux.js/lib/flv":79}],70:[function(e,t,i){(function(r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function s(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}Object.defineProperty(i,"__esModule",{value:!0});var o=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),u=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},d="undefined"!=typeof window?window.videojs:"undefined"!=typeof r?r.videojs:null,l=n(d),f=e("./virtual-source-buffer"),c=n(f),h=e("./codec-utils"),p=function(e){return e.map(function(e){return e.replace(/avc1\.(\d+)\.(\d+)/i,function(e,t,i){var r=("00"+Number(t).toString(16)).slice(-2),n=("00"+Number(i).toString(16)).slice(-2);return"avc1."+r+"00"+n})})},m=function(e){function t(){var e=this;a(this,t),u(Object.getPrototypeOf(t.prototype),"constructor",this).call(this);var i=void 0;this.nativeMediaSource_=new window.MediaSource;for(i in this.nativeMediaSource_)i in t.prototype||"function"!=typeof this.nativeMediaSource_[i]||(this[i]=this.nativeMediaSource_[i].bind(this.nativeMediaSource_));this.duration_=NaN,Object.defineProperty(this,"duration",{get:function(){return this.duration_===1/0?this.duration_:this.nativeMediaSource_.duration},set:function(e){return this.duration_=e,e!==1/0?void(this.nativeMediaSource_.duration=e):void 0}}),Object.defineProperty(this,"seekable",{get:function(){return this.duration_===1/0?l["default"].createTimeRanges([[0,this.nativeMediaSource_.duration]]):this.nativeMediaSource_.seekable}}),Object.defineProperty(this,"readyState",{get:function(){return this.nativeMediaSource_.readyState}}),Object.defineProperty(this,"activeSourceBuffers",{get:function(){return this.activeSourceBuffers_}}),this.sourceBuffers=[],this.activeSourceBuffers_=[],this.updateActiveSourceBuffers_=function(){e.activeSourceBuffers_.length=0;for(var t=!1,i=!0,r=0;r<e.player_.audioTracks().length;r++){var n=e.player_.audioTracks()[r];if(n.enabled&&"main"!==n.kind){t=!0,i=!1;break}}e.sourceBuffers.forEach(function(r){if(r.videoCodec_&&r.audioCodec_)r.audioDisabled_=t;else if(r.videoCodec_&&!r.audioCodec_)r.audioDisabled_=!0,i=!1;else if(!r.videoCodec_&&r.audioCodec_&&(r.audioDisabled_=i,i))return;e.activeSourceBuffers_.push(r)})},["sourceopen","sourceclose","sourceended"].forEach(function(e){this.nativeMediaSource_.addEventListener(e,this.trigger.bind(this))},this),this.on("sourceopen",function(t){var i=document.querySelector('[src="'+e.url_+'"]');i&&(e.player_=(0,l["default"])(i.parentNode),e.player_.audioTracks&&e.player_.audioTracks()&&(e.player_.audioTracks().on("change",e.updateActiveSourceBuffers_),e.player_.audioTracks().on("addtrack",e.updateActiveSourceBuffers_),e.player_.audioTracks().on("removetrack",e.updateActiveSourceBuffers_)))}),this.on("sourceclose",function(e){this.sourceBuffers.forEach(function(e){e.transmuxer_&&e.transmuxer_.terminate()}),this.sourceBuffers.length=0,this.player_&&this.player_.audioTracks&&this.player_.audioTracks()&&(this.player_.audioTracks().off("change",this.updateActiveSourceBuffers_),this.player_.audioTracks().off("addtrack",this.updateActiveSourceBuffers_),this.player_.audioTracks().off("removetrack",this.updateActiveSourceBuffers_))})}return s(t,e),o(t,[{key:"addSeekableRange_",value:function(e,t){var i=void 0;if(this.duration!==1/0)throw i=new Error("MediaSource.addSeekableRange() can only be invoked when the duration is Infinity"),i.name="InvalidStateError",i.code=11,i;(t>this.nativeMediaSource_.duration||isNaN(this.nativeMediaSource_.duration))&&(this.nativeMediaSource_.duration=t)}},{key:"addSourceBuffer",value:function(e){var t=void 0,i=(0,h.parseContentType)(e);if("video/mp2t"===i.type){var r=[];i.parameters&&i.parameters.codecs&&(r=i.parameters.codecs.split(","),r=p(r),r=r.filter(function(e){return(0,h.isAudioCodec)(e)||(0,h.isVideoCodec)(e)})),0===r.length&&(r=["avc1.4d400d","mp4a.40.2"]),t=new c["default"](this,r),0!==this.sourceBuffers.length&&(this.sourceBuffers[0].createRealSourceBuffers_(),t.createRealSourceBuffers_(),this.sourceBuffers[0].audioDisabled_=!0)}else t=this.nativeMediaSource_.addSourceBuffer(e);return this.sourceBuffers.push(t),t}}]),t}(l["default"].EventTarget);i["default"]=m,t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./codec-utils":65,"./virtual-source-buffer":74}],71:[function(e,t,i){"use strict";Object.defineProperty(i,"__esModule",{value:!0});var r=function(e,t,i){var r=void 0,n=void 0;if(i)for(r=i.cues.length;r--;)n=i.cues[r],n.startTime<=t&&n.endTime>=e&&i.removeCue(n)};i["default"]=r,t.exports=i["default"]},{}],72:[function(e,t,i){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}function n(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(i,"__esModule",{value:!0});var a=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),s=e("mux.js/lib/mp4"),o=r(s),u=function(e){e.on("data",function(e){var t=e.data;e.data=t.buffer,postMessage({action:"data",segment:e,byteOffset:t.byteOffset,byteLength:t.byteLength},[e.data])}),e.captionStream&&e.captionStream.on("data",function(e){postMessage({action:"caption",data:e})}),e.on("done",function(e){postMessage({action:"done"})})},d=function(){function e(t){n(this,e),this.options=t||{},this.init()}return a(e,[{key:"init",value:function(){this.transmuxer&&this.transmuxer.dispose(),this.transmuxer=new o["default"].Transmuxer(this.options),u(this.transmuxer)}},{key:"push",value:function(e){var t=new Uint8Array(e.data,e.byteOffset,e.byteLength);this.transmuxer.push(t)}},{key:"reset",value:function(){this.init()}},{key:"setTimestampOffset",value:function(e){var t=e.timestampOffset||0;this.transmuxer.setBaseMediaDecodeTime(Math.round(9e4*t))}},{key:"flush",value:function(e){this.transmuxer.flush()}}]),e}(),l=function(e){e.onmessage=function(e){return"init"===e.data.action&&e.data.options?void(this.messageHandlers=new d(e.data.options)):(this.messageHandlers||(this.messageHandlers=new d),void(e.data&&e.data.action&&"init"!==e.data.action&&this.messageHandlers[e.data.action]&&this.messageHandlers[e.data.action](e.data)))}};i["default"]=function(e){return new l(e)},t.exports=i["default"]},{"mux.js/lib/mp4":85}],73:[function(e,t,i){(function(t){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}Object.defineProperty(i,"__esModule",{value:!0});var n=e("./flash-media-source"),a=r(n),s=e("./html-media-source"),o=r(s),u="undefined"!=typeof window?window.videojs:"undefined"!=typeof t?t.videojs:null,d=r(u),l=0,f={mode:"auto"};d["default"].mediaSources={};var c=function(e,t){var i=d["default"].mediaSources[e];if(!i)throw new Error("Media Source not found (Video.js)");i.trigger({type:"sourceopen",swfId:t})},h=function(){return!!window.MediaSource&&!!window.MediaSource.isTypeSupported&&window.MediaSource.isTypeSupported('video/mp4;codecs="avc1.4d400d,mp4a.40.2"')},p=function(e){var t=d["default"].mergeOptions(f,e);return this.MediaSource={open:c,supportsNativeMediaSources:h},"html5"===t.mode||"auto"===t.mode&&h()?new o["default"]:new a["default"]};i.MediaSource=p,p.open=c,p.supportsNativeMediaSources=h;var m={createObjectURL:function(e){var t="blob:vjs-media-source/",i=void 0;return e instanceof o["default"]?(i=window.URL.createObjectURL(e.nativeMediaSource_),e.url_=i,i):e instanceof a["default"]?(i=t+l,l++,d["default"].mediaSources[i]=e,i):(i=window.URL.createObjectURL(e),e.url_=i,i)}};i.URL=m,d["default"].MediaSource=p,d["default"].URL=m}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./flash-media-source":68,"./html-media-source":70}],74:[function(e,t,i){(function(r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function s(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,
enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}Object.defineProperty(i,"__esModule",{value:!0});var o=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),u=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},d="undefined"!=typeof window?window.videojs:"undefined"!=typeof r?r.videojs:null,l=n(d),f=e("./create-text-tracks-if-necessary"),c=n(f),h=e("./remove-cues-from-track"),p=n(h),m=e("./add-text-track-data"),y=n(m),g=e("webworkify"),v=n(g),b=e("./transmuxer-worker"),_=n(b),w=e("./codec-utils"),S=function(e){function t(e,i){var r=this;a(this,t),u(Object.getPrototypeOf(t.prototype),"constructor",this).call(this,l["default"].EventTarget),this.timestampOffset_=0,this.pendingBuffers_=[],this.bufferUpdating_=!1,this.mediaSource_=e,this.codecs_=i,this.audioCodec_=null,this.videoCodec_=null,this.audioDisabled_=!1;var n={remux:!1};this.codecs_.forEach(function(e){(0,w.isAudioCodec)(e)?r.audioCodec_=e:(0,w.isVideoCodec)(e)&&(r.videoCodec_=e)}),this.transmuxer_=(0,v["default"])(_["default"]),this.transmuxer_.postMessage({action:"init",options:n}),this.transmuxer_.onmessage=function(e){return"data"===e.data.action?r.data_(e):"done"===e.data.action?r.done_(e):void 0},Object.defineProperty(this,"timestampOffset",{get:function(){return this.timestampOffset_},set:function(e){"number"==typeof e&&e>=0&&(this.timestampOffset_=e,this.transmuxer_.postMessage({action:"setTimestampOffset",timestampOffset:e}))}}),Object.defineProperty(this,"appendWindowStart",{get:function(){return(this.videoBuffer_||this.audioBuffer_).appendWindowStart},set:function(e){this.videoBuffer_&&(this.videoBuffer_.appendWindowStart=e),this.audioBuffer_&&(this.audioBuffer_.appendWindowStart=e)}}),Object.defineProperty(this,"updating",{get:function(){return!!(this.bufferUpdating_||!this.audioDisabled_&&this.audioBuffer_&&this.audioBuffer_.updating||this.videoBuffer_&&this.videoBuffer_.updating)}}),Object.defineProperty(this,"buffered",{get:function(){var e=null,t=null,i=0,r=[],n=[];if(!this.videoBuffer_&&(this.audioDisabled_||!this.audioBuffer_))return l["default"].createTimeRange();if(!this.videoBuffer_)return this.audioBuffer_.buffered;if(this.audioDisabled_||!this.audioBuffer_)return this.videoBuffer_.buffered;if(!(this.videoBuffer_&&0!==this.videoBuffer_.buffered.length||this.audioBuffer_&&0!==this.audioBuffer_.buffered.length))return l["default"].createTimeRange();for(var a=this.videoBuffer_.buffered,s=this.audioBuffer_.buffered,o=a.length;o--;)r.push({time:a.start(o),type:"start"}),r.push({time:a.end(o),type:"end"});for(o=s.length;o--;)r.push({time:s.start(o),type:"start"}),r.push({time:s.end(o),type:"end"});for(r.sort(function(e,t){return e.time-t.time}),o=0;o<r.length;o++)"start"===r[o].type?(i++,2===i&&(e=r[o].time)):"end"===r[o].type&&(i--,1===i&&(t=r[o].time)),null!==e&&null!==t&&(n.push([e,t]),e=null,t=null);return l["default"].createTimeRanges(n)}})}return s(t,e),o(t,[{key:"data_",value:function(e){var t=e.data.segment;t.data=new Uint8Array(t.data,e.data.byteOffset,e.data.byteLength),(0,c["default"])(this,this.mediaSource_,t),this.pendingBuffers_.push(t)}},{key:"done_",value:function(e){this.processPendingSegments_()}},{key:"createRealSourceBuffers_",value:function(){var e=this,t=["audio","video"];t.forEach(function(i){if(e[i+"Codec_"]&&!e[i+"Buffer_"]){var r=null;e.mediaSource_[i+"Buffer_"]?r=e.mediaSource_[i+"Buffer_"]:(r=e.mediaSource_.nativeMediaSource_.addSourceBuffer(i+'/mp4;codecs="'+e[i+"Codec_"]+'"'),e.mediaSource_[i+"Buffer_"]=r),e[i+"Buffer_"]=r,["update","updatestart","updateend"].forEach(function(n){r.addEventListener(n,function(){if("audio"!==i||!e.audioDisabled_){var r=t.every(function(t){return"audio"===t&&e.audioDisabled_?!0:i===t||!e[t+"Buffer_"]||!e[t+"Buffer_"].updating});return r?e.trigger(n):void 0}})})}})}},{key:"appendBuffer",value:function(e){this.bufferUpdating_=!0,this.transmuxer_.postMessage({action:"push",data:e.buffer,byteOffset:e.byteOffset,byteLength:e.byteLength},[e.buffer]),this.transmuxer_.postMessage({action:"flush"})}},{key:"remove",value:function(e,t){this.videoBuffer_&&this.videoBuffer_.remove(e,t),!this.audioDisabled_&&this.audioBuffer_&&this.audioBuffer_.remove(e,t),(0,p["default"])(e,t,this.metadataTrack_),(0,p["default"])(e,t,this.inbandTextTrack_)}},{key:"processPendingSegments_",value:function(){var e={video:{segments:[],bytes:0},audio:{segments:[],bytes:0},captions:[],metadata:[]};e=this.pendingBuffers_.reduce(function(e,t){var i=t.type,r=t.data;return e[i].segments.push(r),e[i].bytes+=r.byteLength,t.captions&&(e.captions=e.captions.concat(t.captions)),t.info&&(e[i].info=t.info),t.metadata&&(e.metadata=e.metadata.concat(t.metadata)),e},e),this.videoBuffer_||this.audioBuffer_||(0===e.video.bytes&&(this.videoCodec_=null),0===e.audio.bytes&&(this.audioCodec_=null),this.createRealSourceBuffers_()),e.audio.info&&this.mediaSource_.trigger({type:"audioinfo",info:e.audio.info}),e.video.info&&this.mediaSource_.trigger({type:"videoinfo",info:e.video.info}),this.videoBuffer_&&(this.concatAndAppendSegments_(e.video,this.videoBuffer_),(0,y["default"])(this,e.captions,e.metadata)),!this.audioDisabled_&&this.audioBuffer_&&this.concatAndAppendSegments_(e.audio,this.audioBuffer_),this.pendingBuffers_.length=0,this.bufferUpdating_=!1}},{key:"concatAndAppendSegments_",value:function(e,t){var i=0,r=void 0;e.bytes&&(r=new Uint8Array(e.bytes),e.segments.forEach(function(e){r.set(e,i),i+=e.byteLength}),t.appendBuffer(r))}},{key:"abort",value:function(){this.videoBuffer_&&this.videoBuffer_.abort(),this.audioBuffer_&&this.audioBuffer_.abort(),this.transmuxer_&&this.transmuxer_.postMessage({action:"reset"}),this.pendingBuffers_.length=0,this.bufferUpdating_=!1}}]),t}(l["default"].EventTarget);i["default"]=S,t.exports=i["default"]}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./add-text-track-data":64,"./codec-utils":65,"./create-text-tracks-if-necessary":66,"./remove-cues-from-track":71,"./transmuxer-worker":72,webworkify:90}],75:[function(e,t,i){"use strict";var r,n=e("../utils/stream.js");r=function(){var e=new Uint8Array,t=0;r.prototype.init.call(this),this.setTimestamp=function(e){t=e},this.parseId3TagSize=function(e,t){var i=e[t+6]<<21|e[t+7]<<14|e[t+8]<<7|e[t+9],r=e[t+5],n=(16&r)>>4;return n?i+20:i+10},this.parseAdtsSize=function(e,t){var i=(224&e[t+5])>>5,r=e[t+4]<<3,n=6144&e[t+3];return n|r|i},this.push=function(i){var r,n,a,s,o=0,u=0;for(e.length?(s=e.length,e=new Uint8Array(i.byteLength+s),e.set(e.subarray(0,s)),e.set(i,s)):e=i;e.length-u>=3;)if(e[u]!=="I".charCodeAt(0)||e[u+1]!=="D".charCodeAt(0)||e[u+2]!=="3".charCodeAt(0))if(e[u]&!0&&240===(240&e[u+1])){if(e.length-u<7)break;if(o=this.parseAdtsSize(e,u),o>e.length)break;a={type:"audio",data:e.subarray(u,u+o),pts:t,dts:t},this.trigger("data",a),u+=o}else u++;else{if(e.length-u<10)break;if(o=this.parseId3TagSize(e,u),o>e.length)break;n={type:"timed-metadata",data:e.subarray(u,u+o)},this.trigger("data",n),u+=o}r=e.length-u,e=r>0?e.subarray(u):new Uint8Array}},r.prototype=new n,t.exports=r},{"../utils/stream.js":89}],76:[function(e,t,i){"use strict";var r,n=e("../utils/stream.js"),a=[96e3,88200,64e3,48e3,44100,32e3,24e3,22050,16e3,12e3,11025,8e3,7350];r=function(){var e,t;r.prototype.init.call(this),e=this,this.push=function(e){var i,r,n,s,o,u,d=0,l=0;if("audio"===e.type)for(t?(s=t,t=new Uint8Array(s.byteLength+e.data.byteLength),t.set(s),t.set(e.data,s.byteLength)):t=e.data;d+5<t.length;)if(255===t[d]&&240===(246&t[d+1])){if(r=2*(1&~t[d+1]),i=(3&t[d+3])<<11|t[d+4]<<3|(224&t[d+5])>>5,o=1024*((3&t[d+6])+1),u=9e4*o/a[(60&t[d+2])>>>2],n=d+i,t.byteLength<n)return;if(this.trigger("data",{pts:e.pts+l*u,dts:e.dts+l*u,sampleCount:o,audioobjecttype:(t[d+2]>>>6&3)+1,channelcount:(1&t[d+2])<<2|(192&t[d+3])>>>6,samplerate:a[(60&t[d+2])>>>2],samplingfrequencyindex:(60&t[d+2])>>>2,samplesize:16,data:t.subarray(d+7+r,n)}),t.byteLength===n)return void(t=void 0);l++,t=t.subarray(n)}else d++},this.flush=function(){this.trigger("done")}},r.prototype=new n,t.exports=r},{"../utils/stream.js":89}],77:[function(e,t,i){"use strict";var r,n,a=e("../utils/stream.js"),s=e("../utils/exp-golomb.js");n=function(){var e,t,i=0;n.prototype.init.call(this),this.push=function(r){var n;for(t?(n=new Uint8Array(t.byteLength+r.data.byteLength),n.set(t),n.set(r.data,t.byteLength),t=n):t=r.data;i<t.byteLength-3;i++)if(1===t[i+2]){e=i+5;break}for(;e<t.byteLength;)switch(t[e]){case 0:if(0!==t[e-1]){e+=2;break}if(0!==t[e-2]){e++;break}i+3!==e-2&&this.trigger("data",t.subarray(i+3,e-2));do e++;while(1!==t[e]&&e<t.length);i=e-2,e+=3;break;case 1:if(0!==t[e-1]||0!==t[e-2]){e+=3;break}this.trigger("data",t.subarray(i+3,e-2)),i=e-2,e+=3;break;default:e+=3}t=t.subarray(i),e-=i,i=0},this.flush=function(){t&&t.byteLength>3&&this.trigger("data",t.subarray(i+3)),t=null,i=0,this.trigger("done")}},n.prototype=new a,r=function(){var e,t,i,a,o,u,d,l=new n;r.prototype.init.call(this),e=this,this.push=function(e){"video"===e.type&&(t=e.trackId,i=e.pts,a=e.dts,l.push(e))},l.on("data",function(r){var n={trackId:t,pts:i,dts:a,data:r};switch(31&r[0]){case 5:n.nalUnitType="slice_layer_without_partitioning_rbsp_idr";break;case 6:n.nalUnitType="sei_rbsp",n.escapedRBSP=o(r.subarray(1));break;case 7:n.nalUnitType="seq_parameter_set_rbsp",n.escapedRBSP=o(r.subarray(1)),n.config=u(n.escapedRBSP);break;case 8:n.nalUnitType="pic_parameter_set_rbsp";break;case 9:n.nalUnitType="access_unit_delimiter_rbsp"}e.trigger("data",n)}),l.on("done",function(){e.trigger("done")}),this.flush=function(){l.flush()},d=function(e,t){var i,r,n=8,a=8;for(i=0;e>i;i++)0!==a&&(r=t.readExpGolomb(),a=(n+r+256)%256),n=0===a?n:a},o=function(e){for(var t,i,r=e.byteLength,n=[],a=1;r-2>a;)0===e[a]&&0===e[a+1]&&3===e[a+2]?(n.push(a+2),a+=2):a++;if(0===n.length)return e;t=r-n.length,i=new Uint8Array(t);var s=0;for(a=0;t>a;s++,a++)s===n[0]&&(s++,n.shift()),i[a]=e[s];return i},u=function(e){var t,i,r,n,a,o,u,l,f,c,h,p,m,y,g=0,v=0,b=0,_=0,w=1;if(t=new s(e),i=t.readUnsignedByte(),n=t.readUnsignedByte(),r=t.readUnsignedByte(),t.skipUnsignedExpGolomb(),(100===i||110===i||122===i||244===i||44===i||83===i||86===i||118===i||128===i||138===i||139===i||134===i)&&(a=t.readUnsignedExpGolomb(),3===a&&t.skipBits(1),t.skipUnsignedExpGolomb(),t.skipUnsignedExpGolomb(),t.skipBits(1),t.readBoolean()))for(h=3!==a?8:12,y=0;h>y;y++)t.readBoolean()&&(6>y?d(16,t):d(64,t));if(t.skipUnsignedExpGolomb(),o=t.readUnsignedExpGolomb(),0===o)t.readUnsignedExpGolomb();else if(1===o)for(t.skipBits(1),t.skipExpGolomb(),t.skipExpGolomb(),u=t.readUnsignedExpGolomb(),y=0;u>y;y++)t.skipExpGolomb();if(t.skipUnsignedExpGolomb(),t.skipBits(1),l=t.readUnsignedExpGolomb(),f=t.readUnsignedExpGolomb(),c=t.readBits(1),0===c&&t.skipBits(1),t.skipBits(1),t.readBoolean()&&(g=t.readUnsignedExpGolomb(),v=t.readUnsignedExpGolomb(),b=t.readUnsignedExpGolomb(),_=t.readUnsignedExpGolomb()),t.readBoolean()&&t.readBoolean()){switch(m=t.readUnsignedByte()){case 1:p=[1,1];break;case 2:p=[12,11];break;case 3:p=[10,11];break;case 4:p=[16,11];break;case 5:p=[40,33];break;case 6:p=[24,11];break;case 7:p=[20,11];break;case 8:p=[32,11];break;case 9:p=[80,33];break;case 10:p=[18,11];break;case 11:p=[15,11];break;case 12:p=[64,33];break;case 13:p=[160,99];break;case 14:p=[4,3];break;case 15:p=[3,2];break;case 16:p=[2,1];break;case 255:p=[t.readUnsignedByte()<<8|t.readUnsignedByte(),t.readUnsignedByte()<<8|t.readUnsignedByte()]}p&&(w=p[0]/p[1])}return{profileIdc:i,levelIdc:r,profileCompatibility:n,width:Math.ceil((16*(l+1)-2*g-2*v)*w),height:(2-c)*(f+1)*16-2*b-2*_}}},r.prototype=new a,t.exports={H264Stream:r,NalByteStream:n}},{"../utils/exp-golomb.js":88,"../utils/stream.js":89}],78:[function(e,t,i){"use strict";var r;r=function(e,t){var i,n=0,a=16384,s=function(e,t){var i,r=e.position+t;r<e.bytes.byteLength||(i=new Uint8Array(2*r),i.set(e.bytes.subarray(0,e.position),0),e.bytes=i,e.view=new DataView(e.bytes.buffer))},o=r.widthBytes||new Uint8Array("width".length),u=r.heightBytes||new Uint8Array("height".length),d=r.videocodecidBytes||new Uint8Array("videocodecid".length);if(!r.widthBytes){for(i=0;i<"width".length;i++)o[i]="width".charCodeAt(i);for(i=0;i<"height".length;i++)u[i]="height".charCodeAt(i);for(i=0;i<"videocodecid".length;i++)d[i]="videocodecid".charCodeAt(i);r.widthBytes=o,r.heightBytes=u,r.videocodecidBytes=d}switch(this.keyFrame=!1,e){case r.VIDEO_TAG:this.length=16,a*=6;break;case r.AUDIO_TAG:this.length=13,this.keyFrame=!0;break;case r.METADATA_TAG:this.length=29,this.keyFrame=!0;break;default:throw"Error Unknown TagType"}this.bytes=new Uint8Array(a),this.view=new DataView(this.bytes.buffer),this.bytes[0]=e,this.position=this.length,this.keyFrame=t,this.pts=0,this.dts=0,this.writeBytes=function(e,t,i){var r,n=t||0;i=i||e.byteLength,r=n+i,s(this,i),this.bytes.set(e.subarray(n,r),this.position),this.position+=i,this.length=Math.max(this.length,this.position)},this.writeByte=function(e){s(this,1),this.bytes[this.position]=e,this.position++,this.length=Math.max(this.length,this.position)},this.writeShort=function(e){s(this,2),this.view.setUint16(this.position,e),this.position+=2,this.length=Math.max(this.length,this.position)},this.negIndex=function(e){return this.bytes[this.length-e]},this.nalUnitSize=function(){return 0===n?0:this.length-(n+4)},this.startNalUnit=function(){if(n>0)throw new Error("Attempted to create new NAL wihout closing the old one");n=this.length,this.length+=4,this.position=this.length},this.endNalUnit=function(e){var t,i;this.length===n+4?this.length-=4:n>0&&(t=n+4,i=this.length-t,this.position=n,this.view.setUint32(this.position,i),this.position=this.length,e&&e.push(this.bytes.subarray(t,t+i))),n=0},this.writeMetaDataDouble=function(e,t){var i;if(s(this,2+e.length+9),this.view.setUint16(this.position,e.length),this.position+=2,"width"===e)this.bytes.set(o,this.position),this.position+=5;else if("height"===e)this.bytes.set(u,this.position),this.position+=6;else if("videocodecid"===e)this.bytes.set(d,this.position),this.position+=12;else for(i=0;i<e.length;i++)this.bytes[this.position]=e.charCodeAt(i),this.position++;this.position++,this.view.setFloat64(this.position,t),this.position+=8,this.length=Math.max(this.length,this.position),++n},this.writeMetaDataBoolean=function(e,t){var i;for(s(this,2),this.view.setUint16(this.position,e.length),this.position+=2,i=0;i<e.length;i++)s(this,1),this.bytes[this.position]=e.charCodeAt(i),this.position++;s(this,2),this.view.setUint8(this.position,1),this.position++,this.view.setUint8(this.position,t?1:0),this.position++,this.length=Math.max(this.length,this.position),++n},this.finalize=function(){var e,i;switch(this.bytes[0]){case r.VIDEO_TAG:this.bytes[11]=7|(this.keyFrame||t?16:32),this.bytes[12]=t?0:1,e=this.pts-this.dts,this.bytes[13]=(16711680&e)>>>16,this.bytes[14]=(65280&e)>>>8,this.bytes[15]=(255&e)>>>0;break;case r.AUDIO_TAG:this.bytes[11]=175,this.bytes[12]=t?0:1;break;case r.METADATA_TAG:this.position=11,this.view.setUint8(this.position,2),this.position++,this.view.setUint16(this.position,10),this.position+=2,this.bytes.set([111,110,77,101,116,97,68,97,116,97],this.position),this.position+=10,this.bytes[this.position]=8,this.position++,this.view.setUint32(this.position,n),this.position=this.length,this.bytes.set([0,0,9],this.position),this.position+=3,this.length=this.position}return i=this.length-11,this.bytes[1]=(16711680&i)>>>16,this.bytes[2]=(65280&i)>>>8,this.bytes[3]=(255&i)>>>0,this.bytes[4]=(16711680&this.dts)>>>16,this.bytes[5]=(65280&this.dts)>>>8,this.bytes[6]=(255&this.dts)>>>0,this.bytes[7]=(4278190080&this.dts)>>>24,this.bytes[8]=0,this.bytes[9]=0,this.bytes[10]=0,s(this,4),this.view.setUint32(this.length,this.length),this.length+=4,this.position+=4,this.bytes=this.bytes.subarray(0,this.length),this.frameTime=r.frameTime(this.bytes),this}},r.AUDIO_TAG=8,r.VIDEO_TAG=9,r.METADATA_TAG=18,r.isAudioFrame=function(e){return r.AUDIO_TAG===e[0]},r.isVideoFrame=function(e){return r.VIDEO_TAG===e[0]},r.isMetaData=function(e){return r.METADATA_TAG===e[0]},r.isKeyFrame=function(e){return r.isVideoFrame(e)?23===e[11]:r.isAudioFrame(e)?!0:!!r.isMetaData(e)},r.frameTime=function(e){var t=e[4]<<16;return t|=e[5]<<8,t|=e[6]<<0,t|=e[7]<<24},t.exports=r},{}],79:[function(e,t,i){t.exports={tag:e("./flv-tag"),Transmuxer:e("./transmuxer")}},{"./flv-tag":78,"./transmuxer":80}],80:[function(e,t,i){"use strict";var r,n,a,s,o,u,d,l=e("../utils/stream.js"),f=e("./flv-tag.js"),c=e("../m2ts/m2ts.js"),h=e("../codecs/adts.js"),p=e("../codecs/h264").H264Stream;o=function(e,t){"number"==typeof t.pts&&(void 0===e.timelineStartInfo.pts?e.timelineStartInfo.pts=t.pts:e.timelineStartInfo.pts=Math.min(e.timelineStartInfo.pts,t.pts)),"number"==typeof t.dts&&(void 0===e.timelineStartInfo.dts?e.timelineStartInfo.dts=t.dts:e.timelineStartInfo.dts=Math.min(e.timelineStartInfo.dts,t.dts))},u=function(e,t){var i=new f(f.METADATA_TAG);return i.dts=t,i.pts=t,i.writeMetaDataDouble("videocodecid",7),i.writeMetaDataDouble("width",e.width),i.writeMetaDataDouble("height",e.height),i},d=function(e,t){var i,r=new f(f.VIDEO_TAG,!0);for(r.dts=t,r.pts=t,r.writeByte(1),r.writeByte(e.profileIdc),r.writeByte(e.profileCompatibility),r.writeByte(e.levelIdc),r.writeByte(255),r.writeByte(225),r.writeShort(e.sps[0].length),r.writeBytes(e.sps[0]),r.writeByte(e.pps.length),i=0;i<e.pps.length;++i)r.writeShort(e.pps[i].length),r.writeBytes(e.pps[i]);return r},a=function(e){var t,i=[];a.prototype.init.call(this),this.push=function(t){o(e,t),e&&void 0===e.channelcount&&(e.audioobjecttype=t.audioobjecttype,e.channelcount=t.channelcount,e.samplerate=t.samplerate,e.samplingfrequencyindex=t.samplingfrequencyindex,e.samplesize=t.samplesize,e.extraData=e.audioobjecttype<<11|e.samplingfrequencyindex<<7|e.channelcount<<3),t.pts=Math.round(t.pts/90),t.dts=Math.round(t.dts/90),i.push(t)},this.flush=function(){var r,n,a,s=[];if(0===i.length)return void this.trigger("done");for(a=-(1/0);i.length;)r=i.shift(),(e.extraData!==t||r.pts-a>=1e3)&&(n=new f(f.METADATA_TAG),n.pts=r.pts,n.dts=r.dts,n.writeMetaDataDouble("audiocodecid",10),n.writeMetaDataBoolean("stereo",2===e.channelcount),n.writeMetaDataDouble("audiosamplerate",e.samplerate),n.writeMetaDataDouble("audiosamplesize",16),s.push(n),t=e.extraData,n=new f(f.AUDIO_TAG,!0),n.pts=r.pts,n.dts=r.dts,n.view.setUint16(n.position,e.extraData),n.position+=2,n.length=Math.max(n.length,n.position),s.push(n),a=r.pts),n=new f(f.AUDIO_TAG),n.pts=r.pts,n.dts=r.dts,n.writeBytes(r.data),s.push(n);t=null,this.trigger("data",{track:e,tags:s}),this.trigger("done")}},a.prototype=new l,n=function(e){var t,i,r=[];n.prototype.init.call(this),this.finishFrame=function(i,r){r&&(t&&e&&e.newMetadata&&(r.keyFrame||0===i.length)&&(i.push(u(t,r.pts)),i.push(d(e,r.pts)),e.newMetadata=!1),r.endNalUnit(),i.push(r))},this.push=function(t){o(e,t),t.pts=Math.round(t.pts/90),t.dts=Math.round(t.dts/90),r.push(t)},this.flush=function(){for(var n,a=[];r.length&&"access_unit_delimiter_rbsp"!==r[0].nalUnitType;)r.shift();if(0===r.length)return void this.trigger("done");for(;r.length;)n=r.shift(),"seq_parameter_set_rbsp"===n.nalUnitType?(e.newMetadata=!0,t=n.config,e.width=t.width,e.height=t.height,e.sps=[n.data],e.profileIdc=t.profileIdc,e.levelIdc=t.levelIdc,e.profileCompatibility=t.profileCompatibility,i.endNalUnit()):"pic_parameter_set_rbsp"===n.nalUnitType?(e.newMetadata=!0,e.pps=[n.data],i.endNalUnit()):"access_unit_delimiter_rbsp"===n.nalUnitType?(i&&this.finishFrame(a,i),i=new f(f.VIDEO_TAG),i.pts=n.pts,i.dts=n.dts):("slice_layer_without_partitioning_rbsp_idr"===n.nalUnitType&&(i.keyFrame=!0),i.endNalUnit()),i.startNalUnit(),i.writeBytes(n.data);i&&this.finishFrame(a,i),this.trigger("data",{track:e,tags:a}),this.trigger("done")}},n.prototype=new l,s=function(e){this.numberOfTracks=0,this.metadataStream=e.metadataStream,this.videoTags=[],this.audioTags=[],this.videoTrack=null,this.audioTrack=null,this.pendingCaptions=[],this.pendingMetadata=[],this.pendingTracks=0,s.prototype.init.call(this),this.push=function(e){return e.text?this.pendingCaptions.push(e):e.frames?this.pendingMetadata.push(e):("video"===e.track.type&&(this.videoTrack=e.track,this.videoTags=e.tags,this.pendingTracks++),void("audio"===e.track.type&&(this.audioTrack=e.track,this.audioTags=e.tags,this.pendingTracks++)))}},s.prototype=new l,s.prototype.flush=function(){var e,t,i,r,n={tags:{},captions:[],metadata:[]};if(!(this.pendingTracks<this.numberOfTracks)){for(this.videoTrack?r=this.videoTrack.timelineStartInfo.pts:this.audioTrack&&(r=this.audioTrack.timelineStartInfo.pts),n.tags.videoTags=this.videoTags,n.tags.audioTags=this.audioTags,i=0;i<this.pendingCaptions.length;i++)t=this.pendingCaptions[i],t.startTime=t.startPts-r,t.startTime/=9e4,t.endTime=t.endPts-r,t.endTime/=9e4,n.captions.push(t);for(i=0;i<this.pendingMetadata.length;i++)e=this.pendingMetadata[i],e.cueTime=e.pts-r,e.cueTime/=9e4,n.metadata.push(e);n.metadata.dispatchType=this.metadataStream.dispatchType,this.videoTrack=null,this.audioTrack=null,this.videoTags=[],this.audioTags=[],this.pendingCaptions.length=0,this.pendingMetadata.length=0,this.pendingTracks=0,this.trigger("data",n),this.trigger("done")}},r=function(e){var t,i,o,u,d,l,m,y,g,v=this;r.prototype.init.call(this),e=e||{},this.metadataStream=new c.MetadataStream,e.metadataStream=this.metadataStream,t=new c.TransportPacketStream,i=new c.TransportParseStream,o=new c.ElementaryStream,u=new h,d=new p,g=new s(e),t.pipe(i).pipe(o),o.pipe(d),o.pipe(u),o.pipe(this.metadataStream).pipe(g),y=new c.CaptionStream,d.pipe(y).pipe(g),o.on("data",function(e){var t,i,r;if("metadata"===e.type){for(t=e.tracks.length;t--;)"video"===e.tracks[t].type?i=e.tracks[t]:"audio"===e.tracks[t].type&&(r=e.tracks[t]);i&&!l&&(g.numberOfTracks++,l=new n(i),d.pipe(l).pipe(g)),r&&!m&&(g.numberOfTracks++,m=new a(r),u.pipe(m).pipe(g))}}),this.push=function(e){t.push(e)},this.flush=function(){t.flush()},g.on("data",function(e){v.trigger("data",e)}),g.on("done",function(){v.trigger("done")}),this.getFlvHeader=function(e,t,i){var r,n,a,s=new Uint8Array(9),o=new DataView(s.buffer);return e=e||0,t=void 0===t?!0:t,i=void 0===i?!0:i,o.setUint8(0,70),o.setUint8(1,76),o.setUint8(2,86),o.setUint8(3,1),o.setUint8(4,(t?4:0)|(i?1:0)),o.setUint32(5,s.byteLength),0>=e?(n=new Uint8Array(s.byteLength+4),n.set(s),n.set([0,0,0,0],s.byteLength),n):(r=new f(f.METADATA_TAG),r.pts=r.dts=0,r.writeMetaDataDouble("duration",e),a=r.finalize().length,n=new Uint8Array(s.byteLength+a),n.set(s),n.set(o.byteLength,a),n)}},r.prototype=new l,t.exports=r},{"../codecs/adts.js":76,"../codecs/h264":77,"../m2ts/m2ts.js":82,"../utils/stream.js":89,"./flv-tag.js":78}],81:[function(e,t,i){"use strict";var r=4,n=128,a=e("../utils/stream"),s=function(e){for(var t=0,i={payloadType:-1,payloadSize:0},a=0,s=0;t<e.byteLength&&e[t]!==n;){for(;255===e[t];)a+=255,t++;for(a+=e[t++];255===e[t];)s+=255,t++;if(s+=e[t++],!i.payload&&a===r){i.payloadType=a,i.payloadSize=s,i.payload=e.subarray(t,t+s);break}t+=s,a=0,s=0}return i},o=function(e){return 181!==e.payload[0]?null:49!==(e.payload[1]<<8|e.payload[2])?null:"GA94"!==String.fromCharCode(e.payload[3],e.payload[4],e.payload[5],e.payload[6])?null:3!==e.payload[7]?null:e.payload.subarray(8,e.payload.length-1)},u=function(e,t){var i,r,n,a,s=[];if(!(64&t[0]))return s;for(r=31&t[0],i=0;r>i;i++)n=3*i,a={type:3&t[n+2],pts:e},4&t[n+2]&&(a.ccData=t[n+3]<<8|t[n+4],s.push(a));return s},d=function(){d.prototype.init.call(this),this.captionPackets_=[],this.field1_=new k,this.field1_.on("data",this.trigger.bind(this,"data")),this.field1_.on("done",this.trigger.bind(this,"done"))};d.prototype=new a,d.prototype.push=function(e){var t,i;"sei_rbsp"===e.nalUnitType&&(t=s(e.escapedRBSP),t.payloadType===r&&(i=o(t),i&&(this.captionPackets_=this.captionPackets_.concat(u(e.pts,i)))))},d.prototype.flush=function(){return this.captionPackets_.length?(this.captionPackets_.sort(function(e,t){return e.pts-t.pts}),this.captionPackets_.forEach(this.field1_.push,this.field1_),this.captionPackets_.length=0,void this.field1_.flush()):void this.field1_.flush()};var l={42:225,92:233,94:237,95:243,96:250,123:231,124:247,125:209,126:241,127:9608},f=function(e){return null===e?"":(e=l[e]||e,String.fromCharCode(e))},c=0,h=5152,p=5167,m=5157,y=5158,g=5159,v=5165,b=5153,_=5164,w=5166,S=14,T=function(){for(var e=[],t=S+1;t--;)e.push("");return e},k=function(){k.prototype.init.call(this),this.mode_="popOn",this.topRow_=0,this.startPts_=0,this.displayed_=T(),this.nonDisplayed_=T(),this.lastControlCode_=null,this.push=function(e){if(0===e.type){var t,i,r,n;if(t=32639&e.ccData,t===this.lastControlCode_)return void(this.lastControlCode_=null);switch(4096===(61440&t)?this.lastControlCode_=t:this.lastControlCode_=null,t){case c:break;case h:this.mode_="popOn";break;case p:this.flushDisplayed(e.pts),i=this.displayed_,this.displayed_=this.nonDisplayed_,this.nonDisplayed_=i,this.startPts_=e.pts;break;case m:this.topRow_=S-1,this.mode_="rollUp";break;case y:this.topRow_=S-2,this.mode_="rollUp";break;case g:this.topRow_=S-3,this.mode_="rollUp";break;case v:this.flushDisplayed(e.pts),this.shiftRowsUp_(),this.startPts_=e.pts;break;case b:"popOn"===this.mode_?this.nonDisplayed_[S]=this.nonDisplayed_[S].slice(0,-1):this.displayed_[S]=this.displayed_[S].slice(0,-1);break;case _:this.flushDisplayed(e.pts),this.displayed_=T();break;case w:this.nonDisplayed_=T();break;default:if(r=t>>>8,n=255&t,r>=16&&23>=r&&n>=64&&127>=n&&(16!==r||96>n)&&(r=32,n=null),(17===r||25===r)&&n>=48&&63>=n&&(r=9834,n=""),16===(240&r))return;this[this.mode_](e.pts,r,n)}}}};k.prototype=new a,k.prototype.flushDisplayed=function(e){var t=this.displayed_.map(function(e){return e.trim()}).filter(function(e){return e.length}).join("\n");t.length&&this.trigger("data",{startPts:this.startPts_,endPts:e,text:t})},k.prototype.popOn=function(e,t,i){var r=this.nonDisplayed_[S];r+=f(t),r+=f(i),this.nonDisplayed_[S]=r},k.prototype.rollUp=function(e,t,i){var r=this.displayed_[S];""===r&&(this.flushDisplayed(e),this.startPts_=e),r+=f(t),r+=f(i),this.displayed_[S]=r},k.prototype.shiftRowsUp_=function(){var e;for(e=0;e<this.topRow_;e++)this.displayed_[e]="";for(e=this.topRow_;S>e;e++)this.displayed_[e]=this.displayed_[e+1];this.displayed_[S]=""},t.exports={CaptionStream:d,Cea608Stream:k}},{"../utils/stream":89}],82:[function(e,t,i){"use strict";var r,n,a,s=e("../utils/stream.js"),o=e("./caption-stream"),u=e("./stream-types"),s=e("../utils/stream.js"),d=e("./stream-types.js"),l=188,f=71,r=function(){var e=new Uint8Array(l),t=0;r.prototype.init.call(this),this.push=function(i){var r,n=0,a=l;for(t?(r=new Uint8Array(i.byteLength+t),r.set(e.subarray(0,t)),r.set(i,t),t=0):r=i;a<r.byteLength;)r[n]!==f||r[a]!==f?(n++,a++):(this.trigger("data",r.subarray(n,a)),n+=l,a+=l);n<r.byteLength&&(e.set(r.subarray(n),0),t=r.byteLength-n)},this.flush=function(){t===l&&e[0]===f&&(this.trigger("data",e),t=0),this.trigger("done")}};r.prototype=new s,n=function(){var e,t,i,r;n.prototype.init.call(this),r=this,this.packetsWaitingForPmt=[],this.programMapTable=void 0,e=function(e,r){var n=0;r.payloadUnitStartIndicator&&(n+=e[n]+1),"pat"===r.type?t(e.subarray(n),r):i(e.subarray(n),r)},t=function(e,t){t.section_number=e[7],t.last_section_number=e[8],r.pmtPid=(31&e[10])<<8|e[11],t.pmtPid=r.pmtPid},i=function(e,t){var i,n,a,s;if(1&e[5]){for(r.programMapTable={},i=(15&e[1])<<8|e[2],n=3+i-4,a=(15&e[10])<<8|e[11],s=12+a;n>s;)r.programMapTable[(31&e[s+1])<<8|e[s+2]]=e[s],s+=((15&e[s+3])<<8|e[s+4])+5;for(t.programMapTable=r.programMapTable;r.packetsWaitingForPmt.length;)r.processPes_.apply(r,r.packetsWaitingForPmt.shift())}},this.push=function(t){var i={},r=4;i.payloadUnitStartIndicator=!!(64&t[1]),i.pid=31&t[1],i.pid<<=8,i.pid|=t[2],(48&t[3])>>>4>1&&(r+=t[r]+1),0===i.pid?(i.type="pat",e(t.subarray(r),i),this.trigger("data",i)):i.pid===this.pmtPid?(i.type="pmt",e(t.subarray(r),i),this.trigger("data",i)):void 0===this.programMapTable?this.packetsWaitingForPmt.push([t,r,i]):this.processPes_(t,r,i)},this.processPes_=function(e,t,i){i.streamType=this.programMapTable[i.pid],i.type="pes",i.data=e.subarray(t),this.trigger("data",i)}},n.prototype=new s,n.STREAM_TYPES={h264:27,adts:15},a=function(){var e,t={data:[],size:0},i={data:[],size:0},r={data:[],size:0},n=function(e,t){var i;t.dataAlignmentIndicator=0!==(4&e[6]),i=e[7],192&i&&(t.pts=(14&e[9])<<27|(255&e[10])<<20|(254&e[11])<<12|(255&e[12])<<5|(254&e[13])>>>3,t.pts*=4,t.pts+=(6&e[13])>>>1,t.dts=t.pts,64&i&&(t.dts=(14&e[14])<<27|(255&e[15])<<20|(254&e[16])<<12|(255&e[17])<<5|(254&e[18])>>>3,t.dts*=4,t.dts+=(6&e[18])>>>1)),t.data=e.subarray(9+e[8])},s=function(t,i){var r,a=new Uint8Array(t.size),s={type:i},o=0;if(t.data.length){for(s.trackId=t.data[0].pid;t.data.length;)r=t.data.shift(),a.set(r.data,o),o+=r.data.byteLength;n(a,s),t.size=0,e.trigger("data",s)}};a.prototype.init.call(this),e=this,this.push=function(n){({pat:function(){},pes:function(){var e,a;switch(n.streamType){case u.H264_STREAM_TYPE:case d.H264_STREAM_TYPE:e=t,a="video";break;case u.ADTS_STREAM_TYPE:e=i,a="audio";break;case u.METADATA_STREAM_TYPE:e=r,a="timed-metadata";break;default:return}n.payloadUnitStartIndicator&&s(e,a),e.data.push(n),e.size+=n.data.byteLength},pmt:function(){var t,i,r={type:"metadata",tracks:[]},a=n.programMapTable;for(t in a)a.hasOwnProperty(t)&&(i={timelineStartInfo:{baseMediaDecodeTime:0}},i.id=+t,a[t]===d.H264_STREAM_TYPE?(i.codec="avc",i.type="video"):a[t]===d.ADTS_STREAM_TYPE&&(i.codec="adts",i.type="audio"),r.tracks.push(i));e.trigger("data",r)}})[n.type]()},this.flush=function(){s(t,"video"),s(i,"audio"),s(r,"timed-metadata"),this.trigger("done")}},a.prototype=new s;var c={PAT_PID:0,MP2T_PACKET_LENGTH:l,TransportPacketStream:r,TransportParseStream:n,ElementaryStream:a,CaptionStream:o.CaptionStream,Cea608Stream:o.Cea608Stream,MetadataStream:e("./metadata-stream")};for(var h in u)u.hasOwnProperty(h)&&(c[h]=u[h]);t.exports=c},{"../utils/stream.js":89,"./caption-stream":81,"./metadata-stream":83,"./stream-types":84,"./stream-types.js":84}],83:[function(e,t,i){"use strict";var r,n=e("../utils/stream"),a=e("./stream-types"),s=function(e,t,i){var r,n="";for(r=t;i>r;r++)n+="%"+("00"+e[r].toString(16)).slice(-2);return n},o=function(e,t,i){return decodeURIComponent(s(e,t,i))},u=function(e,t,i){return unescape(s(e,t,i))},d=function(e){return e[0]<<21|e[1]<<14|e[2]<<7|e[3]},l={TXXX:function(e){var t;if(3===e.data[0]){for(t=1;t<e.data.length;t++)if(0===e.data[t]){e.description=o(e.data,1,t),e.value=o(e.data,t+1,e.data.length-1);break}e.data=e.value}},WXXX:function(e){var t;if(3===e.data[0])for(t=1;t<e.data.length;t++)if(0===e.data[t]){e.description=o(e.data,1,t),e.url=o(e.data,t+1,e.data.length);break}},PRIV:function(e){var t;for(t=0;t<e.data.length;t++)if(0===e.data[t]){e.owner=u(e.data,0,t);break}e.privateData=e.data.subarray(t+1),e.data=e.privateData}};r=function(e){var t,i={debug:!(!e||!e.debug),descriptor:e&&e.descriptor},n=0,s=[],o=0;if(r.prototype.init.call(this),this.dispatchType=a.METADATA_STREAM_TYPE.toString(16),i.descriptor)for(t=0;t<i.descriptor.length;t++)this.dispatchType+=("00"+i.descriptor[t].toString(16)).slice(-2);this.push=function(e){var t,r,a,u,f,c;if("timed-metadata"===e.type){if(e.dataAlignmentIndicator&&(o=0,s.length=0),0===s.length&&(e.data.length<10||e.data[0]!=="I".charCodeAt(0)||e.data[1]!=="D".charCodeAt(0)||e.data[2]!=="3".charCodeAt(0)))return void(i.debug&&console.log("Skipping unrecognized metadata packet"));if(s.push(e),o+=e.data.byteLength,1===s.length&&(n=d(e.data.subarray(6,10)),n+=10),!(n>o)){for(t={data:new Uint8Array(n),frames:[],
pts:s[0].pts,dts:s[0].dts},f=0;n>f;)t.data.set(s[0].data.subarray(0,n-f),f),f+=s[0].data.byteLength,o-=s[0].data.byteLength,s.shift();r=10,64&t.data[5]&&(r+=4,r+=d(t.data.subarray(10,14)),n-=d(t.data.subarray(16,20)));do{if(a=d(t.data.subarray(r+4,r+8)),1>a)return console.log("Malformed ID3 frame encountered. Skipping metadata parsing.");if(c=String.fromCharCode(t.data[r],t.data[r+1],t.data[r+2],t.data[r+3]),u={id:c,data:t.data.subarray(r+10,r+a+10)},u.key=u.id,l[u.id]&&(l[u.id](u),"com.apple.streaming.transportStreamTimestamp"===u.owner)){var h=u.data,p=(1&h[3])<<30|h[4]<<22|h[5]<<14|h[6]<<6|h[7]>>>2;p*=4,p+=3&h[7],u.timeStamp=p,this.trigger("timestamp",u)}t.frames.push(u),r+=10,r+=a}while(n>r);this.trigger("data",t)}}}},r.prototype=new n,t.exports=r},{"../utils/stream":89,"./stream-types":84}],84:[function(e,t,i){"use strict";t.exports={H264_STREAM_TYPE:27,ADTS_STREAM_TYPE:15,METADATA_STREAM_TYPE:21}},{}],85:[function(e,t,i){t.exports={generator:e("./mp4-generator"),Transmuxer:e("./transmuxer").Transmuxer,AudioSegmentStream:e("./transmuxer").AudioSegmentStream,VideoSegmentStream:e("./transmuxer").VideoSegmentStream}},{"./mp4-generator":86,"./transmuxer":87}],86:[function(e,t,i){"use strict";var r,n,a,s,o,u,d,l,f,c,h,p,m,y,g,v,b,_,w,S,T,k,O,P,x,A,L,j,E,C,U,D,M,I,B,R,N;!function(){var e;if(P={avc1:[],avcC:[],btrt:[],dinf:[],dref:[],esds:[],ftyp:[],hdlr:[],mdat:[],mdhd:[],mdia:[],mfhd:[],minf:[],moof:[],moov:[],mp4a:[],mvex:[],mvhd:[],sdtp:[],smhd:[],stbl:[],stco:[],stsc:[],stsd:[],stsz:[],stts:[],styp:[],tfdt:[],tfhd:[],traf:[],trak:[],trun:[],trex:[],tkhd:[],vmhd:[]},"undefined"!=typeof Uint8Array){for(e in P)P.hasOwnProperty(e)&&(P[e]=[e.charCodeAt(0),e.charCodeAt(1),e.charCodeAt(2),e.charCodeAt(3)]);x=new Uint8Array(["i".charCodeAt(0),"s".charCodeAt(0),"o".charCodeAt(0),"m".charCodeAt(0)]),L=new Uint8Array(["a".charCodeAt(0),"v".charCodeAt(0),"c".charCodeAt(0),"1".charCodeAt(0)]),A=new Uint8Array([0,0,0,1]),j=new Uint8Array([0,0,0,0,0,0,0,0,118,105,100,101,0,0,0,0,0,0,0,0,0,0,0,0,86,105,100,101,111,72,97,110,100,108,101,114,0]),E=new Uint8Array([0,0,0,0,0,0,0,0,115,111,117,110,0,0,0,0,0,0,0,0,0,0,0,0,83,111,117,110,100,72,97,110,100,108,101,114,0]),C={video:j,audio:E},M=new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,12,117,114,108,32,0,0,0,1]),D=new Uint8Array([0,0,0,0,0,0,0,0]),I=new Uint8Array([0,0,0,0,0,0,0,0]),B=I,R=new Uint8Array([0,0,0,0,0,0,0,0,0,0,0,0]),N=I,U=new Uint8Array([0,0,0,1,0,0,0,0,0,0,0,0])}}(),r=function(e){var t,i,r,n=[],a=0;for(t=1;t<arguments.length;t++)n.push(arguments[t]);for(t=n.length;t--;)a+=n[t].byteLength;for(i=new Uint8Array(a+8),r=new DataView(i.buffer,i.byteOffset,i.byteLength),r.setUint32(0,i.byteLength),i.set(e,4),t=0,a=8;t<n.length;t++)i.set(n[t],a),a+=n[t].byteLength;return i},n=function(){return r(P.dinf,r(P.dref,M))},a=function(e){return r(P.esds,new Uint8Array([0,0,0,0,3,25,0,0,0,4,17,64,21,0,6,0,0,0,218,192,0,0,218,192,5,2,e.audioobjecttype<<3|e.samplingfrequencyindex>>>1,e.samplingfrequencyindex<<7|e.channelcount<<3,6,1,2]))},s=function(){return r(P.ftyp,x,A,x,L)},v=function(e){return r(P.hdlr,C[e])},o=function(e){return r(P.mdat,e)},g=function(e){var t=new Uint8Array([0,0,0,0,0,0,0,2,0,0,0,3,0,1,95,144,e.duration>>>24&255,e.duration>>>16&255,e.duration>>>8&255,255&e.duration,85,196,0,0]);return e.samplerate&&(t[12]=e.samplerate>>>24&255,t[13]=e.samplerate>>>16&255,t[14]=e.samplerate>>>8&255,t[15]=255&e.samplerate),r(P.mdhd,t)},y=function(e){return r(P.mdia,g(e),v(e.type),d(e))},u=function(e){return r(P.mfhd,new Uint8Array([0,0,0,0,(4278190080&e)>>24,(16711680&e)>>16,(65280&e)>>8,255&e]))},d=function(e){return r(P.minf,"video"===e.type?r(P.vmhd,U):r(P.smhd,D),n(),_(e))},l=function(e,t){for(var i=[],n=t.length;n--;)i[n]=T(t[n]);return r.apply(null,[P.moof,u(e)].concat(i))},f=function(e){for(var t=e.length,i=[];t--;)i[t]=p(e[t]);return r.apply(null,[P.moov,h(4294967295)].concat(i).concat(c(e)))},c=function(e){for(var t=e.length,i=[];t--;)i[t]=k(e[t]);return r.apply(null,[P.mvex].concat(i))},h=function(e){var t=new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,2,0,1,95,144,(4278190080&e)>>24,(16711680&e)>>16,(65280&e)>>8,255&e,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255]);return r(P.mvhd,t)},b=function(e){var t,i,n=e.samples||[],a=new Uint8Array(4+n.length);for(i=0;i<n.length;i++)t=n[i].flags,a[i+4]=t.dependsOn<<4|t.isDependedOn<<2|t.hasRedundancy;return r(P.sdtp,a)},_=function(e){return r(P.stbl,w(e),r(P.stts,N),r(P.stsc,B),r(P.stsz,R),r(P.stco,I))},function(){var e,t;w=function(i){return r(P.stsd,new Uint8Array([0,0,0,0,0,0,0,1]),"video"===i.type?e(i):t(i))},e=function(e){var t,i=e.sps||[],n=e.pps||[],a=[],s=[];for(t=0;t<i.length;t++)a.push((65280&i[t].byteLength)>>>8),a.push(255&i[t].byteLength),a=a.concat(Array.prototype.slice.call(i[t]));for(t=0;t<n.length;t++)s.push((65280&n[t].byteLength)>>>8),s.push(255&n[t].byteLength),s=s.concat(Array.prototype.slice.call(n[t]));return r(P.avc1,new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,(65280&e.width)>>8,255&e.width,(65280&e.height)>>8,255&e.height,0,72,0,0,0,72,0,0,0,0,0,0,0,1,19,118,105,100,101,111,106,115,45,99,111,110,116,114,105,98,45,104,108,115,0,0,0,0,0,0,0,0,0,0,0,0,0,24,17,17]),r(P.avcC,new Uint8Array([1,e.profileIdc,e.profileCompatibility,e.levelIdc,255].concat([i.length]).concat(a).concat([n.length]).concat(s))),r(P.btrt,new Uint8Array([0,28,156,128,0,45,198,192,0,45,198,192])))},t=function(e){return r(P.mp4a,new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,(65280&e.channelcount)>>8,255&e.channelcount,(65280&e.samplesize)>>8,255&e.samplesize,0,0,0,0,(65280&e.samplerate)>>8,255&e.samplerate,0,0]),a(e))}}(),S=function(){return r(P.styp,x,A,x)},m=function(e){var t=new Uint8Array([0,0,0,7,0,0,0,0,0,0,0,0,(4278190080&e.id)>>24,(16711680&e.id)>>16,(65280&e.id)>>8,255&e.id,0,0,0,0,(4278190080&e.duration)>>24,(16711680&e.duration)>>16,(65280&e.duration)>>8,255&e.duration,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,(65280&e.width)>>8,255&e.width,0,0,(65280&e.height)>>8,255&e.height,0,0]);return r(P.tkhd,t)},T=function(e){var t,i,n,a,s;return t=r(P.tfhd,new Uint8Array([0,0,0,58,(4278190080&e.id)>>24,(16711680&e.id)>>16,(65280&e.id)>>8,255&e.id,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0])),i=r(P.tfdt,new Uint8Array([0,0,0,0,e.baseMediaDecodeTime>>>24&255,e.baseMediaDecodeTime>>>16&255,e.baseMediaDecodeTime>>>8&255,255&e.baseMediaDecodeTime])),s=88,"audio"===e.type?(n=O(e,s),r(P.traf,t,i,n)):(a=b(e),n=O(e,a.length+s),r(P.traf,t,i,n,a))},p=function(e){return e.duration=e.duration||4294967295,r(P.trak,m(e),y(e))},k=function(e){var t=new Uint8Array([0,0,0,0,(4278190080&e.id)>>24,(16711680&e.id)>>16,(65280&e.id)>>8,255&e.id,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1]);return"video"!==e.type&&(t[t.length-1]=0),r(P.trex,t)},function(){var e,t,i;i=function(e,t){var i=0,r=0,n=0,a=0;return e.length&&(void 0!==e[0].duration&&(i=1),void 0!==e[0].size&&(r=2),void 0!==e[0].flags&&(n=4),void 0!==e[0].compositionTimeOffset&&(a=8)),[0,0,i|r|n|a,1,(4278190080&e.length)>>>24,(16711680&e.length)>>>16,(65280&e.length)>>>8,255&e.length,(4278190080&t)>>>24,(16711680&t)>>>16,(65280&t)>>>8,255&t]},t=function(e,t){var n,a,s,o;for(a=e.samples||[],t+=20+16*a.length,n=i(a,t),o=0;o<a.length;o++)s=a[o],n=n.concat([(4278190080&s.duration)>>>24,(16711680&s.duration)>>>16,(65280&s.duration)>>>8,255&s.duration,(4278190080&s.size)>>>24,(16711680&s.size)>>>16,(65280&s.size)>>>8,255&s.size,s.flags.isLeading<<2|s.flags.dependsOn,s.flags.isDependedOn<<6|s.flags.hasRedundancy<<4|s.flags.paddingValue<<1|s.flags.isNonSyncSample,61440&s.flags.degradationPriority,15&s.flags.degradationPriority,(4278190080&s.compositionTimeOffset)>>>24,(16711680&s.compositionTimeOffset)>>>16,(65280&s.compositionTimeOffset)>>>8,255&s.compositionTimeOffset]);return r(P.trun,new Uint8Array(n))},e=function(e,t){var n,a,s,o;for(a=e.samples||[],t+=20+8*a.length,n=i(a,t),o=0;o<a.length;o++)s=a[o],n=n.concat([(4278190080&s.duration)>>>24,(16711680&s.duration)>>>16,(65280&s.duration)>>>8,255&s.duration,(4278190080&s.size)>>>24,(16711680&s.size)>>>16,(65280&s.size)>>>8,255&s.size]);return r(P.trun,new Uint8Array(n))},O=function(i,r){return"audio"===i.type?e(i,r):t(i,r)}}(),t.exports={ftyp:s,mdat:o,moof:l,moov:f,initSegment:function(e){var t,i=s(),r=f(e);return t=new Uint8Array(i.byteLength+r.byteLength),t.set(i),t.set(r,i.byteLength),t}}},{}],87:[function(e,t,i){"use strict";var r,n,a,s,o,u,d,l,f,c,h,p=e("../utils/stream.js"),m=e("./mp4-generator.js"),y=e("../m2ts/m2ts.js"),g=e("../codecs/adts.js"),v=e("../codecs/h264").H264Stream,b=e("../aac"),_=["audioobjecttype","channelcount","samplerate","samplingfrequencyindex","samplesize"],w=["width","height","profileIdc","levelIdc","profileCompatibility"];o=function(){return{size:0,flags:{isLeading:0,dependsOn:1,isDependedOn:0,hasRedundancy:0,degradationPriority:0}}},u=function(e){return e[0]==="I".charCodeAt(0)&&e[1]==="D".charCodeAt(0)&&e[2]==="3".charCodeAt(0)},c=function(e,t){var i;if(e.length!==t.length)return!1;for(i=0;i<e.length;i++)if(e[i]!==t[i])return!1;return!0},h=function(e){var t,i,r=0;for(t=0;t<e.length;t++)i=e[t],r+=i.data.byteLength;return r},n=function(e){var t=[],i=0,r=0;n.prototype.init.call(this),this.push=function(i){d(e,i),e&&_.forEach(function(t){e[t]=i[t]}),t.push(i)},this.setEarliestDts=function(t){r=t-e.timelineStartInfo.baseMediaDecodeTime},this.flush=function(){var r,n,a,s;return 0===t.length?void this.trigger("done","AudioSegmentStream"):(r=this.trimAdtsFramesByEarliestDts_(t),e.samples=this.generateSampleTable_(r),a=m.mdat(this.concatenateFrameData_(r)),t=[],f(e),n=m.moof(i,[e]),s=new Uint8Array(n.byteLength+a.byteLength),i++,s.set(n),s.set(a,n.byteLength),l(e),this.trigger("data",{track:e,boxes:s}),void this.trigger("done","AudioSegmentStream"))},this.trimAdtsFramesByEarliestDts_=function(t){return e.minSegmentDts>=r?t:(e.minSegmentDts=1/0,t.filter(function(t){return t.dts>=r?(e.minSegmentDts=Math.min(e.minSegmentDts,t.dts),e.minSegmentPts=e.minSegmentDts,!0):!1}))},this.generateSampleTable_=function(e){var t,i,r=[];for(t=0;t<e.length;t++)i=e[t],r.push({size:i.data.byteLength,duration:1024});return r},this.concatenateFrameData_=function(e){var t,i,r=0,n=new Uint8Array(h(e));for(t=0;t<e.length;t++)i=e[t],n.set(i.data,r),r+=i.data.byteLength;return n}},n.prototype=new p,r=function(e){var t,i,n=0,a=[];r.prototype.init.call(this),delete e.minPTS,this.gopCache_=[],this.push=function(r){d(e,r),"seq_parameter_set_rbsp"!==r.nalUnitType||t||(t=r.config,e.sps=[r.data],w.forEach(function(i){e[i]=t[i]},this)),"pic_parameter_set_rbsp"!==r.nalUnitType||i||(i=r.data,e.pps=[r.data]),a.push(r)},this.flush=function(){for(var t,i,r,s,o,u;a.length&&"access_unit_delimiter_rbsp"!==a[0].nalUnitType;)a.shift();return 0===a.length?(this.resetStream_(),void this.trigger("done","VideoSegmentStream")):(t=this.groupNalsIntoFrames_(a),r=this.groupFramesIntoGops_(t),r[0][0].keyFrame||(i=this.getGopForFusion_(a[0],e),i?(r.unshift(i),r.byteLength+=i.byteLength,r.nalCount+=i.nalCount,r.pts=i.pts,r.dts=i.dts,r.duration+=i.duration):r=this.extendFirstKeyFrame_(r)),d(e,r),e.samples=this.generateSampleTable_(r),o=m.mdat(this.concatenateNalData_(r)),this.gopCache_.unshift({gop:r.pop(),pps:e.pps,sps:e.sps}),this.gopCache_.length=Math.min(6,this.gopCache_.length),a=[],f(e),this.trigger("timelineStartInfo",e.timelineStartInfo),s=m.moof(n,[e]),u=new Uint8Array(s.byteLength+o.byteLength),n++,u.set(s),u.set(o,s.byteLength),this.trigger("data",{track:e,boxes:u}),this.resetStream_(),void this.trigger("done","VideoSegmentStream"))},this.resetStream_=function(){l(e),t=void 0,i=void 0},this.getGopForFusion_=function(t){var i,r,n,a,s,o=45e3,u=1e4,d=1/0;for(s=0;s<this.gopCache_.length;s++)a=this.gopCache_[s],n=a.gop,e.pps&&c(e.pps[0],a.pps[0])&&e.sps&&c(e.sps[0],a.sps[0])&&(n.dts<e.timelineStartInfo.dts||(i=t.dts-n.dts-n.duration,i>=-u&&o>=i&&(!r||d>i)&&(r=a,d=i)));return r?r.gop:null},this.extendFirstKeyFrame_=function(e){var t;return e[0][0].keyFrame||(t=e.shift(),e.byteLength-=t.byteLength,e.nalCount-=t.nalCount,e[0][0].dts=t.dts,e[0][0].pts=t.pts,e[0][0].duration+=t.duration),e},this.groupNalsIntoFrames_=function(e){var t,i,r=[],n=[];for(r.byteLength=0,t=0;t<e.length;t++)i=e[t],"access_unit_delimiter_rbsp"===i.nalUnitType?(r.length&&(r.duration=i.dts-r.dts,n.push(r)),r=[i],r.byteLength=i.data.byteLength,r.pts=i.pts,r.dts=i.dts):("slice_layer_without_partitioning_rbsp_idr"===i.nalUnitType&&(r.keyFrame=!0),r.duration=i.dts-r.dts,r.byteLength+=i.data.byteLength,r.push(i));return n.length&&(!r.duration||r.duration<=0)&&(r.duration=n[n.length-1].duration),n.push(r),n},this.groupFramesIntoGops_=function(e){var t,i,r=[],n=[];for(r.byteLength=0,r.nalCount=0,r.duration=0,r.pts=e[0].pts,r.dts=e[0].dts,n.byteLength=0,n.nalCount=0,n.duration=0,n.pts=e[0].pts,n.dts=e[0].dts,t=0;t<e.length;t++)i=e[t],i.keyFrame?(r.length&&(n.push(r),n.byteLength+=r.byteLength,n.nalCount+=r.nalCount,n.duration+=r.duration),r=[i],r.nalCount=i.length,r.byteLength=i.byteLength,r.pts=i.pts,r.dts=i.dts,r.duration=i.duration):(r.duration+=i.duration,r.nalCount+=i.length,r.byteLength+=i.byteLength,r.push(i));return n.length&&r.duration<=0&&(r.duration=n[n.length-1].duration),n.byteLength+=r.byteLength,n.nalCount+=r.nalCount,n.duration+=r.duration,n.push(r),n},this.generateSampleTable_=function(e,t){var i,r,n,a,s,u=t||0,d=[];for(i=0;i<e.length;i++)for(a=e[i],r=0;r<a.length;r++)s=a[r],n=o(),n.dataOffset=u,n.compositionTimeOffset=s.pts-s.dts,n.duration=s.duration,n.size=4*s.length,n.size+=s.byteLength,s.keyFrame&&(n.flags.dependsOn=2),u+=n.size,d.push(n);return d},this.concatenateNalData_=function(e){var t,i,r,n,a,s,o=0,u=e.byteLength,d=e.nalCount,l=u+4*d,f=new Uint8Array(l),c=new DataView(f.buffer);for(t=0;t<e.length;t++)for(n=e[t],i=0;i<n.length;i++)for(a=n[i],r=0;r<a.length;r++)s=a[r],c.setUint32(o,s.data.byteLength),o+=4,f.set(s.data,o),o+=s.data.byteLength;return f}},r.prototype=new p,d=function(e,t){"number"==typeof t.pts&&(void 0===e.timelineStartInfo.pts&&(e.timelineStartInfo.pts=t.pts),void 0===e.minSegmentPts?e.minSegmentPts=t.pts:e.minSegmentPts=Math.min(e.minSegmentPts,t.pts),void 0===e.maxSegmentPts?e.maxSegmentPts=t.pts:e.maxSegmentPts=Math.max(e.maxSegmentPts,t.pts)),"number"==typeof t.dts&&(void 0===e.timelineStartInfo.dts&&(e.timelineStartInfo.dts=t.dts),void 0===e.minSegmentDts?e.minSegmentDts=t.dts:e.minSegmentDts=Math.min(e.minSegmentDts,t.dts),void 0===e.maxSegmentDts?e.maxSegmentDts=t.dts:e.maxSegmentDts=Math.max(e.maxSegmentDts,t.dts))},l=function(e){delete e.minSegmentDts,delete e.maxSegmentDts,delete e.minSegmentPts,delete e.maxSegmentPts},f=function(e){var t,i=9e4,r=e.minSegmentDts-e.timelineStartInfo.dts,n=e.minSegmentPts-e.minSegmentDts;e.baseMediaDecodeTime=e.timelineStartInfo.baseMediaDecodeTime,e.baseMediaDecodeTime+=r,e.baseMediaDecodeTime-=n,e.baseMediaDecodeTime=Math.max(0,e.baseMediaDecodeTime),"audio"===e.type&&(t=e.samplerate/i,e.baseMediaDecodeTime*=t,e.baseMediaDecodeTime=Math.floor(e.baseMediaDecodeTime))},s=function(e,t){this.numberOfTracks=0,this.metadataStream=t,"undefined"!=typeof e.remux?this.remuxTracks=!!e.remux:this.remuxTracks=!0,this.pendingTracks=[],this.videoTrack=null,this.pendingBoxes=[],this.pendingCaptions=[],this.pendingMetadata=[],this.pendingBytes=0,this.emittedTracks=0,s.prototype.init.call(this),this.push=function(e){return e.text?this.pendingCaptions.push(e):e.frames?this.pendingMetadata.push(e):(this.pendingTracks.push(e.track),this.pendingBoxes.push(e.boxes),this.pendingBytes+=e.boxes.byteLength,"video"===e.track.type&&(this.videoTrack=e.track),void("audio"===e.track.type&&(this.audioTrack=e.track)))}},s.prototype=new p,s.prototype.flush=function(e){var t,i,r,n,a=0,s={captions:[],metadata:[],info:{}},o=0;if(this.pendingTracks.length<this.numberOfTracks){if("VideoSegmentStream"!==e&&"AudioSegmentStream"!==e)return;if(this.remuxTracks)return;if(0===this.pendingTracks.length)return this.emittedTracks++,void(this.emittedTracks>=this.numberOfTracks&&(this.trigger("done"),this.emittedTracks=0))}for(this.videoTrack?(o=this.videoTrack.timelineStartInfo.pts,w.forEach(function(e){s.info[e]=this.videoTrack[e]},this)):this.audioTrack&&(o=this.audioTrack.timelineStartInfo.pts,_.forEach(function(e){s.info[e]=this.audioTrack[e]},this)),1===this.pendingTracks.length?s.type=this.pendingTracks[0].type:s.type="combined",this.emittedTracks+=this.pendingTracks.length,r=m.initSegment(this.pendingTracks),s.data=new Uint8Array(r.byteLength+this.pendingBytes),s.data.set(r),a+=r.byteLength,n=0;n<this.pendingBoxes.length;n++)s.data.set(this.pendingBoxes[n],a),a+=this.pendingBoxes[n].byteLength;for(n=0;n<this.pendingCaptions.length;n++)t=this.pendingCaptions[n],t.startTime=t.startPts-o,t.startTime/=9e4,t.endTime=t.endPts-o,t.endTime/=9e4,s.captions.push(t);for(n=0;n<this.pendingMetadata.length;n++)i=this.pendingMetadata[n],i.cueTime=i.pts-o,i.cueTime/=9e4,s.metadata.push(i);s.metadata.dispatchType=this.metadataStream.dispatchType,this.pendingTracks.length=0,this.videoTrack=null,this.pendingBoxes.length=0,this.pendingCaptions.length=0,this.pendingBytes=0,this.pendingMetadata.length=0,this.trigger("data",s),this.emittedTracks>=this.numberOfTracks&&(this.trigger("done"),this.emittedTracks=0)},a=function(e){var t,i,o=this,d=!0;a.prototype.init.call(this),e=e||{},this.baseMediaDecodeTime=e.baseMediaDecodeTime||0,this.transmuxPipeline_={},this.setupAacPipeline=function(){var t={};this.transmuxPipeline_=t,t.type="aac",t.metadataStream=new y.MetadataStream,t.aacStream=new b,t.adtsStream=new g,t.coalesceStream=new s(e,t.metadataStream),t.headOfPipeline=t.aacStream,t.aacStream.pipe(t.adtsStream),t.aacStream.pipe(t.metadataStream),t.metadataStream.pipe(t.coalesceStream),t.metadataStream.on("timestamp",function(e){t.aacStream.setTimestamp(e.timeStamp)}),t.aacStream.on("data",function(e){"timed-metadata"!==e.type||t.audioSegmentStream||(i=i||{timelineStartInfo:{baseMediaDecodeTime:o.baseMediaDecodeTime},codec:"adts",type:"audio"},t.coalesceStream.numberOfTracks++,t.audioSegmentStream=new n(i),t.adtsStream.pipe(t.audioSegmentStream).pipe(t.coalesceStream))}),t.coalesceStream.on("data",this.trigger.bind(this,"data")),t.coalesceStream.on("done",this.trigger.bind(this,"done"))},this.setupTsPipeline=function(){var a={};this.transmuxPipeline_=a,a.type="ts",a.metadataStream=new y.MetadataStream,a.packetStream=new y.TransportPacketStream,a.parseStream=new y.TransportParseStream,a.elementaryStream=new y.ElementaryStream,a.adtsStream=new g,a.h264Stream=new v,a.captionStream=new y.CaptionStream,a.coalesceStream=new s(e,a.metadataStream),a.headOfPipeline=a.packetStream,a.packetStream.pipe(a.parseStream).pipe(a.elementaryStream),a.elementaryStream.pipe(a.h264Stream),a.elementaryStream.pipe(a.adtsStream),a.elementaryStream.pipe(a.metadataStream).pipe(a.coalesceStream),a.h264Stream.pipe(a.captionStream).pipe(a.coalesceStream),a.elementaryStream.on("data",function(e){var s;if("metadata"===e.type){for(s=e.tracks.length;s--;)t||"video"!==e.tracks[s].type?i||"audio"!==e.tracks[s].type||(i=e.tracks[s],i.timelineStartInfo.baseMediaDecodeTime=o.baseMediaDecodeTime):(t=e.tracks[s],t.timelineStartInfo.baseMediaDecodeTime=o.baseMediaDecodeTime);t&&!a.videoSegmentStream&&(a.coalesceStream.numberOfTracks++,a.videoSegmentStream=new r(t),a.videoSegmentStream.on("timelineStartInfo",function(e){i&&(i.timelineStartInfo=e,a.audioSegmentStream.setEarliestDts(e.dts))}),a.h264Stream.pipe(a.videoSegmentStream).pipe(a.coalesceStream)),i&&!a.audioSegmentStream&&(a.coalesceStream.numberOfTracks++,a.audioSegmentStream=new n(i),a.adtsStream.pipe(a.audioSegmentStream).pipe(a.coalesceStream))}}),a.coalesceStream.on("data",this.trigger.bind(this,"data")),a.coalesceStream.on("done",this.trigger.bind(this,"done"))},this.setBaseMediaDecodeTime=function(e){var r=this.transmuxPipeline_;this.baseMediaDecodeTime=e,i&&(i.timelineStartInfo.dts=void 0,i.timelineStartInfo.pts=void 0,l(i),i.timelineStartInfo.baseMediaDecodeTime=e),t&&(r.videoSegmentStream&&(r.videoSegmentStream.gopCache_=[]),t.timelineStartInfo.dts=void 0,t.timelineStartInfo.pts=void 0,l(t),t.timelineStartInfo.baseMediaDecodeTime=e)},this.push=function(e){if(d){var t=u(e);t&&"aac"!==this.transmuxPipeline_.type?this.setupAacPipeline():t||"ts"===this.transmuxPipeline_.type||this.setupTsPipeline(),d=!1}this.transmuxPipeline_.headOfPipeline.push(e)},this.flush=function(){d=!0,this.transmuxPipeline_.headOfPipeline.flush()}},a.prototype=new p,t.exports={Transmuxer:a,VideoSegmentStream:r,AudioSegmentStream:n,AUDIO_PROPERTIES:_,VIDEO_PROPERTIES:w}},{"../aac":75,"../codecs/adts.js":76,"../codecs/h264":77,"../m2ts/m2ts.js":82,"../utils/stream.js":89,"./mp4-generator.js":86}],88:[function(e,t,i){"use strict";var r;r=function(e){var t=e.byteLength,i=0,r=0;this.length=function(){return 8*t},this.bitsAvailable=function(){return 8*t+r},this.loadWord=function(){var n=e.byteLength-t,a=new Uint8Array(4),s=Math.min(4,t);if(0===s)throw new Error("no bytes available");a.set(e.subarray(n,n+s)),i=new DataView(a.buffer).getUint32(0),r=8*s,t-=s},this.skipBits=function(e){var n;r>e?(i<<=e,r-=e):(e-=r,n=Math.floor(e/8),e-=8*n,t-=n,this.loadWord(),i<<=e,r-=e)},this.readBits=function(e){var n=Math.min(r,e),a=i>>>32-n;return r-=n,r>0?i<<=n:t>0&&this.loadWord(),n=e-n,n>0?a<<n|this.readBits(n):a},this.skipLeadingZeros=function(){var e;for(e=0;r>e;++e)if(0!==(i&2147483648>>>e))return i<<=e,r-=e,e;return this.loadWord(),e+this.skipLeadingZeros()},this.skipUnsignedExpGolomb=function(){this.skipBits(1+this.skipLeadingZeros())},this.skipExpGolomb=function(){this.skipBits(1+this.skipLeadingZeros())},this.readUnsignedExpGolomb=function(){var e=this.skipLeadingZeros();return this.readBits(e+1)-1},this.readExpGolomb=function(){var e=this.readUnsignedExpGolomb();return 1&e?1+e>>>1:-1*(e>>>1)},this.readBoolean=function(){return 1===this.readBits(1)},this.readUnsignedByte=function(){return this.readBits(8)},this.loadWord()},t.exports=r},{}],89:[function(e,t,i){"use strict";var r=function(){this.init=function(){var e={};this.on=function(t,i){e[t]||(e[t]=[]),e[t].push(i)},this.off=function(t,i){var r;return e[t]?(r=e[t].indexOf(i),e[t].splice(r,1),r>-1):!1},this.trigger=function(t){var i,r,n,a;if(i=e[t])if(2===arguments.length)for(n=i.length,r=0;n>r;++r)i[r].call(this,arguments[1]);else{for(a=[],r=arguments.length,r=1;r<arguments.length;++r)a.push(arguments[r]);for(n=i.length,r=0;n>r;++r)i[r].apply(this,a)}},this.dispose=function(){e={}}}};r.prototype.pipe=function(e){return this.on("data",function(t){e.push(t)}),this.on("done",function(t){e.flush(t)}),e},r.prototype.push=function(e){this.trigger("data",e)},r.prototype.flush=function(e){this.trigger("done",e)},t.exports=r},{}],90:[function(e,t,i){var r=arguments[3],n=arguments[4],a=arguments[5],s=JSON.stringify;t.exports=function(e){for(var t,i=Object.keys(a),o=0,u=i.length;u>o;o++){var d=i[o];if(a[d].exports===e){t=d;break}}if(!t){t=Math.floor(Math.pow(16,8)*Math.random()).toString(16);for(var l={},o=0,u=i.length;u>o;o++){var d=i[o];l[d]=d}n[t]=[Function(["require","module","exports"],"("+e+")(self)"),l]}var f=Math.floor(Math.pow(16,8)*Math.random()).toString(16),c={};c[t]=t,n[f]=[Function(["require"],"require("+s(t)+")(self)"),c];var h="("+r+")({"+Object.keys(n).map(function(e){return s(e)+":["+n[e][0]+","+s(n[e][1])+"]"}).join(",")+"},{},["+s(f)+"])",p=window.URL||window.webkitURL||window.mozURL||window.msURL;return new Worker(p.createObjectURL(new Blob([h],{type:"text/javascript"})))}},{}],91:[function(e,t,i){(function(i){"use strict";function r(e){return e&&e.__esModule?e:{"default":e}}function n(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function a(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}var s=function(){function e(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,i,r){return i&&e(t.prototype,i),r&&e(t,r),t}}(),o=function(e,t,i){for(var r=!0;r;){var n=e,a=t,s=i;r=!1,null===n&&(n=Function.prototype);var o=Object.getOwnPropertyDescriptor(n,a);if(void 0!==o){if("value"in o)return o.value;var u=o.get;if(void 0===u)return;return u.call(s)}var d=Object.getPrototypeOf(n);if(null===d)return;e=d,t=a,i=s,r=!0,o=d=void 0}},u=e("global/document"),d=r(u),l=e("./playlist-loader"),f=r(l),c=e("./playlist"),h=r(c),p=e("./xhr"),m=r(p),y=e("./decrypter"),g=e("./bin-utils"),v=r(g),b=e("videojs-contrib-media-sources"),_=e("m3u8-parser"),w=r(_),S="undefined"!=typeof window?window.videojs:"undefined"!=typeof i?i.videojs:null,T=r(S),k=e("./master-playlist-controller"),O=r(k),P=e("./config"),x=r(P),A=e("./rendition-mixin"),L=r(A),j=function(e,t){if(typeof e!=typeof t)return!0;if(Object.keys(e).length!==Object.keys(t).length)return!0;for(var i in e)if(!t[i]||e[i]!==t[i])return!0;return!1},E={PlaylistLoader:f["default"],Playlist:h["default"],Decrypter:y.Decrypter,AsyncStream:y.AsyncStream,decrypt:y.decrypt,utils:v["default"],xhr:(0,m["default"])()};Object.defineProperty(E,"GOAL_BUFFER_LENGTH",{get:function(){return T["default"].log.warn("using Hls.GOAL_BUFFER_LENGTH is UNSAFE be sure you know what you are doing"),x["default"].GOAL_BUFFER_LENGTH},set:function(e){return T["default"].log.warn("using Hls.GOAL_BUFFER_LENGTH is UNSAFE be sure you know what you are doing"),"number"!=typeof e||0>=e?void T["default"].log.warn("value passed to Hls.GOAL_BUFFER_LENGTH must be a number and greater than 0"):void(x["default"].GOAL_BUFFER_LENGTH=e)}});var C=1.2,U=function(e,t){var i=void 0;return e?(i=getComputedStyle(e),i?i[t]:""):""};E.STANDARD_PLAYLIST_SELECTOR=function(){var e=void 0,t=this.playlists.master.playlists.slice(),i=[],r=+new Date,n=void 0,a=void 0,s=void 0,o=void 0,u=void 0,d=void 0,l=void 0,f=void 0;for(t.sort(E.comparePlaylistBandwidth),t=t.filter(function(e){return"undefined"!=typeof e.excludeUntil?r>=e.excludeUntil:!0}),n=t.length;n--;)a=t[n],a.attributes&&a.attributes.BANDWIDTH&&(e=a.attributes.BANDWIDTH*C,e<this.bandwidth&&(i.push(a),s||(s=a)));for(n=i.length,i.sort(E.comparePlaylistResolution),a=null,l=parseInt(U(this.tech_.el(),"width"),10),f=parseInt(U(this.tech_.el(),"height"),10);n--;)if(a=i[n],a.attributes&&a.attributes.RESOLUTION&&a.attributes.RESOLUTION.width&&a.attributes.RESOLUTION.height){var c=a.attributes.RESOLUTION;if(c.width===l&&c.height===f){o=null,d=a;break}if(c.width<l&&c.height<f)break;(!o||c.width<u.width&&c.height<u.height)&&(o=a,u=o.attributes.RESOLUTION)}return o||d||s||t[0]},E.canPlaySource=function(){return T["default"].log.warn("HLS is no longer a tech. Please remove it from your player's techOrder.")},E.supportsNativeHls=function(){var e=d["default"].createElement("video");if(!T["default"].getComponent("Html5").isSupported())return!1;var t=["application/vnd.apple.mpegurl","audio/mpegurl","audio/x-mpegurl","application/x-mpegurl","video/x-mpegurl","video/mpegurl","application/mpegurl"];return t.some(function(t){return/maybe|probably/i.test(e.canPlayType(t))})}(),E.isSupported=function(){return T["default"].log.warn("HLS is no longer a tech. Please remove it from your player's techOrder.")};var D=T["default"].getComponent("Component"),M=function(e){function t(e,i,r){var a=this;if(n(this,t),o(Object.getPrototypeOf(t.prototype),"constructor",this).call(this,i),i.options_&&i.options_.playerId){var s=(0,T["default"])(i.options_.playerId);s.hasOwnProperty("hls")||Object.defineProperty(s,"hls",{get:function(){return T["default"].log.warn("player.hls is deprecated. Use player.tech.hls instead."),a}})}this.tech_=i,this.source_=e,this.stats={},this.options_=T["default"].mergeOptions(T["default"].options.hls||{},r.hls),this.setOptions_(),this.on(d["default"],["fullscreenchange","webkitfullscreenchange","mozfullscreenchange","MSFullscreenChange"],function(e){var t=d["default"].fullscreenElement||d["default"].webkitFullscreenElement||d["default"].mozFullScreenElement||d["default"].msFullscreenElement;t&&t.contains(a.tech_.el())&&a.masterPlaylistController_.fastQualityChange_()}),this.on(this.tech_,"seeking",function(){this.setCurrentTime(this.tech_.currentTime())}),this.on(this.tech_,"error",function(){this.masterPlaylistController_&&this.masterPlaylistController_.pauseLoading()}),this.audioTrackChange_=function(){a.masterPlaylistController_.useAudio()},this.on(this.tech_,"play",this.play)}return a(t,e),s(t,[{key:"setOptions_",value:function(){var e=this;this.options_.withCredentials=this.options_.withCredentials||!1,this.options_.bandwidth=this.options_.bandwidth||4194304,["withCredentials","bandwidth"].forEach(function(t){"undefined"!=typeof e.source_[t]&&(e.options_[t]=e.source_[t])}),this.bandwidth=this.options_.bandwidth}},{key:"src",value:function(e){var t=this;e&&(this.setOptions_(),this.options_.url=this.source_.src,this.options_.tech=this.tech_,this.options_.externHls=E,this.masterPlaylistController_=new O["default"](this.options_),this.masterPlaylistController_.selectPlaylist=E.STANDARD_PLAYLIST_SELECTOR.bind(this),this.playlists=this.masterPlaylistController_.masterPlaylistLoader_,this.mediaSource=this.masterPlaylistController_.mediaSource,Object.defineProperties(this,{selectPlaylist:{get:function(){return this.masterPlaylistController_.selectPlaylist},set:function(e){this.masterPlaylistController_.selectPlaylist=e.bind(this)}},bandwidth:{get:function(){return this.masterPlaylistController_.mainSegmentLoader_.bandwidth},set:function(e){this.masterPlaylistController_.mainSegmentLoader_.bandwidth=e}}}),Object.defineProperty(this.stats,"bandwidth",{get:function(){return t.bandwidth||0}}),Object.defineProperty(this.stats,"mediaRequests",{get:function(){return t.masterPlaylistController_.mediaRequests_()||0}}),Object.defineProperty(this.stats,"mediaTransferDuration",{get:function(){return t.masterPlaylistController_.mediaTransferDuration_()||0}}),Object.defineProperty(this.stats,"mediaBytesTransferred",{get:function(){return t.masterPlaylistController_.mediaBytesTransferred_()||0}}),this.tech_.one("canplay",this.masterPlaylistController_.setupFirstPlay.bind(this.masterPlaylistController_)),this.masterPlaylistController_.on("sourceopen",function(){t.tech_.audioTracks().addEventListener("change",t.audioTrackChange_)}),this.masterPlaylistController_.on("audioinfo",function(e){if(!T["default"].browser.IS_FIREFOX||!t.audioInfo_||!j(t.audioInfo_,e.info))return void(t.audioInfo_=e.info);var i="had different audio properties (channels, sample rate, etc.) or changed in some other way.  This behavior is currently unsupported in Firefox due to an issue: \n\nhttps://bugzilla.mozilla.org/show_bug.cgi?id=1247138\n\n",r=void 0,n=void 0;t.masterPlaylistController_.audioTracks_.forEach(function(e){!n&&e["default"]&&(n=e),!r&&e.enabled&&(r=e)}),r.getLoader(t.activeAudioGroup_())?(i="The audio track '"+r.label+"' that we tried to "+("switch to "+i+" Unfortunately this means we will have to ")+("return you to the main track '"+n.label+"'. Sorry!"),n.enabled=!0,t.tech_.audioTracks().removeTrack(r)):(i="The rendition that we tried to switch to "+i+"Unfortunately that means we will have to blacklist the current playlist and switch to another. Sorry!",t.masterPlaylistController_.blacklistCurrentPlaylist()),T["default"].log.warn(i),t.masterPlaylistController_.useAudio()}),this.masterPlaylistController_.on("selectedinitialmedia",function(){t.tech_.clearTracks("audio"),t.masterPlaylistController_.audioTracks_.forEach(function(e){t.tech_.audioTracks().addTrack(e)}),(0,L["default"])(t)}),this.on(this.masterPlaylistController_,"progress",function(){this.bandwidth=this.masterPlaylistController_.mainSegmentLoader_.bandwidth,this.tech_.trigger("progress")}),this.tech_.el()&&this.tech_.src(T["default"].URL.createObjectURL(this.masterPlaylistController_.mediaSource)));
}},{key:"activeAudioGroup_",value:function(){return this.masterPlaylistController_.activeAudioGroup()}},{key:"play",value:function(){this.masterPlaylistController_.play()}},{key:"setCurrentTime",value:function(e){this.masterPlaylistController_.setCurrentTime(e)}},{key:"duration",value:function(){return this.masterPlaylistController_.duration()}},{key:"seekable",value:function(){return this.masterPlaylistController_.seekable()}},{key:"dispose",value:function(){this.masterPlaylistController_&&this.masterPlaylistController_.dispose(),this.tech_.audioTracks().removeEventListener("change",this.audioTrackChange_),o(Object.getPrototypeOf(t.prototype),"dispose",this).call(this)}}]),t}(D),I=function B(e){return{canHandleSource:function(t){return T["default"].options.hls&&T["default"].options.hls.mode&&T["default"].options.hls.mode!==e?!1:B.canPlayType(t.type)},handleSource:function(t,i,r){"flash"===e&&i.setTimeout(function(){i.trigger("loadstart")},1);var n=T["default"].mergeOptions(r,{hls:{mode:e}});return i.hls=new M(t,i,n),i.hls.xhr=(0,m["default"])(),T["default"].Hls.xhr.beforeRequest&&(i.hls.xhr.beforeRequest=T["default"].Hls.xhr.beforeRequest),i.hls.src(t.src),i.hls},canPlayType:function(e){return B.canPlayType(e)?"maybe":""}}};E.comparePlaylistBandwidth=function(e,t){var i=void 0,r=void 0;return e.attributes&&e.attributes.BANDWIDTH&&(i=e.attributes.BANDWIDTH),i=i||window.Number.MAX_VALUE,t.attributes&&t.attributes.BANDWIDTH&&(r=t.attributes.BANDWIDTH),r=r||window.Number.MAX_VALUE,i-r},E.comparePlaylistResolution=function(e,t){var i=void 0,r=void 0;return e.attributes&&e.attributes.RESOLUTION&&e.attributes.RESOLUTION.width&&(i=e.attributes.RESOLUTION.width),i=i||window.Number.MAX_VALUE,t.attributes&&t.attributes.RESOLUTION&&t.attributes.RESOLUTION.width&&(r=t.attributes.RESOLUTION.width),r=r||window.Number.MAX_VALUE,i===r&&e.attributes.BANDWIDTH&&t.attributes.BANDWIDTH?e.attributes.BANDWIDTH-t.attributes.BANDWIDTH:i-r},I.canPlayType=function(e){var t=/^(audio|video|application)\/(x-|vnd\.apple\.)?mpegurl/i;return E.supportsNativeHls?!1:t.test(e)},"undefined"!=typeof T["default"].MediaSource&&"undefined"!=typeof T["default"].URL||(T["default"].MediaSource=b.MediaSource,T["default"].URL=b.URL),b.MediaSource.supportsNativeMediaSources()&&T["default"].getComponent("Html5").registerSourceHandler(I("html5")),window.Uint8Array&&T["default"].getComponent("Flash").registerSourceHandler(I("flash")),T["default"].HlsHandler=M,T["default"].HlsSourceHandler=I,T["default"].Hls=E,T["default"].m3u8=w["default"],T["default"].registerComponent("Hls",E),T["default"].options.hls=T["default"].options.hls||{},t.exports={Hls:E,HlsHandler:M,HlsSourceHandler:I}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./bin-utils":1,"./config":2,"./decrypter":6,"./master-playlist-controller":8,"./playlist":10,"./playlist-loader":9,"./rendition-mixin":12,"./xhr":17,"global/document":19,"m3u8-parser":56,"videojs-contrib-media-sources":73}]},{},[91])(91)});
!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{var t;t="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this,t.Hls=e()}}(function(){return function s(e,t,r){function i(a,d){if(!t[a]){if(!e[a]){var l="function"==typeof require&&require;if(!d&&l)return l(a,!0);if(n)return n(a,!0);var u=new Error("Cannot find module '"+a+"'");throw u.code="MODULE_NOT_FOUND",u}var o=t[a]={exports:{}};e[a][0].call(o.exports,function(t){var r=e[a][1][t];return i(r?r:t)},o,o.exports,s,e,t,r)}return t[a].exports}for(var n="function"==typeof require&&require,a=0;a<r.length;a++)i(r[a]);return i}({1:[function(s,a,o){function e(){this._events=this._events||{},this._maxListeners=this._maxListeners||void 0}function t(e){return"function"==typeof e}function n(e){return"number"==typeof e}function r(e){return"object"==typeof e&&null!==e}function i(e){return void 0===e}a.exports=e,e.EventEmitter=e,e.prototype._events=void 0,e.prototype._maxListeners=void 0,e.defaultMaxListeners=10,e.prototype.setMaxListeners=function(e){if(!n(e)||0>e||isNaN(e))throw TypeError("n must be a positive number");return this._maxListeners=e,this},e.prototype.emit=function(l){var s,e,u,a,n,o;if(this._events||(this._events={}),"error"===l&&(!this._events.error||r(this._events.error)&&!this._events.error.length)){if(s=arguments[1],s instanceof Error)throw s;throw TypeError('Uncaught, unspecified "error" event.')}if(e=this._events[l],i(e))return!1;if(t(e))switch(arguments.length){case 1:e.call(this);break;case 2:e.call(this,arguments[1]);break;case 3:e.call(this,arguments[1],arguments[2]);break;default:a=Array.prototype.slice.call(arguments,1),e.apply(this,a)}else if(r(e))for(a=Array.prototype.slice.call(arguments,1),o=e.slice(),u=o.length,n=0;u>n;n++)o[n].apply(this,a);return!0},e.prototype.addListener=function(a,n){var s;if(!t(n))throw TypeError("listener must be a function");return this._events||(this._events={}),this._events.newListener&&this.emit("newListener",a,t(n.listener)?n.listener:n),this._events[a]?r(this._events[a])?this._events[a].push(n):this._events[a]=[this._events[a],n]:this._events[a]=n,r(this._events[a])&&!this._events[a].warned&&(s=i(this._maxListeners)?e.defaultMaxListeners:this._maxListeners,s&&s>0&&this._events[a].length>s&&(this._events[a].warned=!0,"function"==typeof console.trace)),this},e.prototype.on=e.prototype.addListener,e.prototype.once=function(i,e){function r(){this.removeListener(i,r),a||(a=!0,e.apply(this,arguments))}if(!t(e))throw TypeError("listener must be a function");var a=!1;return r.listener=e,this.on(i,r),this},e.prototype.removeListener=function(a,i){var e,s,o,n;if(!t(i))throw TypeError("listener must be a function");if(!this._events||!this._events[a])return this;if(e=this._events[a],o=e.length,s=-1,e===i||t(e.listener)&&e.listener===i)delete this._events[a],this._events.removeListener&&this.emit("removeListener",a,i);else if(r(e)){for(n=o;n-- >0;)if(e[n]===i||e[n].listener&&e[n].listener===i){s=n;break}if(0>s)return this;1===e.length?(e.length=0,delete this._events[a]):e.splice(s,1),this._events.removeListener&&this.emit("removeListener",a,i)}return this},e.prototype.removeAllListeners=function(r){var i,e;if(!this._events)return this;if(!this._events.removeListener)return 0===arguments.length?this._events={}:this._events[r]&&delete this._events[r],this;if(0===arguments.length){for(i in this._events)"removeListener"!==i&&this.removeAllListeners(i);return this.removeAllListeners("removeListener"),this._events={},this}if(e=this._events[r],t(e))this.removeListener(r,e);else if(e)for(;e.length;)this.removeListener(r,e[e.length-1]);return delete this._events[r],this},e.prototype.listeners=function(e){var r;return r=this._events&&this._events[e]?t(this._events[e])?[this._events[e]]:this._events[e].slice():[]},e.prototype.listenerCount=function(r){if(this._events){var e=this._events[r];if(t(e))return 1;if(e)return e.length}return 0},e.listenerCount=function(e,t){return e.listenerCount(t)}},{}],2:[function(n,i,s){var a=arguments[3],e=arguments[4],r=arguments[5],t=JSON.stringify;i.exports=function(l){for(var i,s=Object.keys(r),n=0,d=s.length;d>n;n++){var o=s[n],u=r[o].exports;if(u===l||u.default===l){i=o;break}}if(!i){i=Math.floor(Math.pow(16,8)*Math.random()).toString(16);for(var f={},n=0,d=s.length;d>n;n++){var o=s[n];f[o]=o}e[i]=[Function(["require","module","exports"],"("+l+")(self)"),f]}var h=Math.floor(Math.pow(16,8)*Math.random()).toString(16),c={};c[i]=i,e[h]=[Function(["require"],"var f = require("+t(i)+");(f.default ? f.default : f)(self);"),c];var v="("+a+")({"+Object.keys(e).map(function(r){return t(r)+":["+e[r][0]+","+t(e[r][1])+"]"}).join(",")+"},{},["+t(h)+"])",g=window.URL||window.webkitURL||window.mozURL||window.msURL;return new Worker(g.createObjectURL(new Blob([v],{type:"text/javascript"})))}},{}],3:[function(e,m,n){"use strict";function r(e){return e&&e.__esModule?e:{default:e}}function f(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function g(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function v(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(n,"__esModule",{value:!0});var l=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),c=e("../events"),t=r(c),d=e("../event-handler"),a=r(d),h=e("../helper/buffer-helper"),o=r(h),s=e("../errors"),i=e("../utils/logger"),p=e("./ewma-bandwidth-estimator"),u=r(p),y=function(r){function e(i){f(this,e);var r=g(this,Object.getPrototypeOf(e).call(this,i,t.default.FRAG_LOADING,t.default.FRAG_LOADED,t.default.ERROR));return r.lastLoadedFragLevel=0,r._autoLevelCapping=-1,r._nextAutoLevel=-1,r.hls=i,r.bwEstimator=new u.default(i),r.onCheck=r.abandonRulesCheck.bind(r),r}return v(e,r),l(e,[{key:"destroy",value:function(){this.clearTimer(),a.default.prototype.destroy.call(this)}},{key:"onFragLoading",value:function(e){this.timer||(this.timer=setInterval(this.onCheck,100)),this.fragCurrent=e.frag}},{key:"abandonRulesCheck",value:function(){var a=this.hls,n=a.media,e=this.fragCurrent;if(!e.loader||e.loader.stats&&e.loader.stats.aborted)return i.logger.warn("frag loader destroy or aborted, disarm abandonRulesCheck"),void this.clearTimer();if(n&&(!n.paused||!n.readyState)&&e.autoLevel&&e.level){var u=performance.now()-e.trequest;if(u>500*e.duration){var f=Math.max(1,1e3*e.loaded/u);e.expectedLen<e.loaded&&(e.expectedLen=e.loaded);var h=n.currentTime,d=(e.expectedLen-e.loaded)/f,s=o.default.bufferInfo(n,h,a.config.maxBufferHole).end-h;if(s<2*e.duration&&d>s){var l=void 0,r=void 0;for(r=e.level-1;r>=0&&(l=e.duration*a.levels[r].bitrate/(6.4*f),i.logger.log("fragLoadedDelay/bufferStarvationDelay/fragLevelNextLoadedDelay["+r+"] :"+d.toFixed(1)+"/"+s.toFixed(1)+"/"+l.toFixed(1)),!(s>l));r--);d>l&&(r=Math.max(0,r),a.nextLoadLevel=r,this.bwEstimator.sample(u,e.loaded),i.logger.warn("loading too slow, abort fragment loading and switch to level "+r),e.loader.abort(),this.clearTimer(),a.trigger(t.default.FRAG_LOAD_EMERGENCY_ABORTED,{frag:e}))}}}}},{key:"onFragLoaded",value:function(e){var t=e.stats;void 0===t.aborted&&1===e.frag.loadCounter&&this.bwEstimator.sample(performance.now()-t.trequest,t.loaded),this.clearTimer(),this.lastLoadedFragLevel=e.frag.level,this._nextAutoLevel=-1}},{key:"onError",value:function(e){switch(e.details){case s.ErrorDetails.FRAG_LOAD_ERROR:case s.ErrorDetails.FRAG_LOAD_TIMEOUT:this.clearTimer()}}},{key:"clearTimer",value:function(){this.timer&&(clearInterval(this.timer),this.timer=null)}},{key:"autoLevelCapping",get:function(){return this._autoLevelCapping},set:function(e){this._autoLevelCapping=e}},{key:"nextAutoLevel",get:function(){var e,r,i=this.hls,t=i.levels,a=i.config;if(r=-1===this._autoLevelCapping&&t&&t.length?t.length-1:this._autoLevelCapping,-1!==this._nextAutoLevel)return Math.min(this._nextAutoLevel,r);var n=this.bwEstimator.getEstimate(),s=void 0;for(e=0;r>=e;e++)if(s=e<=this.lastLoadedFragLevel?a.abrBandWidthFactor*n:a.abrBandWidthUpFactor*n,s<t[e].bitrate)return Math.max(0,e-1);return e-1},set:function(e){this._nextAutoLevel=e}}]),e}(a.default);n.default=y},{"../errors":21,"../event-handler":22,"../events":23,"../helper/buffer-helper":24,"../utils/logger":38,"./ewma-bandwidth-estimator":6}],4:[function(i,v,a){"use strict";function n(e){return e&&e.__esModule?e:{default:e}}function u(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function f(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function h(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(a,"__esModule",{value:!0});var c=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),l=i("../events"),e=n(l),d=i("../event-handler"),s=n(d),t=i("../utils/logger"),r=i("../errors"),o=function(a){function i(r){u(this,i);var t=f(this,Object.getPrototypeOf(i).call(this,r,e.default.MEDIA_ATTACHING,e.default.MEDIA_DETACHING,e.default.BUFFER_RESET,e.default.BUFFER_APPENDING,e.default.BUFFER_CODECS,e.default.BUFFER_EOS,e.default.BUFFER_FLUSHING,e.default.LEVEL_UPDATED));return t._msDuration=null,t._levelDuration=null,t.onsbue=t.onSBUpdateEnd.bind(t),t.onsbe=t.onSBUpdateError.bind(t),t}return h(i,a),c(i,[{key:"destroy",value:function(){s.default.prototype.destroy.call(this)}},{key:"onMediaAttaching",value:function(r){var t=this.media=r.media;if(t){var e=this.mediaSource=new MediaSource;this.onmso=this.onMediaSourceOpen.bind(this),this.onmse=this.onMediaSourceEnded.bind(this),this.onmsc=this.onMediaSourceClose.bind(this),e.addEventListener("sourceopen",this.onmso),e.addEventListener("sourceended",this.onmse),e.addEventListener("sourceclose",this.onmsc),t.src=URL.createObjectURL(e)}}},{key:"onMediaDetaching",value:function(){var r=this.mediaSource;if(r){if("open"===r.readyState)try{r.endOfStream()}catch(e){t.logger.warn("onMediaDetaching:"+e.message+" while calling endOfStream")}r.removeEventListener("sourceopen",this.onmso),r.removeEventListener("sourceended",this.onmse),r.removeEventListener("sourceclose",this.onmsc);try{this.media.src="",this.media.removeAttribute("src")}catch(e){t.logger.warn("onMediaDetaching:"+e.message+" while unlinking video.src")}this.mediaSource=null,this.media=null,this.pendingTracks=null,this.sourceBuffer=null}this.onmso=this.onmse=this.onmsc=null,this.hls.trigger(e.default.MEDIA_DETACHED)}},{key:"onMediaSourceOpen",value:function(){t.logger.log("media source opened"),this.hls.trigger(e.default.MEDIA_ATTACHED,{media:this.media}),this.mediaSource.removeEventListener("sourceopen",this.onmso);var r=this.pendingTracks;r&&(this.onBufferCodecs(r),this.pendingTracks=null,this.doAppending())}},{key:"onMediaSourceClose",value:function(){t.logger.log("media source closed")}},{key:"onMediaSourceEnded",value:function(){t.logger.log("media source ended")}},{key:"onSBUpdateEnd",value:function(){this._needsFlush&&this.doFlush(),this._needsEos&&this.onBufferEos(),this.hls.trigger(e.default.BUFFER_APPENDED),this.doAppending()}},{key:"onSBUpdateError",value:function(i){t.logger.error("sourceBuffer error:"+i),this.hls.trigger(e.default.ERROR,{type:r.ErrorTypes.MEDIA_ERROR,details:r.ErrorDetails.BUFFER_APPENDING_ERROR,fatal:!1})}},{key:"onBufferReset",value:function(){var e=this.sourceBuffer;if(e){for(var r in e){var t=e[r];try{this.mediaSource.removeSourceBuffer(t),t.removeEventListener("updateend",this.onsbue),t.removeEventListener("error",this.onsbe)}catch(e){}}this.sourceBuffer=null}this.flushRange=[],this.appended=0}},{key:"onBufferCodecs",value:function(e){var r=this.mediaSource;if(!r||"open"!==r.readyState)return void(this.pendingTracks=e);if(!this.sourceBuffer){var a={};for(var n in e){var i=e[n],l=i.levelCodec||i.codec,s=i.container+";codecs="+l;t.logger.log("creating sourceBuffer with mimeType:"+s);var o=a[n]=r.addSourceBuffer(s);o.addEventListener("updateend",this.onsbue),o.addEventListener("error",this.onsbe)}this.sourceBuffer=a}}},{key:"onBufferAppending",value:function(e){this.segments?this.segments.push(e):this.segments=[e],this.doAppending()}},{key:"onBufferAppendFail",value:function(i){t.logger.error("sourceBuffer error:"+i.event),this.hls.trigger(e.default.ERROR,{type:r.ErrorTypes.MEDIA_ERROR,details:r.ErrorDetails.BUFFER_APPENDING_ERROR,fatal:!1,frag:this.fragCurrent})}},{key:"onBufferEos",value:function(){var e=this.sourceBuffer,r=this.mediaSource;r&&"open"===r.readyState&&(e.audio&&e.audio.updating||e.video&&e.video.updating?this._needsEos=!0:(t.logger.log("all media data available, signal endOfStream() to MediaSource and stop loading fragment"),r.endOfStream(),this._needsEos=!1))}},{key:"onBufferFlushing",value:function(e){this.flushRange.push({start:e.startOffset,end:e.endOffset}),this.flushBufferCounter=0,this.doFlush()}},{key:"onLevelUpdated",value:function(t){var e=t.details;0!==e.fragments.length&&(this._levelDuration=e.totalduration+e.fragments[0].start,this.updateMediaElementDuration())}},{key:"updateMediaElementDuration",value:function(){if(null!==this._levelDuration){var r=this.media,e=this.mediaSource;if(r&&e&&0!==r.readyState&&"open"===e.readyState){for(var i in e.sourceBuffers)if(e.sourceBuffers[i].updating)return;null===this._msDuration&&(this._msDuration=e.duration),this._levelDuration>this._msDuration&&(t.logger.log("Updating mediasource duration to "+this._levelDuration),e.duration=this._levelDuration,this._msDuration=this._levelDuration)}}}},{key:"doFlush",value:function(){for(;this.flushRange.length;){var r=this.flushRange[0];if(!this.flushBuffer(r.start,r.end))return void(this._needsFlush=!0);this.flushRange.shift(),this.flushBufferCounter=0}if(0===this.flushRange.length){this._needsFlush=!1;var i=0,t=this.sourceBuffer;if(t)for(var a in t)i+=t[a].buffered.length;this.appended=i,this.hls.trigger(e.default.BUFFER_FLUSHED)}}},{key:"doAppending",value:function(){var n=this.hls,s=this.sourceBuffer,a=this.segments;if(s){if(this.media.error)return a=[],void t.logger.error("trying to append although a media error occured, flush segment and abort");for(var l in s)if(s[l].updating)return;if(a.length){var o=a.shift();try{s[o.type].appendBuffer(o.data),this.appendError=0,this.appended++}catch(s){t.logger.error("error while trying to append buffer:"+s.message),a.unshift(o);var i={type:r.ErrorTypes.MEDIA_ERROR};if(22!==s.code){if(this.appendError?this.appendError++:this.appendError=1,i.details=r.ErrorDetails.BUFFER_APPEND_ERROR,i.frag=this.fragCurrent,this.appendError>n.config.appendErrorMaxRetry)return t.logger.log("fail "+n.config.appendErrorMaxRetry+" times to append segment in sourceBuffer"),a=[],i.fatal=!0,void n.trigger(e.default.ERROR,i);i.fatal=!1,n.trigger(e.default.ERROR,i)}else a=[],i.details=r.ErrorDetails.BUFFER_FULL_ERROR,n.trigger(e.default.ERROR,i)}}}}},{key:"flushBuffer",value:function(l,s){var e,r,o,n,i,a;if(this.flushBufferCounter<this.appended&&this.sourceBuffer)for(var u in this.sourceBuffer){if(e=this.sourceBuffer[u],e.updating)return t.logger.warn("cannot flush, sb updating in progress"),!1;for(r=0;r<e.buffered.length;r++)if(o=e.buffered.start(r),n=e.buffered.end(r),-1!==navigator.userAgent.toLowerCase().indexOf("firefox")&&s===Number.POSITIVE_INFINITY?(i=l,a=s):(i=Math.max(o,l),a=Math.min(n,s)),Math.min(a,n)-i>.5)return this.flushBufferCounter++,t.logger.log("flush "+u+" ["+i+","+a+"], of ["+o+","+n+"], pos:"+this.media.currentTime),e.remove(i,a),!1}else t.logger.warn("abort flushing too many retries");return t.logger.log("buffer flushed"),!0}}]),i}(s.default);a.default=o},{"../errors":21,"../event-handler":22,"../events":23,"../utils/logger":38}],5:[function(e,h,t){"use strict";function r(e){return e&&e.__esModule?e:{default:e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function n(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function f(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(t,"__esModule",{value:!0});var o=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),l=e("../events"),i=r(l),d=e("../event-handler"),s=r(d),u=function(t){function e(t){return a(this,e),n(this,Object.getPrototypeOf(e).call(this,t,i.default.MEDIA_ATTACHING,i.default.MANIFEST_PARSED))}return f(e,t),o(e,[{key:"destroy",value:function(){this.hls.config.capLevelToPlayerSize&&(this.media=null,this.autoLevelCapping=Number.POSITIVE_INFINITY,this.timer&&(this.timer=clearInterval(this.timer)))}},{key:"onMediaAttaching",value:function(e){this.media=e.media instanceof HTMLVideoElement?e.media:null}},{key:"onManifestParsed",value:function(e){this.hls.config.capLevelToPlayerSize&&(this.autoLevelCapping=Number.POSITIVE_INFINITY,this.levels=e.levels,this.hls.firstLevel=this.getMaxLevel(e.firstLevel),clearInterval(this.timer),this.timer=setInterval(this.detectPlayerSize.bind(this),1e3),this.detectPlayerSize())}},{key:"detectPlayerSize",value:function(){if(this.media){var e=this.levels?this.levels.length:0;e&&(this.hls.autoLevelCapping=this.getMaxLevel(e-1),this.hls.autoLevelCapping>this.autoLevelCapping&&this.hls.streamController.nextLevelSwitch(),this.autoLevelCapping=this.hls.autoLevelCapping)}}},{key:"getMaxLevel",value:function(n){var r=void 0,e=void 0,t=void 0,s=this.mediaWidth,o=this.mediaHeight,i=0,a=0;for(e=0;n>=e&&(t=this.levels[e],r=e,i=t.width,a=t.height,!(i>=s||a>=o));e++);return r}},{key:"contentScaleFactor",get:function(){var e=1;try{e=window.devicePixelRatio}catch(e){}return e}},{key:"mediaWidth",get:function(){var e=void 0;return this.media&&(e=this.media.width||this.media.clientWidth||this.media.offsetWidth,e*=this.contentScaleFactor),e}},{key:"mediaHeight",get:function(){var e=void 0;return this.media&&(e=this.media.height||this.media.clientHeight||this.media.offsetHeight,e*=this.contentScaleFactor),e}}]),e}(s.default);t.default=u},{"../event-handler":22,"../events":23}],6:[function(r,l,e){"use strict";function i(e){return e&&e.__esModule?e:{default:e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(e,"__esModule",{value:!0});var n=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),s=r("../utils/ewma"),t=i(s),o=function(){function e(t){a(this,e),this.hls=t,this.defaultEstimate_=5e5,this.minWeight_=.001,this.minDelayMs_=50}return n(e,[{key:"sample",value:function(e,n){e=Math.max(e,this.minDelayMs_);var r=8e3*n/e,i=e/1e3;if(!this.fast_){var a=this.hls.config;this.fast_=new t.default(a.abrEwmaFast),this.slow_=new t.default(a.abrEwmaSlow)}this.fast_.sample(i,r),this.slow_.sample(i,r)}},{key:"getEstimate",value:function(){return this.fast_.getTotalWeight()<this.minWeight_?this.defaultEstimate_:Math.min(this.fast_.getEstimate(),this.slow_.getEstimate())}},{key:"destroy",value:function(){}}]),e}();e.default=o},{"../utils/ewma":37}],7:[function(i,v,a){"use strict";function n(e){return e&&e.__esModule?e:{default:e}}function u(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function h(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(a,"__esModule",{value:!0});var c=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),l=i("../events"),t=n(l),d=i("../event-handler"),f=n(d),r=i("../utils/logger"),e=i("../errors"),o=function(a){function i(r){u(this,i);var e=h(this,Object.getPrototypeOf(i).call(this,r,t.default.MANIFEST_LOADED,t.default.LEVEL_LOADED,t.default.ERROR));return e.ontick=e.tick.bind(e),e._manualLevel=e._autoLevelCapping=-1,e}return s(i,a),c(i,[{key:"destroy",value:function(){this.timer&&(clearTimeout(this.timer),this.timer=null),this._manualLevel=-1}},{key:"startLoad",value:function(){this.canload=!0,this.timer&&this.tick()}},{key:"stopLoad",value:function(){this.canload=!1}},{key:"onManifestLoaded",value:function(l){var s,a,n=[],i=[],u={},d=!1,f=!1,o=this.hls;if(l.levels.forEach(function(e){e.videoCodec&&(d=!0),e.audioCodec&&(f=!0);var t=u[e.bitrate];void 0===t?(u[e.bitrate]=n.length,e.url=[e.url],e.urlId=0,n.push(e)):n[t].url.push(e.url)}),d&&f?n.forEach(function(e){e.videoCodec&&i.push(e)}):i=n,i=i.filter(function(e){var i=function(e){return MediaSource.isTypeSupported("audio/mp4;codecs="+e)},a=function(e){return MediaSource.isTypeSupported("video/mp4;codecs="+e)},t=e.audioCodec,r=e.videoCodec;return(!t||i(t))&&(!r||a(r))}),i.length){for(s=i[0].bitrate,i.sort(function(e,t){return e.bitrate-t.bitrate}),this._levels=i,a=0;a<i.length;a++)if(i[a].bitrate===s){this._firstLevel=a,r.logger.log("manifest loaded,"+i.length+" level(s) found, first bitrate:"+s);break}o.trigger(t.default.MANIFEST_PARSED,{levels:this._levels,firstLevel:this._firstLevel,stats:l.stats})}else o.trigger(t.default.ERROR,{type:e.ErrorTypes.MEDIA_ERROR,details:e.ErrorDetails.MANIFEST_INCOMPATIBLE_CODECS_ERROR,fatal:!0,url:o.url,reason:"no level with compatible codecs found in manifest"})}},{key:"setLevelInternal",value:function(i){var n=this._levels;if(i>=0&&i<n.length){this.timer&&(clearTimeout(this.timer),this.timer=null),this._level=i,r.logger.log("switching to level "+i),this.hls.trigger(t.default.LEVEL_SWITCH,{level:i});var a=n[i];if(void 0===a.details||a.details.live===!0){r.logger.log("(re)loading playlist for level "+i);var s=a.urlId;this.hls.trigger(t.default.LEVEL_LOADING,{url:a.url[s],level:i,id:s})}}else this.hls.trigger(t.default.ERROR,{type:e.ErrorTypes.OTHER_ERROR,details:e.ErrorDetails.LEVEL_SWITCH_ERROR,level:i,fatal:!1,reason:"invalid level idx"})}},{key:"onError",value:function(n){if(!n.fatal){var a=n.details,o=this.hls,s=void 0,i=void 0,l=!1;switch(a){case e.ErrorDetails.FRAG_LOAD_ERROR:case e.ErrorDetails.FRAG_LOAD_TIMEOUT:case e.ErrorDetails.FRAG_LOOP_LOADING_ERROR:case e.ErrorDetails.KEY_LOAD_ERROR:case e.ErrorDetails.KEY_LOAD_TIMEOUT:s=n.frag.level;break;case e.ErrorDetails.LEVEL_LOAD_ERROR:case e.ErrorDetails.LEVEL_LOAD_TIMEOUT:s=n.level,l=!0}if(void 0!==s)if(i=this._levels[s],i.urlId<i.url.length-1)i.urlId++,i.details=void 0,r.logger.warn("level controller,"+a+" for level "+s+": switching to redundant stream id "+i.urlId);else{var u=-1===this._manualLevel&&s;u?(r.logger.warn("level controller,"+a+": emergency switch-down for next fragment"),o.abrController.nextAutoLevel=0):i&&i.details&&i.details.live?(r.logger.warn("level controller,"+a+" on live stream, discard"),l&&(this._level=void 0)):a!==e.ErrorDetails.FRAG_LOAD_ERROR&&a!==e.ErrorDetails.FRAG_LOAD_TIMEOUT&&(r.logger.error("cannot recover "+a+" error"),this._level=void 0,this.timer&&(clearTimeout(this.timer),this.timer=null),n.fatal=!0,o.trigger(t.default.ERROR,n))}}}},{key:"onLevelLoaded",value:function(t){if(t.level===this._level){var i=t.details;if(i.live){var e=1e3*i.targetduration,n=this._levels[t.level],a=n.details;a&&i.endSN===a.endSN&&(e/=2,r.logger.log("same live playlist, reload twice faster")),e-=performance.now()-t.stats.trequest,e=Math.max(1e3,Math.round(e)),r.logger.log("live playlist, reload in "+e+" ms"),this.timer=setTimeout(this.ontick,e)}else this.timer=null}}},{key:"tick",value:function(){var e=this._level;if(void 0!==e&&this.canload){var r=this._levels[e],i=r.urlId;this.hls.trigger(t.default.LEVEL_LOADING,{url:r.url[i],level:e,id:i})}}},{key:"levels",get:function(){return this._levels}},{key:"level",get:function(){return this._level},set:function(e){var t=this._levels;t&&t.length>e&&(this._level===e&&void 0!==t[e].details||this.setLevelInternal(e))}},{key:"manualLevel",get:function(){return this._manualLevel},set:function(e){this._manualLevel=e,void 0===this._startLevel&&(this._startLevel=e),-1!==e&&(this.level=e)}},{key:"firstLevel",get:function(){return this._firstLevel},set:function(e){this._firstLevel=e}},{key:"startLevel",get:function(){return void 0===this._startLevel?this._firstLevel:this._startLevel},set:function(e){this._startLevel=e}},{key:"nextLoadLevel",get:function(){return-1!==this._manualLevel?this._manualLevel:this.hls.abrController.nextAutoLevel},set:function(e){this.level=e,-1===this._manualLevel&&(this.hls.abrController.nextAutoLevel=e)}}]),i}(f.default);a.default=o},{"../errors":21,"../event-handler":22,"../events":23,"../utils/logger":38}],8:[function(a,A,o){"use strict";function n(e){return e&&e.__esModule?e:{default:e}}function h(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function c(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function v(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(o,"__esModule",{value:!0});var m=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),b=a("../demux/demuxer"),_=n(b),d=a("../events"),r=n(d),R=a("../event-handler"),l=n(R),t=a("../utils/logger"),g=a("../utils/binary-search"),p=n(g),y=a("../helper/buffer-helper"),s=n(y),E=a("../helper/level-helper"),u=n(E),i=a("../errors"),e={STOPPED:"STOPPED",STARTING:"STARTING",IDLE:"IDLE",PAUSED:"PAUSED",KEY_LOADING:"KEY_LOADING",FRAG_LOADING:"FRAG_LOADING",FRAG_LOADING_WAITING_RETRY:"FRAG_LOADING_WAITING_RETRY",WAITING_LEVEL:"WAITING_LEVEL",PARSING:"PARSING",PARSED:"PARSED",ENDED:"ENDED",ERROR:"ERROR"},f=function(n){function a(t){h(this,a);var e=c(this,Object.getPrototypeOf(a).call(this,t,r.default.MEDIA_ATTACHED,r.default.MEDIA_DETACHING,r.default.MANIFEST_LOADING,r.default.MANIFEST_PARSED,r.default.LEVEL_LOADED,r.default.KEY_LOADED,r.default.FRAG_LOADED,r.default.FRAG_LOAD_EMERGENCY_ABORTED,r.default.FRAG_PARSING_INIT_SEGMENT,r.default.FRAG_PARSING_DATA,r.default.FRAG_PARSED,r.default.ERROR,r.default.BUFFER_APPENDED,r.default.BUFFER_FLUSHED));return e.config=t.config,e.audioCodecSwap=!1,e.ticks=0,e.ontick=e.tick.bind(e),e}return v(a,n),m(a,[{key:"destroy",value:function(){this.stopLoad(),this.timer&&(clearInterval(this.timer),this.timer=null),l.default.prototype.destroy.call(this),this.state=e.STOPPED}},{key:"startLoad",value:function(){var a=arguments.length<=0||void 0===arguments[0]?0:arguments[0];if(this.levels){var r=this.media,i=this.lastCurrentTime;this.stopLoad(),this.demuxer=new _.default(this.hls),this.timer||(this.timer=setInterval(this.ontick,100)),this.level=-1,this.fragLoadError=0,r&&i?(t.logger.log("configure startPosition @"+i),this.lastPaused||(t.logger.log("resuming video"),r.play()),this.state=e.IDLE):(this.lastCurrentTime=this.startPosition?this.startPosition:a,this.state=e.STARTING),this.nextLoadPosition=this.startPosition=this.lastCurrentTime,this.tick()}else t.logger.warn("cannot start loading as manifest not parsed yet"),this.state=e.STOPPED}},{key:"stopLoad",value:function(){var t=this.fragCurrent;t&&(t.loader&&t.loader.abort(),this.fragCurrent=null),this.fragPrevious=null,this.demuxer&&(this.demuxer.destroy(),this.demuxer=null),this.state=e.STOPPED}},{key:"tick",value:function(){this.ticks++,1===this.ticks&&(this.doTick(),this.ticks>1&&setTimeout(this.tick,1),this.ticks=0)}},{key:"doTick",value:function(){var R,l,n,f=this.hls,o=f.config,h=this.media,b=h&&h.seeking;switch(this.state){case e.ERROR:case e.PAUSED:break;case e.STARTING:var _=f.startLevel;-1===_&&(_=0,this.fragBitrateTest=!0),this.level=f.nextLoadLevel=_,this.state=e.WAITING_LEVEL,this.loadedmetadata=!1;break;case e.IDLE:if(!h&&(this.startFragRequested||!o.startFragPrefetch))break;R=this.loadedmetadata?h.currentTime:this.nextLoadPosition,l=f.nextLoadLevel;var c,A=s.default.bufferInfo(h,R,o.maxBufferHole),T=A.len,u=A.end,v=this.fragPrevious;if(this.levels[l].hasOwnProperty("bitrate")?(c=Math.max(8*o.maxBufferSize/this.levels[l].bitrate,o.maxBufferLength),c=Math.min(c,o.maxMaxBufferLength)):c=o.maxBufferLength,c>T){if(f.nextLoadLevel=l,this.level=l,n=this.levels[l].details,"undefined"==typeof n||n.live&&this.levelLastLoaded!==l){this.state=e.WAITING_LEVEL;break}var d=n.fragments,g=d.length,y=d[0].start,m=d[g-1].start+d[g-1].duration,a=void 0;if(n.live){var S=void 0!==o.liveMaxLatencyDuration?o.liveMaxLatencyDuration:o.liveMaxLatencyDurationCount*n.targetduration;if(u<Math.max(y,m-S)){var w=void 0!==o.liveSyncDuration?o.liveSyncDuration:o.liveSyncDurationCount*n.targetduration;this.seekAfterBuffered=y+Math.max(0,n.totalduration-w),t.logger.log("buffer end: "+u+" is located too far from the end of live sliding playlist, media position will be reseted to: "+this.seekAfterBuffered.toFixed(3)),u=this.seekAfterBuffered}if(n.PTSKnown&&u>m)break;if(this.startFragRequested&&!n.PTSKnown){if(v){var E=v.sn+1;E>=n.startSN&&E<=n.endSN&&(a=d[E-n.startSN],t.logger.log("live playlist, switching playlist, load frag with next SN: "+a.sn))}a||(a=d[Math.min(g-1,Math.round(g/2))],t.logger.log("live playlist, switching playlist, unknown, load middle frag : "+a.sn))}}else y>u&&(a=d[0]);if(a||!function(){var e=o.maxFragLookUpTolerance;m>u?((u>m-e||b)&&(e=0),a=p.default.search(d,function(t){return t.start+t.duration-e<=u?1:t.start-e>u?-1:0})):a=d[g-1]}(),a){if(y=a.start,v&&a.level===v.level&&a.sn===v.sn){if(!(a.sn<n.endSN))return void(n.live||(this.hls.trigger(r.default.BUFFER_EOS),b||(this.state=e.ENDED)));a=d[a.sn+1-n.startSN],t.logger.log("SN just loaded, load next one: "+a.sn)}if(null!=a.decryptdata.uri&&null==a.decryptdata.key)t.logger.log("Loading key for "+a.sn+" of ["+n.startSN+" ,"+n.endSN+"],level "+l),this.state=e.KEY_LOADING,f.trigger(r.default.KEY_LOADING,{frag:a
});else{if(t.logger.log("Loading "+a.sn+" of ["+n.startSN+" ,"+n.endSN+"],level "+l+", currentTime:"+R+",bufferEnd:"+u.toFixed(3)),a.autoLevel=f.autoLevelEnabled,this.levels.length>1&&(a.expectedLen=Math.round(a.duration*this.levels[l].bitrate/8),a.trequest=performance.now()),void 0!==this.fragLoadIdx?this.fragLoadIdx++:this.fragLoadIdx=0,a.loadCounter){a.loadCounter++;var L=o.fragLoadingLoopThreshold;if(a.loadCounter>L&&Math.abs(this.fragLoadIdx-a.loadIdx)<L)return void f.trigger(r.default.ERROR,{type:i.ErrorTypes.MEDIA_ERROR,details:i.ErrorDetails.FRAG_LOOP_LOADING_ERROR,fatal:!1,frag:a})}else a.loadCounter=1;a.loadIdx=this.fragLoadIdx,this.fragCurrent=a,this.startFragRequested=!0,f.trigger(r.default.FRAG_LOADING,{frag:a}),this.state=e.FRAG_LOADING}}}break;case e.WAITING_LEVEL:l=this.levels[this.level],l&&l.details&&(this.state=e.IDLE);break;case e.FRAG_LOADING_WAITING_RETRY:var D=performance.now(),k=this.retryDate;(!k||D>=k||b)&&(t.logger.log("mediaController: retryDate reached, switch back to IDLE state"),this.state=e.IDLE);break;case e.STOPPED:case e.FRAG_LOADING:case e.PARSING:case e.PARSED:case e.ENDED:}this._checkBuffer(),this._checkFragmentChanged()}},{key:"getBufferRange",value:function(i){var e,t,r=this.bufferRange;if(r)for(e=r.length-1;e>=0;e--)if(t=r[e],i>=t.start&&i<=t.end)return t;return null}},{key:"followingBufferRange",value:function(e){return e?this.getBufferRange(e.end+.5):null}},{key:"isBuffered",value:function(r){var i=this.media;if(i)for(var t=i.buffered,e=0;e<t.length;e++)if(r>=t.start(e)&&r<=t.end(e))return!0;return!1}},{key:"_checkFragmentChanged",value:function(){var t,e,i=this.media;if(i&&i.seeking===!1&&(e=i.currentTime,e>i.playbackRate*this.lastCurrentTime&&(this.lastCurrentTime=e),this.isBuffered(e)?t=this.getBufferRange(e):this.isBuffered(e+.1)&&(t=this.getBufferRange(e+.1)),t)){var a=t.frag;a!==this.fragPlaying&&(this.fragPlaying=a,this.hls.trigger(r.default.FRAG_CHANGED,{frag:a}))}}},{key:"immediateLevelSwitch",value:function(){t.logger.log("immediateLevelSwitch"),this.immediateSwitch||(this.immediateSwitch=!0,this.previouslyPaused=this.media.paused,this.media.pause());var i=this.fragCurrent;i&&i.loader&&i.loader.abort(),this.fragCurrent=null,this.fragLoadIdx+=2*this.config.fragLoadingLoopThreshold,this.state=e.PAUSED,this.hls.trigger(r.default.BUFFER_FLUSHING,{startOffset:0,endOffset:Number.POSITIVE_INFINITY})}},{key:"immediateLevelSwitchEnd",value:function(){this.immediateSwitch=!1;var e=this.media;e&&e.readyState&&(e.currentTime-=1e-4,this.previouslyPaused||e.play())}},{key:"nextLevelSwitch",value:function(){var t=this.media;if(t&&t.readyState){var n=void 0,a=void 0,i=void 0;if(this.fragLoadIdx+=2*this.config.fragLoadingLoopThreshold,a=this.getBufferRange(t.currentTime),a&&a.start>1&&(this.state=e.PAUSED,this.hls.trigger(r.default.BUFFER_FLUSHING,{startOffset:0,endOffset:a.start-1})),t.paused)n=0;else{var l=this.hls.nextLoadLevel,u=this.levels[l],o=this.fragLastKbps;n=o&&this.fragCurrent?this.fragCurrent.duration*u.bitrate/(1e3*o)+1:0}if(i=this.getBufferRange(t.currentTime+n),i&&(i=this.followingBufferRange(i))){var s=this.fragCurrent;s&&s.loader&&s.loader.abort(),this.fragCurrent=null,this.state=e.PAUSED,this.hls.trigger(r.default.BUFFER_FLUSHING,{startOffset:i.start,endOffset:Number.POSITIVE_INFINITY})}}}},{key:"onMediaAttached",value:function(t){var e=this.media=t.media;this.onvseeking=this.onMediaSeeking.bind(this),this.onvseeked=this.onMediaSeeked.bind(this),this.onvended=this.onMediaEnded.bind(this),e.addEventListener("seeking",this.onvseeking),e.addEventListener("seeked",this.onvseeked),e.addEventListener("ended",this.onvended),this.levels&&this.config.autoStartLoad&&this.hls.startLoad()}},{key:"onMediaDetaching",value:function(){var e=this.media;e&&e.ended&&(t.logger.log("MSE detaching and video ended, reset startPosition"),this.startPosition=this.lastCurrentTime=0);var r=this.levels;r&&r.forEach(function(e){e.details&&e.details.fragments.forEach(function(e){e.loadCounter=void 0})}),e&&(e.removeEventListener("seeking",this.onvseeking),e.removeEventListener("seeked",this.onvseeked),e.removeEventListener("ended",this.onvended),this.onvseeking=this.onvseeked=this.onvended=null),this.media=null,this.loadedmetadata=!1,this.stopLoad()}},{key:"onMediaSeeking",value:function(){if(this.state===e.FRAG_LOADING){if(0===s.default.bufferInfo(this.media,this.media.currentTime,this.config.maxBufferHole).len){t.logger.log("seeking outside of buffer while fragment load in progress, cancel fragment load");var r=this.fragCurrent;r&&(r.loader&&r.loader.abort(),this.fragCurrent=null),this.fragPrevious=null,this.state=e.IDLE}}else this.state===e.ENDED&&(this.state=e.IDLE);this.media&&(this.lastCurrentTime=this.media.currentTime),void 0!==this.fragLoadIdx&&(this.fragLoadIdx+=2*this.config.fragLoadingLoopThreshold),this.tick()}},{key:"onMediaSeeked",value:function(){this.tick()}},{key:"onMediaEnded",value:function(){t.logger.log("media ended"),this.startPosition=this.lastCurrentTime=0}},{key:"onManifestLoading",value:function(){t.logger.log("trigger BUFFER_RESET"),this.hls.trigger(r.default.BUFFER_RESET),this.bufferRange=[],this.stalled=!1}},{key:"onManifestParsed",value:function(r){var e,i=!1,a=!1;r.levels.forEach(function(t){e=t.audioCodec,e&&(-1!==e.indexOf("mp4a.40.2")&&(i=!0),-1!==e.indexOf("mp4a.40.5")&&(a=!0))}),this.audioCodecSwitch=i&&a,this.audioCodecSwitch&&t.logger.log("both AAC/HE-AAC audio found in levels; declaring level codec as HE-AAC"),this.levels=r.levels,this.startLevelLoaded=!1,this.startFragRequested=!1,this.config.autoStartLoad&&this.hls.startLoad()}},{key:"onLevelLoaded",value:function(s){var i=s.details,a=s.level,o=this.levels[a],l=i.totalduration,n=0;if(t.logger.log("level "+a+" loaded ["+i.startSN+","+i.endSN+"],duration:"+l),this.levelLastLoaded=a,i.live){var d=o.details;d?(u.default.mergeDetails(d,i),n=i.fragments[0].start,i.PTSKnown?t.logger.log("live playlist sliding:"+n.toFixed(3)):t.logger.log("live playlist - outdated PTS, unknown sliding")):(i.PTSKnown=!1,t.logger.log("live playlist - first load, unknown sliding"))}else i.PTSKnown=!1;if(o.details=i,this.hls.trigger(r.default.LEVEL_UPDATED,{details:i,level:a}),this.startFragRequested===!1){if(i.live){var f=void 0!==this.config.liveSyncDuration?this.config.liveSyncDuration:this.config.liveSyncDurationCount*i.targetduration;this.startPosition=Math.max(0,n+l-f)}this.nextLoadPosition=this.startPosition}this.state===e.WAITING_LEVEL&&(this.state=e.IDLE),this.tick()}},{key:"onKeyLoaded",value:function(){this.state===e.KEY_LOADING&&(this.state=e.IDLE,this.tick())}},{key:"onFragLoaded",value:function(a){var i=this.fragCurrent;if(this.state===e.FRAG_LOADING&&i&&a.frag.level===i.level&&a.frag.sn===i.sn)if(t.logger.log("Loaded  "+i.sn+" of level "+i.level),this.fragBitrateTest===!0)this.state=e.IDLE,this.fragBitrateTest=!1,this.startFragRequested=!1,a.stats.tparsed=a.stats.tbuffered=performance.now(),this.hls.trigger(r.default.FRAG_BUFFERED,{stats:a.stats,frag:i});else{this.state=e.PARSING,this.stats=a.stats;var s=this.levels[this.level],o=s.details,f=o.totalduration,h=void 0!==i.startDTS?i.startDTS:i.start,l=i.level,u=i.sn,n=s.audioCodec||this.config.defaultAudioCodec;this.audioCodecSwap&&(t.logger.log("swapping playlist audio codec"),void 0===n&&(n=this.lastAudioCodec),n&&(n=-1!==n.indexOf("mp4a.40.5")?"mp4a.40.2":"mp4a.40.5")),this.pendingAppending=0,t.logger.log("Demuxing "+u+" of ["+o.startSN+" ,"+o.endSN+"],level "+l);var d=this.demuxer;d&&d.push(a.payload,n,s.videoCodec,h,i.cc,l,u,f,i.decryptdata)}this.fragLoadError=0}},{key:"onFragParsingInitSegment",value:function(l){if(this.state===e.PARSING){var o,i,a=l.tracks;if(i=a.audio){var n=this.levels[this.level].audioCodec,u=navigator.userAgent.toLowerCase();n&&this.audioCodecSwap&&(t.logger.log("swapping playlist audio codec"),n=-1!==n.indexOf("mp4a.40.5")?"mp4a.40.2":"mp4a.40.5"),this.audioCodecSwitch&&1!==i.metadata.channelCount&&-1===u.indexOf("firefox")&&(n="mp4a.40.5"),-1!==u.indexOf("android")&&(n="mp4a.40.2",t.logger.log("Android: force audio codec to"+n)),i.levelCodec=n}if(i=a.video,i&&(i.levelCodec=this.levels[this.level].videoCodec),l.unique){var s={codec:"",levelCodec:""};for(o in l.tracks)i=a[o],s.container=i.container,s.codec&&(s.codec+=",",s.levelCodec+=","),i.codec&&(s.codec+=i.codec),i.levelCodec&&(s.levelCodec+=i.levelCodec);a={audiovideo:s}}this.hls.trigger(r.default.BUFFER_CODECS,a);for(o in a){i=a[o],t.logger.log("track:"+o+",container:"+i.container+",codecs[level/parsed]=["+i.levelCodec+"/"+i.codec+"]");var d=i.initSegment;d&&(this.pendingAppending++,this.hls.trigger(r.default.BUFFER_APPENDING,{type:o,data:d}))}this.tick()}}},{key:"onFragParsingData",value:function(i){var o=this;if(this.state===e.PARSING){this.tparse2=Date.now();var a=this.levels[this.level],n=this.fragCurrent;t.logger.log("parsed "+i.type+",PTS:["+i.startPTS.toFixed(3)+","+i.endPTS.toFixed(3)+"],DTS:["+i.startDTS.toFixed(3)+"/"+i.endDTS.toFixed(3)+"],nb:"+i.nb);var l=u.default.updateFragPTSDTS(a.details,n.sn,i.startPTS,i.endPTS,i.startDTS,i.endDTS),s=this.hls;s.trigger(r.default.LEVEL_PTS_UPDATED,{details:a.details,level:this.level,drift:l}),[i.data1,i.data2].forEach(function(e){e&&(o.pendingAppending++,s.trigger(r.default.BUFFER_APPENDING,{type:i.type,data:e}))}),this.nextLoadPosition=i.endPTS,this.bufferRange.push({type:i.type,start:i.startPTS,end:i.endPTS,frag:n}),this.tick()}else t.logger.warn("not in PARSING state but "+this.state+", ignoring FRAG_PARSING_DATA event")}},{key:"onFragParsed",value:function(){this.state===e.PARSING&&(this.stats.tparsed=performance.now(),this.state=e.PARSED,this._checkAppendedParsed())}},{key:"onBufferAppended",value:function(){switch(this.state){case e.PARSING:case e.PARSED:this.pendingAppending--,this._checkAppendedParsed()}}},{key:"_checkAppendedParsed",value:function(){if(this.state===e.PARSED&&0===this.pendingAppending){var a=this.fragCurrent,i=this.stats;a&&(this.fragPrevious=a,i.tbuffered=performance.now(),this.fragLastKbps=Math.round(8*i.length/(i.tbuffered-i.tfirst)),this.hls.trigger(r.default.FRAG_BUFFERED,{stats:i,frag:a}),t.logger.log("media buffered : "+this.timeRangesToString(this.media.buffered)),this.state=e.IDLE),this.tick()}}},{key:"onError",value:function(a){switch(a.details){case i.ErrorDetails.FRAG_LOAD_ERROR:case i.ErrorDetails.FRAG_LOAD_TIMEOUT:if(!a.fatal){var n=this.fragLoadError;if(n?n++:n=1,n<=this.config.fragLoadingMaxRetry){this.fragLoadError=n,a.frag.loadCounter=0;var s=Math.min(Math.pow(2,n-1)*this.config.fragLoadingRetryDelay,64e3);t.logger.warn("mediaController: frag loading failed, retry in "+s+" ms"),this.retryDate=performance.now()+s,this.state=e.FRAG_LOADING_WAITING_RETRY}else t.logger.error("mediaController: "+a.details+" reaches max retry, redispatch as fatal ..."),a.fatal=!0,this.hls.trigger(r.default.ERROR,a),this.state=e.ERROR}break;case i.ErrorDetails.FRAG_LOOP_LOADING_ERROR:case i.ErrorDetails.LEVEL_LOAD_ERROR:case i.ErrorDetails.LEVEL_LOAD_TIMEOUT:case i.ErrorDetails.KEY_LOAD_ERROR:case i.ErrorDetails.KEY_LOAD_TIMEOUT:this.state!==e.ERROR&&(this.state=a.fatal?e.ERROR:e.IDLE,t.logger.warn("mediaController: "+a.details+" while loading frag,switch to "+this.state+" state ..."));break;case i.ErrorDetails.BUFFER_FULL_ERROR:this.config.maxMaxBufferLength/=2,t.logger.warn("reduce max buffer length to "+this.config.maxMaxBufferLength+"s and trigger a nextLevelSwitch to flush old buffer and fix QuotaExceededError"),this.nextLevelSwitch()}}},{key:"_checkBuffer",value:function(){var e=this.media;if(e){var g=e.readyState;if(g){var a,n,d=this.seekAfterBuffered;if(d)e.duration>=d&&(a=d,this.seekAfterBuffered=void 0);else{n=e.currentTime;var p=this.loadedmetadata;!p&&e.buffered.length&&(this.loadedmetadata=!0,n||n===this.startPosition||(a=this.startPosition))}a&&(n=a,t.logger.log("target seek position:"+a));var l=s.default.bufferInfo(e,n,0),m=!(e.paused||e.ended||0===e.buffered.length),f=.4,h=n>e.playbackRate*this.lastCurrentTime;if(this.stalled&&h&&(this.stalled=!1,t.logger.log("playback not stuck anymore @"+n)),m&&l.len<=f){if(h?(f=0,this.seekHoleNudgeDuration=0):this.stalled?this.seekHoleNudgeDuration+=this.config.seekHoleNudgeDuration:(this.seekHoleNudgeDuration=0,t.logger.log("playback seems stuck @"+n),this.hls.trigger(r.default.ERROR,{type:i.ErrorTypes.MEDIA_ERROR,details:i.ErrorDetails.BUFFER_STALLED_ERROR,fatal:!1}),this.stalled=!0),l.len<=f){var o=l.nextStart,c=o-n;if(o&&c<this.config.maxSeekHole&&c>0){t.logger.log("adjust currentTime from "+e.currentTime+" to next buffered @ "+o+" + nudge "+this.seekHoleNudgeDuration);var y=o+this.seekHoleNudgeDuration-e.currentTime;e.currentTime=o+this.seekHoleNudgeDuration,this.hls.trigger(r.default.ERROR,{type:i.ErrorTypes.MEDIA_ERROR,details:i.ErrorDetails.BUFFER_SEEK_OVER_HOLE,fatal:!1,hole:y})}}}else{var v=e.currentTime;if(a&&v!==a){if(0===l.len){var u=l.nextStart;void 0!==u&&u-a<this.config.maxSeekHole&&(a=u,t.logger.log("target seek position not buffered, seek to next buffered "+a))}t.logger.log("adjust currentTime from "+v+" to "+a),e.currentTime=a}}}}}},{key:"onFragLoadEmergencyAborted",value:function(){this.state=e.IDLE,this.tick()}},{key:"onBufferFlushed",value:function(){var t,r,i=[];for(r=0;r<this.bufferRange.length;r++)t=this.bufferRange[r],this.isBuffered((t.start+t.end)/2)&&i.push(t);this.bufferRange=i,this.immediateSwitch&&this.immediateLevelSwitchEnd(),this.state=e.IDLE,this.fragPrevious=null}},{key:"swapAudioCodec",value:function(){this.audioCodecSwap=!this.audioCodecSwap}},{key:"timeRangesToString",value:function(t){for(var r="",i=t.length,e=0;i>e;e++)r+="["+t.start(e)+","+t.end(e)+"]";return r}},{key:"currentLevel",get:function(){if(this.media){var e=this.getBufferRange(this.media.currentTime);if(e)return e.frag.level}return-1}},{key:"nextBufferRange",get:function(){return this.media?this.followingBufferRange(this.getBufferRange(this.media.currentTime)):null}},{key:"nextLevel",get:function(){var e=this.nextBufferRange;return e?e.frag.level:-1}}]),a}(l.default);o.default=f},{"../demux/demuxer":17,"../errors":21,"../event-handler":22,"../events":23,"../helper/buffer-helper":24,"../helper/level-helper":25,"../utils/binary-search":35,"../utils/logger":38}],9:[function(t,v,i){"use strict";function r(e){return e&&e.__esModule?e:{default:e}}function f(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function n(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(i,"__esModule",{value:!0});var c=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),l=t("../events"),e=r(l),d=t("../event-handler"),a=r(d),h=t("../utils/cea-708-interpreter"),o=r(h),u=function(r){function t(i){f(this,t);var r=n(this,Object.getPrototypeOf(t).call(this,i,e.default.MEDIA_ATTACHING,e.default.MEDIA_DETACHING,e.default.FRAG_PARSING_USERDATA,e.default.MANIFEST_LOADING,e.default.FRAG_LOADED));return r.hls=i,r.config=i.config,r.config.enableCEA708Captions&&(r.cea708Interpreter=new o.default),r}return s(t,r),c(t,[{key:"destroy",value:function(){a.default.prototype.destroy.call(this)}},{key:"onMediaAttaching",value:function(e){var t=this.media=e.media;this.cea708Interpreter.attach(t)}},{key:"onMediaDetaching",value:function(){this.cea708Interpreter.detach()}},{key:"onManifestLoading",value:function(){this.lastPts=Number.POSITIVE_INFINITY}},{key:"onFragLoaded",value:function(t){var e=t.frag.start;e<=this.lastPts&&this.cea708Interpreter.clear(),this.lastPts=e}},{key:"onFragParsingUserdata",value:function(t){for(var e=0;e<t.samples.length;e++)this.cea708Interpreter.push(t.samples[e].pts,t.samples[e].bytes)}}]),t}(a.default);i.default=u},{"../event-handler":22,"../events":23,"../utils/cea-708-interpreter":36}],10:[function(a,n,e){"use strict";function t(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(e,"__esModule",{value:!0});var r=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),i=function(){function e(f){t(this,e),this._tables=[[[],[],[],[],[]],[[],[],[],[],[]]],this._precompute();var i,s,r,o,l,n=this._tables[0][4],u=this._tables[1],a=f.length,d=1;if(4!==a&&6!==a&&8!==a)throw new Error("Invalid aes key size="+a);for(o=f.slice(0),l=[],this._key=[o,l],i=a;4*a+28>i;i++)r=o[i-1],(i%a===0||8===a&&i%a===4)&&(r=n[r>>>24]<<24^n[r>>16&255]<<16^n[r>>8&255]<<8^n[255&r],i%a===0&&(r=r<<8^r>>>24^d<<24,d=d<<1^283*(d>>7))),o[i]=o[i-a]^r;for(s=0;i;s++,i--)r=o[3&s?i:i-4],4>=i||4>s?l[s]=r:l[s]=u[0][n[r>>>24]]^u[1][n[r>>16&255]]^u[2][n[r>>8&255]]^u[3][n[255&r]]}return r(e,[{key:"_precompute",value:function(){var e,i,r,u,f,d,t,s,l,n=this._tables[0],o=this._tables[1],h=n[4],v=o[4],a=[],c=[];for(e=0;256>e;e++)c[(a[e]=e<<1^283*(e>>7))^e]=e;for(i=r=0;!h[i];i^=u||1,r=c[r]||1)for(t=r^r<<1^r<<2^r<<3^r<<4,t=t>>8^255&t^99,h[i]=t,v[t]=i,d=a[f=a[u=a[i]]],l=16843009*d^65537*f^257*u^16843008*i,s=257*a[t]^16843008*t,e=0;4>e;e++)n[e][i]=s=s<<24^s>>>8,o[e][t]=l=l<<24^l>>>8;for(e=0;5>e;e++)n[e]=n[e].slice(0),o[e]=o[e].slice(0)}},{key:"decrypt",value:function(R,p,_,b,E,m){var h,g,v,n,e=this._key[1],t=R^e[0],i=b^e[1],a=_^e[2],r=p^e[3],y=e.length/4-2,s=4,o=this._tables[1],f=o[0],d=o[1],u=o[2],l=o[3],c=o[4];for(n=0;y>n;n++)h=f[t>>>24]^d[i>>16&255]^u[a>>8&255]^l[255&r]^e[s],g=f[i>>>24]^d[a>>16&255]^u[r>>8&255]^l[255&t]^e[s+1],v=f[a>>>24]^d[r>>16&255]^u[t>>8&255]^l[255&i]^e[s+2],r=f[r>>>24]^d[t>>16&255]^u[i>>8&255]^l[255&a]^e[s+3],s+=4,t=h,i=g,a=v;for(n=0;4>n;n++)E[(3&-n)+m]=c[t>>>24]<<24^c[i>>16&255]<<16^c[a>>8&255]<<8^c[255&r]^e[s++],h=t,t=i,i=a,a=r,r=h}}]),e}();e.default=i},{}],11:[function(t,l,e){"use strict";function r(e){return e&&e.__esModule?e:{default:e}}function i(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(e,"__esModule",{value:!0});var a=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),n=t("./aes"),s=r(n),o=function(){function e(t,r){i(this,e),this.key=t,this.iv=r}return a(e,[{key:"ntoh",value:function(e){return e<<24|(65280&e)<<8|(16711680&e)>>8|e>>>24}},{key:"doDecrypt",value:function(i,g,a){var u,h,o,f,l,c,d,n,e,r=new Int32Array(i.buffer,i.byteOffset,i.byteLength>>2),p=new s.default(Array.prototype.slice.call(g)),v=new Uint8Array(i.byteLength),t=new Int32Array(v.buffer);for(u=~~a[0],h=~~a[1],o=~~a[2],f=~~a[3],e=0;e<r.length;e+=4)l=~~this.ntoh(r[e]),c=~~this.ntoh(r[e+1]),d=~~this.ntoh(r[e+2]),n=~~this.ntoh(r[e+3]),p.decrypt(l,c,d,n,t,e),t[e]=this.ntoh(t[e]^u),t[e+1]=this.ntoh(t[e+1]^h),t[e+2]=this.ntoh(t[e+2]^o),t[e+3]=this.ntoh(t[e+3]^f),u=l,h=c,o=d,f=n;return v}},{key:"localDecrypt",value:function(e,t,r,i){var a=this.doDecrypt(e,t,r);i.set(a,e.byteOffset)}},{key:"decrypt",value:function(n){var r=32e3,t=new Int32Array(n),i=new Uint8Array(n.byteLength),e=0,s=this.key,a=this.iv;for(this.localDecrypt(t.subarray(e,e+r),s,a,i),e=r;e<t.length;e+=r)a=new Uint32Array([this.ntoh(t[e-4]),this.ntoh(t[e-3]),this.ntoh(t[e-2]),this.ntoh(t[e-1])]),this.localDecrypt(t.subarray(e,e+r),s,a,i);return i}}]),e}();e.default=o},{"./aes":10}],12:[function(t,d,r){"use strict";function l(e){return e&&e.__esModule?e:{default:e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(r,"__esModule",{value:!0});var u=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),s=t("./aes128-decrypter"),o=l(s),i=t("../errors"),e=t("../utils/logger"),n=function(){function t(r){a(this,t),this.hls=r;try{var e=window?window.crypto:crypto;this.subtle=e.subtle||e.webkitSubtle,this.disableWebCrypto=!this.subtle}catch(e){this.disableWebCrypto=!0}}return u(t,[{key:"destroy",value:function(){}},{key:"decrypt",value:function(e,t,r,i){this.disableWebCrypto&&this.hls.config.enableSoftwareAES?this.decryptBySoftware(e,t,r,i):this.decryptByWebCrypto(e,t,r,i)}},{key:"decryptByWebCrypto",value:function(t,r,i,a){var n=this;e.logger.log("decrypting by WebCrypto API"),this.subtle.importKey("raw",r,{name:"AES-CBC",length:128},!1,["decrypt"]).then(function(e){n.subtle.decrypt({name:"AES-CBC",iv:i.buffer},e,t).then(a).catch(function(e){n.onWebCryptoError(e,t,r,i,a)})}).catch(function(e){n.onWebCryptoError(e,t,r,i,a)})}},{key:"decryptBySoftware",value:function(r,i,a,n){e.logger.log("decrypting by JavaScript Implementation");var t=new DataView(i.buffer),s=new Uint32Array([t.getUint32(0),t.getUint32(4),t.getUint32(8),t.getUint32(12)]);t=new DataView(a.buffer);var l=new Uint32Array([t.getUint32(0),t.getUint32(4),t.getUint32(8),t.getUint32(12)]),u=new o.default(s,l);n(u.decrypt(r).buffer)}},{key:"onWebCryptoError",value:function(t,r,a,n,s){this.hls.config.enableSoftwareAES?(e.logger.log("disabling to use WebCrypto API"),this.disableWebCrypto=!0,this.decryptBySoftware(r,a,n,s)):(e.logger.error("decrypting error : "+t.message),this.hls.trigger(Event.ERROR,{type:i.ErrorTypes.MEDIA_ERROR,details:i.ErrorDetails.FRAG_DECRYPT_ERROR,fatal:!0,reason:t.message}))}}]),t}();r.default=n},{"../errors":21,"../utils/logger":38,"./aes128-decrypter":11}],13:[function(e,f,t){"use strict";function r(e){return e&&e.__esModule?e:{default:e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(t,"__esModule",{value:!0});var n=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),d=e("./adts"),o=r(d),l=e("../utils/logger"),u=e("../demux/id3"),i=r(u),s=function(){function e(t,r){a(this,e),this.observer=t,this.remuxerClass=r,this.remuxer=new this.remuxerClass(t),this._aacTrack={container:"audio/adts",type:"audio",id:-1,sequenceNumber:0,samples:[],len:0}}return n(e,[{key:"push",value:function(t,p,R,m,_,b,E,y){var a,n,g,c,e,s,f,u,v,r=this._aacTrack,d=new i.default(t),h=90*d.timeStamp;for(e=d.length,u=t.length;u-1>e&&(255!==t[e]||240!==(240&t[e+1]));e++);for(r.audiosamplerate||(a=o.default.getAudioConfig(this.observer,t,e,p),r.config=a.config,r.audiosamplerate=a.samplerate,r.channelCount=a.channelCount,r.codec=a.codec,r.duration=y,l.logger.log("parsed codec:"+r.codec+",rate:"+a.samplerate+",nb channel:"+a.channelCount)),c=0,g=9216e4/r.audiosamplerate;u>e+5&&(s=1&t[e+1]?7:9,n=(3&t[e+3])<<11|t[e+4]<<3|(224&t[e+5])>>>5,n-=s,n>0&&u>=e+s+n);)for(f=h+c*g,v={unit:t.subarray(e+s,e+s+n),pts:f,dts:f},r.samples.push(v),r.len+=n,e+=n+s,c++;u-1>e&&(255!==t[e]||240!==(240&t[e+1]));e++);this.remuxer.remux(this._aacTrack,{samples:[]},{samples:[{pts:h,dts:h,unit:d.payload}]},{samples:[]},m)}},{key:"destroy",value:function(){}}],[{key:"probe",value:function(t){var e,r,a=new i.default(t);if(a.hasTimeStamp)for(e=a.length,r=t.length;r-1>e;e++)if(255===t[e]&&240===(240&t[e+1]))return!0;return!1}}]),e}();t.default=s},{"../demux/id3":19,"../utils/logger":38,"./adts":14}],14:[function(e,o,t){"use strict";function i(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(t,"__esModule",{value:!0});var a=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),n=e("../utils/logger"),r=e("../errors"),s=function(){function e(){i(this,e)}return a(e,null,[{key:"getAudioConfig",value:function(h,u,l,a){var i,e,s,o,t,f=navigator.userAgent.toLowerCase(),d=[96e3,88200,64e3,48e3,44100,32e3,24e3,22050,16e3,12e3,11025,8e3,7350];return i=((192&u[l+2])>>>6)+1,e=(60&u[l+2])>>>2,e>d.length-1?void h.trigger(Event.ERROR,{type:r.ErrorTypes.MEDIA_ERROR,details:r.ErrorDetails.FRAG_PARSING_ERROR,fatal:!0,reason:"invalid ADTS sampling index:"+e}):(o=(1&u[l+2])<<2,o|=(192&u[l+3])>>>6,n.logger.log("manifest codec:"+a+",ADTS data:type:"+i+",sampleingIndex:"+e+"["+d[e]+"Hz],channelConfig:"+o),-1!==f.indexOf("firefox")?e>=6?(i=5,t=new Array(4),s=e-3):(i=2,t=new Array(2),s=e):-1!==f.indexOf("android")?(i=2,t=new Array(2),s=e):(i=5,t=new Array(4),a&&(-1!==a.indexOf("mp4a.40.29")||-1!==a.indexOf("mp4a.40.5"))||!a&&e>=6?s=e-3:((a&&-1!==a.indexOf("mp4a.40.2")&&e>=6&&1===o||!a&&1===o)&&(i=2,t=new Array(2)),s=e)),t[0]=i<<3,t[0]|=(14&e)>>1,t[1]|=(1&e)<<7,t[1]|=o<<3,5===i&&(t[1]|=(14&s)>>1,t[2]=(1&s)<<7,t[2]|=8,t[3]=0),{config:t,samplerate:d[e],channelCount:o,codec:"mp4a.40."+i})}}]),e}();t.default=s},{"../errors":21,"../utils/logger":38}],15:[function(e,y,i){"use strict";function t(e){return e&&e.__esModule?e:{default:e}}function d(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(i,"__esModule",{value:!0});var h=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),v=e("../events"),o=t(v),a=e("../errors"),p=e("../demux/aacdemuxer"),n=t(p),f=e("../demux/tsdemuxer"),r=t(f),c=e("../remux/mp4-remuxer"),s=t(c),g=e("../remux/passthrough-remuxer"),u=t(g),l=function(){function e(t,r){d(this,e),this.hls=t,this.typeSupported=r}return h(e,[{key:"destroy",value:function(){var e=this.demuxer;e&&e.destroy()}},{key:"push",value:function(i,l,d,f,h,c,v,g){var e=this.demuxer;if(!e){var t=this.hls;if(r.default.probe(i))e=this.typeSupported.mp2t===!0?new r.default(t,u.default):new r.default(t,s.default);else{if(!n.default.probe(i))return void t.trigger(o.default.ERROR,{type:a.ErrorTypes.MEDIA_ERROR,details:a.ErrorDetails.FRAG_PARSING_ERROR,fatal:!0,reason:"no demux matching with content found"});e=new n.default(t,s.default)}this.demuxer=e}e.push(i,l,d,f,h,c,v,g)}}]),e}();i.default=l},{"../demux/aacdemuxer":13,"../demux/tsdemuxer":20,"../errors":21,"../events":23,"../remux/mp4-remuxer":32,"../remux/passthrough-remuxer":33}],16:[function(t,d,i){"use strict";function r(e){return e&&e.__esModule?e:{default:e}}Object.defineProperty(i,"__esModule",{value:!0});var a=t("../demux/demuxer-inline"),u=r(a),s=t("../events"),e=r(s),l=t("events"),n=r(l),o=function(r){var t=new n.default;t.trigger=function(i){for(var r=arguments.length,a=Array(r>1?r-1:0),e=1;r>e;e++)a[e-1]=arguments[e];t.emit.apply(t,[i,i].concat(a))},t.off=function(a){for(var r=arguments.length,i=Array(r>1?r-1:0),e=1;r>e;e++)i[e-1]=arguments[e];t.removeListener.apply(t,[a].concat(i))},r.addEventListener("message",function(i){var e=i.data;switch(e.cmd){case"init":r.demuxer=new u.default(t,e.typeSupported);break;case"demux":r.demuxer.push(new Uint8Array(e.data),e.audioCodec,e.videoCodec,e.timeOffset,e.cc,e.level,e.sn,e.duration)}}),t.on(e.default.FRAG_PARSING_INIT_SEGMENT,function(t,e){r.postMessage({event:t,tracks:e.tracks,unique:e.unique})}),t.on(e.default.FRAG_PARSING_DATA,function(i,e){var t={event:i,type:e.type,startPTS:e.startPTS,endPTS:e.endPTS,startDTS:e.startDTS,endDTS:e.endDTS,data1:e.data1.buffer,data2:e.data2.buffer,nb:e.nb};r.postMessage(t,[t.data1,t.data2])}),t.on(e.default.FRAG_PARSED,function(e){r.postMessage({event:e})}),t.on(e.default.ERROR,function(e,t){r.postMessage({event:e,data:t})}),t.on(e.default.FRAG_PARSING_METADATA,function(e,t){var i={event:e,samples:t.samples};r.postMessage(i)}),t.on(e.default.FRAG_PARSING_USERDATA,function(e,t){var i={event:e,samples:t.samples};r.postMessage(i)})};i.default=o},{"../demux/demuxer-inline":15,"../events":23,events:1}],17:[function(t,g,i){"use strict";function r(e){return e&&e.__esModule?e:{default:e}}function u(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(i,"__esModule",{value:!0});var h=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),s=t("../events"),e=r(s),v=t("../demux/demuxer-inline"),a=r(v),d=t("../demux/demuxer-worker"),f=r(d),n=t("../utils/logger"),c=t("../crypt/decrypter"),l=r(c),o=function(){function r(e){u(this,r),this.hls=e;var i={mp4:MediaSource.isTypeSupported("video/mp4"),mp2t:e.config.enableMP2TPassThrough&&MediaSource.isTypeSupported("video/mp2t")};if(e.config.enableWorker&&"undefined"!=typeof Worker){n.logger.log("demuxing in webworker");try{var s=t("webworkify");this.w=s(f.default),this.onwmsg=this.onWorkerMessage.bind(this),this.w.addEventListener("message",this.onwmsg),this.w.postMessage({cmd:"init",typeSupported:i})}catch(t){n.logger.error("error while initializing DemuxerWorker, fallback on DemuxerInline"),this.demuxer=new a.default(e,i)}}else this.demuxer=new a.default(e,i);this.demuxInitialized=!0}return h(r,[{key:"destroy",value:function(){this.w?(this.w.removeEventListener("message",this.onwmsg),this.w.terminate(),this.w=null):(this.demuxer.destroy(),this.demuxer=null),this.decrypter&&(this.decrypter.destroy(),this.decrypter=null)}},{key:"pushDecrypted",value:function(e,t,r,i,a,n,s,o){this.w?this.w.postMessage({cmd:"demux",data:e,audioCodec:t,videoCodec:r,timeOffset:i,cc:a,level:n,sn:s,duration:o},[e]):this.demuxer.push(new Uint8Array(e),t,r,i,a,n,s,o)}},{key:"push",value:function(t,r,i,a,n,s,o,u,e){if(t.byteLength>0&&null!=e&&null!=e.key&&"AES-128"===e.method){null==this.decrypter&&(this.decrypter=new l.default(this.hls));var d=this;this.decrypter.decrypt(t,e.key,e.iv,function(e){d.pushDecrypted(e,r,i,a,n,s,o,u)})}else this.pushDecrypted(t,r,i,a,n,s,o,u)}},{key:"onWorkerMessage",value:function(i){var t=i.data;switch(t.event){case e.default.FRAG_PARSING_INIT_SEGMENT:var r={};r.tracks=t.tracks,r.unique=t.unique,this.hls.trigger(e.default.FRAG_PARSING_INIT_SEGMENT,r);break;case e.default.FRAG_PARSING_DATA:this.hls.trigger(e.default.FRAG_PARSING_DATA,{data1:new Uint8Array(t.data1),data2:new Uint8Array(t.data2),startPTS:t.startPTS,endPTS:t.endPTS,startDTS:t.startDTS,endDTS:t.endDTS,type:t.type,nb:t.nb});break;case e.default.FRAG_PARSING_METADATA:this.hls.trigger(e.default.FRAG_PARSING_METADATA,{samples:t.samples});break;case e.default.FRAG_PARSING_USERDATA:this.hls.trigger(e.default.FRAG_PARSING_USERDATA,{samples:t.samples});break;default:this.hls.trigger(t.event,t.data)}}}]),r}();i.default=o},{"../crypt/decrypter":12,"../demux/demuxer-inline":15,"../demux/demuxer-worker":16,"../events":23,"../utils/logger":38,webworkify:2}],18:[function(t,s,e){"use strict";function r(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(e,"__esModule",{value:!0});var i=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),a=t("../utils/logger"),n=function(){function e(t){r(this,e),this.data=t,this.bytesAvailable=this.data.byteLength,this.word=0,this.bitsAvailable=0;
}return i(e,[{key:"loadWord",value:function(){var t=this.data.byteLength-this.bytesAvailable,r=new Uint8Array(4),e=Math.min(4,this.bytesAvailable);if(0===e)throw new Error("no bytes available");r.set(this.data.subarray(t,t+e)),this.word=new DataView(r.buffer).getUint32(0),this.bitsAvailable=8*e,this.bytesAvailable-=e}},{key:"skipBits",value:function(e){var t;this.bitsAvailable>e?(this.word<<=e,this.bitsAvailable-=e):(e-=this.bitsAvailable,t=e>>3,e-=t>>3,this.bytesAvailable-=t,this.loadWord(),this.word<<=e,this.bitsAvailable-=e)}},{key:"readBits",value:function(t){var e=Math.min(this.bitsAvailable,t),r=this.word>>>32-e;return t>32&&a.logger.error("Cannot read more than 32 bits at a time"),this.bitsAvailable-=e,this.bitsAvailable>0?this.word<<=e:this.bytesAvailable>0&&this.loadWord(),e=t-e,e>0?r<<e|this.readBits(e):r}},{key:"skipLZ",value:function(){var e;for(e=0;e<this.bitsAvailable;++e)if(0!==(this.word&2147483648>>>e))return this.word<<=e,this.bitsAvailable-=e,e;return this.loadWord(),e+this.skipLZ()}},{key:"skipUEG",value:function(){this.skipBits(1+this.skipLZ())}},{key:"skipEG",value:function(){this.skipBits(1+this.skipLZ())}},{key:"readUEG",value:function(){var e=this.skipLZ();return this.readBits(e+1)-1}},{key:"readEG",value:function(){var e=this.readUEG();return 1&e?1+e>>>1:-1*(e>>>1)}},{key:"readBoolean",value:function(){return 1===this.readBits(1)}},{key:"readUByte",value:function(){return this.readBits(8)}},{key:"readUShort",value:function(){return this.readBits(16)}},{key:"readUInt",value:function(){return this.readBits(32)}},{key:"skipScalingList",value:function(a){var t,i,r=8,e=8;for(t=0;a>t;t++)0!==e&&(i=this.readEG(),e=(r+i+256)%256),r=0===e?r:e}},{key:"readSPS",value:function(){var t,g,p,l,a,n,i,o,r,s=0,d=0,f=0,h=0,c=1;if(this.readUByte(),t=this.readUByte(),g=this.readBits(5),this.skipBits(3),p=this.readUByte(),this.skipUEG(),100===t||110===t||122===t||244===t||44===t||83===t||86===t||118===t||128===t){var v=this.readUEG();if(3===v&&this.skipBits(1),this.skipUEG(),this.skipUEG(),this.skipBits(1),this.readBoolean())for(o=3!==v?8:12,r=0;o>r;r++)this.readBoolean()&&(6>r?this.skipScalingList(16):this.skipScalingList(64))}this.skipUEG();var u=this.readUEG();if(0===u)this.readUEG();else if(1===u)for(this.skipBits(1),this.skipEG(),this.skipEG(),l=this.readUEG(),r=0;l>r;r++)this.skipEG();if(this.skipUEG(),this.skipBits(1),a=this.readUEG(),n=this.readUEG(),i=this.readBits(1),0===i&&this.skipBits(1),this.skipBits(1),this.readBoolean()&&(s=this.readUEG(),d=this.readUEG(),f=this.readUEG(),h=this.readUEG()),this.readBoolean()&&this.readBoolean()){var e=void 0,y=this.readUByte();switch(y){case 1:e=[1,1];break;case 2:e=[12,11];break;case 3:e=[10,11];break;case 4:e=[16,11];break;case 5:e=[40,33];break;case 6:e=[24,11];break;case 7:e=[20,11];break;case 8:e=[32,11];break;case 9:e=[80,33];break;case 10:e=[18,11];break;case 11:e=[15,11];break;case 12:e=[64,33];break;case 13:e=[160,99];break;case 14:e=[4,3];break;case 15:e=[3,2];break;case 16:e=[2,1];break;case 255:e=[this.readUByte()<<8|this.readUByte(),this.readUByte()<<8|this.readUByte()]}e&&(c=e[0]/e[1])}return{width:Math.ceil((16*(a+1)-2*s-2*d)*c),height:(2-i)*(n+1)*16-(i?2:4)*(f+h)}}},{key:"readSliceType",value:function(){return this.readUByte(),this.readUEG(),this.readUEG()}}]),e}();e.default=n},{"../utils/logger":38}],19:[function(r,s,t){"use strict";function i(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(t,"__esModule",{value:!0});var a=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),e=r("../utils/logger"),n=function(){function t(a){i(this,t),this._hasTimeStamp=!1;for(var l,u,d,f,h,s,o,n,r=0;;)if(o=this.readUTF(a,r,3),r+=3,"ID3"===o)r+=3,l=127&a[r++],u=127&a[r++],d=127&a[r++],f=127&a[r++],h=(l<<21)+(u<<14)+(d<<7)+f,s=r+h,this._parseID3Frames(a,r,s),r=s;else{if("3DI"!==o)return r-=3,n=r,void(n&&(this.hasTimeStamp||e.logger.warn("ID3 tag found, but no timestamp"),this._length=n,this._payload=a.subarray(0,n)));r+=7,e.logger.log("3DI footer found, end: "+r)}}return a(t,[{key:"readUTF",value:function(i,e,a){var t="",r=e,n=e+a;do t+=String.fromCharCode(i[r++]);while(n>r);return t}},{key:"_parseID3Frames",value:function(r,t,n){for(var a,s,o,l,i;n>=t+8;)switch(a=this.readUTF(r,t,4),t+=4,s=r[t++]<<24+r[t++]<<16+r[t++]<<8+r[t++],l=r[t++]<<8+r[t++],o=t,a){case"PRIV":if("com.apple.streaming.transportStreamTimestamp"===this.readUTF(r,t,44)){t+=44,t+=4;var u=1&r[t++];this._hasTimeStamp=!0,i=((r[t++]<<23)+(r[t++]<<15)+(r[t++]<<7)+r[t++])/45,u&&(i+=47721858.84),i=Math.round(i),e.logger.trace("ID3 timestamp found: "+i),this._timeStamp=i}}}},{key:"hasTimeStamp",get:function(){return this._hasTimeStamp}},{key:"timeStamp",get:function(){return this._timeStamp}},{key:"length",get:function(){return this._length}},{key:"payload",get:function(){return this._payload}}]),t}();t.default=n},{"../utils/logger":38}],20:[function(t,v,a){"use strict";function i(e){return e&&e.__esModule?e:{default:e}}function u(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(a,"__esModule",{value:!0});var f=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),h=t("./adts"),c=i(h),l=t("../events"),n=i(l),d=t("./exp-golomb"),s=i(d),e=t("../utils/logger"),r=t("../errors"),o=function(){function t(e,r){u(this,t),this.observer=e,this.remuxerClass=r,this.lastCC=0,this.remuxer=new this.remuxerClass(e)}return f(t,[{key:"switchLevel",value:function(){this.pmtParsed=!1,this._pmtId=-1,this._avcTrack={container:"video/mp2t",type:"video",id:-1,sequenceNumber:0,samples:[],len:0,nbNalu:0},this._aacTrack={container:"video/mp2t",type:"audio",id:-1,sequenceNumber:0,samples:[],len:0},this._id3Track={type:"id3",id:-1,sequenceNumber:0,samples:[],len:0},this._txtTrack={type:"text",id:-1,sequenceNumber:0,samples:[],len:0},this.aacOverFlow=null,this.aacLastPTS=null,this.avcNaluState=0,this.remuxer.switchLevel()}},{key:"insertDiscontinuity",value:function(){this.switchLevel(),this.remuxer.insertDiscontinuity()}},{key:"push",value:function(i,A,k,R,p,m,E,L){var s,o,l,t,d,u,y,a,c=i.length,b=this.remuxer.passthrough,v=!1;this.audioCodec=A,this.videoCodec=k,this.timeOffset=R,this._duration=L,this.contiguous=!1,p!==this.lastCC&&(e.logger.log("discontinuity detected"),this.insertDiscontinuity(),this.lastCC=p),m!==this.lastLevel?(e.logger.log("level switch detected"),this.switchLevel(),this.lastLevel=m):E===this.lastSN+1&&(this.contiguous=!0),this.lastSN=E;var g=this.pmtParsed,h=this._avcTrack.id,f=this._aacTrack.id,_=this._id3Track.id;for(c-=c%188,t=0;c>t;t+=188)if(71===i[t]){if(d=!!(64&i[t+1]),u=((31&i[t+1])<<8)+i[t+2],y=(48&i[t+3])>>4,y>1){if(a=t+5+i[t+4],a===t+188)continue}else a=t+4;if(g)if(u===h){if(d){if(s&&(this._parseAVCPES(this._parsePES(s)),b&&this._avcTrack.codec&&(-1===f||this._aacTrack.codec)))return void this.remux(i);s={data:[],size:0}}s&&(s.data.push(i.subarray(a,t+188)),s.size+=t+188-a)}else if(u===f){if(d){if(o&&(this._parseAACPES(this._parsePES(o)),b&&this._aacTrack.codec&&(-1===h||this._avcTrack.codec)))return void this.remux(i);o={data:[],size:0}}o&&(o.data.push(i.subarray(a,t+188)),o.size+=t+188-a)}else u===_&&(d&&(l&&this._parseID3PES(this._parsePES(l)),l={data:[],size:0}),l&&(l.data.push(i.subarray(a,t+188)),l.size+=t+188-a));else d&&(a+=i[a]+1),0===u?this._parsePAT(i,a):u===this._pmtId?(this._parsePMT(i,a),g=this.pmtParsed=!0,h=this._avcTrack.id,f=this._aacTrack.id,_=this._id3Track.id,v&&(e.logger.log("reparse from beginning"),v=!1,t=-188)):(e.logger.log("unknown PID found before PAT/PMT"),v=!0)}else this.observer.trigger(n.default.ERROR,{type:r.ErrorTypes.MEDIA_ERROR,details:r.ErrorDetails.FRAG_PARSING_ERROR,fatal:!1,reason:"TS packet did not start with 0x47"});s&&this._parseAVCPES(this._parsePES(s)),o&&this._parseAACPES(this._parsePES(o)),l&&this._parseID3PES(this._parsePES(l)),this.remux(null)}},{key:"remux",value:function(e){this.remuxer.remux(this._aacTrack,this._avcTrack,this._id3Track,this._txtTrack,this.timeOffset,this.contiguous,e)}},{key:"destroy",value:function(){this.switchLevel(),this._initPTS=this._initDTS=void 0,this._duration=0}},{key:"_parsePAT",value:function(e,t){this._pmtId=(31&e[t+10])<<8|e[t+11]}},{key:"_parsePMT",value:function(r,t){var a,n,s,i;for(a=(15&r[t+1])<<8|r[t+2],n=t+3+a-4,s=(15&r[t+10])<<8|r[t+11],t+=12+s;n>t;){switch(i=(31&r[t+1])<<8|r[t+2],r[t]){case 15:this._aacTrack.id=i;break;case 21:this._id3Track.id=i;break;case 27:this._avcTrack.id=i;break;default:e.logger.log("unkown stream type:"+r[t])}t+=((15&r[t+3])<<8|r[t+4])+5}}},{key:"_parsePES",value:function(o){var e,n,h,d,u,l,i,r,t,f=0,s=o.data;if(e=s[0],h=(e[0]<<16)+(e[1]<<8)+e[2],1===h){for(d=(e[4]<<8)+e[5],n=e[7],192&n&&(i=536870912*(14&e[9])+4194304*(255&e[10])+16384*(254&e[11])+128*(255&e[12])+(254&e[13])/2,i>4294967295&&(i-=8589934592),64&n?(r=536870912*(14&e[14])+4194304*(255&e[15])+16384*(254&e[16])+128*(255&e[17])+(254&e[18])/2,r>4294967295&&(r-=8589934592)):r=i),u=e[8],t=u+9,o.size-=t,l=new Uint8Array(o.size);s.length;){e=s.shift();var a=e.byteLength;if(t){if(t>a){t-=a;continue}e=e.subarray(t),a-=t,t=0}l.set(e,f),f+=a}return{data:l,pts:i,dts:r,len:d}}return null}},{key:"_parseAVCPES",value:function(i){var t,m,n,o,y=this,r=this._avcTrack,u=r.samples,p=this._parseAVCNALu(i.data),d=[],l=!1,c=!1,f=0;if(0===p.length&&u.length>0){var v=u[u.length-1],h=v.units.units[v.units.units.length-1],g=new Uint8Array(h.data.byteLength+i.data.byteLength);g.set(h.data,0),g.set(i.data,h.data.byteLength),h.data=g,v.units.length+=i.data.byteLength,r.len+=i.data.byteLength}i.data=null;var a="",E=function(){d.length&&((c===!0||r.sps&&(u.length||this.contiguous))&&(m={units:{units:d,length:f},pts:i.pts,dts:i.dts,key:c},u.push(m),r.len+=f,r.nbNalu+=d.length),d=[],f=0)}.bind(this);p.forEach(function(e){switch(e.type){case 1:n=!0,l&&(a+="NDR ");break;case 5:n=!0,l&&(a+="IDR "),c=!0;break;case 6:n=!0,l&&(a+="SEI "),t=new s.default(e.data),t.readUByte();var b=t.readUByte();if(4===b){var g=0;do g=t.readUByte();while(255===g);var A=t.readUByte();if(181===A){var R=t.readUShort();if(49===R){var L=t.readUInt();if(1195456820===L){var T=t.readUByte();if(3===T){var v=t.readUByte(),_=t.readUByte(),S=31&v,h=[v,_];for(o=0;S>o;o++)h.push(t.readUByte()),h.push(t.readUByte()),h.push(t.readUByte());y._txtTrack.samples.push({type:3,pts:i.pts,bytes:h})}}}}}break;case 7:if(n=!0,l&&(a+="SPS "),!r.sps){t=new s.default(e.data);var p=t.readSPS();r.width=p.width,r.height=p.height,r.sps=[e.data],r.duration=y._duration;var k=e.data.subarray(1,4),m="avc1.";for(o=0;3>o;o++){var u=k[o].toString(16);u.length<2&&(u="0"+u),m+=u}r.codec=m}break;case 8:n=!0,l&&(a+="PPS "),r.pps||(r.pps=[e.data]);break;case 9:n=!1,l&&(a+="AUD "),E();break;default:n=!1,a+="unknown NAL "+e.type+" "}n&&(d.push(e),f+=e.data.byteLength)}),(l||a.length)&&e.logger.log(a),E()}},{key:"_parseAVCNALu",value:function(r){for(var s,i,l,_,n,d,t=0,g=r.byteLength,e=this.avcNaluState,v=[];g>t;)switch(s=r[t++],e){case 0:0===s&&(e=1);break;case 1:e=0===s?2:0;break;case 2:case 3:if(0===s)e=3;else if(1===s&&g>t){if(_=31&r[t],n)l={data:r.subarray(n,t-e-1),type:d},v.push(l);else{var a=this.avcNaluState;if(a&&4-a>=t){var m=this._avcTrack,c=m.samples;if(c.length){var p=c[c.length-1],R=p.units.units,u=R[R.length-1];u.state&&(u.data=u.data.subarray(0,u.data.byteLength-a),p.units.length-=a,m.len-=a)}}if(i=t-e-1,i>0){var y=this._avcTrack,h=y.samples;if(h.length){var E=h[h.length-1],b=E.units.units,o=b[b.length-1],f=new Uint8Array(o.data.byteLength+i);f.set(o.data,0),f.set(r.subarray(0,i),o.data.byteLength),o.data=f,E.units.length+=i,y.len+=i}}}n=t,d=_,e=0}else e=0}return n&&(l={data:r.subarray(n,g),type:d,state:e},v.push(l),this.avcNaluState=e),v}},{key:"_parseAACPES",value:function(R){var l,o,p,E,t,d,f,s,_,a=this._aacTrack,i=R.data,v=R.pts,k=0,L=this._duration,A=this.audioCodec,u=this.aacOverFlow,b=this.aacLastPTS;if(u){var m=new Uint8Array(u.byteLength+i.byteLength);m.set(u,0),m.set(i,u.byteLength),i=m}for(t=k,s=i.length;s-1>t&&(255!==i[t]||240!==(240&i[t+1]));t++);if(t){var y,h;if(s-1>t?(y="AAC PES did not start with ADTS header,offset:"+t,h=!1):(y="no ADTS header found in AAC PES",h=!0),this.observer.trigger(n.default.ERROR,{type:r.ErrorTypes.MEDIA_ERROR,details:r.ErrorDetails.FRAG_PARSING_ERROR,fatal:h,reason:y}),h)return}if(a.audiosamplerate||(l=c.default.getAudioConfig(this.observer,i,t,A),a.config=l.config,a.audiosamplerate=l.samplerate,a.channelCount=l.channelCount,a.codec=l.codec,a.duration=L,e.logger.log("parsed codec:"+a.codec+",rate:"+l.samplerate+",nb channel:"+l.channelCount)),E=0,p=9216e4/a.audiosamplerate,u&&b){var g=b+p;Math.abs(g-v)>1&&(e.logger.log("AAC: align PTS for overlapping frames by "+Math.round((g-v)/90)),v=g)}for(;s>t+5&&(d=1&i[t+1]?7:9,o=(3&i[t+3])<<11|i[t+4]<<3|(224&i[t+5])>>>5,o-=d,o>0&&s>=t+d+o);)for(f=v+E*p,_={unit:i.subarray(t+d,t+d+o),pts:f,dts:f},a.samples.push(_),a.len+=o,t+=o+d,E++;s-1>t&&(255!==i[t]||240!==(240&i[t+1]));t++);u=s>t?i.subarray(t,s):null,this.aacOverFlow=u,this.aacLastPTS=f}},{key:"_parseID3PES",value:function(e){this._id3Track.samples.push(e)}}],[{key:"probe",value:function(e){return e.length>=564&&71===e[0]&&71===e[188]&&71===e[376]}}]),t}();a.default=o},{"../errors":21,"../events":23,"../utils/logger":38,"./adts":14,"./exp-golomb":18}],21:[function(t,r,e){"use strict";Object.defineProperty(e,"__esModule",{value:!0});e.ErrorTypes={NETWORK_ERROR:"networkError",MEDIA_ERROR:"mediaError",OTHER_ERROR:"otherError"},e.ErrorDetails={MANIFEST_LOAD_ERROR:"manifestLoadError",MANIFEST_LOAD_TIMEOUT:"manifestLoadTimeOut",MANIFEST_PARSING_ERROR:"manifestParsingError",MANIFEST_INCOMPATIBLE_CODECS_ERROR:"manifestIncompatibleCodecsError",LEVEL_LOAD_ERROR:"levelLoadError",LEVEL_LOAD_TIMEOUT:"levelLoadTimeOut",LEVEL_SWITCH_ERROR:"levelSwitchError",FRAG_LOAD_ERROR:"fragLoadError",FRAG_LOOP_LOADING_ERROR:"fragLoopLoadingError",FRAG_LOAD_TIMEOUT:"fragLoadTimeOut",FRAG_DECRYPT_ERROR:"fragDecryptError",FRAG_PARSING_ERROR:"fragParsingError",KEY_LOAD_ERROR:"keyLoadError",KEY_LOAD_TIMEOUT:"keyLoadTimeOut",BUFFER_APPEND_ERROR:"bufferAppendError",BUFFER_APPENDING_ERROR:"bufferAppendingError",BUFFER_STALLED_ERROR:"bufferStalledError",BUFFER_FULL_ERROR:"bufferFullError",BUFFER_SEEK_OVER_HOLE:"bufferSeekOverHole",INTERNAL_EXCEPTION:"internalException"}},{}],22:[function(e,f,t){"use strict";function i(e){return e&&e.__esModule?e:{default:e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(t,"__esModule",{value:!0});var n="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol?"symbol":typeof e},d=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),o=e("./utils/logger"),r=e("./errors"),u=e("./events"),s=i(u),l=function(){function e(n){a(this,e),this.hls=n,this.onEvent=this.onEvent.bind(this);for(var r=arguments.length,i=Array(r>1?r-1:0),t=1;r>t;t++)i[t-1]=arguments[t];this.handledEvents=i,this.useGenericHandler=!0,this.registerListeners()}return d(e,[{key:"destroy",value:function(){this.unregisterListeners()}},{key:"isEventHandler",value:function(){return"object"===n(this.handledEvents)&&this.handledEvents.length&&"function"==typeof this.onEvent}},{key:"registerListeners",value:function(){this.isEventHandler()&&this.handledEvents.forEach(function(e){if("hlsEventGeneric"===e)throw new Error("Forbidden event name: "+e);this.hls.on(e,this.onEvent)}.bind(this))}},{key:"unregisterListeners",value:function(){this.isEventHandler()&&this.handledEvents.forEach(function(e){this.hls.off(e,this.onEvent)}.bind(this))}},{key:"onEvent",value:function(e,t){this.onEventGeneric(e,t)}},{key:"onEventGeneric",value:function(e,t){var i=function(t,r){var e="on"+t.replace("hls","");if("function"!=typeof this[e])throw new Error("Event "+t+" has no generic handler in this "+this.constructor.name+" class (tried "+e+")");return this[e].bind(this,r)};try{i.call(this,e,t).call()}catch(t){o.logger.error("internal error happened while processing "+e+":"+t.message),this.hls.trigger(s.default.ERROR,{type:r.ErrorTypes.OTHER_ERROR,details:r.ErrorDetails.INTERNAL_EXCEPTION,fatal:!1,event:e,err:t})}}}]),e}();t.default=l},{"./errors":21,"./events":23,"./utils/logger":38}],23:[function(t,e,r){"use strict";e.exports={MEDIA_ATTACHING:"hlsMediaAttaching",MEDIA_ATTACHED:"hlsMediaAttached",MEDIA_DETACHING:"hlsMediaDetaching",MEDIA_DETACHED:"hlsMediaDetached",BUFFER_RESET:"hlsBufferReset",BUFFER_CODECS:"hlsBufferCodecs",BUFFER_APPENDING:"hlsBufferAppending",BUFFER_APPENDED:"hlsBufferAppended",BUFFER_EOS:"hlsBufferEos",BUFFER_FLUSHING:"hlsBufferFlushing",BUFFER_FLUSHED:"hlsBufferFlushed",MANIFEST_LOADING:"hlsManifestLoading",MANIFEST_LOADED:"hlsManifestLoaded",MANIFEST_PARSED:"hlsManifestParsed",LEVEL_LOADING:"hlsLevelLoading",LEVEL_LOADED:"hlsLevelLoaded",LEVEL_UPDATED:"hlsLevelUpdated",LEVEL_PTS_UPDATED:"hlsLevelPtsUpdated",LEVEL_SWITCH:"hlsLevelSwitch",FRAG_LOADING:"hlsFragLoading",FRAG_LOAD_PROGRESS:"hlsFragLoadProgress",FRAG_LOAD_EMERGENCY_ABORTED:"hlsFragLoadEmergencyAborted",FRAG_LOADED:"hlsFragLoaded",FRAG_PARSING_INIT_SEGMENT:"hlsFragParsingInitSegment",FRAG_PARSING_USERDATA:"hlsFragParsingUserdata",FRAG_PARSING_METADATA:"hlsFragParsingMetadata",FRAG_PARSING_DATA:"hlsFragParsingData",FRAG_PARSED:"hlsFragParsed",FRAG_BUFFERED:"hlsFragBuffered",FRAG_CHANGED:"hlsFragChanged",FPS_DROP:"hlsFpsDrop",ERROR:"hlsError",DESTROYING:"hlsDestroying",KEY_LOADING:"hlsKeyLoading",KEY_LOADED:"hlsKeyLoaded"}},{}],24:[function(a,n,e){"use strict";function t(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(e,"__esModule",{value:!0});var r=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),i=function(){function e(){t(this,e)}return r(e,null,[{key:"bufferInfo",value:function(r,a,n){if(r){var e,t=r.buffered,i=[];for(e=0;e<t.length;e++)i.push({start:t.start(e),end:t.end(e)});return this.bufferedInfo(i,a,n)}return{len:0,start:0,end:0,nextStart:void 0}}},{key:"bufferedInfo",value:function(r,i,s){var o,l,a,h,e,t=[];for(r.sort(function(e,t){var r=e.start-t.start;return r?r:t.end-e.end}),e=0;e<r.length;e++){var u=t.length;if(u){var d=t[u-1].end;r[e].start-d<s?r[e].end>d&&(t[u-1].end=r[e].end):t.push(r[e])}else t.push(r[e])}for(e=0,o=0,l=a=i;e<t.length;e++){var n=t[e].start,f=t[e].end;if(i+s>=n&&f>i)l=n,a=f,o=a-i;else if(n>i+s){h=n;break}}return{len:o,start:l,end:a,nextStart:h}}}]),e}();e.default=i},{}],25:[function(r,s,t){"use strict";function i(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(t,"__esModule",{value:!0});var a=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),e=r("../utils/logger"),n=function(){function t(){i(this,t)}return a(t,null,[{key:"mergeDetails",value:function(s,i){var a,c=Math.max(s.startSN,i.startSN)-i.startSN,h=Math.min(s.endSN,i.endSN)-i.startSN,u=i.startSN-s.startSN,f=s.fragments,l=i.fragments,d=0;if(c>h)return void(i.PTSKnown=!1);for(var r=c;h>=r;r++){var o=f[u+r],n=l[r];d=o.cc-n.cc,isNaN(o.startPTS)||(n.start=n.startPTS=o.startPTS,n.endPTS=o.endPTS,n.duration=o.duration,a=n)}if(d)for(e.logger.log("discontinuity sliding from playlist, take drift into account"),r=0;r<l.length;r++)l[r].cc+=d;if(a)t.updateFragPTSDTS(i,a.sn,a.startPTS,a.endPTS,a.startDTS,a.endDTS);else if(u>=0&&u<f.length){var v=f[u].start;for(r=0;r<l.length;r++)l[r].start+=v}i.PTSKnown=s.PTSKnown}},{key:"updateFragPTSDTS",value:function(i,u,a,s,l,d){var o,n,e,r;if(u<i.startSN||u>i.endSN)return 0;o=u-i.startSN,n=i.fragments,e=n[o],isNaN(e.startPTS)||(a=Math.min(a,e.startPTS),s=Math.max(s,e.endPTS),l=Math.min(l,e.startDTS),d=Math.max(d,e.endDTS));var f=a-e.start;for(e.start=e.startPTS=a,e.endPTS=s,e.startDTS=l,e.endDTS=d,e.duration=s-a,r=o;r>0;r--)t.updatePTS(n,r,r-1);for(r=o;r<n.length-1;r++)t.updatePTS(n,r,r+1);return i.PTSKnown=!0,f}},{key:"updatePTS",value:function(s,i,a){var t=s[i],r=s[a],n=r.startPTS;isNaN(n)?a>i?r.start=t.start+t.duration:r.start=t.start-r.duration:a>i?(t.duration=n-t.start,t.duration<0&&e.logger.error("negative duration computed for frag "+t.sn+",level "+t.level+", there should be some duration drift between playlist and fragment!")):(r.duration=t.start-n,r.duration<0&&e.logger.error("negative duration computed for frag "+r.sn+",level "+r.level+", there should be some duration drift between playlist and fragment!"))}}]),t}();t.default=n},{"../utils/logger":38}],26:[function(t,I,a){"use strict";function r(e){return e&&e.__esModule?e:{default:e}}function o(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(a,"__esModule",{value:!0});var n=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),k=t("./events"),i=r(k),s=t("./errors"),u=t("./loader/playlist-loader"),d=r(u),f=t("./loader/fragment-loader"),h=r(f),c=t("./controller/abr-controller"),v=r(c),g=t("./controller/buffer-controller"),P=r(g),y=t("./controller/cap-level-controller"),m=r(y),E=t("./controller/stream-controller"),b=r(E),_=t("./controller/level-controller"),R=r(_),A=t("./controller/timeline-controller"),L=r(A),e=t("./utils/logger"),T=t("./utils/xhr-loader"),S=r(T),w=t("events"),D=r(w),O=t("./loader/key-loader"),p=r(O),l=function(){function t(){var r=arguments.length<=0||void 0===arguments[0]?{}:arguments[0];o(this,t);var n=t.DefaultConfig;if((r.liveSyncDurationCount||r.liveMaxLatencyDurationCount)&&(r.liveSyncDuration||r.liveMaxLatencyDuration))throw new Error("Illegal hls.js config: don't mix up liveSyncDurationCount/liveMaxLatencyDurationCount and liveSyncDuration/liveMaxLatencyDuration");for(var a in n)a in r||(r[a]=n[a]);if(void 0!==r.liveMaxLatencyDurationCount&&r.liveMaxLatencyDurationCount<=r.liveSyncDurationCount)throw new Error('Illegal hls.js config: "liveMaxLatencyDurationCount" must be gt "liveSyncDurationCount"');if(void 0!==r.liveMaxLatencyDuration&&(r.liveMaxLatencyDuration<=r.liveSyncDuration||void 0===r.liveSyncDuration))throw new Error('Illegal hls.js config: "liveMaxLatencyDuration" must be gt "liveSyncDuration"');(0,e.enableLogs)(r.debug),this.config=r;var i=this.observer=new D.default;i.trigger=function(r){for(var t=arguments.length,a=Array(t>1?t-1:0),e=1;t>e;e++)a[e-1]=arguments[e];i.emit.apply(i,[r,r].concat(a))},i.off=function(a){for(var t=arguments.length,r=Array(t>1?t-1:0),e=1;t>e;e++)r[e-1]=arguments[e];i.removeListener.apply(i,[a].concat(r))},this.on=i.on.bind(i),this.off=i.off.bind(i),this.trigger=i.trigger.bind(i),this.playlistLoader=new d.default(this),this.fragmentLoader=new h.default(this),this.levelController=new R.default(this),this.abrController=new r.abrController(this),this.bufferController=new r.bufferController(this),this.capLevelController=new r.capLevelController(this),this.streamController=new r.streamController(this),this.timelineController=new r.timelineController(this),this.keyLoader=new p.default(this)}return n(t,null,[{key:"isSupported",value:function(){return window.MediaSource&&window.MediaSource.isTypeSupported('video/mp4; codecs="avc1.42E01E,mp4a.40.2"')}},{key:"Events",get:function(){return i.default}},{key:"ErrorTypes",get:function(){return s.ErrorTypes}},{key:"ErrorDetails",get:function(){return s.ErrorDetails}},{key:"DefaultConfig",get:function(){return t.defaultConfig||(t.defaultConfig={autoStartLoad:!0,debug:!1,capLevelToPlayerSize:!1,maxBufferLength:30,maxBufferSize:6e7,maxBufferHole:.5,maxSeekHole:2,seekHoleNudgeDuration:.01,stalledInBufferedNudgeThreshold:10,maxFragLookUpTolerance:.2,liveSyncDurationCount:3,liveMaxLatencyDurationCount:1/0,liveSyncDuration:void 0,liveMaxLatencyDuration:void 0,maxMaxBufferLength:600,enableWorker:!0,enableSoftwareAES:!0,manifestLoadingTimeOut:1e4,manifestLoadingMaxRetry:1,manifestLoadingRetryDelay:1e3,levelLoadingTimeOut:1e4,levelLoadingMaxRetry:4,levelLoadingRetryDelay:1e3,fragLoadingTimeOut:2e4,fragLoadingMaxRetry:6,fragLoadingRetryDelay:1e3,fragLoadingLoopThreshold:3,startFragPrefetch:!1,appendErrorMaxRetry:3,loader:S.default,fLoader:void 0,pLoader:void 0,abrController:v.default,bufferController:P.default,capLevelController:m.default,streamController:b.default,timelineController:L.default,enableCEA708Captions:!0,enableMP2TPassThrough:!1,abrEwmaFast:0,abrEwmaSlow:0,abrBandWidthFactor:.8,abrBandWidthUpFactor:.7}),t.defaultConfig},set:function(e){t.defaultConfig=e}}]),n(t,[{key:"destroy",value:function(){e.logger.log("destroy"),this.trigger(i.default.DESTROYING),this.detachMedia(),this.playlistLoader.destroy(),this.fragmentLoader.destroy(),this.levelController.destroy(),this.abrController.destroy(),this.bufferController.destroy(),this.capLevelController.destroy(),this.streamController.destroy(),this.timelineController.destroy(),this.keyLoader.destroy(),this.url=null,this.observer.removeAllListeners()}},{key:"attachMedia",value:function(t){e.logger.log("attachMedia"),this.media=t,this.trigger(i.default.MEDIA_ATTACHING,{media:t})}},{key:"detachMedia",value:function(){e.logger.log("detachMedia"),this.trigger(i.default.MEDIA_DETACHING),this.media=null}},{key:"loadSource",value:function(t){e.logger.log("loadSource:"+t),this.url=t,this.trigger(i.default.MANIFEST_LOADING,{url:t})}},{key:"startLoad",value:function(){var t=arguments.length<=0||void 0===arguments[0]?0:arguments[0];e.logger.log("startLoad"),this.levelController.startLoad(),this.streamController.startLoad(t)}},{key:"stopLoad",value:function(){e.logger.log("stopLoad"),this.levelController.stopLoad(),this.streamController.stopLoad()}},{key:"swapAudioCodec",value:function(){e.logger.log("swapAudioCodec"),this.streamController.swapAudioCodec()}},{key:"recoverMediaError",value:function(){e.logger.log("recoverMediaError");var t=this.media;this.detachMedia(),this.attachMedia(t)}},{key:"levels",get:function(){return this.levelController.levels}},{key:"currentLevel",get:function(){return this.streamController.currentLevel},set:function(t){e.logger.log("set currentLevel:"+t),this.loadLevel=t,this.streamController.immediateLevelSwitch()}},{key:"nextLevel",get:function(){return this.streamController.nextLevel},set:function(t){e.logger.log("set nextLevel:"+t),this.levelController.manualLevel=t,this.streamController.nextLevelSwitch()}},{key:"loadLevel",get:function(){return this.levelController.level},set:function(t){e.logger.log("set loadLevel:"+t),this.levelController.manualLevel=t}},{key:"nextLoadLevel",get:function(){return this.levelController.nextLoadLevel},set:function(e){this.levelController.nextLoadLevel=e}},{key:"firstLevel",get:function(){return this.levelController.firstLevel},set:function(t){e.logger.log("set firstLevel:"+t),this.levelController.firstLevel=t}},{key:"startLevel",get:function(){return this.levelController.startLevel},set:function(t){e.logger.log("set startLevel:"+t),this.levelController.startLevel=t}},{key:"autoLevelCapping",get:function(){return this.abrController.autoLevelCapping},set:function(t){e.logger.log("set autoLevelCapping:"+t),this.abrController.autoLevelCapping=t}},{key:"autoLevelEnabled",get:function(){return-1===this.levelController.manualLevel}},{key:"manualLevel",get:function(){return this.levelController.manualLevel}}]),t}();a.default=l},{"./controller/abr-controller":3,"./controller/buffer-controller":4,"./controller/cap-level-controller":5,"./controller/level-controller":7,"./controller/stream-controller":8,"./controller/timeline-controller":9,"./errors":21,"./events":23,"./loader/fragment-loader":28,"./loader/key-loader":29,"./loader/playlist-loader":30,"./utils/logger":38,"./utils/xhr-loader":40,events:1}],27:[function(e,t,r){"use strict";t.exports=e("./hls.js").default},{"./hls.js":26}],28:[function(r,c,i){"use strict";function a(e){return e&&e.__esModule?e:{default:e}}function u(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function f(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(i,"__esModule",{value:!0});var h=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),l=r("../events"),e=a(l),d=r("../event-handler"),n=a(d),t=r("../errors"),o=function(i){function r(t){return u(this,r),f(this,Object.getPrototypeOf(r).call(this,t,e.default.FRAG_LOADING))}return s(r,i),h(r,[{key:"destroy",value:function(){this.loader&&(this.loader.destroy(),this.loader=null),n.default.prototype.destroy.call(this)}},{key:"onFragLoading",value:function(r){var t=r.frag;this.frag=t,this.frag.loaded=0;var e=this.hls.config;t.loader=this.loader="undefined"!=typeof e.fLoader?new e.fLoader(e):new e.loader(e),this.loader.load(t.url,"arraybuffer",this.loadsuccess.bind(this),this.loaderror.bind(this),this.loadtimeout.bind(this),e.fragLoadingTimeOut,1,0,this.loadprogress.bind(this),t)}},{key:"loadsuccess",value:function(i,t){var r=i.currentTarget.response;t.length=r.byteLength,this.frag.loader=void 0,this.hls.trigger(e.default.FRAG_LOADED,{payload:r,frag:this.frag,stats:t})}},{key:"loaderror",value:function(r){this.loader&&this.loader.abort(),this.hls.trigger(e.default.ERROR,{type:t.ErrorTypes.NETWORK_ERROR,details:t.ErrorDetails.FRAG_LOAD_ERROR,fatal:!1,frag:this.frag,response:r})}},{key:"loadtimeout",value:function(){this.loader&&this.loader.abort(),this.hls.trigger(e.default.ERROR,{type:t.ErrorTypes.NETWORK_ERROR,details:t.ErrorDetails.FRAG_LOAD_TIMEOUT,fatal:!1,frag:this.frag})}},{key:"loadprogress",value:function(r,t){this.frag.loaded=t.loaded,this.hls.trigger(e.default.FRAG_LOAD_PROGRESS,{frag:this.frag,stats:t})}}]),r}(n.default);i.default=o},{"../errors":21,"../event-handler":22,"../events":23}],29:[function(r,c,i){"use strict";function a(e){return e&&e.__esModule?e:{default:e}}function u(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function f(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function s(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(i,"__esModule",{value:!0});var h=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,
e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),l=r("../events"),e=a(l),d=r("../event-handler"),n=a(d),t=r("../errors"),o=function(i){function r(i){u(this,r);var t=f(this,Object.getPrototypeOf(r).call(this,i,e.default.KEY_LOADING));return t.decryptkey=null,t.decrypturl=null,t}return s(r,i),h(r,[{key:"destroy",value:function(){this.loader&&(this.loader.destroy(),this.loader=null),n.default.prototype.destroy.call(this)}},{key:"onKeyLoading",value:function(n){var t=this.frag=n.frag,a=t.decryptdata,i=a.uri;if(i!==this.decrypturl||null===this.decryptkey){var r=this.hls.config;t.loader=this.loader=new r.loader(r),this.decrypturl=i,this.decryptkey=null,t.loader.load(i,"arraybuffer",this.loadsuccess.bind(this),this.loaderror.bind(this),this.loadtimeout.bind(this),r.fragLoadingTimeOut,r.fragLoadingMaxRetry,r.fragLoadingRetryDelay,this.loadprogress.bind(this),t)}else this.decryptkey&&(a.key=this.decryptkey,this.hls.trigger(e.default.KEY_LOADED,{frag:t}))}},{key:"loadsuccess",value:function(r){var t=this.frag;this.decryptkey=t.decryptdata.key=new Uint8Array(r.currentTarget.response),t.loader=void 0,this.hls.trigger(e.default.KEY_LOADED,{frag:t})}},{key:"loaderror",value:function(r){this.loader&&this.loader.abort(),this.hls.trigger(e.default.ERROR,{type:t.ErrorTypes.NETWORK_ERROR,details:t.ErrorDetails.KEY_LOAD_ERROR,fatal:!1,frag:this.frag,response:r})}},{key:"loadtimeout",value:function(){this.loader&&this.loader.abort(),this.hls.trigger(e.default.ERROR,{type:t.ErrorTypes.NETWORK_ERROR,details:t.ErrorDetails.KEY_LOAD_TIMEOUT,fatal:!1,frag:this.frag})}},{key:"loadprogress",value:function(){}}]),r}(n.default);i.default=o},{"../errors":21,"../event-handler":22,"../events":23}],30:[function(r,y,s){"use strict";function i(e){return e&&e.__esModule?e:{default:e}}function d(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function f(t,e){if(!t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!e||"object"!=typeof e&&"function"!=typeof e?t:e}function h(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function, not "+typeof e);t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),e&&(Object.setPrototypeOf?Object.setPrototypeOf(t,e):t.__proto__=e)}Object.defineProperty(s,"__esModule",{value:!0});var o=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),l=r("../events"),t=i(l),p=r("../event-handler"),n=i(p),e=r("../errors"),c=r("../utils/url"),v=i(c),g=r("../utils/attr-list"),a=i(g),u=function(i){function r(e){return d(this,r),f(this,Object.getPrototypeOf(r).call(this,e,t.default.MANIFEST_LOADING,t.default.LEVEL_LOADING))}return h(r,i),o(r,[{key:"destroy",value:function(){this.loader&&(this.loader.destroy(),this.loader=null),this.url=this.id=null,n.default.prototype.destroy.call(this)}},{key:"onManifestLoading",value:function(e){this.load(e.url,null)}},{key:"onLevelLoading",value:function(e){this.load(e.url,e.level,e.id)}},{key:"load",value:function(t,n,s){var r,i,a,e=this.hls.config;if(this.loading&&this.loader){if(this.url===t&&this.id===n&&this.id2===s)return;this.loader.abort()}this.url=t,this.id=n,this.id2=s,null===this.id?(r=e.manifestLoadingMaxRetry,i=e.manifestLoadingTimeOut,a=e.manifestLoadingRetryDelay):(r=e.levelLoadingMaxRetry,i=e.levelLoadingTimeOut,a=e.levelLoadingRetryDelay),this.loader="undefined"!=typeof e.pLoader?new e.pLoader(e):new e.loader(e),this.loading=!0,this.loader.load(t,"",this.loadsuccess.bind(this),this.loaderror.bind(this),this.loadtimeout.bind(this),i,r,a)}},{key:"resolve",value:function(e,t){return v.default.buildAbsoluteURL(t,e)}},{key:"parseMasterPlaylist",value:function(f,u){for(var l=[],i=void 0,d=/#EXT-X-STREAM-INF:([^\n\r]*)[\r\n]+([^\r\n]+)/g;null!=(i=d.exec(f));){var e={},r=e.attrs=new a.default(i[1]);e.url=this.resolve(i[2],u);var s=r.decimalResolution("RESOLUTION");s&&(e.width=s.width,e.height=s.height),e.bitrate=r.decimalInteger("AVERAGE-BANDWIDTH")||r.decimalInteger("BANDWIDTH"),e.name=r.NAME;var t=r.CODECS;if(t){t=t.split(",");for(var o=0;o<t.length;o++){var n=t[o];-1!==n.indexOf("avc1")?e.videoCodec=this.avc1toavcoti(n):e.audioCodec=n}}l.push(e)}return l}},{key:"avc1toavcoti",value:function(r){var e,t=r.split(".");return t.length>2?(e=t.shift()+".",e+=parseInt(t.shift()).toString(16),e+=("000"+parseInt(t.shift()).toString(16)).substr(-4)):e=r,e}},{key:"cloneObj",value:function(e){return JSON.parse(JSON.stringify(e))}},{key:"parseLevelPlaylist",value:function(L,s,A){var e,b,u,n,v=0,o=0,i={url:s,fragments:[],live:!0,startSN:0},r={method:null,key:null,iv:null,uri:null},y=0,d=null,t=null;for(b=/(?:#EXT-X-(MEDIA-SEQUENCE):(\d+))|(?:#EXT-X-(TARGETDURATION):(\d+))|(?:#EXT-X-(KEY):(.*))|(?:#EXT(INF):([\d\.]+)[^\r\n]*([\r\n]+[^#|\r\n]+)?)|(?:#EXT-X-(BYTERANGE):([\d]+[@[\d]*)]*[\r\n]+([^#|\r\n]+)?|(?:#EXT-X-(ENDLIST))|(?:#EXT-X-(DIS)CONTINUITY))|(?:#EXT-X-(PROGRAM-DATE-TIME):(.*)[\r\n]+([^#|\r\n]+)?)/g;null!==(e=b.exec(L));)switch(e.shift(),e=e.filter(function(e){return void 0!==e}),e[0]){case"MEDIA-SEQUENCE":v=i.startSN=parseInt(e[1]);break;case"TARGETDURATION":i.targetduration=parseFloat(e[1]);break;case"ENDLIST":i.live=!1;break;case"DIS":y++;break;case"BYTERANGE":var h=e[1].split("@");n=1===h.length?u:parseInt(h[1]),u=parseInt(h[0])+n,t&&!t.url&&(t.byteRangeStartOffset=n,t.byteRangeEndOffset=u,t.url=this.resolve(e[2],s));break;case"INF":var c=parseFloat(e[1]);if(!isNaN(c)){var f,m=v++;if(r.method&&r.uri&&!r.iv){f=this.cloneObj(r);for(var E=new Uint8Array(16),l=12;16>l;l++)E[l]=m>>8*(15-l)&255;f.iv=E}else f=r;var k=e[2]?this.resolve(e[2],s):null;t={url:k,duration:c,start:o,sn:m,level:A,cc:y,byteRangeStartOffset:n,byteRangeEndOffset:u,decryptdata:f,programDateTime:d},i.fragments.push(t),o+=c,n=null,d=null}break;case"KEY":var R=e[1],g=new a.default(R),p=g.enumeratedString("METHOD"),_=g.URI,T=g.hexadecimalInteger("IV");p&&(r={method:null,key:null,iv:null,uri:null},_&&"AES-128"===p&&(r.method=p,r.uri=this.resolve(_,s),r.key=null,r.iv=T));break;case"PROGRAM-DATE-TIME":d=new Date(Date.parse(e[1])),t&&!t.url&&e.length>=3&&(t.url=this.resolve(e[2],s),t.programDateTime=d)}return t&&!t.url&&(i.fragments.pop(),o-=t.duration),i.totalduration=o,i.endSN=v-1,i}},{key:"loadsuccess",value:function(u,i){var s,o=u.currentTarget,n=o.responseText,r=o.responseURL,l=this.id,d=this.id2,a=this.hls;if(this.loading=!1,void 0===r&&(r=this.url),i.tload=performance.now(),i.mtime=new Date(o.getResponseHeader("Last-Modified")),0===n.indexOf("#EXTM3U"))if(n.indexOf("#EXTINF:")>0)if(null===this.id)a.trigger(t.default.MANIFEST_LOADED,{levels:[{url:r}],url:r,stats:i});else{var f=this.parseLevelPlaylist(n,r,l);i.tparsed=performance.now(),a.trigger(t.default.LEVEL_LOADED,{details:f,level:l,id:d,stats:i})}else s=this.parseMasterPlaylist(n,r),s.length?a.trigger(t.default.MANIFEST_LOADED,{levels:s,url:r,stats:i}):a.trigger(t.default.ERROR,{type:e.ErrorTypes.NETWORK_ERROR,details:e.ErrorDetails.MANIFEST_PARSING_ERROR,fatal:!0,url:r,reason:"no level found in manifest"});else a.trigger(t.default.ERROR,{type:e.ErrorTypes.NETWORK_ERROR,details:e.ErrorDetails.MANIFEST_PARSING_ERROR,fatal:!0,url:r,reason:"no EXTM3U delimiter"})}},{key:"loaderror",value:function(a){var r,i;null===this.id?(r=e.ErrorDetails.MANIFEST_LOAD_ERROR,i=!0):(r=e.ErrorDetails.LEVEL_LOAD_ERROR,i=!1),this.loader&&this.loader.abort(),this.loading=!1,this.hls.trigger(t.default.ERROR,{type:e.ErrorTypes.NETWORK_ERROR,details:r,fatal:i,url:this.url,loader:this.loader,response:a.currentTarget,level:this.id,id:this.id2})}},{key:"loadtimeout",value:function(){var r,i;null===this.id?(r=e.ErrorDetails.MANIFEST_LOAD_TIMEOUT,i=!0):(r=e.ErrorDetails.LEVEL_LOAD_TIMEOUT,i=!1),this.loader&&this.loader.abort(),this.loading=!1,this.hls.trigger(t.default.ERROR,{type:e.ErrorTypes.NETWORK_ERROR,details:r,fatal:i,url:this.url,loader:this.loader,level:this.id,id:this.id2})}}]),r}(n.default);s.default=u},{"../errors":21,"../event-handler":22,"../events":23,"../utils/attr-list":34,"../utils/url":39}],31:[function(a,n,e){"use strict";function t(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(e,"__esModule",{value:!0});var r=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),i=function(){function e(){t(this,e)}return r(e,null,[{key:"init",value:function(){e.types={avc1:[],avcC:[],btrt:[],dinf:[],dref:[],esds:[],ftyp:[],hdlr:[],mdat:[],mdhd:[],mdia:[],mfhd:[],minf:[],moof:[],moov:[],mp4a:[],mvex:[],mvhd:[],sdtp:[],stbl:[],stco:[],stsc:[],stsd:[],stsz:[],stts:[],tfdt:[],tfhd:[],traf:[],trak:[],trun:[],trex:[],tkhd:[],vmhd:[],smhd:[]};var t;for(t in e.types)e.types.hasOwnProperty(t)&&(e.types[t]=[t.charCodeAt(0),t.charCodeAt(1),t.charCodeAt(2),t.charCodeAt(3)]);var i=new Uint8Array([0,0,0,0,0,0,0,0,118,105,100,101,0,0,0,0,0,0,0,0,0,0,0,0,86,105,100,101,111,72,97,110,100,108,101,114,0]),a=new Uint8Array([0,0,0,0,0,0,0,0,115,111,117,110,0,0,0,0,0,0,0,0,0,0,0,0,83,111,117,110,100,72,97,110,100,108,101,114,0]);e.HDLR_TYPES={video:i,audio:a};var n=new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,12,117,114,108,32,0,0,0,1]),s=new Uint8Array([0,0,0,0,0,0,0,0]);e.STTS=e.STSC=e.STCO=s,e.STSZ=new Uint8Array([0,0,0,0,0,0,0,0,0,0,0,0]),e.VMHD=new Uint8Array([0,0,0,1,0,0,0,0,0,0,0,0]),e.SMHD=new Uint8Array([0,0,0,0,0,0,0,0]),e.STSD=new Uint8Array([0,0,0,0,0,0,0,1]);var r=new Uint8Array([105,115,111,109]),o=new Uint8Array([97,118,99,49]),l=new Uint8Array([0,0,0,1]);e.FTYP=e.box(e.types.ftyp,r,l,r,o),e.DINF=e.box(e.types.dinf,e.box(e.types.dref,n))}},{key:"box",value:function(a){for(var t,i=Array.prototype.slice.call(arguments,1),e=8,r=i.length,n=r;r--;)e+=i[r].byteLength;for(t=new Uint8Array(e),t[0]=e>>24&255,t[1]=e>>16&255,t[2]=e>>8&255,t[3]=255&e,t.set(a,4),r=0,e=8;n>r;r++)t.set(i[r],e),e+=i[r].byteLength;return t}},{key:"hdlr",value:function(t){return e.box(e.types.hdlr,e.HDLR_TYPES[t])}},{key:"mdat",value:function(t){return e.box(e.types.mdat,t)}},{key:"mdhd",value:function(t,r){return r*=t,e.box(e.types.mdhd,new Uint8Array([0,0,0,0,0,0,0,2,0,0,0,3,t>>24&255,t>>16&255,t>>8&255,255&t,r>>24,r>>16&255,r>>8&255,255&r,85,196,0,0]))}},{key:"mdia",value:function(t){return e.box(e.types.mdia,e.mdhd(t.timescale,t.duration),e.hdlr(t.type),e.minf(t))}},{key:"mfhd",value:function(t){return e.box(e.types.mfhd,new Uint8Array([0,0,0,0,t>>24,t>>16&255,t>>8&255,255&t]))}},{key:"minf",value:function(t){return"audio"===t.type?e.box(e.types.minf,e.box(e.types.smhd,e.SMHD),e.DINF,e.stbl(t)):e.box(e.types.minf,e.box(e.types.vmhd,e.VMHD),e.DINF,e.stbl(t))}},{key:"moof",value:function(t,r,i){return e.box(e.types.moof,e.mfhd(t),e.traf(i,r))}},{key:"moov",value:function(t){for(var r=t.length,i=[];r--;)i[r]=e.trak(t[r]);return e.box.apply(null,[e.types.moov,e.mvhd(t[0].timescale,t[0].duration)].concat(i).concat(e.mvex(t)))}},{key:"mvex",value:function(r){for(var t=r.length,i=[];t--;)i[t]=e.trex(r[t]);return e.box.apply(null,[e.types.mvex].concat(i))}},{key:"mvhd",value:function(t,r){r*=t;var i=new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,2,t>>24&255,t>>16&255,t>>8&255,255&t,r>>24&255,r>>16&255,r>>8&255,255&r,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255]);return e.box(e.types.mvhd,i)}},{key:"sdtp",value:function(n){var r,t,i=n.samples||[],a=new Uint8Array(4+i.length);for(t=0;t<i.length;t++)r=i[t].flags,a[t+4]=r.dependsOn<<4|r.isDependedOn<<2|r.hasRedundancy;return e.box(e.types.sdtp,a)}},{key:"stbl",value:function(t){return e.box(e.types.stbl,e.stsd(t),e.box(e.types.stts,e.STTS),e.box(e.types.stsc,e.STSC),e.box(e.types.stsz,e.STSZ),e.box(e.types.stco,e.STCO))}},{key:"avc1",value:function(t){var r,a,n,i=[],s=[];for(r=0;r<t.sps.length;r++)a=t.sps[r],n=a.byteLength,i.push(n>>>8&255),i.push(255&n),i=i.concat(Array.prototype.slice.call(a));for(r=0;r<t.pps.length;r++)a=t.pps[r],n=a.byteLength,s.push(n>>>8&255),s.push(255&n),s=s.concat(Array.prototype.slice.call(a));var u=e.box(e.types.avcC,new Uint8Array([1,i[3],i[4],i[5],255,224|t.sps.length].concat(i).concat([t.pps.length]).concat(s))),o=t.width,l=t.height;return e.box(e.types.avc1,new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,o>>8&255,255&o,l>>8&255,255&l,0,72,0,0,0,72,0,0,0,0,0,0,0,1,18,100,97,105,108,121,109,111,116,105,111,110,47,104,108,115,46,106,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,17,17]),u,e.box(e.types.btrt,new Uint8Array([0,28,156,128,0,45,198,192,0,45,198,192])))}},{key:"esds",value:function(t){var e=t.config.length;return new Uint8Array([0,0,0,0,3,23+e,0,1,0,4,15+e,64,21,0,0,0,0,0,0,0,0,0,0,0,5].concat([e]).concat(t.config).concat([6,1,2]))}},{key:"mp4a",value:function(t){var r=t.audiosamplerate;return e.box(e.types.mp4a,new Uint8Array([0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,t.channelCount,0,16,0,0,0,0,r>>8&255,255&r,0,0]),e.box(e.types.esds,e.esds(t)))}},{key:"stsd",value:function(t){return"audio"===t.type?e.box(e.types.stsd,e.STSD,e.mp4a(t)):e.box(e.types.stsd,e.STSD,e.avc1(t))}},{key:"tkhd",value:function(t){var r=t.id,i=t.duration*t.timescale,a=t.width,n=t.height;return e.box(e.types.tkhd,new Uint8Array([0,0,0,7,0,0,0,0,0,0,0,0,r>>24&255,r>>16&255,r>>8&255,255&r,0,0,0,0,i>>24,i>>16&255,i>>8&255,255&i,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,a>>8&255,255&a,0,0,n>>8&255,255&n,0,0]))}},{key:"traf",value:function(i,t){var a=e.sdtp(i),r=i.id;return e.box(e.types.traf,e.box(e.types.tfhd,new Uint8Array([0,0,0,0,r>>24,r>>16&255,r>>8&255,255&r])),e.box(e.types.tfdt,new Uint8Array([0,0,0,0,t>>24,t>>16&255,t>>8&255,255&t])),e.trun(i,a.length+16+16+8+16+8+8),a)}},{key:"trak",value:function(t){return t.duration=t.duration||4294967295,e.box(e.types.trak,e.tkhd(t),e.mdia(t))}},{key:"trex",value:function(r){var t=r.id;return e.box(e.types.trex,new Uint8Array([0,0,0,0,t>>24,t>>16&255,t>>8&255,255&t,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1]))}},{key:"trun",value:function(h,o){var i,a,n,s,t,l,d=h.samples||[],r=d.length,f=12+16*r,u=new Uint8Array(f);for(o+=8+f,u.set([0,0,15,1,r>>>24&255,r>>>16&255,r>>>8&255,255&r,o>>>24&255,o>>>16&255,o>>>8&255,255&o],0),i=0;r>i;i++)a=d[i],n=a.duration,s=a.size,t=a.flags,l=a.cts,u.set([n>>>24&255,n>>>16&255,n>>>8&255,255&n,s>>>24&255,s>>>16&255,s>>>8&255,255&s,t.isLeading<<2|t.dependsOn,t.isDependedOn<<6|t.hasRedundancy<<4|t.paddingValue<<1|t.isNonSync,61440&t.degradPrio,15&t.degradPrio,l>>>24&255,l>>>16&255,l>>>8&255,255&l],12+16*i);return e.box(e.types.trun,u)}},{key:"initSegment",value:function(i){e.types||e.init();var t,r=e.moov(i);return t=new Uint8Array(e.FTYP.byteLength+r.byteLength),t.set(e.FTYP),t.set(r,e.FTYP.byteLength),t}}]),e}();e.default=i},{}],32:[function(i,h,a){"use strict";function n(e){return e&&e.__esModule?e:{default:e}}function o(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(a,"__esModule",{value:!0});var l=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),f=i("../events"),t=n(f),e=i("../utils/logger"),u=i("../remux/mp4-generator"),r=n(u),s=i("../errors"),d=function(){function i(e){o(this,i),this.observer=e,this.ISGenerated=!1,this.PES2MP4SCALEFACTOR=4,this.PES_TIMESCALE=9e4,this.MP4_TIMESCALE=this.PES_TIMESCALE/this.PES2MP4SCALEFACTOR}return l(i,[{key:"destroy",value:function(){}},{key:"insertDiscontinuity",value:function(){this._initPTS=this._initDTS=void 0}},{key:"switchLevel",value:function(){this.ISGenerated=!1}},{key:"remux",value:function(r,i,a,n,e,s){this.ISGenerated||this.generateIS(r,i,e),this.ISGenerated&&(i.samples.length&&this.remuxVideo(i,e,s),r.samples.length&&this.remuxAudio(r,e,s)),a.samples.length&&this.remuxID3(a,e),n.samples.length&&this.remuxText(n,e),this.observer.trigger(t.default.FRAG_PARSED)}},{key:"generateIS",value:function(i,a,h){var n,o,c=this.observer,v=i.samples,d=a.samples,f=this.PES_TIMESCALE,l={},g={tracks:l,unique:!1},u=void 0===this._initPTS;u&&(n=o=1/0),i.config&&v.length&&(i.timescale=i.audiosamplerate,i.timescale*i.duration>Math.pow(2,32)&&!function(){var e=function r(t,e){return e?r(e,t%e):t};i.timescale=i.audiosamplerate/e(i.audiosamplerate,1024)}(),e.logger.log("audio mp4 timescale :"+i.timescale),l.audio={container:"audio/mp4",codec:i.codec,initSegment:r.default.initSegment([i]),metadata:{channelCount:i.channelCount}},u&&(n=o=v[0].pts-f*h)),a.sps&&a.pps&&d.length&&(a.timescale=this.MP4_TIMESCALE,l.video={container:"video/mp4",codec:a.codec,initSegment:r.default.initSegment([a]),metadata:{width:a.width,height:a.height}},u&&(n=Math.min(n,d[0].pts-f*h),o=Math.min(o,d[0].dts-f*h))),Object.keys(l).length?(c.trigger(t.default.FRAG_PARSING_INIT_SEGMENT,g),this.ISGenerated=!0,u&&(this._initPTS=n,this._initDTS=o)):c.trigger(t.default.ERROR,{type:s.ErrorTypes.MEDIA_ERROR,details:s.ErrorDetails.FRAG_PARSING_ERROR,fatal:!1,reason:"no audio/video samples found"})}},{key:"remuxVideo",value:function(a,w,S){var L,s,p,A,f,d,T,k,R,v,_,g,o,i,n,E=8,c=this.PES_TIMESCALE,h=this.PES2MP4SCALEFACTOR,u=[];for(d=new Uint8Array(a.len+4*a.nbNalu+8),L=new DataView(d.buffer),L.setUint32(0,d.byteLength),d.set(r.default.types.mdat,4);a.samples.length;){for(s=a.samples.shift(),A=0;s.units.units.length;)f=s.units.units.shift(),L.setUint32(E,f.data.byteLength),E+=4,d.set(f.data,E),E+=f.data.byteLength,A+=4+f.data.byteLength;if(_=s.pts-this._initDTS,g=s.dts-this._initDTS,g=Math.min(_,g),void 0!==v){o=this._PTSNormalize(_,v),i=this._PTSNormalize(g,v);var m=(i-v)/h;0>=m&&(e.logger.log("invalid sample duration at PTS/DTS: "+s.pts+"/"+s.dts+":"+m),m=1),p.duration=m}else{var y=void 0,l=void 0;y=S?this.nextAvcDts:w*c,o=this._PTSNormalize(_,y),i=this._PTSNormalize(g,y),l=Math.round((i-y)/90),S&&l&&(l>1?e.logger.log("AVC:"+l+" ms hole between fragments detected,filling it"):-1>l&&e.logger.log("AVC:"+-l+" ms overlapping between fragments detected"),i=y,o=Math.max(o-l,i),e.logger.log("Video/PTS/DTS adjusted: "+o+"/"+i+",delta:"+l)),k=Math.max(0,o),R=Math.max(0,i)}p={size:A,duration:0,cts:(o-i)/h,flags:{isLeading:0,isDependedOn:0,hasRedundancy:0,degradPrio:0}},n=p.flags,s.key===!0?(n.dependsOn=2,n.isNonSync=0):(n.dependsOn=1,n.isNonSync=1),u.push(p),v=i}var b=0;u.length>=2&&(b=u[u.length-2].duration,p.duration=b),this.nextAvcDts=i+b*h,a.len=0,a.nbNalu=0,u.length&&navigator.userAgent.toLowerCase().indexOf("chrome")>-1&&(n=u[0].flags,n.dependsOn=2,n.isNonSync=0),a.samples=u,T=r.default.moof(a.sequenceNumber++,R/h,a),a.samples=[],this.observer.trigger(t.default.FRAG_PARSING_DATA,{data1:T,data2:d,startPTS:k/c,endPTS:(o+h*b)/c,startDTS:R/c,endDTS:this.nextAvcDts/c,type:"video",nb:u.length})}},{key:"remuxAudio",value:function(i,D,S){var T,p,n,h,d,k,L,b,u,g,R,o,a,A=8,s=this.PES_TIMESCALE,w=i.timescale,f=s/w,E=1024*i.timescale/i.audiosamplerate,m=[],_=[];for(i.samples.sort(function(e,t){return e.pts-t.pts}),_=i.samples;_.length;){if(p=_.shift(),h=p.unit,g=p.pts-this._initDTS,R=p.dts-this._initDTS,void 0!==u)o=this._PTSNormalize(g,u),a=this._PTSNormalize(R,u),n.duration=(a-u)/f,Math.abs(n.duration-E)>E/10&&e.logger.log("invalid AAC sample duration at PTS "+Math.round(g/90)+",should be 1024,found :"+Math.round(n.duration*i.audiosamplerate/i.timescale)),n.duration=E,o=a=E*f+u;else{var c=void 0,l=void 0;if(c=S?this.nextAacPts:D*s,o=this._PTSNormalize(g,c),a=this._PTSNormalize(R,c),l=Math.round(1e3*(o-c)/s),S&&l){if(l>0)e.logger.log(l+" ms hole between AAC samples detected,filling it");else if(-12>l){e.logger.log(-l+" ms overlapping between AAC samples detected, drop frame"),i.len-=h.byteLength;continue}o=a=c}if(L=Math.max(0,o),b=Math.max(0,a),!(i.len>0))return;d=new Uint8Array(i.len+8),T=new DataView(d.buffer),T.setUint32(0,d.byteLength),d.set(r.default.types.mdat,4)}d.set(h,A),A+=h.byteLength,n={size:h.byteLength,cts:0,duration:0,flags:{isLeading:0,isDependedOn:0,hasRedundancy:0,degradPrio:0,dependsOn:1}},m.push(n),u=a}var y=0,v=m.length;v>=2&&(y=m[v-2].duration,n.duration=y),v&&(this.nextAacPts=o+f*y,i.len=0,i.samples=m,k=r.default.moof(i.sequenceNumber++,b/f,i),i.samples=[],this.observer.trigger(t.default.FRAG_PARSING_DATA,{data1:k,data2:d,startPTS:L/s,endPTS:this.nextAacPts/s,startDTS:b/s,endDTS:(a+f*y)/s,type:"audio",nb:v}))}},{key:"remuxID3",value:function(r,a){var e,n=r.samples.length;if(n){for(var i=0;n>i;i++)e=r.samples[i],e.pts=(e.pts-this._initPTS)/this.PES_TIMESCALE,e.dts=(e.dts-this._initDTS)/this.PES_TIMESCALE;this.observer.trigger(t.default.FRAG_PARSING_METADATA,{samples:r.samples})}r.samples=[],a=a}},{key:"remuxText",value:function(e,a){e.samples.sort(function(e,t){return e.pts-t.pts});var r,n=e.samples.length;if(n){for(var i=0;n>i;i++)r=e.samples[i],r.pts=(r.pts-this._initPTS)/this.PES_TIMESCALE;this.observer.trigger(t.default.FRAG_PARSING_USERDATA,{samples:e.samples})}e.samples=[],a=a}},{key:"_PTSNormalize",value:function(e,t){var r;if(void 0===t)return e;for(r=e>t?-8589934592:8589934592;Math.abs(e-t)>4294967296;)e+=r;return e}},{key:"passthrough",get:function(){return!1}}]),i}();a.default=d},{"../errors":21,"../events":23,"../remux/mp4-generator":31,"../utils/logger":38}],33:[function(r,l,e){"use strict";function i(e){return e&&e.__esModule?e:{default:e}}function a(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(e,"__esModule",{value:!0});var n=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),s=r("../events"),t=i(s),o=function(){function e(t){a(this,e),this.observer=t,this.ISGenerated=!1}return n(e,[{key:"destroy",value:function(){}},{key:"insertDiscontinuity",value:function(){}},{key:"switchLevel",value:function(){this.ISGenerated=!1}},{key:"remux",value:function(o,s,f,d,a,u){var n=this.observer;if(!this.ISGenerated){var l={},i={tracks:l,unique:!0},e=s,r=e.codec;r&&(i.tracks.video={container:e.container,codec:r,metadata:{width:e.width,height:e.height}}),e=o,r=e.codec,r&&(i.tracks.audio={container:e.container,codec:r,metadata:{channelCount:e.channelCount}}),this.ISGenerated=!0,n.trigger(t.default.FRAG_PARSING_INIT_SEGMENT,i)}n.trigger(t.default.FRAG_PARSING_DATA,{data1:u,startPTS:a,startDTS:a,type:"audiovideo",nb:1})}},{key:"passthrough",get:function(){return!0}}]),e}();e.default=o},{"../events":23}],34:[function(a,n,e){"use strict";function t(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(e,"__esModule",{value:!0});var r=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),i=function(){function e(r){t(this,e),"string"==typeof r&&(r=e.parseAttrList(r));for(var i in r)r.hasOwnProperty(i)&&(this[i]=r[i])}return r(e,[{key:"decimalInteger",value:function(t){var e=parseInt(this[t],10);return e>Number.MAX_SAFE_INTEGER?1/0:e}},{key:"hexadecimalInteger",value:function(r){if(this[r]){var e=(this[r]||"0x").slice(2);e=(1&e.length?"0":"")+e;for(var i=new Uint8Array(e.length/2),t=0;t<e.length/2;t++)i[t]=parseInt(e.slice(2*t,2*t+2),16);return i}return null}},{key:"hexadecimalIntegerAsNumber",value:function(t){var e=parseInt(this[t],16);return e>Number.MAX_SAFE_INTEGER?1/0:e}},{key:"decimalFloatingPoint",value:function(e){return parseFloat(this[e])}},{key:"enumeratedString",value:function(e){return this[e]}},{key:"decimalResolution",value:function(t){var e=/^(\d+)x(\d+)$/.exec(this[t]);if(null!==e)return{width:parseInt(e[1],10),height:parseInt(e[2],10)}}}],[{key:"parseAttrList",value:function(a){for(var t,n=/\s*(.+?)\s*=((?:\".*?\")|.*?)(?:,|$)/g,r={};null!==(t=n.exec(a));){var e=t[2],i='"';0===e.indexOf(i)&&e.lastIndexOf(i)===e.length-1&&(e=e.slice(1,-1)),r[t[1]]=e}return r}}]),e}();e.default=i},{}],35:[function(r,e,i){"use strict";var t={search:function(a,s){for(var t=0,r=a.length-1,e=null,i=null;r>=t;){e=(t+r)/2|0,i=a[e];var n=s(i);if(n>0)t=e+1;else{if(!(0>n))return i;r=e-1}}return null}};e.exports=t},{}],36:[function(a,n,e){"use strict";function t(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(e,"__esModule",{value:!0});var r=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),i=function(){function e(){t(this,e)}return r(e,[{key:"attach",value:function(e){this.media=e,this.display=[],this.memory=[]}},{key:"detach",value:function(){this.clear()}},{key:"destroy",value:function(){}},{key:"_createCue",value:function(){var t=window.VTTCue||window.TextTrackCue,e=this.cue=new t(-1,-1,"");e.text="",e.pauseOnExit=!1,e.startTime=Number.MAX_VALUE,e.endTime=Number.MAX_VALUE,this.memory.push(e)}},{key:"clear",value:function(){var e=this._textTrack;if(e&&e.cues)for(;e.cues.length>0;)e.removeCue(e.cues[0])}},{key:"push",value:function(r,i){this.cue||this._createCue();for(var a,t,e,s,o,u=31&i[0],n=2,l=0;u>l;l++)if(a=i[n++],t=127&i[n++],e=127&i[n++],s=0!==(4&a),o=3&a,(0!==t||0!==e)&&s&&0===o){if(32&t||64&t)this.cue.text+=this._fromCharCode(t)+this._fromCharCode(e);else if((17===t||25===t)&&e>=48&&63>=e)switch(e){case 48:this.cue.text+="®";break;case 49:this.cue.text+="°";break;case 50:this.cue.text+="½";break;case 51:this.cue.text+="¿";break;case 52:this.cue.text+="™";break;case 53:this.cue.text+="¢";break;case 54:this.cue.text+="";break;case 55:this.cue.text+="£";break;case 56:this.cue.text+="♪";break;case 57:this.cue.text+=" ";break;case 58:this.cue.text+="è";break;case 59:this.cue.text+="â";break;case 60:this.cue.text+="ê";break;case 61:this.cue.text+="î";break;case 62:this.cue.text+="ô";break;case 63:this.cue.text+="û"}if((17===t||25===t)&&e>=32&&47>=e)switch(e){case 32:break;case 33:break;case 34:break;case 35:break;case 36:break;case 37:break;case 38:break;case 39:break;case 40:break;case 41:break;case 42:break;case 43:break;case 44:break;case 45:break;case 46:break;case 47:}if((20===t||28===t)&&e>=32&&47>=e)switch(e){case 32:this._clearActiveCues(r);break;case 33:this.cue.text=this.cue.text.substr(0,this.cue.text.length-1);break;case 34:break;case 35:break;case 36:break;case 37:break;case 38:break;case 39:break;case 40:break;case 41:this._clearActiveCues(r);break;case 42:break;case 43:break;case 44:this._clearActiveCues(r);break;case 45:break;case 46:this._text="";break;case 47:this._flipMemory(r)}if((23===t||31===t)&&e>=33&&35>=e)switch(e){case 33:break;case 34:break;case 35:}}}},{key:"_fromCharCode",value:function(e){switch(e){case 42:return"á";case 2:return"á";case 2:return"é";case 4:return"í";case 5:return"ó";case 6:return"ú";case 3:return"ç";case 4:return"÷";case 5:return"Ñ";case 6:return"ñ";case 7:return"█";default:return String.fromCharCode(e)}}},{key:"_flipMemory",value:function(e){this._clearActiveCues(e),this._flushCaptions(e)}},{key:"_flushCaptions",value:function(s){this._has708||(this._textTrack=this.media.addTextTrack("captions","English","en"),this._has708=!0);var e=!0,i=!1,a=void 0;try{for(var n,t=this.memory[Symbol.iterator]();!(e=(n=t.next()).done);e=!0){var r=n.value;r.startTime=s,this._textTrack.addCue(r),this.display.push(r)}}catch(e){i=!0,a=e}finally{try{!e&&t.return&&t.return()}finally{if(i)throw a}}this.memory=[],this.cue=null}},{key:"_clearActiveCues",value:function(n){var e=!0,r=!1,i=void 0;try{for(var a,t=this.display[Symbol.iterator]();!(e=(a=t.next()).done);e=!0){var s=a.value;s.endTime=n}}catch(e){r=!0,i=e}finally{try{!e&&t.return&&t.return()}finally{if(r)throw i}}this.display=[]}},{key:"_clearBufferedCues",value:function(){}}]),e}();e.default=i},{}],37:[function(a,n,e){"use strict";function t(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(e,"__esModule",{value:!0});var r=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),i=function(){function e(r){t(this,e),this.alpha_=r?Math.exp(Math.log(.5)/r):0,this.estimate_=0,this.totalWeight_=0}return r(e,[{key:"sample",value:function(e,r){var t=Math.pow(this.alpha_,e);this.estimate_=r*(1-t)+t*this.estimate_,this.totalWeight_+=e}},{key:"getTotalWeight",value:function(){return this.totalWeight_}},{key:"getEstimate",value:function(){if(this.alpha_){var e=1-Math.pow(this.alpha_,this.totalWeight_);return this.estimate_/e}return this.estimate_}}]),e}();e.default=i},{}],38:[function(l,u,r){"use strict";function e(){}function a(t,e){return e="["+t+"] > "+e}function n(t){var r=window.console[t];return r?function(){for(var n=arguments.length,e=Array(n),i=0;n>i;i++)e[i]=arguments[i];e[0]&&(e[0]=a(t,e[0])),r.apply(window.console,e)}:e}function s(r){for(var i=arguments.length,a=Array(i>1?i-1:0),e=1;i>e;e++)a[e-1]=arguments[e];a.forEach(function(e){t[e]=r[e]?r[e].bind(r):n(e)})}Object.defineProperty(r,"__esModule",{value:!0});var o="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol?"symbol":typeof e},i={trace:e,debug:e,log:e,warn:e,info:e,error:e},t=i;r.enableLogs=function(e){if(e===!0||"object"===("undefined"==typeof e?"undefined":o(e))){s(e,"debug","log","info","warn","error");try{t.log()}catch(e){t=i}}else t=i},r.logger=t},{}],39:[function(r,t,i){"use strict";var e={buildAbsoluteURL:function(r,t){if(t=t.trim(),/^[a-z]+:/i.test(t))return t;var l=null,o=null,n=/^([^#]*)(.*)$/.exec(t);n&&(o=n[2],t=n[1]);var s=/^([^\?]*)(.*)$/.exec(t);s&&(l=s[2],t=s[1]);var f=/^([^#]*)(.*)$/.exec(r);f&&(r=f[1]);var u=/^([^\?]*)(.*)$/.exec(r);u&&(r=u[1]);var i=/^(([a-z]+:)?\/\/[a-z0-9\.\-_~]+(:[0-9]+)?)?(\/.*)$/i.exec(r);if(!i)throw new Error("Error trying to parse base URL.");var h=i[2]||"",d=i[1]||"",c=i[4],a=null;return a=/^\/\//.test(t)?h+"//"+e.buildAbsolutePath("",t.substring(2)):/^\//.test(t)?d+"/"+e.buildAbsolutePath("",t.substring(1)):e.buildAbsolutePath(d+c,t),l&&(a+=l),o&&(a+=o),a},buildAbsolutePath:function(n,s){for(var i,e,o=s,a="",t=n.replace(/[^\/]*$/,o.replace(/(\/|^)(?:\.?\/+)+/g,"$1")),r=0;e=t.indexOf("/../",r),e>-1;r=e+i)i=/^\/(?:\.\.\/)*/.exec(t.slice(e))[0].length,a=(a+t.substring(r,e)).replace(new RegExp("(?:\\/+[^\\/]*){0,"+(i-1)/3+"}$"),"/");return a+t.substr(r)}};t.exports=e},{}],40:[function(r,s,t){"use strict";function i(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}Object.defineProperty(t,"__esModule",{value:!0});var a=function(){function e(i,r){for(var t=0;t<r.length;t++){var e=r[t];e.enumerable=e.enumerable||!1,e.configurable=!0,"value"in e&&(e.writable=!0),Object.defineProperty(i,e.key,e)}}return function(t,r,i){return r&&e(t.prototype,r),i&&e(t,i),t}}(),e=r("../utils/logger"),n=function(){function t(e){i(this,t),e&&e.xhrSetup&&(this.xhrSetup=e.xhrSetup)}return a(t,[{key:"destroy",value:function(){this.abort(),this.loader=null}},{key:"abort",value:function(){var e=this.loader,t=this.timeoutHandle;e&&4!==e.readyState&&(this.stats.aborted=!0,e.abort()),t&&window.clearTimeout(t)}},{key:"load",value:function(t,r,i,a,n,s,o,l){
var u=arguments.length<=8||void 0===arguments[8]?null:arguments[8],e=arguments.length<=9||void 0===arguments[9]?null:arguments[9];this.url=t,!e||isNaN(e.byteRangeStartOffset)||isNaN(e.byteRangeEndOffset)||(this.byteRange=e.byteRangeStartOffset+"-"+(e.byteRangeEndOffset-1)),this.responseType=r,this.onSuccess=i,this.onProgress=u,this.onTimeout=n,this.onError=a,this.stats={trequest:performance.now(),retry:0},this.timeout=s,this.maxRetry=o,this.retryDelay=l,this.loadInternal()}},{key:"loadInternal",value:function(){var e;e="undefined"!=typeof XDomainRequest?this.loader=new XDomainRequest:this.loader=new XMLHttpRequest,e.onloadend=this.loadend.bind(this),e.onprogress=this.loadprogress.bind(this),e.open("GET",this.url,!0),this.byteRange&&e.setRequestHeader("Range","bytes="+this.byteRange),e.responseType=this.responseType,this.stats.tfirst=null,this.stats.loaded=0,this.xhrSetup&&this.xhrSetup(e,this.url),this.timeoutHandle=window.setTimeout(this.loadtimeout.bind(this),this.timeout),e.send()}},{key:"loadend",value:function(i){var a=i.currentTarget,r=a.status,t=this.stats;t.aborted||(r>=200&&300>r?(window.clearTimeout(this.timeoutHandle),t.tload=performance.now(),this.onSuccess(i,t)):t.retry<this.maxRetry?(e.logger.warn(r+" while loading "+this.url+", retrying in "+this.retryDelay+"..."),this.destroy(),window.setTimeout(this.loadInternal.bind(this),this.retryDelay),this.retryDelay=Math.min(2*this.retryDelay,64e3),t.retry++):(window.clearTimeout(this.timeoutHandle),e.logger.error(r+" while loading "+this.url),this.onError(i)))}},{key:"loadtimeout",value:function(t){e.logger.warn("timeout while loading "+this.url),this.onTimeout(t,this.stats)}},{key:"loadprogress",value:function(t){var e=this.stats;null===e.tfirst&&(e.tfirst=performance.now()),e.loaded=t.loaded,this.onProgress&&this.onProgress(t,e)}}]),t}();t.default=n},{"../utils/logger":38}]},{},[27])(27)});
